(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   3249315,      89913]
NotebookOptionsPosition[   3050130,      87520]
NotebookOutlinePosition[   3050469,      87535]
CellTagsIndexPosition[   3050426,      87532]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This Notebook contains the proofs of some of the results in  the paper
\"Relationships between a Central Quadrilateral and its Reference \
Quadrilateral\"
by Stanley Rabinowitz and Ercole Suppa,
submitted to the International Journal of Computer Discovered Mathematics 
(http : // www.journal - 1. eu/) in May 2022.
 
This Notebook is Copyright \[Copyright] May 2022 by Stanley Rabinowitz \
(stan.rabinowitz@comcast.net) and is published with open access. This \
Notebook is distributed under the terms of the Creative Commons Attribution \
License which permits any use, distribution, and reproduction in any medium, \
provided the original author and the source are credited.

The file GeoxCenters.m must reside in the same directory as this notebook.\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.8517106718981447`*^9, 3.851710701258429*^9}, {
   3.851711035640792*^9, 3.851711101569191*^9}, 3.8517113718428907`*^9, 
   3.857582052616704*^9, {3.857582090190035*^9, 3.857582135392453*^9}, {
   3.857582371185758*^9, 3.857582392353647*^9}, {3.8610823148482943`*^9, 
   3.8610823338414307`*^9}},ExpressionUUID->"d08986c7-ef4f-4445-8a81-\
a177c140a9e8"],

Cell[CellGroupData[{

Cell["Set Up", "Section",
 CellChangeTimes->{{3.858790576808064*^9, 
  3.858790582733438*^9}},ExpressionUUID->"89212534-7237-4eed-b992-\
f4fefc071f04"],

Cell[BoxData[
 RowBox[{"Get", "[", 
  RowBox[{
   RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<GeoxCenters.m\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8575821470498457`*^9, 3.857582155304802*^9}, {
  3.857582233458603*^9, 3.8575822336486893`*^9}, {3.857582304313387*^9, 
  3.857582311272935*^9}, {3.857582350681676*^9, 3.857582360353598*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"7c63bfc2-58ce-4821-8658-b86ccade219d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"normed", "[", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"squaredDistance", "[", 
    RowBox[{"p1_", ",", "p2_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Expand", "[", 
          RowBox[{"Total", "[", "p2", "]"}], "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{"Return", "[", "Infinity", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], "=", 
       RowBox[{
        RowBox[{"normed", "[", "p1", "]"}], "-", 
        RowBox[{"normed", "[", "p2", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "^", "2"}]}], "*", "y", "*", "z"}], "-", 
        RowBox[{
         RowBox[{"b", "^", "2"}], "*", "z", "*", "x"}], "-", 
        RowBox[{
         RowBox[{"c", "^", "2"}], "*", "x", "*", "y"}]}], "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dist", "[", 
    RowBox[{"P_", ",", "Q_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Sqrt", "[", 
      RowBox[{"squaredDistance", "[", 
       RowBox[{"P", ",", "Q"}], "]"}], "]"}], "//", "Simplify"}], "//", 
    "PowerExpand"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"p1_", ",", "p2_", ",", "p3_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Det", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"normed", "[", "p1", "]"}], ",", 
       RowBox[{"normed", "[", "p2", "]"}], ",", 
       RowBox[{"normed", "[", "p3", "]"}]}], "}"}], "]"}], "K"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{
  3.857587210978294*^9, {3.857829439574634*^9, 3.857829493669174*^9}, {
   3.85782974708759*^9, 3.857829749542029*^9}, {3.858054883464953*^9, 
   3.8580548913999*^9}, {3.858238372066176*^9, 3.8582383734407187`*^9}, {
   3.859887583762052*^9, 3.859887586169178*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"0863b046-8b0f-4b7d-9bfd-c8c5ca9bd6b2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Quadrilaterals classes", "Section",
 CellChangeTimes->{{3.8149372947743545`*^9, 3.81493730456911*^9}, {
   3.8150766619788237`*^9, 3.815076687722373*^9}, {3.815307218478911*^9, 
   3.81530722210299*^9}, 3.815307770176461*^9, {3.815830618003149*^9, 
   3.81583062373456*^9}, {3.8492735680842953`*^9, 3.849273590155794*^9}, {
   3.85688823644116*^9, 3.856888237608892*^9}, 
   3.861082538322009*^9},ExpressionUUID->"7932e666-d308-4af3-820e-\
66659bf35ae8"],

Cell[TextData[StyleBox["X -> Y means that Y is a special type of X, i.e. X \
specializes to Y",
 FontSize->24]], "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.814933108126809*^9, 3.81493323211734*^9}, {
  3.8149338547094793`*^9, 3.8149339178193626`*^9}, {3.815830684213579*^9, 
  3.815830701911251*^9}, {3.815830759045865*^9, 3.8158308083977613`*^9}, {
  3.8158308579099913`*^9, 
  3.8158308650778646`*^9}},ExpressionUUID->"f5a7ec9c-ccac-4438-8f9e-\
acbe28753294"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"quadrilaterals", "=", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"\"\<APquad\>\"", "\[DirectedEdge]", "\"\<rhombus\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<bicentric\>\"", "\[Rule]", "\"\<bicentricTrap\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<bicentricTrap\>\"", "\[Rule]", "\"\<square\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<convex\>\"", "\[DirectedEdge]", "\"\<trapezoid\>\""}], ",", 
      RowBox[{"\"\<convex\>\"", "\[DirectedEdge]", "\"\<cyclic\>\""}], ",", 
      RowBox[{"\"\<convex\>\"", "\[DirectedEdge]", "\"\<tangential\>\""}], 
      ",", 
      RowBox[{"\"\<convex\>\"", "\[DirectedEdge]", "\"\<orthodiagonal\>\""}], 
      ",", 
      RowBox[{"\"\<convex\>\"", "\[DirectedEdge]", "\"\<equidiagonal\>\""}], 
      ",", 
      RowBox[{"\"\<convex\>\"", "\[DirectedEdge]", "\"\<equalProdOpp\>\""}], 
      ",", 
      RowBox[{"\"\<convex\>\"", "\[DirectedEdge]", "\"\<exTangential\>\""}], 
      ",", 
      RowBox[{"\"\<convex\>\"", "\[DirectedEdge]", "\"\<equalProdAdj\>\""}], 
      ",", 
      RowBox[{"\"\<convex\>\"", "\[DirectedEdge]", "\"\<Pythagorean\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<cyclic\>\"", "\[DirectedEdge]", "\"\<harmonic\>\""}], ",", 
      
      RowBox[{"\"\<cyclic\>\"", "\[DirectedEdge]", "\"\<Hjelmslev\>\""}], ",", 
      RowBox[{"\"\<cyclic\>\"", "\[DirectedEdge]", "\"\<bicentric\>\""}], ",", 
      RowBox[{"\"\<cyclic\>\"", "\[DirectedEdge]", "\"\<isoTrap\>\""}], ",", 
      RowBox[{"\"\<cyclic\>\"", "\[DirectedEdge]", "\"\<cyclicOrtho\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<cyclic\>\"", "\[DirectedEdge]", "\"\<exBicentric\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<cyclicOrtho\>\"", "\[DirectedEdge]", "\"\<square\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<equalProdAdj\>\"", "\[DirectedEdge]", "\"\<kite\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<equalProdOpp\>\"", "\[DirectedEdge]", "\"\<harmonic\>\""}],
       ",", 
      RowBox[{"\"\<equalProdOpp\>\"", "\[DirectedEdge]", "\"\<kite\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{
      "\"\<equidiagonal\>\"", "\[DirectedEdge]", "\"\<equiOrthoQuad\>\""}], 
      ",", 
      RowBox[{"\"\<equidiagonal\>\"", "\[DirectedEdge]", "\"\<isoTrap\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<equiOrthoQuad\>\"", "\[Rule]", "\"\<equiOrthoKite\>\""}], 
      ",", 
      RowBox[{"\"\<equiOrthoQuad\>\"", "\[Rule]", "\"\<equiOrthoTrap\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<equiOrthoKite\>\"", "\[Rule]", "\"\<square\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<equiOrthoTrap\>\"", "\[Rule]", "\"\<square\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<exBicentric\>\"", "\[DirectedEdge]", "\"\<square\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<exTangential\>\"", "\[DirectedEdge]", "\"\<kite\>\""}], 
      ",", 
      RowBox[{
      "\"\<exTangential\>\"", "\[DirectedEdge]", "\"\<exBicentric\>\""}], ",", 
      RowBox[{
      "\"\<exTangential\>\"", "\[DirectedEdge]", "\"\<parallelogram\>\""}], 
      ",", 
      RowBox[{"\"\<exTangential\>\"", "\[DirectedEdge]", "\"\<APquad\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<harmonic\>\"", "\[DirectedEdge]", "\"\<rectangle\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<Hjelmslev\>\"", "\[Rule]", " ", "\"\<rectangle\>\""}], ",",
       "\[IndentingNewLine]", 
      RowBox[{"\"\<isoTrap\>\"", "\[Rule]", "\"\<bicentricTrap\>\""}], ",", 
      RowBox[{"\"\<isoTrap\>\"", "\[Rule]", "\"\<equiOrthoTrap\>\""}], ",", 
      RowBox[{"\"\<isoTrap\>\"", "\[Rule]", "\"\<rectangle\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<kite\>\"", "\[Rule]", "\"\<rhombus\>\""}], ",", 
      RowBox[{"\"\<kite\>\"", "\[Rule]", "\"\<equiOrthoKite\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<orthoTrap\>\"", "\[Rule]", "\"\<equiOrthoTrap\>\""}], ",", 
      
      RowBox[{"\"\<orthoTrap\>\"", "\[Rule]", "\"\<rhombus\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
      "\"\<orthodiagonal\>\"", "\[DirectedEdge]", "\"\<equiOrthoQuad\>\""}], 
      ",", 
      RowBox[{
      "\"\<orthodiagonal\>\"", "\[DirectedEdge]", "\"\<orthoTrap\>\""}], ",", 
      
      RowBox[{
      "\"\<orthodiagonal\>\"", "\[DirectedEdge]", "\"\<cyclicOrtho\>\""}], 
      ",", 
      RowBox[{"\"\<orthodiagonal\>\"", "\[DirectedEdge]", "\"\<kite\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<parallelogram\>\"", "\[Rule]", "\"\<rhombus\>\""}], ",", 
      RowBox[{"\"\<parallelogram\>\"", "\[Rule]", "\"\<rectangle\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<Pythagorean\>\"", "\[DirectedEdge]", "\"\<Hjelmslev\>\""}],
       ",", " ", 
      RowBox[{"\"\<Pythagorean\>\"", "\[DirectedEdge]", "\"\<kite\>\""}], ",", 
      RowBox[{
      "\"\<Pythagorean\>\"", "\[DirectedEdge]", "\"\<parallelogram\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<rectangle\>\"", "\[Rule]", "\"\<square\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<rhombus\>\"", "\[Rule]", "\"\<square\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<tangential\>\"", "\[DirectedEdge]", "\"\<tangTrap\>\""}], 
      ",", 
      RowBox[{"\"\<tangential\>\"", "\[DirectedEdge]", "\"\<kite\>\""}], ",", 
      
      RowBox[{"\"\<tangential\>\"", "\[DirectedEdge]", "\"\<bicentric\>\""}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\"\<tangTrap\>\"", "\[Rule]", "\"\<rhombus\>\""}], ",", 
      RowBox[{"\"\<tangTrap\>\"", "\[Rule]", "\"\<bicentricTrap\>\""}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\"\<trapezoid\>\"", "\[DirectedEdge]", "\"\<tangTrap\>\""}], 
      ",", 
      RowBox[{
      "\"\<trapezoid\>\"", "\[DirectedEdge]", "\"\<parallelogram\>\""}], ",", 
      
      RowBox[{"\"\<trapezoid\>\"", "\[DirectedEdge]", "\"\<isoTrap\>\""}], 
      ",", 
      RowBox[{"\"\<trapezoid\>\"", "\[DirectedEdge]", "\"\<orthoTrap\>\""}]}],
      "\[IndentingNewLine]", "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"qGraph", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{"quadrilaterals", ",", " ", 
    RowBox[{"VertexShapeFunction", "\[Rule]", "\"\<Square\>\""}], ",", 
    RowBox[{"VertexSize", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{".5", ",", ".2"}], "}"}]}], ",", " ", 
    RowBox[{"VertexLabels", "\[Rule]", 
     RowBox[{"Placed", "[", 
      RowBox[{"\"\<Name\>\"", ",", "Center"}], "]"}]}], ",", 
    RowBox[{"VertexStyle", "\[Rule]", 
     RowBox[{"Hue", "[", 
      RowBox[{"0.125", ",", "0.7", ",", "0.9"}], "]"}]}], ",", 
    RowBox[{"VertexLabelStyle", "\[Rule]", 
     RowBox[{"Directive", "[", 
      RowBox[{
       RowBox[{"FontFamily", "->", "\"\<TimesNewRoman\>\""}], ",", " ", 
       "10"}], "]"}]}], ",", 
    RowBox[{"ImageSize", "\[Rule]", "1000"}], ",", " ", 
    RowBox[{"EdgeShapeFunction", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Arrowheads", "[", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{".01", ",", ".4"}], "}"}], "}"}], "]"}], ",", 
         RowBox[{"Arrow", "[", "#", "]"}]}], "}"}], "&"}], ")"}]}]}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.814933240241745*^9, 3.8149332467192683`*^9}, {
   3.8149332811263742`*^9, 3.814933291079313*^9}, {3.81493342381786*^9, 
   3.814933487046664*^9}, {3.814933521953658*^9, 3.8149335414266453`*^9}, {
   3.814933737524289*^9, 3.814933781209375*^9}, {3.8149339190536814`*^9, 
   3.814933970822487*^9}, {3.814934020888803*^9, 3.8149340244507017`*^9}, {
   3.814934057114873*^9, 3.8149340745324073`*^9}, {3.8149341080403643`*^9, 
   3.8149341353618126`*^9}, {3.814934183538186*^9, 3.81493420048708*^9}, {
   3.814934230745803*^9, 3.8149342902630177`*^9}, {3.814935473967944*^9, 
   3.814935550699851*^9}, {3.8149356179186068`*^9, 3.8149357450761223`*^9}, {
   3.814935775287527*^9, 3.8149361367820854`*^9}, {3.8149367603806567`*^9, 
   3.814936802057534*^9}, {3.814937009684128*^9, 3.8149370336452937`*^9}, {
   3.814937100868298*^9, 3.8149371126231976`*^9}, {3.8149371537235694`*^9, 
   3.814937168816131*^9}, {3.8149372168334346`*^9, 3.814937216866169*^9}, {
   3.814937362527124*^9, 3.8149373698707466`*^9}, {3.814937609979744*^9, 
   3.81493761885634*^9}, {3.814937765970805*^9, 3.8149377791690445`*^9}, {
   3.8149380423711815`*^9, 3.8149380683397818`*^9}, {3.8149382724585395`*^9, 
   3.8149382958888617`*^9}, {3.8149383574425783`*^9, 
   3.8149383678888235`*^9}, {3.8149384639306927`*^9, 3.814938476027583*^9}, {
   3.814938610480615*^9, 3.8149386184243546`*^9}, {3.8149388822698326`*^9, 
   3.8149388957183723`*^9}, {3.8149389493951855`*^9, 3.814938995346192*^9}, {
   3.81493913183998*^9, 3.814939159782529*^9}, {3.8149393139590836`*^9, 
   3.814939321744573*^9}, {3.81493935296774*^9, 3.814939356487717*^9}, {
   3.814939402864936*^9, 3.814939437911641*^9}, {3.8149397934261103`*^9, 
   3.814939913302286*^9}, {3.8149400948009553`*^9, 3.814940103403845*^9}, {
   3.8149402037367735`*^9, 3.814940209182803*^9}, 3.814940241293773*^9, {
   3.8149404453765316`*^9, 3.814940451878065*^9}, {3.814940565248521*^9, 
   3.814940571352062*^9}, {3.8149406410165005`*^9, 3.8149406551020346`*^9}, {
   3.8149407501524005`*^9, 3.8149407794781637`*^9}, {3.814940840856262*^9, 
   3.814940890877486*^9}, {3.81494101644554*^9, 3.8149410671857505`*^9}, {
   3.814941259470688*^9, 3.814941404924508*^9}, {3.8149415979728937`*^9, 
   3.8149416036517677`*^9}, {3.814941839096223*^9, 3.81494184753257*^9}, {
   3.814941953183123*^9, 3.8149419629508467`*^9}, {3.814952079867736*^9, 
   3.814952085491398*^9}, {3.814952153988135*^9, 3.8149521761371975`*^9}, {
   3.814952258865845*^9, 3.814952268285758*^9}, {3.8149525423236494`*^9, 
   3.814952575419134*^9}, {3.814952655651478*^9, 3.814952688214507*^9}, {
   3.814952788443186*^9, 3.8149528003011885`*^9}, {3.8149528560028467`*^9, 
   3.8149528702369604`*^9}, {3.8149529997467847`*^9, 3.814953016064758*^9}, {
   3.8149530827717094`*^9, 3.814953095758891*^9}, {3.814953337883398*^9, 
   3.814953405896021*^9}, {3.8149535331384974`*^9, 3.8149535441071076`*^9}, {
   3.8149537954190445`*^9, 3.8149538045759196`*^9}, {3.8149538402988653`*^9, 
   3.814953860231078*^9}, {3.8149543967624655`*^9, 3.8149544037540927`*^9}, {
   3.8149545316171503`*^9, 3.814954538230318*^9}, {3.814955623399245*^9, 
   3.814955627835932*^9}, {3.8149559101295033`*^9, 3.8149559362374363`*^9}, {
   3.8149560041722918`*^9, 3.814956013792997*^9}, {3.814967218666486*^9, 
   3.8149672279242263`*^9}, {3.814967330662284*^9, 3.8149673419762497`*^9}, {
   3.8149674111545415`*^9, 3.814967423894358*^9}, {3.81496746496045*^9, 
   3.814967496825802*^9}, {3.814970485977045*^9, 3.8149704974671803`*^9}, {
   3.814970527770938*^9, 3.814970549315061*^9}, {3.8149705864514112`*^9, 
   3.814970588849679*^9}, {3.814970709926813*^9, 3.814970714913628*^9}, {
   3.814970783154889*^9, 3.814970877338237*^9}, {3.81497095055576*^9, 
   3.814970964746674*^9}, {3.814971004835935*^9, 3.814971014201108*^9}, {
   3.8149761975401373`*^9, 3.814976200900532*^9}, {3.81497624305612*^9, 
   3.814976259452667*^9}, 3.814976364087845*^9, {3.815068377173395*^9, 
   3.8150684880566072`*^9}, {3.815068540580529*^9, 3.815068609233412*^9}, {
   3.815068673650549*^9, 3.815068712141062*^9}, {3.815068791268303*^9, 
   3.8150688091334963`*^9}, {3.815075960484665*^9, 3.815076026803945*^9}, {
   3.8152353733879337`*^9, 3.8152356763464622`*^9}, {3.815307168266974*^9, 
   3.8153071818813887`*^9}, {3.815307540461192*^9, 3.8153077429388933`*^9}, {
   3.815830988174406*^9, 3.815831045466968*^9}, {3.815831199761703*^9, 
   3.815831217578204*^9}, {3.815832100444838*^9, 3.815832111891919*^9}, {
   3.8158324437650347`*^9, 3.8158324509562817`*^9}, {3.815832524339994*^9, 
   3.815832572652769*^9}, {3.815832603143921*^9, 3.81583272366145*^9}, {
   3.8159270856426888`*^9, 3.815927109713147*^9}, {3.8159935017116413`*^9, 
   3.815993540765583*^9}, {3.815993589399685*^9, 3.815993606181724*^9}, {
   3.815993639951994*^9, 3.815993640596836*^9}, {3.815993813439662*^9, 
   3.815993815870315*^9}, {3.8160022756273003`*^9, 3.816002354393774*^9}, {
   3.816002416010592*^9, 3.816002418866193*^9}, 3.816002810765256*^9, {
   3.816003325567091*^9, 3.81600337395726*^9}, {3.816003457422798*^9, 
   3.816003464462126*^9}, {3.816003742864805*^9, 3.8160037470233088`*^9}, {
   3.816004504554291*^9, 3.816004507416346*^9}, {3.849273642032983*^9, 
   3.8492736606233892`*^9}, {3.849273773216798*^9, 3.849273811192919*^9}, 
   3.849273842440482*^9, {3.849273990801811*^9, 3.8492740272254953`*^9}, {
   3.849274057690053*^9, 3.8492740645138063`*^9}, 3.849274096057906*^9, {
   3.8492741645624247`*^9, 3.8492741724821577`*^9}, 3.849274300628645*^9, {
   3.84927436427573*^9, 3.849274369891342*^9}, {3.849274446308695*^9, 
   3.849274493724263*^9}, 3.849274565438623*^9, {3.849274613374476*^9, 
   3.849274670278284*^9}, {3.8493460343490334`*^9, 3.849346097332273*^9}, {
   3.849346211727066*^9, 3.849346254007297*^9}, {3.849346302928334*^9, 
   3.849346310223556*^9}, {3.849346355184963*^9, 3.849346379112021*^9}, 
   3.849346436114224*^9, {3.849346466707322*^9, 3.8493464704667273`*^9}, {
   3.8493465145548573`*^9, 3.8493465187467003`*^9}, {3.8493465702753572`*^9, 
   3.849346670573954*^9}, {3.8493467089097767`*^9, 3.8493467833098173`*^9}, {
   3.84934682248728*^9, 3.849346850880147*^9}, {3.849347188806123*^9, 
   3.849347195060052*^9}, {3.849347356294697*^9, 3.8493473922627277`*^9}, {
   3.84934745720022*^9, 3.849347468807946*^9}, {3.849347630362927*^9, 
   3.8493476333623857`*^9}, 3.849347669947912*^9, 3.849347754996591*^9, {
   3.849347792596924*^9, 3.849347794220347*^9}, 3.8493478857511377`*^9, {
   3.8493479925130243`*^9, 3.849347995727697*^9}, 3.849348028385387*^9, 
   3.849348195187696*^9, {3.8493483385882883`*^9, 3.8493483516527843`*^9}, {
   3.849348415278081*^9, 3.849348422540011*^9}, {3.8493487943070087`*^9, 
   3.849348855066429*^9}, {3.849348885595248*^9, 3.84934897998009*^9}, {
   3.849349026614011*^9, 3.849349062933237*^9}, 3.849349101375464*^9, {
   3.849353093331274*^9, 3.8493531245709047`*^9}, 3.849353309435112*^9, 
   3.8493533575008717`*^9, {3.84944035062191*^9, 3.849440351924449*^9}, {
   3.849440486015437*^9, 3.849440501141389*^9}, {3.849440891462924*^9, 
   3.8494409000283957`*^9}, {3.85012835298006*^9, 3.850128355658296*^9}, {
   3.850128427931806*^9, 3.85012848418671*^9}, {3.850128545814266*^9, 
   3.85012854639552*^9}, {3.85015068804596*^9, 3.850150690091119*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"513fce6d-e219-4b80-a7c7-f036d4f949ec"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "APquad", "rhombus", "bicentric", "bicentricTrap", "square", "convex", 
       "trapezoid", "cyclic", "tangential", "orthodiagonal", "equidiagonal", 
       "equalProdOpp", "exTangential", "equalProdAdj", "Pythagorean", 
       "harmonic", "Hjelmslev", "isoTrap", "cyclicOrtho", "exBicentric", 
       "kite", "equiOrthoQuad", "equiOrthoKite", "equiOrthoTrap", 
       "parallelogram", "rectangle", "orthoTrap", "tangTrap"}, {{{1, 2}, {3, 
       4}, {4, 5}, {6, 7}, {6, 8}, {6, 9}, {6, 10}, {6, 11}, {6, 12}, {6, 
       13}, {6, 14}, {6, 15}, {8, 16}, {8, 17}, {8, 3}, {8, 18}, {8, 19}, {8, 
       20}, {19, 5}, {14, 21}, {12, 16}, {12, 21}, {11, 22}, {11, 18}, {22, 
       23}, {22, 24}, {23, 5}, {24, 5}, {20, 5}, {13, 21}, {13, 20}, {13, 
       25}, {13, 1}, {16, 26}, {17, 26}, {18, 4}, {18, 24}, {18, 26}, {21, 
       2}, {21, 23}, {27, 24}, {27, 2}, {10, 22}, {10, 27}, {10, 19}, {10, 
       21}, {25, 2}, {25, 26}, {15, 17}, {15, 21}, {15, 25}, {26, 5}, {2, 
       5}, {9, 28}, {9, 21}, {9, 3}, {28, 2}, {28, 4}, {7, 28}, {7, 25}, {7, 
       18}, {7, 27}}, Null}, {EdgeShapeFunction -> {{
          Arrowheads[{{0.01, 0.4}}], 
          Arrow[#]}& }, ImageSize -> 1000, VertexLabels -> {
         Placed["Name", Center]}, VertexLabelStyle -> {
         Directive[FontFamily -> "TimesNewRoman", 10]}, 
       VertexShapeFunction -> {"Square"}, VertexSize -> {{0.5, 0.2}}, 
       VertexStyle -> {
         Hue[0.125, 0.7, 0.9]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{0., 2.}, {-3., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-3., 1.}, {-5., 0.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-11., 2.}, {-9., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-9., 1.}, {-5., 0.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-5., 4.}, {-7., 3.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-5., 4.}, {-6., 3.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-5., 4.}, {-10., 3.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-5., 4.}, {-5., 3.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-5., 4.}, {-8., 3.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-5., 4.}, {-4., 3.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-5., 4.}, {-1., 3.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-5., 4.}, {-2., 3.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-5., 4.}, {-3., 3.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-7., 3.}, {-9., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-7., 3.}, {-2., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-7., 3.}, {-7., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-7., 3.}, {-10., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-6., 3.}, {-11., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-6., 3.}, {-6., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-6., 3.}, {-4., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-6., 3.}, {-9., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-6., 3.}, {-5., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-6., 3.}, {-1., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-10., 3.}, {-11., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-10., 3.}, {-3., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-10., 3.}, {-10., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-5., 3.}, {-5., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-5., 3.}, {-3., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-5., 3.}, {-8., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-5., 3.}, {-7., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-8., 3.}, {-9., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-8., 3.}, {-8., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-4., 3.}, {-6., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-4., 3.}, {-3., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-1., 3.}, {0., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-1., 3.}, {-1., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-1., 3.}, {-3., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-1., 3.}, {-2., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-2., 3.}, {-3., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-3., 3.}, {-4., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-3., 3.}, {-3., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-3., 3.}, {-2., 2.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-6., 2.}, {-6., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-4., 2.}, {-6., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-9., 2.}, {-9., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-9., 2.}, {-7., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-9., 2.}, {-6., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEiB6AMBxh/+byN3dft/9vD+EkTjT6UZP+zZ4Ty
9W406d5o+guX5yle5MzY9gfO/5UI0vAbwV/iD0II9TZ3Z8mL/YTzDdWtRBJO
fIfz08DgG5y/GKz9C5z/2KIPiD7D3aOsBAKf4PKJ3NsSuLd9gPPtX062ezn5
HZy/ZzcIvIbzLUHGPX4B54N0J3A/g/ONweAxnA8OnvwHcP45/u4pjctvw90j
nnNQLOfgNbi8ZMUuU3udS3D+ivQ3j76ePw3nT7EDOfAwnP/g5bU/Gzx2wvn/
tM508rGugPNhMQcAztODKA==
          "]]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf9kMZDjD+8nkbu6/b/7eH8ZMmGn0oyf5nzwjl
691o0r3R9Bcuz1O8yJmx7Q+c/ysRpOE3gr/EH4QQ6m3uzpIX+wnnG6pbiSSc
+A7np4HBN/s1y+53zxf+sP+5oPHLhZxf7TfPqtOv8/uw/71j4ZfG05/the7c
eTV7w4f99d8UOtjWfLI/lfVr7w/Lj/sn6zst0V/90f6O2/UVU1593K/39orH
3xMf7N0KilfnH/q031//Zmk+6wd77ufnjnYe/Lz/zeu5YTwH39lrrH75/dHz
L/s9mnIuNW15az9/z2HHatNv+zcoysU7PX1jPzdSTcLm/P/9BpfffE6UeGGf
JsUgcdCP5cDsp/+f2218bC+0fMURtQCOA3c3rivbFH/f/tolHqHzr7kPhEQ9
u52occN+41wdhl2K/AfmHln2v3vPRftLzC3HP/8QOFD28P7hRIsT9mEd/ve1
9YQOrKhi53aS3WufeqfCvdVA+EBS8ROB8PcroeEjcgAWcwBAgc4h
          "]]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-3., 2.}, {-3., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-3., 2.}, {-4., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-8., 2.}, {-4., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-8., 2.}, {-7., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-4., 1.}, {-5., 0.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-7., 1.}, {-5., 0.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-2., 2.}, {-3., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-2., 2.}, {-6., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-6., 1.}, {-5., 0.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-7., 2.}, {-3., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-7., 2.}, {-7., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-10., 2.}, {-3., 1.}}]}, 
        {Arrowheads[{{0.01, 0.4}}], ArrowBox[{{-10., 2.}, {-9., 1.}}]}}, 
       {Hue[0.125, 0.7, 0.9], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         RectangleBox[{-0.4411765, 1.8235294}, {0.4411765, 2.1764706}], 
         InsetBox[
          StyleBox["\<\"APquad\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {0., 2.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-3.4411765, 0.8235294}, {-2.5588235, 1.1764706}], 
         InsetBox[
          StyleBox["\<\"rhombus\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-3., 1.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-11.4411765, 1.8235294}, {-10.5588235, 2.1764706}], 
         InsetBox[
          StyleBox["\<\"bicentric\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-11., 2.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-9.4411765, 0.8235294}, {-8.5588235, 1.1764706}], 
         InsetBox[
          StyleBox["\<\"bicentricTrap\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-9., 1.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-5.4411765, -0.17647060000000003}, \
{-4.5588235, 0.17647060000000003}], InsetBox[
          StyleBox["\<\"square\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-5., 0.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-5.4411765, 3.8235294}, {-4.5588235, 4.1764706}], 
         InsetBox[
          StyleBox["\<\"convex\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-5., 4.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-7.4411765, 2.8235294}, {-6.5588235, 3.1764706}], 
         InsetBox[
          StyleBox["\<\"trapezoid\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-7., 3.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-6.4411765, 2.8235294}, {-5.5588235, 3.1764706}], 
         InsetBox[
          StyleBox["\<\"cyclic\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-6., 3.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-10.4411765, 2.8235294}, {-9.5588235, 3.1764706}], 
         InsetBox[
          StyleBox["\<\"tangential\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-10., 3.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-5.4411765, 2.8235294}, {-4.5588235, 3.1764706}], 
         InsetBox[
          StyleBox["\<\"orthodiagonal\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-5., 3.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-8.4411765, 2.8235294}, {-7.5588235, 3.1764706}], 
         InsetBox[
          StyleBox["\<\"equidiagonal\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-8., 3.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-4.4411765, 2.8235294}, {-3.5588235, 3.1764706}], 
         InsetBox[
          StyleBox["\<\"equalProdOpp\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-4., 3.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-1.4411765, 2.8235294}, \
{-0.5588234999999999, 3.1764706}], InsetBox[
          StyleBox["\<\"exTangential\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-1., 3.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-2.4411765, 2.8235294}, {-1.5588235, 3.1764706}], 
         InsetBox[
          StyleBox["\<\"equalProdAdj\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-2., 3.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-3.4411765, 2.8235294}, {-2.5588235, 3.1764706}], 
         InsetBox[
          StyleBox["\<\"Pythagorean\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-3., 3.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-6.4411765, 1.8235294}, {-5.5588235, 2.1764706}], 
         InsetBox[
          StyleBox["\<\"harmonic\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-6., 2.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-4.4411765, 1.8235294}, {-3.5588235, 2.1764706}], 
         InsetBox[
          StyleBox["\<\"Hjelmslev\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-4., 2.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-9.4411765, 1.8235294}, {-8.5588235, 2.1764706}], 
         InsetBox[
          StyleBox["\<\"isoTrap\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-9., 2.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-5.4411765, 1.8235294}, {-4.5588235, 2.1764706}], 
         InsetBox[
          StyleBox["\<\"cyclicOrtho\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-5., 2.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-1.4411765, 1.8235294}, \
{-0.5588234999999999, 2.1764706}], InsetBox[
          StyleBox["\<\"exBicentric\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-1., 2.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-3.4411765, 1.8235294}, {-2.5588235, 2.1764706}], 
         InsetBox[
          StyleBox["\<\"kite\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-3., 2.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-8.4411765, 1.8235294}, {-7.5588235, 2.1764706}], 
         InsetBox[
          StyleBox["\<\"equiOrthoQuad\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-8., 2.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-4.4411765, 0.8235294}, {-3.5588235, 1.1764706}], 
         InsetBox[
          StyleBox["\<\"equiOrthoKite\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-4., 1.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-7.4411765, 0.8235294}, {-6.5588235, 1.1764706}], 
         InsetBox[
          StyleBox["\<\"equiOrthoTrap\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-7., 1.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-2.4411765, 1.8235294}, {-1.5588235, 2.1764706}], 
         InsetBox[
          StyleBox["\<\"parallelogram\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-2., 2.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-6.4411765, 0.8235294}, {-5.5588235, 1.1764706}], 
         InsetBox[
          StyleBox["\<\"rectangle\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-6., 1.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-7.4411765, 1.8235294}, {-6.5588235, 2.1764706}], 
         InsetBox[
          StyleBox["\<\"orthoTrap\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-7., 2.},
          BaseStyle->"Graphics"]}, {
         RectangleBox[{-10.4411765, 1.8235294}, {-9.5588235, 2.1764706}], 
         InsetBox[
          StyleBox["\<\"tangTrap\"\>",
           StripOnInput->False,
           FontFamily->"TimesNewRoman",
           FontSize->10], {-10., 2.},
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None,
  ImageSize->1000]], "Output",
 CellChangeTimes->{
  3.8149328574333897`*^9, 3.8149330228921804`*^9, 3.814933248164137*^9, {
   3.8149332841744833`*^9, 3.814933291651991*^9}, {3.814933424867361*^9, 
   3.8149334876556673`*^9}, {3.814933523527711*^9, 3.814933542191884*^9}, {
   3.8149337414450016`*^9, 3.8149337819589605`*^9}, 3.8149338795940294`*^9, 
   3.814933909993079*^9, 3.8149339734781346`*^9, 3.814934025356499*^9, 
   3.8149340752197404`*^9, {3.8149341093523164`*^9, 3.8149341361741433`*^9}, 
   3.8149342013931117`*^9, 3.8149342915749707`*^9, 3.8149355651808057`*^9, 
   3.8149356710933285`*^9, 3.814935746216238*^9, 3.814935930080829*^9, 
   3.8149361377349854`*^9, 3.8149370650546722`*^9, 3.8149371136058416`*^9, 
   3.814937172940775*^9, 3.81493721989657*^9, 3.814937371645132*^9, 
   3.814937619644045*^9, 3.81493777991296*^9, 3.8149381387249956`*^9, 
   3.8149382971508355`*^9, 3.8149384847784476`*^9, 3.8149386195671287`*^9, {
   3.8149389701648855`*^9, 3.81493899604193*^9}, {3.8149391417917204`*^9, 
   3.8149391606280255`*^9}, 3.814939359022555*^9, 3.8149394395776777`*^9, {
   3.81493979484791*^9, 3.8149398503357005`*^9}, {3.814939887506054*^9, 
   3.8149399144822736`*^9}, 3.8149401126570024`*^9, 3.814940210030543*^9, 
   3.8149402420707417`*^9, 3.8149404531602993`*^9, 3.8149405721893215`*^9, 
   3.814940655966129*^9, 3.814940789338151*^9, 3.814940891687418*^9, {
   3.81494102582813*^9, 3.814941067919046*^9}, 3.814941344331996*^9, {
   3.8149413777173157`*^9, 3.814941405829751*^9}, 3.8149416133955917`*^9, 
   3.814941848776698*^9, 3.8149419639378195`*^9, 3.8149521071279774`*^9, 
   3.814952195705406*^9, 3.8149522693321147`*^9, 3.8149525769324036`*^9, 
   3.814952729570315*^9, 3.8149528013618507`*^9, 3.8149528832544074`*^9, 
   3.8149530177631645`*^9, 3.814953100139425*^9, 3.8149534154198256`*^9, 
   3.8149535458140354`*^9, 3.814953807767313*^9, 3.814953861355632*^9, 
   3.814954405755102*^9, 3.8149545391958437`*^9, 3.8149550095619974`*^9, 
   3.8149556433445487`*^9, 3.8149559371628056`*^9, 3.814956015618497*^9, 
   3.8149672618918347`*^9, 3.814967348944423*^9, {3.81496746802709*^9, 
   3.8149674978117476`*^9}, {3.814970481367044*^9, 3.8149705503307753`*^9}, 
   3.814970589810676*^9, 3.814970715786607*^9, {3.8149708462583733`*^9, 
   3.8149708779212427`*^9}, 3.814970967309207*^9, 3.814971015081802*^9, 
   3.8149762617424707`*^9, 3.8149763746391153`*^9, 3.8150670599679937`*^9, 
   3.815068615076007*^9, {3.815068679005802*^9, 3.8150687179110003`*^9}, {
   3.815068795712207*^9, 3.815068811543044*^9}, {3.815075976812758*^9, 
   3.8150760278082848`*^9}, 3.815235681344532*^9, 3.815306921361067*^9, 
   3.815307184785961*^9, 3.8153077451565647`*^9, 3.815390711982278*^9, {
   3.815831187141522*^9, 3.81583121850384*^9}, 3.815832113103244*^9, 
   3.815832451996985*^9, {3.815832552213523*^9, 3.815832573600924*^9}, 
   3.815832663665708*^9, {3.815832697716661*^9, 3.8158327269716043`*^9}, 
   3.815993495824991*^9, 3.815993541846777*^9, 3.815993607066683*^9, 
   3.8159936419098587`*^9, 3.8159938169501677`*^9, 3.816002429249799*^9, 
   3.8160028161500797`*^9, 3.816003471007547*^9, 3.816003628023088*^9, 
   3.816003748475473*^9, 3.816004513017827*^9, {3.8383700291616898`*^9, 
   3.838370034138897*^9}, 3.8492741842148943`*^9, 3.849274501457224*^9, 
   3.849274568235083*^9, {3.849274614415606*^9, 3.849274674452454*^9}, 
   3.8493461097753696`*^9, 3.849346893720264*^9, 3.849347938299635*^9, {
   3.8493480006212673`*^9, 3.8493480294411573`*^9}, 3.849348196320517*^9, {
   3.84934833940221*^9, 3.849348352747261*^9}, {3.849348389451375*^9, 
   3.849348423986429*^9}, {3.849348821138719*^9, 3.8493488269309177`*^9}, {
   3.849348898638562*^9, 3.849348980795323*^9}, 3.849349064250403*^9, 
   3.8493491026703*^9, 3.84935332775566*^9, 3.8493533586415873`*^9, 
   3.849440353288872*^9, {3.849440487139781*^9, 3.8494405024540567`*^9}, 
   3.8494409016050262`*^9, 3.850128496399374*^9, 3.850128555431669*^9, 
   3.8501506920540533`*^9, 3.856888303505625*^9, 3.861082542712867*^9, 
   3.861097763697052*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"7cce6fb0-2805-4de9-aa13-e73715dd2225"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Section 5 (Lemmas)", "Section",
 CellChangeTimes->{{3.858790601848362*^9, 3.858790609085968*^9}, {
  3.8587907131195*^9, 3.858790715655356*^9}, {3.858790753239759*^9, 
  3.858790755903316*^9}, {3.859446154639089*^9, 
  3.859446158222807*^9}},ExpressionUUID->"47b6734f-7749-43fd-be07-\
f0a57a6ed3f6"],

Cell[CellGroupData[{

Cell["Lemmas about Medians", "Subsection",
 CellChangeTimes->{{3.858790798137211*^9, 
  3.8587908084156523`*^9}},ExpressionUUID->"e3e32188-b387-447f-b9c4-\
d6665e1c49ac"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"liesOnMedian", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"coincidesWithE", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rational", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"n", "=", "1"}], ",", 
    RowBox[{"n", "\[LessEqual]", "1000"}], ",", 
    RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"coords", "=", 
      RowBox[{"ETC1", "[", 
       RowBox[{"[", 
        RowBox[{"n", ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"coords", "\[Equal]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
       RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"coords", "=", 
      RowBox[{"coords", "/.", 
       RowBox[{"S", "->", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"simpl", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"coord1", ",", "coord2", ",", "coord3"}], "}"}], "=", 
       RowBox[{"Simplify", "[", 
        RowBox[{"coords", ",", 
         RowBox[{
          RowBox[{"a", "^", "2"}], "==", 
          RowBox[{
           RowBox[{"b", "^", "2"}], "+", 
           RowBox[{"c", "^", "2"}]}]}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Simplify", "[", 
         RowBox[{"coord2", "-", "coord3"}], "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AX", "=", 
         RowBox[{"Simplify", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{"squaredDistance", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", "simpl"}], 
             "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"a", "^", "2"}], "==", 
             RowBox[{
              RowBox[{"b", "^", "2"}], "+", 
              RowBox[{"c", "^", "2"}]}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"AX", "===", "Infinity"}], ",", 
          RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"AX", "=", 
         RowBox[{"Factor", "[", "AX", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"AX", "=", 
         RowBox[{
          RowBox[{"AX", "/.", 
           RowBox[{
            RowBox[{
             RowBox[{"b", "^", "2"}], "+", 
             RowBox[{"c", "^", "2"}]}], "\[Rule]", 
            RowBox[{"a", "^", "2"}]}]}], "//", "PowerExpand"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"AX", "=", 
         RowBox[{"Simplify", "[", "AX", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"AX", "=!=", "0"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"coord1", "===", "0"}], ",", "\[IndentingNewLine]", 
             RowBox[{"AppendTo", "[", 
              RowBox[{"coincidesWithE", ",", "n"}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"AppendTo", "[", 
               RowBox[{"liesOnMedian", ",", "n"}], "]"}], ";"}]}], 
            "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"Print", "[", 
            RowBox[{
            "\"\<n=\>\"", ",", "n", ",", "\"\<   \>\"", ",", "simpl", ",", 
             "\"\<   \>\"", ",", 
             RowBox[{"Style", "[", 
              RowBox[{"AX", ",", "Red"}], "]"}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"ratio", "=", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"a", "/", "2"}], ")"}], "/", "AX"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"NumericQ", "[", "ratio", "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"AppendTo", "[", 
               RowBox[{"rational", ",", 
                RowBox[{"{", 
                 RowBox[{"n", ",", "ratio"}], "}"}]}], "]"}], ";"}]}], 
            "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
         "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.857582475474887*^9, 3.8575824914258633`*^9}, {
   3.857582603098516*^9, 3.8575826063462563`*^9}, {3.8575826859946957`*^9, 
   3.857582834628669*^9}, {3.857582866761621*^9, 3.857582918269206*^9}, {
   3.8575829593432627`*^9, 3.8575829820122347`*^9}, {3.857583038556037*^9, 
   3.857583062875787*^9}, {3.857583132646698*^9, 3.857583139204028*^9}, {
   3.857583181647155*^9, 3.857583183044416*^9}, {3.857583236261652*^9, 
   3.857583241380466*^9}, {3.8575832790085163`*^9, 3.857583305296854*^9}, 
   3.8575833511115637`*^9, {3.85758370730136*^9, 3.85758372383037*^9}, {
   3.857584603034121*^9, 3.8575846802253313`*^9}, {3.857584732516699*^9, 
   3.857584733129534*^9}, {3.857585384557624*^9, 3.857585389483748*^9}, {
   3.8575855773775473`*^9, 3.857585750868944*^9}, {3.857586122032404*^9, 
   3.857586179918844*^9}, {3.8575862381032963`*^9, 3.857586332422942*^9}, {
   3.857587216418792*^9, 3.8575872822338667`*^9}, {3.85758940733781*^9, 
   3.8575894818251257`*^9}, {3.8575895361455193`*^9, 3.8575895514893293`*^9}, 
   3.857590807770513*^9, {3.857591511468974*^9, 3.857591575915415*^9}, {
   3.8576253931570997`*^9, 3.857625400911703*^9}, {3.8576255152800837`*^9, 
   3.857625555024227*^9}, {3.857625644906721*^9, 3.8576256668969088`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"36e45cb8-39da-47de-8414-d6ba15565464"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "3"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm["n=", 2, "   ", {1, 1, 1}, "   ", 
   Style[Rational[1, 3] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097763819264*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"5c6d8d5e-770a-4186-b380-72766d646354"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 3, "   ", {
   0, (-2) $CellContext`b^2 $CellContext`c^2, (-2) $CellContext`b^2 \
$CellContext`c^2}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097763820141*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"2d3a2bdc-b1a6-4c9b-84af-4ac36810f9a5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "4"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 5, "   ", {(-4) $CellContext`b^2 $CellContext`c^2, (-2) \
$CellContext`b^2 $CellContext`c^2, (-2) $CellContext`b^2 $CellContext`c^2}, 
   "   ", 
   Style[Rational[1, 4] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097763831079*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"e2e11ac7-186e-4c6e-9619-f79dc87decc0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "20", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox["a",
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 20, "   ", {
   4 $CellContext`b^2 $CellContext`c^2, (-4) $CellContext`b^2 \
$CellContext`c^2, (-4) $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[$CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097764252201*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"f9a0297d-5b10-4bcc-be47-4e5ac1bac8d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "21", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "b"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "b"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "b"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}], 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"4", " ", "b", " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 21, 
   "   ", {-$CellContext`b $CellContext`c ($CellContext`b^2 + \
$CellContext`c^2 + $CellContext`a ($CellContext`b + $CellContext`c)), \
-$CellContext`b $CellContext`c ($CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c), -$CellContext`b \
$CellContext`c ($CellContext`b + $CellContext`c) ($CellContext`a + \
$CellContext`b + $CellContext`c)}, "   ", 
   Style[$CellContext`a ($CellContext`b + $CellContext`c) ($CellContext`a + \
$CellContext`b + $CellContext`c)/(3 $CellContext`b^2 + 
    4 $CellContext`b $CellContext`c + 3 $CellContext`c^2 + 
    3 $CellContext`a ($CellContext`b + $CellContext`c)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097764396639*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"132e3841-7ce8-4df2-8a9c-673e8e62e98b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "22", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox["a",
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 22, "   ", {
   2 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`c^2), \
(-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`c^2), \
(-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`c^2)},
    "   ", 
   Style[$CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610977644285727`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"d5bbd7b9-29b1-45b7-ad74-0415515871cc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["b", "2"]}], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["b", "2"]}], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox["a",
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 23, "   ", {
   3 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`c^2), \
-$CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`c^2), \
-$CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`c^2)}, 
   "   ", 
   Style[$CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097764431464*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"7199de73-10dc-4fb2-b880-09617b211a28"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "95", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"2", " ", "a"}], "5"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 95, "   ", {
   4 $CellContext`b^4 $CellContext`c^4, 8 $CellContext`b^4 $CellContext`c^4, 
    8 $CellContext`b^4 $CellContext`c^4}, "   ", 
   Style[Rational[2, 5] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097765150221*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"230c65cb-31d6-453f-b9fe-d85dfc9e3124"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "97", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}], ",", 
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 97, "   ", {
   0, (-16) $CellContext`b^6 $CellContext`c^6, (-16) $CellContext`b^6 \
$CellContext`c^6}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097765183282*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"88bac6c7-30f3-4357-aa2f-c53cc1c6e875"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "122", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"16", " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}], ",", 
     RowBox[{"16", " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 122, "   ", {
   0, 16 $CellContext`b^6 $CellContext`c^6, 
    16 $CellContext`b^6 $CellContext`c^6}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097765704996*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"c656a51f-b4e5-411a-8b86-16924d87893e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "123", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"], "-", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           RowBox[{"b", " ", "c"}], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"], "-", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           RowBox[{"b", " ", "c"}], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 123, "   ", {
   0, 8 $CellContext`b^3 $CellContext`c^3 ($CellContext`b^3 + \
$CellContext`b^2 $CellContext`c + $CellContext`b $CellContext`c^2 + \
$CellContext`c^3 - $CellContext`a ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2)), 
    8 $CellContext`b^3 $CellContext`c^3 ($CellContext`b^3 + $CellContext`b^2 \
$CellContext`c + $CellContext`b $CellContext`c^2 + $CellContext`c^3 - \
$CellContext`a ($CellContext`b^2 + $CellContext`b $CellContext`c + \
$CellContext`c^2))}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097765738944*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"78405997-abb3-4837-abc6-c38cfb3ab2b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "127", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 127, "   ", {
   0, 4 $CellContext`b^4 $CellContext`c^4 ($CellContext`b^2 + \
$CellContext`c^2), 
    4 $CellContext`b^4 $CellContext`c^4 ($CellContext`b^2 + \
$CellContext`c^2)}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097765795353*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"cd004355-3b19-4471-9710-c08e82c22c36"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "131", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"16", " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}], ",", 
     RowBox[{"16", " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 131, "   ", {
   0, 16 $CellContext`b^6 $CellContext`c^6 ($CellContext`b^2 - \
$CellContext`c^2)^2, 
    16 $CellContext`b^6 $CellContext`c^6 ($CellContext`b^2 - \
$CellContext`c^2)^2}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097765889843*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"f5351527-193c-4044-83f6-b649869aae56"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "140", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"3", " ", "a"}], "8"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 140, 
   "   ", {(-4) $CellContext`b^2 $CellContext`c^2, (-6) $CellContext`b^2 \
$CellContext`c^2, (-6) $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[Rational[3, 8] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097766077079*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"d8241ae3-0717-4e13-9d8a-0cbb502f041b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "199", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a"}], "+", "b", "+", "c"}], ")"}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 199, "   ", {
   2 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`c^2), \
(-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2 + $CellContext`a ($CellContext`b + \
$CellContext`c)), (-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + \
$CellContext`b $CellContext`c + $CellContext`c^2 + $CellContext`a \
($CellContext`b + $CellContext`c))}, "   ", 
   Style[$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c) ($CellContext`b + $CellContext`c)^(-1)/(
    2 $CellContext`a + $CellContext`b + $CellContext`c), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097880010159*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"10c4a303-8086-4837-87ed-baf6049cdd1b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "216", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 216, "   ", {
   0, (-4) $CellContext`b^4 $CellContext`c^4, (-4) $CellContext`b^4 \
$CellContext`c^4}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097881107349*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"1753cea4-4441-4f14-88a3-c3c6818cb1a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "233", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", "12"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", "12"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"3", " ", "a"}], "10"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 233, 
   "   ", {(-16) $CellContext`b^4 $CellContext`c^4, (-12) $CellContext`b^4 \
$CellContext`c^4, (-12) $CellContext`b^4 $CellContext`c^4}, "   ", 
   Style[Rational[3, 10] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978813864937`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"a2c88a31-ef6b-42dd-858e-e4f53df7d1f1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "237", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], 
     RowBox[{
      SuperscriptBox["b", "4"], "+", 
      SuperscriptBox["c", "4"]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 237, "   ", {
   2 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + \
$CellContext`c^2)^2, (-2) $CellContext`b^4 $CellContext`c^4, (-2) \
$CellContext`b^4 $CellContext`c^4}, "   ", 
   Style[$CellContext`a $CellContext`b^2 $CellContext`c^2/($CellContext`b^4 + \
$CellContext`c^4), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097881908008*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"9ad79ee6-dc85-41a9-b70f-12f88632f2ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "253", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"16", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox["a",
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 253, "   ", {
   16 $CellContext`b^4 $CellContext`c^4, (-16) $CellContext`b^4 \
$CellContext`c^4, (-16) $CellContext`b^4 $CellContext`c^4}, "   ", 
   Style[$CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978821731853`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"b690c040-489d-474c-9aef-3fbf564f2bbe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "268", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      SuperscriptBox["b", "5"], " ", 
      SuperscriptBox["c", "5"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      SuperscriptBox["b", "5"], " ", 
      SuperscriptBox["c", "5"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 268, "   ", {
   0, (-16) $CellContext`b^5 $CellContext`c^5 (-$CellContext`a + \
$CellContext`b + $CellContext`c), (-16) $CellContext`b^5 $CellContext`c^5 \
(-$CellContext`a + $CellContext`b + $CellContext`c)}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097883159745*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"d268053f-45ab-43e1-a120-c81f991a32b6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "280", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox["a",
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 280, 
   "   ", {(-8) $CellContext`b^3 $CellContext`c^3 (-$CellContext`a + \
$CellContext`b + $CellContext`c), 
    8 $CellContext`b^3 $CellContext`c^3 (-$CellContext`a + $CellContext`b + \
$CellContext`c), 
    8 $CellContext`b^3 $CellContext`c^3 (-$CellContext`a + $CellContext`b + \
$CellContext`c)}, "   ", 
   Style[$CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978834358892`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"d5e3011b-243b-4678-b9cf-689948156116"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "339", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 339, "   ", {
   0, 2 $CellContext`b^4 $CellContext`c^4 ($CellContext`b^2 + \
$CellContext`c^2), 
    2 $CellContext`b^4 $CellContext`c^4 ($CellContext`b^2 + \
$CellContext`c^2)}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978879508123`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"17b71c74-8c14-486d-a9b4-e6462ff11d52"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "347", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox["a",
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 347, "   ", {
   4 $CellContext`b^2 $CellContext`c^2 (-$CellContext`a + $CellContext`b + \
$CellContext`c), (-4) $CellContext`b^2 $CellContext`c^2 (-$CellContext`a + \
$CellContext`b + $CellContext`c), (-4) $CellContext`b^2 $CellContext`c^2 \
(-$CellContext`a + $CellContext`b + $CellContext`c)}, "   ", 
   Style[$CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978880547113`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"5f2eaeec-b51e-4453-a95b-3db966c16996"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "376", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"2", " ", "a"}], "3"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 376, "   ", {
   4 $CellContext`b^2 $CellContext`c^2, (-8) $CellContext`b^2 \
$CellContext`c^2, (-8) $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[Rational[2, 3] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978917264643`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"892ced67-2b03-4341-a63c-12871fcba72a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "377", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"2", " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["a", "2"], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "b"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}]}]]}], 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 377, "   ", {
   2 $CellContext`b $CellContext`c ($CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c), 
    2 $CellContext`b $CellContext`c ($CellContext`b^2 + $CellContext`c^2 + \
$CellContext`a ($CellContext`b + $CellContext`c)), 
    2 $CellContext`b $CellContext`c ($CellContext`b^2 + $CellContext`c^2 + \
$CellContext`a ($CellContext`b + $CellContext`c))}, "   ", 
   Style[2^
     Rational[1, 
       2] $CellContext`a^2 (($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c))^Rational[1, 2]/(3 $CellContext`b^2 + 
    2 $CellContext`b $CellContext`c + 3 $CellContext`c^2 + 
    3 $CellContext`a ($CellContext`b + $CellContext`c)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978919379053`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"ee896ad0-9412-42f1-886f-aee0fc973e87"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "379", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SuperscriptBox["a", "2"], 
     RowBox[{
      RowBox[{"4", " ", "a"}], "+", "b", "+", "c"}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 379, "   ", {
   2 $CellContext`b^2 $CellContext`c^2 (
     2 $CellContext`a + $CellContext`b + $CellContext`c), 
    2 $CellContext`a $CellContext`b^2 $CellContext`c^2, 
    2 $CellContext`a $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[$CellContext`a^2/(
    4 $CellContext`a + $CellContext`b + $CellContext`c), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097891985651*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"9512e5ae-a3ec-4a38-978d-ac0bb7fc0fb1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "381", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"8", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "6"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 381, "   ", {
   8 $CellContext`b^2 $CellContext`c^2, 2 $CellContext`b^2 $CellContext`c^2, 
    2 $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[Rational[1, 6] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097892039646*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"310f45a6-0720-470e-9860-b97acc98c45e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "382", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"8", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 382, "   ", {
   8 $CellContext`b^2 $CellContext`c^2, (-2) $CellContext`b^2 \
$CellContext`c^2, (-2) $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978920736513`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"96765896-037c-47ee-b925-5e19f3ad4361"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "383", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SqrtBox["3"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SqrtBox["3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SqrtBox[
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"]}]]}], ")"}]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox[
      RowBox[{"a", " ", "b", " ", "c"}], 
      RowBox[{
       RowBox[{
        SqrtBox["3"], " ", 
        SuperscriptBox["b", "2"]}], "-", 
       RowBox[{"3", " ", "b", " ", "c"}], "+", 
       RowBox[{
        SqrtBox["3"], " ", 
        SuperscriptBox["c", "2"]}]}]]}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 383, 
   "   ", {(-8) $CellContext`b^2 $CellContext`c^2 (
     3^Rational[1, 2] $CellContext`b^2 + 
     3^Rational[1, 2] $CellContext`c^2 - ($CellContext`b^2 $CellContext`c^2)^
     Rational[1, 2]), 8 ($CellContext`b^2 $CellContext`c^2)^Rational[3, 2], 
    8 ($CellContext`b^2 $CellContext`c^2)^Rational[3, 2]}, "   ", 
   Style[-$CellContext`a $CellContext`b $CellContext`c/(
    3^Rational[1, 2] $CellContext`b^2 - 3 $CellContext`b $CellContext`c + 
    3^Rational[1, 2] $CellContext`c^2), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097892240921*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"2b8d6f4d-d092-4bd9-92cf-0bcd8e32903b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "401", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox["a",
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 401, 
   "   ", {(-4) $CellContext`b^4 $CellContext`c^4, 
    4 $CellContext`b^4 $CellContext`c^4, 4 $CellContext`b^4 $CellContext`c^4},
    "   ", 
   Style[$CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097893402203*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"47c0c36f-0650-43b6-b552-b713985d31bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "402", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"16", " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "4"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 402, "   ", {
   16 $CellContext`b^6 $CellContext`c^6, 8 $CellContext`b^6 $CellContext`c^6, 
    8 $CellContext`b^6 $CellContext`c^6}, "   ", 
   Style[Rational[1, 4] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097893437654*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"aae936cc-0df0-46f5-8df0-c28c6a487393"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "404", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "c"}], ")"}], "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"4", " ", "b", " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 404, 
   "   ", {$CellContext`b $CellContext`c ($CellContext`b^2 + $CellContext`c^2 + \
$CellContext`a ($CellContext`b + $CellContext`c)), $CellContext`b \
$CellContext`c (($CellContext`b - $CellContext`c)^2 + $CellContext`a \
($CellContext`b + $CellContext`c)), $CellContext`b $CellContext`c \
(($CellContext`b - $CellContext`c)^2 + $CellContext`a ($CellContext`b + \
$CellContext`c))}, "   ", 
   Style[$CellContext`a ($CellContext`a^2 - 
     2 $CellContext`b $CellContext`c + $CellContext`a ($CellContext`b + \
$CellContext`c))/(3 $CellContext`b^2 - 4 $CellContext`b $CellContext`c + 
    3 $CellContext`c^2 + 3 $CellContext`a ($CellContext`b + $CellContext`c)), 
    
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097893587975*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"6c04ff74-5c06-4531-b319-1b56c4416a28"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "405", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 405, 
   "   ", {(-2) $CellContext`b $CellContext`c ($CellContext`b^2 + \
$CellContext`c^2 + $CellContext`a ($CellContext`b + $CellContext`c)), (-2) \
$CellContext`b $CellContext`c ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2 + $CellContext`a ($CellContext`b + \
$CellContext`c)), (-2) $CellContext`b $CellContext`c ($CellContext`b^2 + \
$CellContext`b $CellContext`c + $CellContext`c^2 + $CellContext`a \
($CellContext`b + $CellContext`c))}, "   ", 
   Style[$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c)/(3 $CellContext`b^2 + 2 $CellContext`b $CellContext`c + 
    3 $CellContext`c^2 + 3 $CellContext`a ($CellContext`b + $CellContext`c)), 
    
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978937344027`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"ac0d9d0e-33b5-4fba-bb48-0250ef47e162"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "408", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 408, "   ", {
   0, 8 $CellContext`b^6 $CellContext`c^6 ($CellContext`a + $CellContext`b + \
$CellContext`c), 
    8 $CellContext`b^6 $CellContext`c^6 ($CellContext`a + $CellContext`b + \
$CellContext`c)}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097893785803*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"82a3c1db-f6f9-40ec-bae3-e08ca71c0ddb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "409", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"3", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           RowBox[{"b", " ", "c"}], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "+", "c"}], ")"}], "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["b", "2"]}], "+", 
         RowBox[{"b", " ", "c"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["c", "2"]}]}], ")"}]}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["b", "4"]}], "+", 
         RowBox[{"10", " ", 
          SuperscriptBox["b", "3"], " ", "c"}], "+", 
         RowBox[{"13", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"10", " ", "b", " ", 
          SuperscriptBox["c", "3"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["c", "4"]}]}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 409, "   ", {
   2 $CellContext`b $CellContext`c ($CellContext`b^2 + 
     3 $CellContext`b $CellContext`c + $CellContext`c^2) ($CellContext`b^3 + \
$CellContext`b^2 $CellContext`c + $CellContext`b $CellContext`c^2 + \
$CellContext`c^3 + $CellContext`a ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2)), 
    2 $CellContext`b $CellContext`c ($CellContext`b^3 + 
     2 $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b $CellContext`c^2 + $CellContext`c^3) ($CellContext`b^2 + \
$CellContext`b $CellContext`c + $CellContext`c^2 + $CellContext`a \
($CellContext`b + $CellContext`c)), 
    2 $CellContext`b $CellContext`c ($CellContext`b^3 + 
     2 $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b $CellContext`c^2 + $CellContext`c^3) ($CellContext`b^2 + \
$CellContext`b $CellContext`c + $CellContext`c^2 + $CellContext`a \
($CellContext`b + $CellContext`c))}, "   ", 
   Style[$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c) ($CellContext`b^3 + 2 $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b $CellContext`c^2 + $CellContext`c^3)/(($CellContext`b + \
$CellContext`c)^3 (3 $CellContext`b^2 + $CellContext`b $CellContext`c + 
      3 $CellContext`c^2) + $CellContext`a (3 $CellContext`b^4 + 
      10 $CellContext`b^3 $CellContext`c + 
      13 $CellContext`b^2 $CellContext`c^2 + 
      10 $CellContext`b $CellContext`c^3 + 3 $CellContext`c^4)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.86109789415351*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"9679f988-5b22-45d5-9726-74ffdfa67723"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "411", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "a", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox[
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}]}], 
      RowBox[{"a", "-", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"b", "+", "c"}], ")"}]}]}]]}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 411, 
   "   ", {(-4) $CellContext`a $CellContext`b^3 $CellContext`c^3, 
    4 $CellContext`b^3 $CellContext`c^3 ($CellContext`b + $CellContext`c), 
    4 $CellContext`b^3 $CellContext`c^3 ($CellContext`b + $CellContext`c)}, 
   "   ", 
   Style[-$CellContext`a ($CellContext`b + $CellContext`c)/($CellContext`a - 
    2 ($CellContext`b + $CellContext`c)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097894250765*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"5f36d8f6-4999-43e2-9d95-d1a2816406dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "413", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}]}]]}], 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"5", " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["b", "3"]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         RowBox[{"4", " ", "b", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["c", "3"]}]}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 413, 
   "   ", {(-4) $CellContext`b^3 $CellContext`c^3 ($CellContext`b^2 - \
$CellContext`b $CellContext`c + $CellContext`c^2) ($CellContext`b^2 + \
$CellContext`c^2 + $CellContext`a ($CellContext`b + $CellContext`c)), (-4) \
$CellContext`b^3 $CellContext`c^3 ($CellContext`a + $CellContext`b + \
$CellContext`c) ($CellContext`b^3 + 2 $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b $CellContext`c^2 + $CellContext`c^3), (-4) \
$CellContext`b^3 $CellContext`c^3 ($CellContext`a + $CellContext`b + \
$CellContext`c) ($CellContext`b^3 + 2 $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b $CellContext`c^2 + $CellContext`c^3)}, "   ", 
   Style[Complex[
     0, 1] ($CellContext`a + $CellContext`b + $CellContext`c) \
($CellContext`b^3 + 2 $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b $CellContext`c^2 + $CellContext`c^3) ($CellContext`a^2 - 
      2 ($CellContext`b^2 + $CellContext`c^2))^Rational[1, 2]/(
    3 $CellContext`b^4 + 5 $CellContext`b^3 $CellContext`c + 
    10 $CellContext`b^2 $CellContext`c^2 + 5 $CellContext`b $CellContext`c^3 + 
    3 $CellContext`c^4 + $CellContext`a (3 $CellContext`b^3 + 
      4 $CellContext`b^2 $CellContext`c + 4 $CellContext`b $CellContext`c^2 + 
      3 $CellContext`c^3)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097894491434*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"8fc7b2f3-e2b2-451f-b689-b99dd6e09785"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "416", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "5"], " ", 
      SuperscriptBox["c", "5"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "5"], " ", 
      SuperscriptBox["c", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "5"], " ", 
      SuperscriptBox["c", "5"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}], 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      RowBox[{"4", " ", "b", " ", "c"}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 416, 
   "   ", {(-4) $CellContext`b^5 $CellContext`c^5 ($CellContext`b^2 + \
$CellContext`c^2 + $CellContext`a ($CellContext`b + $CellContext`c)), 
    4 $CellContext`b^5 $CellContext`c^5 ($CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c), 
    4 $CellContext`b^5 $CellContext`c^5 ($CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c)}, "   ", 
   Style[$CellContext`a ($CellContext`b + $CellContext`c) ($CellContext`a + \
$CellContext`b + $CellContext`c)/($CellContext`a^2 + 
    4 $CellContext`b $CellContext`c + $CellContext`a ($CellContext`b + \
$CellContext`c)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097894695709*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"d0c55bf9-de04-49ab-932c-31038521afb2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "417", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", "32"}], " ", 
      SuperscriptBox["b", "8"], " ", 
      SuperscriptBox["c", "8"]}], ",", 
     RowBox[{
      RowBox[{"-", "32"}], " ", 
      SuperscriptBox["b", "8"], " ", 
      SuperscriptBox["c", "8"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 417, "   ", {
   0, (-32) $CellContext`b^8 $CellContext`c^8, (-32) $CellContext`b^8 \
$CellContext`c^8}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978947311783`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"38a5b87d-b66b-40e5-a813-f4378b7baa12"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "418", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 418, "   ", {
   0, 8 $CellContext`b^6 $CellContext`c^6, 
    8 $CellContext`b^6 $CellContext`c^6}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097894734201*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"db6a52f9-6aa8-45af-b1b0-bebda354b0b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "426", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}], ",", 
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 426, "   ", {
   0, (-16) $CellContext`b^6 $CellContext`c^6, (-16) $CellContext`b^6 \
$CellContext`c^6}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978948621817`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"9c4848af-a513-41d0-a1ff-8421176a9108"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "439", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}], 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "4"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 439, "   ", {
   4 ($CellContext`b^2 + $CellContext`c^2)^2, 
    4 ($CellContext`b^2 - $CellContext`c^2)^2, 
    4 ($CellContext`b^2 - $CellContext`c^2)^2}, "   ", 
   Style[$CellContext`a ($CellContext`b^2 - $CellContext`c^2)^2/(
    3 $CellContext`b^4 - 2 $CellContext`b^2 $CellContext`c^2 + 
    3 $CellContext`c^4), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097895114785*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"927e7963-55fa-44ef-8bfe-231ad6ea9dd8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "440", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 440, "   ", {
   0, 4 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2 + $CellContext`a ($CellContext`b + \
$CellContext`c)), 
    4 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2 + $CellContext`a ($CellContext`b + \
$CellContext`c))}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097895150202*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"47768016-18b4-4c79-97f3-be97971c98d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "441", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 441, "   ", {
   0, 8 $CellContext`b^4 $CellContext`c^4, 
    8 $CellContext`b^4 $CellContext`c^4}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978951533117`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"b4b41159-4267-4f11-a9f6-cb720777b203"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "442", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"4", " ", "b", " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 442, 
   "   ", {(-2) $CellContext`b $CellContext`c ($CellContext`b + \
$CellContext`c) ($CellContext`a + $CellContext`b + $CellContext`c), (-2) \
$CellContext`b $CellContext`c ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2 + $CellContext`a ($CellContext`b + \
$CellContext`c)), (-2) $CellContext`b $CellContext`c ($CellContext`b^2 + \
$CellContext`b $CellContext`c + $CellContext`c^2 + $CellContext`a \
($CellContext`b + $CellContext`c))}, "   ", 
   Style[$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c)/(3 $CellContext`b^2 + 4 $CellContext`b $CellContext`c + 
    3 $CellContext`c^2 + 3 $CellContext`a ($CellContext`b + $CellContext`c)), 
    
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097895268154*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"c1f0bcf8-614b-455b-b7b9-a672726e0626"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "443", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"4", " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"4", " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["a", "2"], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "b"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "c"}], ")"}]}]]}], 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"b", " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 443, "   ", {
   4 $CellContext`b $CellContext`c ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2 + $CellContext`a ($CellContext`b + \
$CellContext`c)), 
    4 $CellContext`b $CellContext`c ($CellContext`b^2 + $CellContext`c^2 + \
$CellContext`a ($CellContext`b + $CellContext`c)), 
    4 $CellContext`b $CellContext`c ($CellContext`b^2 + $CellContext`c^2 + \
$CellContext`a ($CellContext`b + $CellContext`c))}, "   ", 
   Style[2^
     Rational[1, 
       2] $CellContext`a^2 (($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c))^Rational[1, 2]/(
    3 $CellContext`b^2 + $CellContext`b $CellContext`c + 3 $CellContext`c^2 + 
    3 $CellContext`a ($CellContext`b + $CellContext`c)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978954681273`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"e1170123-7a2a-426f-983e-c7a9f51a440a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "446", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"8", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "8"], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], 
     RowBox[{
      SuperscriptBox["b", "8"], "-", 
      RowBox[{
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      SuperscriptBox["c", "8"]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 446, "   ", {
   8 $CellContext`b^4 $CellContext`c^4 ($CellContext`b^8 + $CellContext`b^6 \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8), \
(-8) $CellContext`b^6 $CellContext`c^6 ($CellContext`b^4 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4), (-8) $CellContext`b^6 $CellContext`c^6 \
($CellContext`b^4 + $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, 
   "   ", 
   Style[$CellContext`a $CellContext`b^2 $CellContext`c^2 ($CellContext`b^4 + \
$CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)/($CellContext`b^8 - \
$CellContext`b^6 $CellContext`c^2 - 
    2 $CellContext`b^4 $CellContext`c^4 - $CellContext`b^2 $CellContext`c^6 + \
$CellContext`c^8), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097895633312*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"7bfd27e7-bf31-49bc-ab69-ea9f42238e65"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "448", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}], 
     RowBox[{"2", " ", "b", " ", "c"}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 448, 
   "   ", {(-4) $CellContext`b^3 $CellContext`c^3 ($CellContext`b^2 + \
$CellContext`b $CellContext`c + $CellContext`c^2 + $CellContext`a \
($CellContext`b + $CellContext`c)), 
    2 $CellContext`b^3 $CellContext`c^3 ($CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c), 
    2 $CellContext`b^3 $CellContext`c^3 ($CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c)}, "   ", 
   Style[Rational[
     1, 2] $CellContext`a $CellContext`b^(-1) $CellContext`c^(-1) \
($CellContext`b + $CellContext`c) ($CellContext`a + $CellContext`b + \
$CellContext`c), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.86109789582763*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"83131197-dd01-4593-9acf-1cbbc5785e3a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "449", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], 
     RowBox[{"2", " ", "b", " ", "c"}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 449, 
   "   ", {(-16) $CellContext`b^3 $CellContext`c^3 ($CellContext`b^2 + \
$CellContext`c^2 + $CellContext`a ($CellContext`b + $CellContext`c)), 
    8 $CellContext`b^3 $CellContext`c^3 ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2 + $CellContext`a ($CellContext`b + \
$CellContext`c)), 
    8 $CellContext`b^3 $CellContext`c^3 ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2 + $CellContext`a ($CellContext`b + \
$CellContext`c))}, "   ", 
   Style[Rational[
     1, 2] $CellContext`a $CellContext`b^(-1) ($CellContext`a + \
$CellContext`b) $CellContext`c^(-1) ($CellContext`a + $CellContext`c), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978960355263`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"3adead6f-6b3b-4546-a32d-d6764903e79d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "452", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"b", " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 452, 
   "   ", {(-4) $CellContext`b $CellContext`c ($CellContext`b^2 - \
$CellContext`b $CellContext`c + $CellContext`c^2 + $CellContext`a \
($CellContext`b + $CellContext`c)), (-4) $CellContext`b $CellContext`c \
($CellContext`b^2 + $CellContext`b $CellContext`c + $CellContext`c^2 + \
$CellContext`a ($CellContext`b + $CellContext`c)), (-4) $CellContext`b \
$CellContext`c ($CellContext`b^2 + $CellContext`b $CellContext`c + \
$CellContext`c^2 + $CellContext`a ($CellContext`b + $CellContext`c))}, "   ", 
   
   Style[$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c)/(3 $CellContext`b^2 + $CellContext`b $CellContext`c + 
    3 $CellContext`c^2 + 3 $CellContext`a ($CellContext`b + $CellContext`c)), 
    
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097896173955*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"f9ef0307-aa07-4d97-bc5f-c3fc26e4412c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "453", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}]}], 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["b", "2"]}], "-", 
         RowBox[{"2", " ", "b", " ", "c"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["c", "2"]}]}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 453, 
   "   ", {(-4) $CellContext`b^3 $CellContext`c^3 ($CellContext`b + \
$CellContext`c)^2 ($CellContext`b^2 + $CellContext`c^2 + $CellContext`a \
($CellContext`b + $CellContext`c)), (-4) $CellContext`b^3 ($CellContext`b - \
$CellContext`c)^2 $CellContext`c^3 ($CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c), (-4) $CellContext`b^3 \
($CellContext`b - $CellContext`c)^2 $CellContext`c^3 ($CellContext`b + \
$CellContext`c) ($CellContext`a + $CellContext`b + $CellContext`c)}, "   ", 
   Style[$CellContext`a ($CellContext`b - $CellContext`c)^2 ($CellContext`a + \
$CellContext`b + $CellContext`c)/(
    3 $CellContext`b^3 - $CellContext`b^2 $CellContext`c - $CellContext`b \
$CellContext`c^2 + 
    3 $CellContext`c^3 + $CellContext`a (3 $CellContext`b^2 - 
      2 $CellContext`b $CellContext`c + 3 $CellContext`c^2)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978964466753`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"431979c6-7eb3-4dae-845a-cbdb1c03d65f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "454", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", "32"}], " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "32"}], " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 454, "   ", {
   0, (-32) $CellContext`b^6 $CellContext`c^6 ($CellContext`b^2 - \
$CellContext`c^2)^2, (-32) $CellContext`b^6 $CellContext`c^6 \
($CellContext`b^2 - $CellContext`c^2)^2}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978964819193`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"3aa71f05-0f2a-49ea-a718-15946c8e6f39"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "464", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 464, "   ", {
   0, (-8) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + \
$CellContext`b $CellContext`c + $CellContext`c^2 + $CellContext`a \
($CellContext`b + $CellContext`c)), (-8) $CellContext`b^2 $CellContext`c^2 \
($CellContext`b^2 + $CellContext`b $CellContext`c + $CellContext`c^2 + \
$CellContext`a ($CellContext`b + $CellContext`c))}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097896662897*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"0fb326f9-869e-4630-9620-ee4613497bc7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "465", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}], ",", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 465, "   ", {
   0, 4 3^Rational[1, 2] ($CellContext`b^2 $CellContext`c^2)^Rational[3, 2], 
    4 3^Rational[1, 2] ($CellContext`b^2 $CellContext`c^2)^Rational[3, 2]}, 
   "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978966974783`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"02930c5d-8c6a-4444-9093-30c83371673a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "466", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}], ",", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 466, "   ", {
   0, 4 3^Rational[1, 2] ($CellContext`b^2 $CellContext`c^2)^Rational[3, 2], 
    4 3^Rational[1, 2] ($CellContext`b^2 $CellContext`c^2)^Rational[3, 2]}, 
   "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610978967419977`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"34c38970-e371-4370-81c3-1aaf77f6efd5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "474", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "3"], "+", 
           SuperscriptBox["c", "3"]}], ")"}]}]}]]}], 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 474, "   ", {
   2 $CellContext`b $CellContext`c ($CellContext`b^2 + $CellContext`c^2 + \
$CellContext`a ($CellContext`b + $CellContext`c)), 
    2 $CellContext`b $CellContext`c ($CellContext`b^2 - $CellContext`b \
$CellContext`c + $CellContext`c^2 + $CellContext`a ($CellContext`b + \
$CellContext`c)), 
    2 $CellContext`b $CellContext`c ($CellContext`b^2 - $CellContext`b \
$CellContext`c + $CellContext`c^2 + $CellContext`a ($CellContext`b + \
$CellContext`c))}, "   ", 
   Style[$CellContext`a (3 $CellContext`b^2 - 2 $CellContext`b $CellContext`c + 
      3 $CellContext`c^2 + 
      3 $CellContext`a ($CellContext`b + $CellContext`c))^(-1) (
      2 $CellContext`b^4 + 5 $CellContext`b^2 $CellContext`c^2 + 
      2 $CellContext`c^4 + 
      2 $CellContext`a ($CellContext`b^3 + $CellContext`c^3))^Rational[1, 2], 
    
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097896969851*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"aa9fd7cc-3b28-43e6-b7ff-5999aabf83cd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "546", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"12", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "8"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 546, "   ", {
   12 $CellContext`b^2 $CellContext`c^2, 2 $CellContext`b^2 $CellContext`c^2, 
    2 $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[Rational[1, 8] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610979016273823`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"52bcb4f5-a9dc-4786-aad3-c956f1fbdc9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "547", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "20"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "14"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "14"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"7", " ", "a"}], "24"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 547, 
   "   ", {(-20) $CellContext`b^2 $CellContext`c^2, (-14) $CellContext`b^2 \
$CellContext`c^2, (-14) $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[Rational[7, 24] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.86109790166439*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"1f232323-f321-4cd8-8bb1-6628891b6bf5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "548", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "10"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "10"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"5", " ", "a"}], "8"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 548, "   ", {
   4 $CellContext`b^2 $CellContext`c^2, (-10) $CellContext`b^2 \
$CellContext`c^2, (-10) $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[Rational[5, 8] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097901667561*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"f4d6070f-f25b-4569-9db4-da97b4b91262"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "549", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "10"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "10"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"5", " ", "a"}], "12"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 549, 
   "   ", {(-4) $CellContext`b^2 $CellContext`c^2, (-10) $CellContext`b^2 \
$CellContext`c^2, (-10) $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[Rational[5, 12] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097901670079*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"efe64d11-ab01-464b-b878-343d826e06fd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "550", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "6"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"3", " ", "a"}], "4"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 550, "   ", {
   4 $CellContext`b^2 $CellContext`c^2, (-6) $CellContext`b^2 \
$CellContext`c^2, (-6) $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[Rational[3, 4] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610979016724663`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"87b27210-d1f0-4d6d-b1be-71640bde146b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "577", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 577, "   ", {
   0, 4 $CellContext`b^4 $CellContext`c^4, 
    4 $CellContext`b^4 $CellContext`c^4}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097902679924*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"3fd78cd7-235b-4c59-8850-9ced10caa02a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "631", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"2", " ", "a"}], "5"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 631, 
   "   ", {(-4) $CellContext`b^2 $CellContext`c^2, (-8) $CellContext`b^2 \
$CellContext`c^2, (-8) $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[Rational[2, 5] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097905023986*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"8fb626f5-5ef2-4399-ba19-40514a50626f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "632", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "12"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "14"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "14"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"7", " ", "a"}], "20"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 632, 
   "   ", {(-12) $CellContext`b^2 $CellContext`c^2, (-14) $CellContext`b^2 \
$CellContext`c^2, (-14) $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[Rational[7, 20] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610979050596533`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"cf91fb30-501b-40a1-881e-031f318591cd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "828", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"16", " ", 
      SuperscriptBox["b", "7"], " ", 
      SuperscriptBox["c", "7"]}], ",", 
     RowBox[{"16", " ", 
      SuperscriptBox["b", "7"], " ", 
      SuperscriptBox["c", "7"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 828, "   ", {
   0, 16 $CellContext`b^7 $CellContext`c^7, 
    16 $CellContext`b^7 $CellContext`c^7}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097914199259*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"0abadcb0-b9d9-4656-8882-e9a601062415"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "851", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox[
      RowBox[{"a", " ", "b", " ", "c"}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "b", " ", "c"}], "+", 
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{"b", "+", "c"}], ")"}]}]}]]}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 851, "   ", {
   2 $CellContext`a $CellContext`b^2 $CellContext`c^2 ($CellContext`b + \
$CellContext`c), (-2) $CellContext`b^3 $CellContext`c^3, (-2) \
$CellContext`b^3 $CellContext`c^3}, "   ", 
   Style[-$CellContext`a $CellContext`b $CellContext`c/((-2) $CellContext`b \
$CellContext`c + $CellContext`a ($CellContext`b + $CellContext`c)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097917944048*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"91706627-8d00-41a6-ba95-33b6375aa1ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "852", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 852, "   ", {
   0, 8 $CellContext`b^6 $CellContext`c^6, 
    8 $CellContext`b^6 $CellContext`c^6}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097917979308*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"e57dc30f-a964-48c7-96dc-3526d4d7d071"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "853", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        SuperscriptBox["c", "4"], "-", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "3"], "+", 
           SuperscriptBox["c", "3"]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "5"], " ", 
      SuperscriptBox["c", "5"]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "5"], " ", 
      SuperscriptBox["c", "5"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"]}], 
     RowBox[{
      SuperscriptBox["b", "6"], "+", 
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      SuperscriptBox["c", "6"], "-", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "5"], "+", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "3"]}], "+", 
         SuperscriptBox["c", "5"]}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 853, "   ", {
   4 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`c^2) \
($CellContext`b^4 + $CellContext`c^4 - $CellContext`a ($CellContext`b^3 + \
$CellContext`c^3)), 4 $CellContext`b^5 $CellContext`c^5, 
    4 $CellContext`b^5 $CellContext`c^5}, "   ", 
   Style[$CellContext`a $CellContext`b^3 $CellContext`c^3/($CellContext`b^6 + \
$CellContext`b^4 $CellContext`c^2 + 
    2 $CellContext`b^3 $CellContext`c^3 + $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6 - $CellContext`a ($CellContext`b^5 + $CellContext`b^3 \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^3 + $CellContext`c^5)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097918223558*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"54497ec0-d65a-4713-8c84-7eb28b49aa21"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "854", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], 
     RowBox[{
      SuperscriptBox["b", "5"], "-", 
      RowBox[{
       SuperscriptBox["b", "4"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      SuperscriptBox["c", "5"], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "4"], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         SuperscriptBox["c", "4"]}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 854, "   ", {
   2 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`c^2) \
(($CellContext`b - $CellContext`c)^2 ($CellContext`b + $CellContext`c) + \
$CellContext`a ($CellContext`b^2 + $CellContext`c^2)), (-2) $CellContext`b^4 \
$CellContext`c^4 (-$CellContext`a + $CellContext`b + $CellContext`c), (-2) \
$CellContext`b^4 $CellContext`c^4 (-$CellContext`a + $CellContext`b + \
$CellContext`c)}, "   ", 
   Style[$CellContext`a $CellContext`b^2 $CellContext`c^2 (-$CellContext`a + \
$CellContext`b + $CellContext`c)/($CellContext`b^5 - $CellContext`b^4 \
$CellContext`c - 2 $CellContext`b^3 $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^3 - $CellContext`b $CellContext`c^4 + \
$CellContext`c^5 + $CellContext`a ($CellContext`b^4 + 
      4 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610979184525642`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"92c72a33-01b2-4a99-8d9d-a0c22932960f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "855", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"b", "-", "c"}], ")"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox[
      RowBox[{"a", " ", "b", " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", "c"}], 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"b", "+", "c"}], ")"}]}], "+", 
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"]}], ")"}]}]}]]}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 855, "   ", {
   2 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^3 + $CellContext`a \
($CellContext`b - $CellContext`c)^2 + $CellContext`b^2 $CellContext`c + \
$CellContext`b $CellContext`c^2 + $CellContext`c^3), (-2) $CellContext`b^3 \
$CellContext`c^3 (-$CellContext`a + $CellContext`b + $CellContext`c), (-2) \
$CellContext`b^3 $CellContext`c^3 (-$CellContext`a + $CellContext`b + \
$CellContext`c)}, "   ", 
   Style[-$CellContext`a $CellContext`b ($CellContext`a - $CellContext`b - \
$CellContext`c) $CellContext`c/(($CellContext`b - $CellContext`c)^2 \
($CellContext`b + $CellContext`c) + $CellContext`a ($CellContext`b^2 + \
$CellContext`c^2)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610979186069393`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"6fd52933-caba-4a4b-8742-cb28d0883229"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "856", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "5"], " ", 
      SuperscriptBox["c", "5"]}], ",", 
     RowBox[{"8", " ", 
      SuperscriptBox["b", "5"], " ", 
      SuperscriptBox["c", "5"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["a", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 856, "   ", {
   0, 8 $CellContext`b^5 $CellContext`c^5, 
    8 $CellContext`b^5 $CellContext`c^5}, "   ", 
   Style[Rational[1, 2] $CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.86109791864242*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"525d56bd-1da1-4955-8b0d-1a44f868a62f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "857", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox["a", "2"], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}]]}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 857, 
   "   ", {(-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b + \
$CellContext`c), 2 $CellContext`a $CellContext`b^2 $CellContext`c^2, 
    2 $CellContext`a $CellContext`b^2 $CellContext`c^2}, "   ", 
   Style[-$CellContext`a^2/((-2) $CellContext`a + $CellContext`b + \
$CellContext`c), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097918687409*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"7b5594eb-1f31-4bc5-a9ec-1bd909a59285"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "858", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox["a",
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 858, "   ", {
   2 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`c^2), \
(-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`c^2), \
(-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`c^2)},
    "   ", 
   Style[$CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610979187228622`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"32bce703-9f74-43fc-afaf-6bf45fff8487"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "859", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", "b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], 
     RowBox[{
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}]}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"]}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 859, "   ", {
   2 $CellContext`b^2 $CellContext`c^2 ($CellContext`a + $CellContext`b + \
$CellContext`c) ($CellContext`b^2 + $CellContext`c^2), (-2) $CellContext`b^3 \
$CellContext`c^3 ($CellContext`b + $CellContext`c), (-2) $CellContext`b^3 \
$CellContext`c^3 ($CellContext`b + $CellContext`c)}, "   ", 
   Style[$CellContext`a $CellContext`b $CellContext`c ($CellContext`b + \
$CellContext`c)/(($CellContext`b - $CellContext`c)^2 ($CellContext`b + \
$CellContext`c) + $CellContext`a ($CellContext`b^2 + $CellContext`c^2)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097918851914*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"406fde6c-86de-41ff-bef9-9f740fdf9530"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "861", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}], "2"], "-", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "3"], "+", 
           SuperscriptBox["c", "3"]}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{"4", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], 
     RowBox[{
      SuperscriptBox["b", "4"], "+", 
      SuperscriptBox["c", "4"], "-", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "3"], "+", 
         SuperscriptBox["c", "3"]}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 861, 
   "   ", {(-4) $CellContext`b^2 $CellContext`c^2 (($CellContext`b^2 + \
$CellContext`c^2)^2 - $CellContext`a ($CellContext`b^3 + $CellContext`c^3)), 
    4 $CellContext`b^4 $CellContext`c^4, 4 $CellContext`b^4 $CellContext`c^4},
    "   ", 
   Style[$CellContext`a $CellContext`b^2 $CellContext`c^2/($CellContext`b^4 + \
$CellContext`c^4 - $CellContext`a ($CellContext`b^3 + $CellContext`c^3)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097918985608*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"95635b8f-f6c4-455b-a03c-a88e78777a01"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "863", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", "a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "5"], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "5"], " ", 
      SuperscriptBox["c", "5"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "5"], " ", 
      SuperscriptBox["c", "5"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"]}], 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "5"], "+", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "3"]}], "+", 
         SuperscriptBox["c", "5"]}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 863, "   ", {
   2 $CellContext`a $CellContext`b^2 $CellContext`c^2 ($CellContext`b^5 + \
$CellContext`b^3 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^3 + \
$CellContext`c^5), (-2) $CellContext`b^5 $CellContext`c^5, (-2) \
$CellContext`b^5 $CellContext`c^5}, "   ", 
   Style[$CellContext`a $CellContext`b^3 $CellContext`c^3/((-2) \
$CellContext`b^3 $CellContext`c^3 + $CellContext`a ($CellContext`b^5 + \
$CellContext`b^3 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^3 + \
$CellContext`c^5)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610979191105556`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"623114e1-1f00-4a34-8013-62ca6e6a8b7c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "864", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"]}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], 
     RowBox[{
      SuperscriptBox["b", "8"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      SuperscriptBox["c", "8"]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 864, "   ", {
   2 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + \
$CellContext`c^2)^2 ($CellContext`b^4 + $CellContext`c^4), (-2) \
$CellContext`b^6 $CellContext`c^6, (-2) $CellContext`b^6 $CellContext`c^6}, 
   "   ", 
   Style[$CellContext`a $CellContext`b^4 $CellContext`c^4/($CellContext`b^8 + 
    2 $CellContext`b^6 $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097919166563*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"353db427-eedc-43cd-90c2-bc944188abcf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "865", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "4"], "-", 
         SuperscriptBox["c", "4"]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "6"], " ", 
      SuperscriptBox["c", "6"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], 
     RowBox[{
      SuperscriptBox["b", "8"], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      SuperscriptBox["c", "8"]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 865, "   ", {
   2 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^4 - \
$CellContext`c^4)^2, (-2) $CellContext`b^6 $CellContext`c^6, (-2) \
$CellContext`b^6 $CellContext`c^6}, "   ", 
   Style[$CellContext`a $CellContext`b^4 $CellContext`c^4/($CellContext`b^8 - 
    4 $CellContext`b^4 $CellContext`c^4 + $CellContext`c^8), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.86109791921358*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"c3ef3b65-ecbd-43c8-86d7-5ef58347a1ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "866", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "-", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "-", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "c"}], ")"}], " ", "c"}], 
     RowBox[{
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"2", " ", "b", " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", 
         RowBox[{"2", " ", "c"}]}], ")"}], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 866, "   ", {
   2 $CellContext`b^2 ($CellContext`b - $CellContext`c)^2 $CellContext`c^2 \
($CellContext`b^2 + $CellContext`c^2), (-2) $CellContext`b^3 $CellContext`c^3 \
($CellContext`b^2 + $CellContext`b $CellContext`c + $CellContext`c^2 - \
$CellContext`a ($CellContext`b + $CellContext`c)), (-2) $CellContext`b^3 \
$CellContext`c^3 ($CellContext`b^2 + $CellContext`b $CellContext`c + \
$CellContext`c^2 - $CellContext`a ($CellContext`b + $CellContext`c))}, "   ", 
   
   Style[$CellContext`a ($CellContext`a - $CellContext`b) $CellContext`b \
($CellContext`a - $CellContext`c) $CellContext`c/($CellContext`b^4 + 
    2 $CellContext`a $CellContext`b^2 $CellContext`c - 
    4 $CellContext`b^3 $CellContext`c + 
    2 $CellContext`b ($CellContext`a - 
      2 $CellContext`c) $CellContext`c^2 + $CellContext`c^4), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097919421874*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"e09b9580-cccf-4def-a0b7-a60b5fcd73dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "867", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "-", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ",", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"], "-", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "c"}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", 
        RowBox[{"2", " ", "b"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", 
        RowBox[{"2", " ", "c"}]}], ")"}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 867, 
   "   ", {(-2) $CellContext`b^2 ($CellContext`b - $CellContext`c)^2 \
$CellContext`c^2, 
    2 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2 - $CellContext`a ($CellContext`b + \
$CellContext`c)), 
    2 $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2 - $CellContext`a ($CellContext`b + \
$CellContext`c))}, "   ", 
   Style[$CellContext`a ($CellContext`a - 
      2 $CellContext`b)^(-1) ($CellContext`a - $CellContext`b) \
($CellContext`a - 2 $CellContext`c)^(-1) ($CellContext`a - $CellContext`c), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.861097919617333*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"e0aa6da3-3e5d-45a1-aba1-96df23674776"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "868", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}], ",", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   \"\>",
    "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], 
     RowBox[{
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 868, 
   "   ", {(-2) $CellContext`b^2 $CellContext`c^2 ($CellContext`b^2 - \
$CellContext`c^2)^2, 2 $CellContext`b^4 $CellContext`c^4, 
    2 $CellContext`b^4 $CellContext`c^4}, "   ", 
   Style[$CellContext`a $CellContext`b^2 $CellContext`c^2/($CellContext`b^4 - 
    4 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610979196637583`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"5bf45707-0280-4b35-9594-a985ea3dc41d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "925", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      SuperscriptBox["b", "4"], " ", 
      SuperscriptBox["c", "4"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox["a",
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 925, "   ", {
   4 $CellContext`b^4 $CellContext`c^4 ($CellContext`b^2 - \
$CellContext`c^2)^2, (-4) $CellContext`b^4 $CellContext`c^4 ($CellContext`b^2 - \
$CellContext`c^2)^2, (-4) $CellContext`b^4 $CellContext`c^4 ($CellContext`b^2 - \
$CellContext`c^2)^2}, "   ", 
   Style[$CellContext`a, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.8610979210557003`*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"774b31ad-990f-483b-8a41-6c8500eae181"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "964", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["b", "3"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         RowBox[{"3", " ", "b", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "3"]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["b", "3"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         RowBox[{"3", " ", "b", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "3"]}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["b", "3"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         RowBox[{"3", " ", "b", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "3"]}]}], ")"}]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["b", "3"]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["b", "2"], " ", "c"}], "+", 
           RowBox[{"3", " ", "b", " ", 
            SuperscriptBox["c", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["c", "3"]}]}], ")"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"6", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"9", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"14", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"9", " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          SuperscriptBox["b", "3"]}], "+", 
         RowBox[{"9", " ", 
          SuperscriptBox["b", "2"], " ", "c"}], "+", 
         RowBox[{"9", " ", "b", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["c", "3"]}]}], ")"}]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 964, "   ", {
   2 $CellContext`b^4 + 3 $CellContext`b^3 $CellContext`c + 
    6 $CellContext`b^2 $CellContext`c^2 + 3 $CellContext`b $CellContext`c^3 + 
    2 $CellContext`c^4 + $CellContext`a (2 $CellContext`b^3 + 
      3 $CellContext`b^2 $CellContext`c + 3 $CellContext`b $CellContext`c^2 + 
      2 $CellContext`c^3), 2 $CellContext`b^4 + 
    3 $CellContext`b^3 $CellContext`c + 4 $CellContext`b^2 $CellContext`c^2 + 
    3 $CellContext`b $CellContext`c^3 + 
    2 $CellContext`c^4 + $CellContext`a (2 $CellContext`b^3 + 
      3 $CellContext`b^2 $CellContext`c + 3 $CellContext`b $CellContext`c^2 + 
      2 $CellContext`c^3), 2 $CellContext`b^4 + 
    3 $CellContext`b^3 $CellContext`c + 4 $CellContext`b^2 $CellContext`c^2 + 
    3 $CellContext`b $CellContext`c^3 + 
    2 $CellContext`c^4 + $CellContext`a (2 $CellContext`b^3 + 
      3 $CellContext`b^2 $CellContext`c + 3 $CellContext`b $CellContext`c^2 + 
      2 $CellContext`c^3)}, "   ", 
   Style[$CellContext`a (2 $CellContext`b^4 + 
     3 $CellContext`b^3 $CellContext`c + 4 $CellContext`b^2 $CellContext`c^2 + 
     3 $CellContext`b $CellContext`c^3 + 
     2 $CellContext`c^4 + $CellContext`a (2 $CellContext`b^3 + 
       3 $CellContext`b^2 $CellContext`c + 3 $CellContext`b $CellContext`c^2 + 
       2 $CellContext`c^3))/(6 $CellContext`b^4 + 
    9 $CellContext`b^3 $CellContext`c + 14 $CellContext`b^2 $CellContext`c^2 + 
    9 $CellContext`b $CellContext`c^3 + 
    6 $CellContext`c^4 + $CellContext`a (6 $CellContext`b^3 + 
      9 $CellContext`b^2 $CellContext`c + 9 $CellContext`b $CellContext`c^2 + 
      6 $CellContext`c^3)), 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.857625569025097*^9, {3.857625646823153*^9, 3.857625668769244*^9}, 
   3.859025991424939*^9, 3.859909214840852*^9, 3.86109792313623*^9},
 CellLabel->
  "During evaluation of \
In[8]:=",ExpressionUUID->"910a2eaa-9070-4731-a9b3-156868ec3d68"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["liesOnMedian"], "Input",
 CellLabel->"In[12]:=",ExpressionUUID->"54ce18c6-d528-4685-9991-19db1b739853"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "5", ",", "20", ",", "21", ",", "22", ",", "23", ",", "95", ",", 
   "140", ",", "199", ",", "233", ",", "237", ",", "253", ",", "280", ",", 
   "347", ",", "376", ",", "377", ",", "379", ",", "381", ",", "382", ",", 
   "383", ",", "401", ",", "402", ",", "404", ",", "405", ",", "409", ",", 
   "411", ",", "413", ",", "416", ",", "439", ",", "442", ",", "443", ",", 
   "446", ",", "448", ",", "449", ",", "452", ",", "453", ",", "474", ",", 
   "546", ",", "547", ",", "548", ",", "549", ",", "550", ",", "631", ",", 
   "632", ",", "851", ",", "853", ",", "854", ",", "855", ",", "857", ",", 
   "858", ",", "859", ",", "861", ",", "863", ",", "864", ",", "865", ",", 
   "866", ",", "867", ",", "868", ",", "925", ",", "964"}], "}"}]], "Output",
 CellChangeTimes->{3.8575876991332817`*^9, 3.8576255694726973`*^9, 
  3.857625651702629*^9, 3.857626935315383*^9, 3.859026149351355*^9, 
  3.8599093737051773`*^9, 3.861097924615768*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"64181869-f189-428e-a9e8-d85137825471"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["rational"], "Input",
 CellChangeTimes->{{3.857591043077764*^9, 3.857591044877014*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"9b0cb274-4df1-455a-add5-1a58f07de223"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", 
     FractionBox["3", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"20", ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"22", ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"23", ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"95", ",", 
     FractionBox["5", "4"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"97", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"122", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"123", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"127", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"131", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"140", ",", 
     FractionBox["4", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"216", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"233", ",", 
     FractionBox["5", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"253", ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"268", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"280", ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"339", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"347", ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"376", ",", 
     FractionBox["3", "4"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"381", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"382", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"401", ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"402", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"408", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"417", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"418", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"426", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"440", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"441", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"454", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"464", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"465", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"466", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"546", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"547", ",", 
     FractionBox["12", "7"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"548", ",", 
     FractionBox["4", "5"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"549", ",", 
     FractionBox["6", "5"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"550", ",", 
     FractionBox["2", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"577", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"631", ",", 
     FractionBox["5", "4"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"632", ",", 
     FractionBox["10", "7"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"828", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"852", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"856", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"858", ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"925", ",", 
     FractionBox["1", "2"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8575910460340433`*^9, 3.857592021705902*^9, 
  3.857625569506566*^9, 3.857626939390044*^9, 3.859026149360941*^9, 
  3.859909373718733*^9, 3.861097924628339*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"42125a45-8754-462b-ba84-f36534e49b33"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["coincidesWithE"], "Input",
 CellLabel->"In[14]:=",ExpressionUUID->"554b814f-00b0-4a8b-95c8-add2a6a0fdff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3", ",", "97", ",", "122", ",", "123", ",", "127", ",", "131", ",", "216", 
   ",", "268", ",", "339", ",", "408", ",", "417", ",", "418", ",", "426", 
   ",", "440", ",", "441", ",", "454", ",", "464", ",", "465", ",", "466", 
   ",", "577", ",", "828", ",", "852", ",", "856"}], "}"}]], "Output",
 CellChangeTimes->{3.857625604455371*^9, 3.85762694328474*^9, 
  3.859026149398769*^9, 3.859909373819765*^9, 3.8610979247261143`*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"33668292-374e-4110-9668-0743227781f2"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["X(102) lies on angle bisector", "Subsection",
 CellChangeTimes->{{3.858791069881806*^9, 3.85879107882787*^9}, {
   3.859404818267939*^9, 3.8594048240996017`*^9}, 
   3.8610921440084352`*^9},ExpressionUUID->"dbb1befd-a849-425c-9ea4-\
b9d195bfaf81"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f102", "[", 
   RowBox[{"a_", ",", "b_", ",", "c_"}], "]"}], ":=", 
  RowBox[{
   SuperscriptBox["a", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox["b", "4"], "-", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", "c"}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["b", "2"], " ", "c"}], "-", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", "c"}], "+", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     RowBox[{"2", " ", "a", " ", "b", " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{"a", " ", 
      SuperscriptBox["c", "3"]}], "+", 
     RowBox[{"b", " ", 
      SuperscriptBox["c", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["c", "4"]}]}], ")"}], " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "4"]}], ")"}], "/", "a"}]}]}]], "Input",
 CellChangeTimes->{{3.857740503942257*^9, 3.857740526901718*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"306bc053-b366-4a7d-aed9-13d10022fc9a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"f102", "[", 
     RowBox[{"a", ",", "b", ",", "c"}], "]"}], "-", 
    RowBox[{"f102", "[", 
     RowBox[{"b", ",", "a", ",", "c"}], "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "^", "2"}], "+", 
     RowBox[{"b", "^", "2"}]}], "\[Equal]", 
    RowBox[{"c", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.857727925741263*^9, 3.857727960893217*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"c59c02c8-1f35-487d-91fc-7de37b4179a2"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.857727961958148*^9, 3.857728085897991*^9, 
  3.85774054970686*^9, 3.8577405989880857`*^9, 3.85902614944405*^9, 
  3.8599093739272947`*^9, 3.86109792482961*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"c2189221-d3e3-4148-bcf1-d063c91ac4bb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"f102", "[", 
     RowBox[{"a", ",", "b", ",", "c"}], "]"}], "-", 
    RowBox[{"f102", "[", 
     RowBox[{"b", ",", "a", ",", "c"}], "]"}]}], "]"}], "//", 
  "Factor"}]], "Input",
 CellChangeTimes->{{3.85774060852573*^9, 3.857740630765485*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"d5187fbc-36b2-4e24-b3ea-6a94f77efc90"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"a", "-", "b"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"a", "+", "b", "+", "c"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["a", "2"], "+", 
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["a", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    SuperscriptBox["b", "4"], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["b", "3"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", "a", " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["c", "4"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.8577406096715603`*^9, 3.8577406315947857`*^9}, 
   3.859026149488964*^9, 3.859909374026567*^9, 3.8610979249259567`*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"2ae7d054-9bbc-43ac-ab21-56ecaaf5d104"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Lemmas about Isosceles Triangles", "Subsection",
 CellChangeTimes->{{3.859445076022099*^9, 3.859445084999343*^9}, {
  3.859445221884012*^9, 3.859445228707782*^9}, {3.859445273990197*^9, 
  3.8594452945879297`*^9}, {3.859445819846087*^9, 
  3.85944583211761*^9}},ExpressionUUID->"7f694f99-2216-46d0-b435-\
d277881be957"],

Cell[CellGroupData[{

Cell["Code", "Subsubsection",
 CellChangeTimes->{{3.859446068161223*^9, 
  3.859446074114582*^9}},ExpressionUUID->"3592fc2f-0498-4a33-8241-\
5a0cecd78f72"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"coincidesWithM", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"onLineAtInfinity", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"atInfinitWhenIsosceles", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"transcendental", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"coincidesWithA", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rational", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptA", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptM", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"n", "=", "1"}], ",", 
    RowBox[{"n", "\[LessEqual]", "1000"}], ",", 
    RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"coords", "=", 
      RowBox[{"ETC1", "[", 
       RowBox[{"[", 
        RowBox[{"n", ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"ignore", " ", "transcendental", " ", "centers"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"coords", "\[Equal]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"transcendental", ",", "n"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
      RowBox[{"ptX", "=", 
       RowBox[{"coords", "/.", 
        RowBox[{"S", "->", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}]}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"ignore", " ", "points", " ", "at", " ", "infinity"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{"u", "+", "v", "+", "w"}], "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"onLineAtInfinity", ",", "n"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Continue", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{
          RowBox[{"u", "+", "v", "+", "w"}], "/.", 
          RowBox[{"c", "\[Rule]", "b"}]}], "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"atInfinitWhenIsosceles", ",", "n"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Continue", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{"u", "/.", 
          RowBox[{"c", "\[Rule]", "b"}]}], "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"coincidesWithM", ",", "n"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Continue", "[", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"ratio", " ", "=", " ", 
       RowBox[{"XM", "/", "AM"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"ratio", "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"u", "/", 
         RowBox[{"(", 
          RowBox[{"u", "+", 
           RowBox[{"2", "v"}]}], ")"}]}], "/.", 
        RowBox[{"c", "\[Rule]", "b"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"(*", " ", 
      RowBox[{
      "ignore", " ", "points", " ", "that", " ", "coincide", " ", "with", " ",
        "A"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ratio", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"coincidesWithA", ",", "n"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Continue", "[", "]"}]}]}], "]"}], "\[IndentingNewLine]", ";",
      "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"NumericQ", "[", "ratio", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<n=\>\"", ",", "n", ",", "\"\<   \>\"", ",", "ptX", ",", 
          "\"\<   XM/AM=\>\"", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"ratio", ",", "Red"}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"rational", ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "ratio"}], "}"}]}], "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.85823859791429*^9, 3.85823861081002*^9}, {
   3.858238666170635*^9, 3.858238671842203*^9}, {3.8582387034349937`*^9, 
   3.858238879946652*^9}, {3.8582389657328787`*^9, 3.8582389797310667`*^9}, {
   3.8582392486772118`*^9, 3.8582392767083197`*^9}, {3.858239316526222*^9, 
   3.858239316940321*^9}, {3.8582393919104853`*^9, 3.858239410404519*^9}, {
   3.858331060436795*^9, 3.8583310835636053`*^9}, {3.8583311335560627`*^9, 
   3.8583312056613417`*^9}, {3.858331353269075*^9, 3.858331361757183*^9}, {
   3.85833142168615*^9, 3.858331476637041*^9}, {3.8583315261749496`*^9, 
   3.858331647885808*^9}, 3.858331679870125*^9, {3.858331841511511*^9, 
   3.858331889799799*^9}, {3.858331948776697*^9, 3.858331950886672*^9}, {
   3.858332138091186*^9, 3.858332168351516*^9}, {3.8583598800744762`*^9, 
   3.858359881256414*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"2174a73f-b1f9-4467-aa7a-16b96a1a56b4"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "3"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm["n=", 2, "   ", {1, 1, 1}, "   XM/AM=", 
   Style[
    Rational[1, 3], 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8582388810740433`*^9, 3.858238982017474*^9, 3.858239293903975*^9, 
   3.858239324800816*^9, 3.8582394196432247`*^9, 3.8583316812055197`*^9, 
   3.858331891465007*^9, 3.858331952268735*^9, {3.858332141041862*^9, 
   3.858332169750382*^9}, 3.858359883598342*^9, 3.859026180337306*^9, 
   3.8599093741520576`*^9, 3.861097924951191*^9},
 CellLabel->
  "During evaluation of \
In[18]:=",ExpressionUUID->"4fa7a0c0-e321-4e38-aced-94e41f5cdfcd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "148", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 148, 
   "   ", {$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 + 
    3 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 - \
$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
    3 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 - \
$CellContext`c^4, -$CellContext`a^4 + 
    3 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8582388810740433`*^9, 3.858238982017474*^9, 3.858239293903975*^9, 
   3.858239324800816*^9, 3.8582394196432247`*^9, 3.8583316812055197`*^9, 
   3.858331891465007*^9, 3.858331952268735*^9, {3.858332141041862*^9, 
   3.858332169750382*^9}, 3.858359883598342*^9, 3.859026180337306*^9, 
   3.8599093741520576`*^9, 3.8610979254708433`*^9},
 CellLabel->
  "During evaluation of \
In[18]:=",ExpressionUUID->"66ecab55-a542-4b63-8a4b-43294fc2e036"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "149", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "3"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", "b", " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "3"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "3"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", "b", " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "3"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "3"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", "b", " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "3"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 149, 
   "   ", {$CellContext`a^3 - $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c + \
$CellContext`b^2 $CellContext`c + $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2 - $CellContext`c^3, -$CellContext`a^3 + \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c - $CellContext`b^2 $CellContext`c + \
$CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2 - \
$CellContext`c^3, -$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c + \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2 + $CellContext`c^3}, "   XM/AM=", 
   Style[-1, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8582388810740433`*^9, 3.858238982017474*^9, 3.858239293903975*^9, 
   3.858239324800816*^9, 3.8582394196432247`*^9, 3.8583316812055197`*^9, 
   3.858331891465007*^9, 3.858331952268735*^9, {3.858332141041862*^9, 
   3.858332169750382*^9}, 3.858359883598342*^9, 3.859026180337306*^9, 
   3.8599093741520576`*^9, 3.861097925479149*^9},
 CellLabel->
  "During evaluation of \
In[18]:=",ExpressionUUID->"608e0e89-dbca-4e28-925a-b194be006c6d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "150", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 150, 
   "   ", {$CellContext`a^4 - $CellContext`a^3 $CellContext`b + \
$CellContext`a $CellContext`b^3 - $CellContext`b^4 - $CellContext`a^3 \
$CellContext`c + $CellContext`a^2 $CellContext`b $CellContext`c - \
$CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c^2 + \
$CellContext`a $CellContext`c^3 + $CellContext`b $CellContext`c^3 - \
$CellContext`c^4, -$CellContext`a^4 + $CellContext`a^3 $CellContext`b - \
$CellContext`a $CellContext`b^3 + $CellContext`b^4 + $CellContext`a^3 \
$CellContext`c - $CellContext`a^2 $CellContext`b $CellContext`c + \
$CellContext`a $CellContext`b^2 $CellContext`c - $CellContext`b^3 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c^2 + \
$CellContext`a $CellContext`c^3 + $CellContext`b $CellContext`c^3 - \
$CellContext`c^4, -$CellContext`a^4 + $CellContext`a^3 $CellContext`b + \
$CellContext`a $CellContext`b^3 - $CellContext`b^4 + $CellContext`a^3 \
$CellContext`c - $CellContext`a^2 $CellContext`b $CellContext`c - \
$CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c + $CellContext`a $CellContext`b $CellContext`c^2 - \
$CellContext`a $CellContext`c^3 - $CellContext`b $CellContext`c^3 + \
$CellContext`c^4}, "   XM/AM=", 
   Style[-1, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8582388810740433`*^9, 3.858238982017474*^9, 3.858239293903975*^9, 
   3.858239324800816*^9, 3.8582394196432247`*^9, 3.8583316812055197`*^9, 
   3.858331891465007*^9, 3.858331952268735*^9, {3.858332141041862*^9, 
   3.858332169750382*^9}, 3.858359883598342*^9, 3.859026180337306*^9, 
   3.8599093741520576`*^9, 3.861097925483327*^9},
 CellLabel->
  "During evaluation of \
In[18]:=",ExpressionUUID->"f84d67bb-a0a7-464c-8728-9b8e2f2aa65c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "290", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", "3"]}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 290, 
   "   ", {$CellContext`b^2 $CellContext`c^2 ($CellContext`a^4 + \
$CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2) ($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), $CellContext`a^2 \
$CellContext`c^2 ($CellContext`a^4 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) (-$CellContext`a^2 \
$CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 + \
$CellContext`c^4), $CellContext`a^2 $CellContext`b^2 (-$CellContext`a^2 \
$CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 + \
$CellContext`c^4) ($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[-1, 3], 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8582388810740433`*^9, 3.858238982017474*^9, 3.858239293903975*^9, 
   3.858239324800816*^9, 3.8582394196432247`*^9, 3.8583316812055197`*^9, 
   3.858331891465007*^9, 3.858331952268735*^9, {3.858332141041862*^9, 
   3.858332169750382*^9}, 3.858359883598342*^9, 3.859026180337306*^9, 
   3.8599093741520576`*^9, 3.861097928972438*^9},
 CellLabel->
  "During evaluation of \
In[18]:=",ExpressionUUID->"4b40fde0-48d1-4a47-9b92-a0db020a8e18"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "402", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "8"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "8"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        SuperscriptBox["b", "8"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 402, 
   "   ", {(2 $CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4) \
($CellContext`a^8 - $CellContext`a^6 $CellContext`b^2 - 
     2 $CellContext`a^4 $CellContext`b^4 + 
     3 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 - \
$CellContext`a^6 $CellContext`c^2 + 
     5 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - $CellContext`b^6 \
$CellContext`c^2 - 2 $CellContext`a^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     4 $CellContext`b^4 $CellContext`c^4 + 
     3 $CellContext`a^2 $CellContext`c^6 - $CellContext`b^2 $CellContext`c^6 - \
$CellContext`c^8), (-$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 - \
$CellContext`c^4) (-$CellContext`a^8 + 3 $CellContext`a^6 $CellContext`b^2 - 
     2 $CellContext`a^4 $CellContext`b^4 - $CellContext`a^2 $CellContext`b^6 + \
$CellContext`b^8 - $CellContext`a^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
     5 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - $CellContext`b^6 \
$CellContext`c^2 + 4 $CellContext`a^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     2 $CellContext`b^4 $CellContext`c^4 - $CellContext`a^2 $CellContext`c^6 + 
     3 $CellContext`b^2 $CellContext`c^6 - $CellContext`c^8), \
(-$CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`c^4) (-$CellContext`a^8 - $CellContext`a^6 \
$CellContext`b^2 + 
     4 $CellContext`a^4 $CellContext`b^4 - $CellContext`a^2 $CellContext`b^6 - \
$CellContext`b^8 + 3 $CellContext`a^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + 
     3 $CellContext`b^6 $CellContext`c^2 - 
     2 $CellContext`a^4 $CellContext`c^4 + 
     5 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     2 $CellContext`b^4 $CellContext`c^4 - $CellContext`a^2 $CellContext`c^6 - \
$CellContext`b^2 $CellContext`c^6 + $CellContext`c^8)}, "   XM/AM=", 
   Style[
    Rational[1, 2], 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8582388810740433`*^9, 3.858238982017474*^9, 3.858239293903975*^9, 
   3.858239324800816*^9, 3.8582394196432247`*^9, 3.8583316812055197`*^9, 
   3.858331891465007*^9, 3.858331952268735*^9, {3.858332141041862*^9, 
   3.858332169750382*^9}, 3.858359883598342*^9, 3.859026180337306*^9, 
   3.8599093741520576`*^9, 3.861097929907825*^9},
 CellLabel->
  "During evaluation of \
In[18]:=",ExpressionUUID->"d3d3bdd8-eadb-44b9-8bc8-90a5b9a7aa6d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "620", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 620, "   ", {
   2 $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + 2 $CellContext`b^4 - 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 + \
$CellContext`b^4 - 2 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + 2 $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[1, 2], 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8582388810740433`*^9, 3.858238982017474*^9, 3.858239293903975*^9, 
   3.858239324800816*^9, 3.8582394196432247`*^9, 3.8583316812055197`*^9, 
   3.858331891465007*^9, 3.858331952268735*^9, {3.858332141041862*^9, 
   3.858332169750382*^9}, 3.858359883598342*^9, 3.859026180337306*^9, 
   3.8599093741520576`*^9, 3.8610979319908247`*^9},
 CellLabel->
  "During evaluation of \
In[18]:=",ExpressionUUID->"54591df9-04f6-456e-afd7-32c1ecd2f74a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "671", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", "3"]}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 671, 
   "   ", {($CellContext`a^2 + $CellContext`b^2 - 
     2 $CellContext`c^2) ($CellContext`a^2 - 
     2 $CellContext`b^2 + $CellContext`c^2), ($CellContext`a^2 + \
$CellContext`b^2 - 
     2 $CellContext`c^2) ((-2) $CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2), ($CellContext`a^2 - 
     2 $CellContext`b^2 + $CellContext`c^2) ((-2) $CellContext`a^2 + \
$CellContext`b^2 + $CellContext`c^2)}, "   XM/AM=", 
   Style[
    Rational[-1, 3], 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8582388810740433`*^9, 3.858238982017474*^9, 3.858239293903975*^9, 
   3.858239324800816*^9, 3.8582394196432247`*^9, 3.8583316812055197`*^9, 
   3.858331891465007*^9, 3.858331952268735*^9, {3.858332141041862*^9, 
   3.858332169750382*^9}, 3.858359883598342*^9, 3.859026180337306*^9, 
   3.8599093741520576`*^9, 3.861097932512117*^9},
 CellLabel->
  "During evaluation of \
In[18]:=",ExpressionUUID->"af1ad1e6-336c-426b-b55b-450788ccd2e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "903", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", 
        RowBox[{"2", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", 
        RowBox[{"2", " ", "b"}], "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", 
        RowBox[{"2", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", 
        RowBox[{"2", " ", "b"}], "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}]}], 
    "}"}], "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", "3"]}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 903, 
   "   ", {($CellContext`a + $CellContext`b - 
     2 $CellContext`c) ($CellContext`a - 
     2 $CellContext`b + $CellContext`c), ($CellContext`a + $CellContext`b - 
     2 $CellContext`c) ((-2) $CellContext`a + $CellContext`b + \
$CellContext`c), ($CellContext`a - 
     2 $CellContext`b + $CellContext`c) ((-2) $CellContext`a + $CellContext`b + \
$CellContext`c)}, "   XM/AM=", 
   Style[
    Rational[-1, 3], 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8582388810740433`*^9, 3.858238982017474*^9, 3.858239293903975*^9, 
   3.858239324800816*^9, 3.8582394196432247`*^9, 3.8583316812055197`*^9, 
   3.858331891465007*^9, 3.858331952268735*^9, {3.858332141041862*^9, 
   3.858332169750382*^9}, 3.858359883598342*^9, 3.859026180337306*^9, 
   3.8599093741520576`*^9, 3.861097932927553*^9},
 CellLabel->
  "During evaluation of \
In[18]:=",ExpressionUUID->"de91ae73-49e0-4a61-87b4-9da43eca257e"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Lemma 5.11", "Subsubsection",
 CellChangeTimes->{{3.8594453686306143`*^9, 3.8594453774601097`*^9}, {
  3.8594458978974247`*^9, 
  3.859445905493806*^9}},ExpressionUUID->"8d28747c-75c4-4366-8c07-\
c55bccddb632"],

Cell[CellGroupData[{

Cell[BoxData["coincidesWithA"], "Input",
 CellChangeTimes->{{3.858331728301318*^9, 3.858331735140511*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"5c83edd7-f0f5-4b4d-a147-4ccc1ecc1f5c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "59", ",", "99", ",", "100", ",", "101", ",", "107", ",", "108", ",", "109",
    ",", "110", ",", "112", ",", "162", ",", "163", ",", "190", ",", "249", 
   ",", "250", ",", "476", ",", "643", ",", "644", ",", "645", ",", "646", 
   ",", "648", ",", "651", ",", "653", ",", "655", ",", "658", ",", "660", 
   ",", "662", ",", "664", ",", "666", ",", "668", ",", "670", ",", "677", 
   ",", "681", ",", "685", ",", "687", ",", "689", ",", "691", ",", "692", 
   ",", "765", ",", "769", ",", "771", ",", "773", ",", "777", ",", "779", 
   ",", "781", ",", "783", ",", "785", ",", "787", ",", "789", ",", "791", 
   ",", "793", ",", "795", ",", "797", ",", "799", ",", "803", ",", "805", 
   ",", "807", ",", "809", ",", "811", ",", "813", ",", "815", ",", "817", 
   ",", "819", ",", "823", ",", "825", ",", "827", ",", "831", ",", "833", 
   ",", "835", ",", "839", ",", "874", ",", "877", ",", "880", ",", "883", 
   ",", "886", ",", "889", ",", "892", ",", "898", ",", "901", ",", "906", 
   ",", "907", ",", "919", ",", "925", ",", "927", ",", "929", ",", "930", 
   ",", "931", ",", "932", ",", "933", ",", "934", ",", "935"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.858331736185823*^9, 3.858332195471545*^9, 
  3.8590261882992573`*^9, 3.85990938211487*^9, 3.861097933214198*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"c25cee09-4cdf-4c2f-81b2-205788e9684e"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Lemma 5.12", "Subsubsection",
 CellChangeTimes->{{3.8594453350151377`*^9, 3.859445346092084*^9}, {
  3.859445882051116*^9, 
  3.859445891101851*^9}},ExpressionUUID->"0c41d9be-0cc4-4472-b345-\
b69011c186c7"],

Cell[CellGroupData[{

Cell[BoxData["coincidesWithM"], "Input",
 CellLabel->"In[28]:=",ExpressionUUID->"9d5ae49b-cb60-4a60-abe0-66b0cab9790e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "11", ",", "115", ",", "116", ",", "122", ",", "123", ",", "124", ",", 
   "125", ",", "127", ",", "130", ",", "134", ",", "135", ",", "136", ",", 
   "137", ",", "139", ",", "244", ",", "245", ",", "246", ",", "247", ",", 
   "338", ",", "339", ",", "865", ",", "866", ",", "867", ",", "868"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.858241236301021*^9, 3.858331717152158*^9, 
  3.858332189871676*^9, 3.859026188290164*^9, 3.859909382125209*^9, 
  3.861097933222493*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"a6a9de13-18e9-40e1-82e5-0f451a412796"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Lemma 5.13", "Subsubsection",
 CellChangeTimes->{{3.859445420310774*^9, 3.859445426996429*^9}, {
  3.859445958498151*^9, 
  3.859445966518209*^9}},ExpressionUUID->"8c5cc360-a212-4ed8-9aa8-\
3e86e887ee9d"],

Cell[CellGroupData[{

Cell[BoxData["atInfinitWhenIsosceles"], "Input",
 CellLabel->"In[29]:=",ExpressionUUID->"cf2286b8-72f0-4c7a-8c11-f9111d10bdba"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "351", ",", "647", ",", "649", ",", "650", ",", "652", ",", "654", ",", 
   "656", ",", "657", ",", "659", ",", "661", ",", "663", ",", "665", ",", 
   "667", ",", "669", ",", "676", ",", "684", ",", "686", ",", "693", ",", 
   "764", ",", "770", ",", "798", ",", "810", ",", "822", ",", "850", ",", 
   "875", ",", "876", ",", "878", ",", "879", ",", "881", ",", "882", ",", 
   "884", ",", "885", ",", "887", ",", "890", ",", "905"}], "}"}]], "Output",
 CellChangeTimes->{3.8583317601366863`*^9, 3.8583319096033287`*^9, 
  3.8583319671088057`*^9, 3.858332158416903*^9, 3.8583322201885433`*^9, 
  3.8590261883861437`*^9, 3.859909382217884*^9, 3.8610979332623568`*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"4087c3ff-4390-4d7f-938f-7dbaae67c307"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["On Line at Infinity", "Subsubsection",
 CellChangeTimes->{{3.85944591621681*^9, 
  3.859445923902027*^9}},ExpressionUUID->"45a91fab-27f0-4050-8126-\
7564dbe45784"],

Cell[CellGroupData[{

Cell[BoxData["onLineAtInfinity"], "Input",
 CellLabel->"In[30]:=",ExpressionUUID->"d45c2ca2-d9e4-4c4b-96db-3b090776d3fd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "30", ",", "511", ",", "512", ",", "513", ",", "514", ",", "515", ",", 
   "516", ",", "517", ",", "518", ",", "519", ",", "520", ",", "521", ",", 
   "522", ",", "523", ",", "524", ",", "525", ",", "526", ",", "527", ",", 
   "528", ",", "529", ",", "530", ",", "531", ",", "532", ",", "533", ",", 
   "534", ",", "535", ",", "536", ",", "537", ",", "538", ",", "539", ",", 
   "540", ",", "541", ",", "542", ",", "543", ",", "544", ",", "545", ",", 
   "674", ",", "680", ",", "688", ",", "690", ",", "696", ",", "698", ",", 
   "700", ",", "702", ",", "704", ",", "706", ",", "708", ",", "710", ",", 
   "712", ",", "714", ",", "716", ",", "718", ",", "720", ",", "722", ",", 
   "724", ",", "726", ",", "730", ",", "732", ",", "734", ",", "736", ",", 
   "740", ",", "742", ",", "744", ",", "746", ",", "752", ",", "754", ",", 
   "758", ",", "760", ",", "766", ",", "768", ",", "772", ",", "776", ",", 
   "778", ",", "780", ",", "782", ",", "784", ",", "786", ",", "788", ",", 
   "790", ",", "792", ",", "794", ",", "796", ",", "802", ",", "804", ",", 
   "806", ",", "808", ",", "812", ",", "814", ",", "816", ",", "818", ",", 
   "824", ",", "826", ",", "830", ",", "832", ",", "834", ",", "838", ",", 
   "888", ",", "891", ",", "900", ",", "912", ",", "916", ",", "918", ",", 
   "924", ",", "926", ",", "928", ",", "952", ",", "971"}], "}"}]], "Output",
 CellChangeTimes->{3.858331749174711*^9, 3.858332210629137*^9, 
  3.859026188338099*^9, 3.859909382229315*^9, 3.8610979332717047`*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"66b8f85f-c297-4018-976b-e133360ea132"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Transcendental", "Subsubsection",
 CellChangeTimes->{{3.859445937776704*^9, 
  3.8594459469135027`*^9}},ExpressionUUID->"59324dc0-4f8b-49b9-8a79-\
4259442ad5b3"],

Cell[CellGroupData[{

Cell[BoxData["transcendental"], "Input",
 CellChangeTimes->{{3.858331763374083*^9, 3.85833177063699*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"0b14d143-dc6c-419b-b6db-272b3e063e8b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "356", ",", "357", ",", "358", ",", "359", ",", "360", ",", "368", ",", 
   "369", ",", "370", ",", "848"}], "}"}]], "Output",
 CellChangeTimes->{3.85833177269938*^9, 3.8583322156324463`*^9, 
  3.859026188346973*^9, 3.859909382269559*^9, 3.86109793331126*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"19b49d1c-e7c1-42bb-984d-bf389796cd06"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Rational", "Subsubsection",
 CellChangeTimes->{{3.8594459827928257`*^9, 
  3.8594459914495*^9}},ExpressionUUID->"eed99e70-3dba-4177-be17-e45b82903e47"],

Cell[CellGroupData[{

Cell[BoxData["rational"], "Input",
 CellLabel->"In[32]:=",ExpressionUUID->"6b9c45d9-fd46-4d07-a773-7601139e9543"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2", ",", 
     FractionBox["1", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"148", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"149", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"150", ",", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"290", ",", 
     RowBox[{"-", 
      FractionBox["1", "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"402", ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"620", ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"671", ",", 
     RowBox[{"-", 
      FractionBox["1", "3"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"903", ",", 
     RowBox[{"-", 
      FractionBox["1", "3"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8583317869725113`*^9, 3.858332233644271*^9, 
  3.859026188395537*^9, 3.85990938227991*^9, 3.861097933320671*^9},
 CellLabel->"Out[32]=",ExpressionUUID->"14fecc82-ad46-428f-837b-197ddc35acef"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"all", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"i", ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "1000"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"other", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
    "coincidesWithM", ",", "coincidesWithA", ",", "onLineAtInfinity", ",", 
     "transcendental", ",", "atInfinitWhenIsosceles"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"none", "=", 
   RowBox[{"Complement", "[", 
    RowBox[{"all", ",", "other"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.858332254199299*^9, 3.85833234927109*^9}, 
   3.858332386272368*^9},
 CellLabel->"In[33]:=",ExpressionUUID->"a7008ab6-a0de-4671-86f5-e4001438a3eb"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Section 7 (Diagonal Point)", "Section",
 CellChangeTimes->{{3.8594049965053043`*^9, 3.859405006959635*^9}, {
  3.859405114436821*^9, 
  3.8594051228924417`*^9}},ExpressionUUID->"470861c6-3446-4848-9c07-\
bf0f9b32f469"],

Cell[CellGroupData[{

Cell["Section 7.1 - General Quadrilaterals", "Subsection",
 CellChangeTimes->{{3.859405167493054*^9, 3.859405189953619*^9}, {
   3.859405283973345*^9, 3.859405287892915*^9}, 
   3.861083890286337*^9},ExpressionUUID->"9d82def8-3fac-42a3-817b-\
114b3e835fcd"],

Cell[CellGroupData[{

Cell["Theorem 7.1", "Subsubsection",
 CellChangeTimes->{{3.861083874246047*^9, 
  3.861083884323084*^9}},ExpressionUUID->"64765008-1a29-4e9f-ab64-\
b3955dcd556a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"QA", "-", 
    RowBox[{"CT", " ", "coordinates"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  
  RowBox[{
   RowBox[{
    RowBox[{"Clear", "[", 
     RowBox[{"p", ",", "q", ",", "r"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ptA", "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ptB", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ptC", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ptD", "=", 
     RowBox[{"normed", "[", 
      RowBox[{"{", 
       RowBox[{"p", ",", "q", ",", "r"}], "}"}], "]"}]}], ";"}]}]}]], "Input",\

 CellChangeTimes->{{3.857821799077696*^9, 3.857821847212615*^9}, {
  3.8578219118616257`*^9, 3.857821922421125*^9}, {3.857822075245823*^9, 
  3.8578220876217203`*^9}, {3.85782866926807*^9, 3.857828683971848*^9}, {
  3.857830483378106*^9, 3.857830486464405*^9}, {3.857830801522435*^9, 
  3.8578308063216476`*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"4ecfe8d7-059a-474a-9395-a78585538ea2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x20", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["a", "4"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "-", 
     SuperscriptBox["b", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["c", "4"]}], ",", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "4"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["b", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["c", "4"]}], ",", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "-", 
     SuperscriptBox["b", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["c", "4"]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.85782214283048*^9, 3.857822144815009*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"575920e1-afc7-4733-889e-249b92cd939a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["a", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    SuperscriptBox["b", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    SuperscriptBox["c", "4"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["b", "4"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    SuperscriptBox["c", "4"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    SuperscriptBox["b", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["c", "4"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8578221468457413`*^9, 3.8578304906481028`*^9, 
  3.857899078752836*^9, 3.859026149588591*^9, 3.859909382416641*^9, 
  3.861097933379541*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"41071dad-4586-4e15-bd8e-858653dd6762"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"line", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"u1_", ",", "v1_", ",", "w1_"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"u2_", ",", "v2_", ",", "w2_"}], "}"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Det", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"u1", ",", "v1", ",", "w1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"u2", ",", "v2", ",", "w2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "}"}], "]"}], "\[Equal]", 
   "0"}]}]], "Input",
 CellChangeTimes->{{3.8578226329358377`*^9, 3.857822735792715*^9}, {
  3.857822783545182*^9, 3.857822786431864*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"c8f366ff-0239-44cc-af57-aead5947df52"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lineAC", "=", 
  RowBox[{"line", "[", 
   RowBox[{"ptA", ",", "ptC"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.857822741807932*^9, 3.857822769487686*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"dfa843dd-4249-4cb9-be50-67fbe28e24be"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "y"}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.857822770643796*^9, 3.857822790473426*^9}, 
   3.857831817804304*^9, 3.859026149632494*^9, 3.859909382521009*^9, 
   3.8610979334259567`*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"adbedf3a-21d3-4da9-8ef9-80c9854d839c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lineBD", "=", 
  RowBox[{"line", "[", 
   RowBox[{"ptB", ",", "ptD"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.857822801408043*^9, 3.857822808904139*^9}},
 CellLabel->"In[44]:=",ExpressionUUID->"5b36009d-8ab9-4e5b-8739-4736dc02c121"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"r", " ", "x"}], 
    RowBox[{"p", "+", "q", "+", "r"}]], "-", 
   FractionBox[
    RowBox[{"p", " ", "z"}], 
    RowBox[{"p", "+", "q", "+", "r"}]]}], "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{3.8578228104902143`*^9, 3.8578318210093307`*^9, 
  3.857833309241169*^9, 3.8590261496415157`*^9, 3.859909382530648*^9, 
  3.861097933435483*^9},
 CellLabel->"Out[44]=",ExpressionUUID->"a65f9d0f-9424-4c77-b9f4-61449db61722"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ans", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"lineAC", ",", "lineBD"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], "//", 
   "Quiet"}]}]], "Input",
 CellChangeTimes->{{3.857822827680702*^9, 3.85782283623978*^9}, {
  3.857822869744315*^9, 3.857822917588708*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"ddd8c2fa-fbeb-44f1-bee4-33dfccb73d3b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"y", "\[Rule]", "0"}], ",", 
    RowBox[{"z", "\[Rule]", 
     FractionBox[
      RowBox[{"r", " ", "x"}], "p"]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.857822899723321*^9, 3.857822918679459*^9}, 
   3.8578318270976553`*^9, 3.8590261496802893`*^9, 3.859909382629826*^9, 
   3.861097933478096*^9},
 CellLabel->"Out[45]=",ExpressionUUID->"e8668853-214b-4c9e-92d0-22134f0eab8a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["ptD"], "Input",
 CellChangeTimes->{{3.857831803422064*^9, 3.8578318042129593`*^9}},
 CellLabel->"In[46]:=",ExpressionUUID->"186439ff-86f1-44a0-a8d9-f3ec25b5e78c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["p", 
    RowBox[{"p", "+", "q", "+", "r"}]], ",", 
   FractionBox["q", 
    RowBox[{"p", "+", "q", "+", "r"}]], ",", 
   FractionBox["r", 
    RowBox[{"p", "+", "q", "+", "r"}]]}], "}"}]], "Output",
 CellChangeTimes->{3.857831805213594*^9, 3.8578326853133802`*^9, 
  3.857899090061749*^9, 3.8590261496890697`*^9, 3.859909382640901*^9, 
  3.861097933487049*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"47b17f17-c67c-46d3-a47e-2da9ab41a3b9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptE", "=", 
  RowBox[{"normed", "[", 
   RowBox[{"{", 
    RowBox[{"p", ",", "0", ",", "r"}], "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.857822930600896*^9, 3.857822988728651*^9}, {
  3.857828692748207*^9, 3.8578286968909616`*^9}, {3.857830495697688*^9, 
  3.8578304980483513`*^9}, {3.857830790138736*^9, 3.8578307944256067`*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"9291d8b1-7f95-4e75-ae2a-a4036117b8a1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["p", 
    RowBox[{"p", "+", "r"}]], ",", "0", ",", 
   FractionBox["r", 
    RowBox[{"p", "+", "r"}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8578229901518383`*^9, 3.857828697936102*^9, 3.857830499128005*^9, {
   3.857830795263682*^9, 3.857830813989064*^9}, 3.857832682358939*^9, 
   3.857833314002297*^9, 3.857898578665101*^9, 3.8578990942327433`*^9, 
   3.859026149728395*^9, 3.859909382737132*^9, 3.861097933528062*^9},
 CellLabel->"Out[47]=",ExpressionUUID->"d4dcdb96-fea5-4c2d-a4de-1e9fe89a0612"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaABC", "=", 
  RowBox[{"baryArea", "[", 
   RowBox[{"ptA", ",", "ptB", ",", "ptC"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.857827314751285*^9, 3.857827349150406*^9}},
 CellLabel->"In[48]:=",ExpressionUUID->"3208da89-5644-4afa-a68a-1d74528a20f5"],

Cell[BoxData["K"], "Output",
 CellChangeTimes->{{3.8578273261494503`*^9, 3.857827352310793*^9}, 
   3.857828708538477*^9, 3.857830506639841*^9, 3.8578333173660173`*^9, 
   3.8590261497735567`*^9, 3.859909382746719*^9, 3.861097933537244*^9},
 CellLabel->"Out[48]=",ExpressionUUID->"393043e2-3140-4b71-83e1-569c55badfea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaCDA", "=", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptC", ",", "ptD", ",", "ptA"}], "]"}], "/.", 
   RowBox[{
    RowBox[{"p", "+", "q", "+", "r"}], "\[Rule]", "1"}]}]}]], "Input",
 CellChangeTimes->{{3.857827354822645*^9, 3.857827384718645*^9}, {
  3.857830214121159*^9, 3.8578302268075533`*^9}},
 CellLabel->"In[49]:=",ExpressionUUID->"0f132a9e-c928-42df-88cb-5010ffa52448"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"K", " ", "q"}], 
   RowBox[{"p", "+", "q", "+", "r"}]]}]], "Output",
 CellChangeTimes->{3.8578273863582373`*^9, 3.857828712406196*^9, 
  3.857830229448584*^9, 3.857830509359467*^9, 3.857833320109062*^9, 
  3.85902614978332*^9, 3.859909382842771*^9, 3.8610979335787573`*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"79132867-195e-4c47-a1e5-07f097530548"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaABCD", "=", 
  RowBox[{
   RowBox[{"areaABC", "+", "areaCDA"}], "//", "Factor"}]}]], "Input",
 CellChangeTimes->{{3.857830194192675*^9, 3.8578302431515102`*^9}},
 CellLabel->"In[50]:=",ExpressionUUID->"b451f244-a13e-4e1f-9218-9b8d9ccba488"],

Cell[BoxData[
 FractionBox[
  RowBox[{"K", " ", 
   RowBox[{"(", 
    RowBox[{"p", "+", "r"}], ")"}]}], 
  RowBox[{"p", "+", "q", "+", "r"}]]], "Output",
 CellChangeTimes->{{3.857830233250979*^9, 3.857830244357922*^9}, 
   3.857830513457922*^9, 3.85902614982122*^9, 3.859909382852379*^9, 
   3.8610979335881453`*^9},
 CellLabel->"Out[50]=",ExpressionUUID->"e8fcc13b-b103-43d3-88b8-4f0434a7a80e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nx20", "=", 
  RowBox[{"normed", "[", "x20", "]"}]}]], "Input",
 CellChangeTimes->{{3.857827691216062*^9, 3.8578277013752813`*^9}},
 CellLabel->"In[51]:=",ExpressionUUID->"d3dff3e0-0cfe-44b1-83cf-2a60d61091fe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["a", "4"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "-", 
     SuperscriptBox["b", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["c", "4"]}], 
    RowBox[{
     SuperscriptBox["a", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox["b", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     SuperscriptBox["c", "4"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "4"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["b", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["c", "4"]}], 
    RowBox[{
     SuperscriptBox["a", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox["b", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     SuperscriptBox["c", "4"]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "-", 
     SuperscriptBox["b", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["c", "4"]}]}], 
    RowBox[{
     SuperscriptBox["a", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "+", 
     SuperscriptBox["b", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     SuperscriptBox["c", "4"]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.8578277025766153`*^9, 3.8578287304108686`*^9, 
  3.8578326945242157`*^9, 3.857833326172031*^9, 3.857899113785033*^9, 
  3.859026149832725*^9, 3.859909382947319*^9, 3.861097933630587*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"86afd077-7753-4c78-8389-6366d4e3cf89"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"lenAB", "=", 
   RowBox[{"dist", "[", 
    RowBox[{"ptA", ",", "ptB"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lenBC", "=", 
   RowBox[{"dist", "[", 
    RowBox[{"ptB", ",", "ptC"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lenCD", "=", 
   RowBox[{"dist", "[", 
    RowBox[{"ptC", ",", "ptD"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lenAD", "=", 
   RowBox[{"dist", "[", 
    RowBox[{"ptA", ",", "ptD"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lenAE", "=", 
   RowBox[{"dist", "[", 
    RowBox[{"ptA", ",", "ptE"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lenBE", "=", 
   RowBox[{"dist", "[", 
    RowBox[{"ptB", ",", "ptE"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lenCE", "=", 
   RowBox[{"dist", "[", 
    RowBox[{"ptC", ",", "ptE"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lenDE", "=", 
   RowBox[{"dist", "[", 
    RowBox[{"ptD", ",", "ptE"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8578295110855827`*^9, 3.85782957461443*^9}},
 CellLabel->"In[52]:=",ExpressionUUID->"57e50172-32e8-477f-a5f3-ebf840f66a77"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ptF", "=", 
   RowBox[{"centerABE", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"nx20", ".", 
       RowBox[{"{", 
        RowBox[{"ptA", ",", "ptB", ",", "ptE"}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "lenBE"}], ",", 
        RowBox[{"b", "\[Rule]", "lenAE"}], ",", 
        RowBox[{"c", "\[Rule]", "lenAB"}]}], "}"}]}], "//", "Simplify"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptG", "=", 
   RowBox[{"centerBCE", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"nx20", ".", 
       RowBox[{"{", 
        RowBox[{"ptB", ",", "ptC", ",", "ptE"}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "lenCE"}], ",", 
        RowBox[{"b", "\[Rule]", "lenBE"}], ",", 
        RowBox[{"c", "\[Rule]", "lenBC"}]}], "}"}]}], "//", "Simplify"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptH", "=", 
   RowBox[{"centerCDE", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"nx20", ".", 
       RowBox[{"{", 
        RowBox[{"ptC", ",", "ptD", ",", "ptE"}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "lenDE"}], ",", 
        RowBox[{"b", "\[Rule]", "lenCE"}], ",", 
        RowBox[{"c", "\[Rule]", "lenCD"}]}], "}"}]}], "//", "Simplify"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptI", "=", 
   RowBox[{"centerDAE", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"nx20", ".", 
       RowBox[{"{", 
        RowBox[{"ptD", ",", "ptA", ",", "ptE"}], "}"}]}], "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"a", "\[Rule]", "lenAE"}], ",", 
        RowBox[{"b", "\[Rule]", "lenDE"}], ",", 
        RowBox[{"c", "\[Rule]", "lenAD"}]}], "}"}]}], "//", "Simplify"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.857829624470192*^9, 3.85782968199827*^9}, {
  3.8578299812552443`*^9, 3.857830099983593*^9}, {3.857830711955052*^9, 
  3.857830715065485*^9}, {3.857830779658985*^9, 3.8578307828018208`*^9}, {
  3.85783336440307*^9, 3.857833379810071*^9}},
 CellLabel->"In[60]:=",ExpressionUUID->"532664f9-0673-4f1c-a9c6-d9bba576ddde"],

Cell[CellGroupData[{

Cell[BoxData["ptF"], "Input",
 CellChangeTimes->{{3.857899128408311*^9, 3.8578991292793617`*^9}},
 CellLabel->"In[64]:=",ExpressionUUID->"5524ae46-e8c0-40c7-b089-fa04c6294abe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "p"}], "+", 
        RowBox[{"3", " ", "r"}]}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["c", "2"], " ", "r"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "p"}], "+", "r"}], ")"}]}]}], ")"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "p"}], "-", "r"}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["c", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "p"}], "+", "r"}], ")"}]}]}], ")"}]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "4"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ")"}], "2"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"p", "+", "r"}], ")"}]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"p", "-", 
         RowBox[{"3", " ", "r"}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"p", "+", "r"}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["c", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"p", "+", "r"}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "p"}], "+", "r"}], ")"}]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"p", "-", "r"}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"p", "+", "r"}], ")"}]}]}], ")"}]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "-", 
           SuperscriptBox["c", "2"]}], ")"}], "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["b", "2"], "+", 
           SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"p", "+", "r"}], ")"}]}]]}], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "p"}], "-", "r"}], ")"}]}], "-", 
     RowBox[{
      SuperscriptBox["a", "4"], " ", "r"}], "-", 
     RowBox[{
      SuperscriptBox["b", "4"], " ", "r"}], "+", 
     RowBox[{
      SuperscriptBox["c", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "p"}], "+", 
        RowBox[{"3", " ", "r"}]}], ")"}]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["b", "2"]}], " ", "r"}], "+", 
        RowBox[{
         SuperscriptBox["c", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "p"}], "+", "r"}], ")"}]}]}], ")"}]}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "4"], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ")"}], "2"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"p", "+", "r"}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.857899130447198*^9, 3.859026150537359*^9, 
  3.8599093836422*^9, 3.861097934387591*^9},
 CellLabel->"Out[64]=",ExpressionUUID->"cf9e7862-8485-476e-a74d-85e83fc9eab4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaFGH", "=", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptF", ",", "ptG", ",", "ptH"}], "]"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.8578302610250883`*^9, 3.857830273129084*^9}, {
  3.85783035448252*^9, 3.857830368338265*^9}, {3.857830850498886*^9, 
  3.857830860938717*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"9730d227-81b9-44c9-ac5c-60f628ab0f61"],

Cell[BoxData[
 FractionBox[
  RowBox[{"K", " ", 
   RowBox[{"(", 
    RowBox[{"p", "+", "r"}], ")"}]}], 
  RowBox[{"p", "+", "q", "+", "r"}]]], "Output",
 CellChangeTimes->{
  3.857830133785974*^9, {3.857830265423327*^9, 3.857830275279084*^9}, {
   3.8578303570224257`*^9, 3.857830371272946*^9}, 3.857830534393124*^9, 
   3.857830729286992*^9, {3.857830836784233*^9, 3.857830862025066*^9}, 
   3.857832810214882*^9, 3.85783334037889*^9, 3.8578333930223017`*^9, 
   3.859026150578435*^9, 3.859909383681114*^9, 3.8610979344279633`*^9},
 CellLabel->"Out[65]=",ExpressionUUID->"1556f727-324d-474b-aa85-141c9dde579b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaFGH", "/.", 
  RowBox[{"r", "\[Rule]", 
   RowBox[{"1", "-", "p", "-", "q"}]}]}]], "Input",
 CellChangeTimes->{{3.857830283455956*^9, 3.857830288687751*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"8275d24e-0dfa-4bae-a0f3-1fb9f14b2475"],

Cell[BoxData[
 RowBox[{"K", " ", 
  RowBox[{"(", 
   RowBox[{"1", "-", "q"}], ")"}]}]], "Output",
 CellChangeTimes->{3.857830290188567*^9, 3.8578305423124332`*^9, 
  3.857830737877524*^9, 3.8578308697386103`*^9, 3.859026150587051*^9, 
  3.859909383691805*^9, 3.8610979344374313`*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"d23c9a2b-05df-48c2-81ce-03dc61d398d0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"areaABCD", "/", "areaFGH"}], "/.", 
   RowBox[{"r", "\[Rule]", 
    RowBox[{"1", "-", "p", "-", "q"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.857830325088152*^9, 3.85783033373602*^9}, {
  3.85783038233053*^9, 3.857830392791869*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"ae8021bd-6cdf-48db-9b4a-796dfbc8e40a"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.857830336801631*^9, {3.857830383154911*^9, 3.857830394053072*^9}, 
   3.857830873731242*^9, 3.8590261506254272`*^9, 3.859909383787958*^9, 
   3.861097934478499*^9},
 CellLabel->"Out[67]=",ExpressionUUID->"9e7d500e-bccb-4155-ab86-88adbfad0fbe"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Section 7.2 - Orthodiagonal Quadrilaterals", "Subsection",
 CellChangeTimes->{{3.861083672513912*^9, 3.8610837265016613`*^9}, {
  3.861083772333666*^9, 
  3.861083783117765*^9}},ExpressionUUID->"0d17fde0-0d53-4260-88b7-\
c578768f6c33"],

Cell[CellGroupData[{

Cell["Lemma 7.5 for X(402)", "Subsubsection",
 CellChangeTimes->{{3.861083840788579*^9, 3.861083852282742*^9}, {
  3.8610882500044317`*^9, 3.8610882527400427`*^9}, {3.861092164568664*^9, 
  3.861092168016555*^9}},ExpressionUUID->"146aa3cb-e612-4e95-9dfd-\
28e103e8b38d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x5", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"5", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8610839403537073`*^9, 3.861083947742229*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"221e464c-a8d6-447e-932e-736ba26b3155"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    SuperscriptBox["b", "4"], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    SuperscriptBox["c", "4"]}], ",", 
   RowBox[{
    SuperscriptBox["a", "4"], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    SuperscriptBox["c", "4"]}], ",", 
   RowBox[{
    SuperscriptBox["a", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    SuperscriptBox["b", "4"], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.861083949738892*^9, 3.8610979344884777`*^9},
 CellLabel->"Out[68]=",ExpressionUUID->"23634c37-100d-45ea-af9d-30d2133c1bf9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"x5", ",", 
    RowBox[{
     RowBox[{"a", "^", "2"}], "==", 
     RowBox[{
      RowBox[{"b", "^", "2"}], "+", 
      RowBox[{"c", "^", "2"}]}]}]}], "]"}], "/", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "2"}], 
    RowBox[{"b", "^", "2"}], 
    RowBox[{"c", "^", "2"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.861083981625944*^9, 3.8610840047445383`*^9}, {
  3.8610840382697973`*^9, 3.861084053070752*^9}},
 CellLabel->"In[69]:=",ExpressionUUID->"bdfe97ac-0647-471a-bf2f-551298bda867"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "1", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{{3.861084000059473*^9, 3.861084005739766*^9}, 
   3.8610840545692787`*^9, 3.8610979345323353`*^9},
 CellLabel->"Out[69]=",ExpressionUUID->"7b9d42fd-523f-4917-9502-b394f4f28689"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x402", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"402", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.861083918400093*^9, 3.861083934735454*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"c7923504-0ddd-42b1-b9c1-9db7cafa8d78"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "8"], "-", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "-", 
      SuperscriptBox["b", "8"], "-", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      SuperscriptBox["c", "8"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "8"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "+", 
      SuperscriptBox["b", "8"], "-", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      SuperscriptBox["c", "8"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "8"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "-", 
      SuperscriptBox["b", "8"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.861083935751359*^9, 3.861097934545478*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"640be061-c8a3-45ec-82f8-54fc6b04615f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Simplify", "[", 
   RowBox[{"x402", ",", 
    RowBox[{
     RowBox[{"a", "^", "2"}], "==", 
     RowBox[{
      RowBox[{"b", "^", "2"}], "+", 
      RowBox[{"c", "^", "2"}]}]}]}], "]"}], "/", 
  RowBox[{"(", 
   RowBox[{"8", 
    RowBox[{"b", "^", "6"}], 
    RowBox[{"c", "^", "6"}]}], ")"}]}]], "Input",
 CellChangeTimes->{{3.8610840689750957`*^9, 3.8610840884045773`*^9}},
 CellLabel->"In[71]:=",ExpressionUUID->"a04c9867-66ef-4ac5-8d99-9ce89c7d3075"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "1", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{{3.861084070702342*^9, 3.8610840896611147`*^9}, 
   3.861097934599875*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"67c44df8-fedd-403f-8297-17a98c194fc2"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Lemma 7.13 for X(102)", "Subsubsection",
 CellChangeTimes->{{3.861084262893421*^9, 3.8610842795473967`*^9}, {
  3.8610882340604467`*^9, 3.861088236723963*^9}, {3.861092171008654*^9, 
  3.8610921738086567`*^9}},ExpressionUUID->"aaf6148f-d5fe-4ba1-88e3-\
8a9e590b3d46"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x102", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"102", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.861084291558082*^9, 3.861084306872923*^9}},
 CellLabel->"In[72]:=",ExpressionUUID->"3543d712-1fe4-4727-a85b-dd8b31d1d764"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "4"]}], ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["b", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "4"]}], ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.861084307802376*^9, 3.861097934620344*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"90cdad47-7011-4b85-a1e2-f100664f48e4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "center", " ", "functions", " ", "use", " ", "trilinear", " ", 
    "coordinates"}], ",", " ", 
   RowBox[{"ETC1", " ", "gives", " ", "barycentric", " ", "coordinates"}]}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.861085857264145*^9, 3.861085888836368*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"3bacc282-27a9-4321-9459-1cabc57e00b3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"centerFunction102", "=", 
  RowBox[{
   RowBox[{"x102", "[", 
    RowBox[{"[", "1", "]"}], "]"}], "/", "a"}]}]], "Input",
 CellChangeTimes->{{3.861084326230919*^9, 3.861084340871442*^9}, {
  3.861084377513638*^9, 3.8610843825518093`*^9}, {3.861085740868072*^9, 
  3.86108574121194*^9}},
 CellLabel->"In[74]:=",ExpressionUUID->"aecccb34-fabd-42e4-8765-b67e6b4dc5ee"],

Cell[BoxData[
 RowBox[{"a", " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["a", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    SuperscriptBox["b", "4"], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["b", "3"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", "a", " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["c", "4"]}]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["a", "4"], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "b"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
    RowBox[{"2", " ", "a", " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["b", "3"], " ", "c"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"a", " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "3"]}], "+", 
    SuperscriptBox["c", "4"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.861084341786139*^9, 3.8610857445736513`*^9, 
  3.861085828962948*^9, 3.861085894414536*^9, 3.861097934675214*^9},
 CellLabel->"Out[74]=",ExpressionUUID->"e8a7a926-4c90-404d-aaea-ae70d8c150e2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fabc", "=", "centerFunction102"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fbac", "=", 
   RowBox[{"fabc", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "\[Rule]", "b"}], ",", 
      RowBox[{"b", "\[Rule]", "a"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Factor", "[", 
  RowBox[{"fabc", "-", "fbac"}], "]"}]}], "Input",
 CellChangeTimes->{{3.861084385175583*^9, 3.861084461415924*^9}, {
  3.861084506025692*^9, 3.8610845094164762`*^9}, {3.8610845596978703`*^9, 
  3.8610845729843197`*^9}, {3.861084665970015*^9, 3.861084672505911*^9}, {
  3.8610847516591873`*^9, 3.86108477521703*^9}, {3.861084904739153*^9, 
  3.8610849084735622`*^9}, {3.861085733598029*^9, 3.8610857381645527`*^9}, {
  3.861085846172873*^9, 3.861085852268873*^9}},
 CellLabel->"In[75]:=",ExpressionUUID->"7e858350-d466-41f7-b7f7-2626e7c8ceba"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "a"}], "+", "b"}], ")"}]}], " ", 
  RowBox[{"(", 
   RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{"a", "+", "b", "+", "c"}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["a", "2"], "+", 
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"]}], ")"}], " ", 
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["a", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    SuperscriptBox["b", "4"], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["b", "3"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", "a", " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["c", "4"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.861084424344079*^9, 3.861084463084681*^9, {3.861084514167388*^9, 
   3.861084574471871*^9}, {3.861084667191182*^9, 3.86108467405328*^9}, 
   3.861084776275116*^9, 3.861084909682946*^9, 3.861085853543077*^9, 
   3.861085897917819*^9, 3.861097934720786*^9},
 CellLabel->"Out[77]=",ExpressionUUID->"5d5455d2-dd01-4bcc-bcbc-f2c749fd5546"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"fabc", "-", "fbac"}], "/.", 
   RowBox[{"c", "\[Rule]", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"a", "^", "2"}], "+", 
      RowBox[{"b", "^", "2"}]}], "]"}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.8610848570414457`*^9, 3.861084876001211*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"fba84d91-bbdd-4fd6-af56-00d518d05eee"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.8610848705144672`*^9, 3.861084877219542*^9}, 
   3.861085948841217*^9, 3.861097934731729*^9},
 CellLabel->"Out[78]=",ExpressionUUID->"c9950c45-b737-490c-9160-9badb73fa273"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Section 7.4 - Rhombi", "Subsection",
 CellChangeTimes->{{3.861089245893405*^9, 
  3.861089262711451*^9}},ExpressionUUID->"33efc3b8-cc24-4b49-bdd3-\
11597d0f8696"],

Cell[CellGroupData[{

Cell["Proposition 7.19 for X(40)", "Subsubsection",
 CellChangeTimes->{{3.860669617752452*^9, 3.8606696379733267`*^9}, {
  3.8606712433112993`*^9, 3.8606712500231113`*^9}, {3.861097461139688*^9, 
  3.861097474737636*^9}},ExpressionUUID->"85dbcfac-3ed2-44b0-890d-\
8efa96290fc7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ptA", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptB", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptC", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ptF", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ETC1", "[", 
     RowBox[{"[", 
      RowBox[{"40", ",", "2"}], "]"}], "]"}], "/.", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"a", "^", "2"}], "+", 
       RowBox[{"b", "^", "2"}]}], "]"}]}]}], "//", "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.860669669250484*^9, 3.8606697322743692`*^9}},
 CellLabel->"In[79]:=",ExpressionUUID->"b30efd96-3fde-4377-93d9-4ec246afc3df"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["a", "2"], " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", "a", " ", 
    SuperscriptBox["b", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}], ")"}]}], ",", 
   RowBox[{"2", " ", "a", " ", "b", " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}]], " ", 
    RowBox[{"(", 
     RowBox[{"a", "+", "b", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8606696959950237`*^9, 3.8606697332694902`*^9}, 
   3.8610975086444387`*^9, 3.861097934779408*^9},
 CellLabel->"Out[82]=",ExpressionUUID->"c4644419-a184-4e70-9d5a-d655c6c71725"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "=", 
  RowBox[{
   RowBox[{"ptF", "/.", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "^", "2"}], "+", 
      RowBox[{"b", "^", "2"}]}], "\[Rule]", 
     RowBox[{"c", "^", "2"}]}]}], "//", "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.86066974684604*^9, 3.860669810524342*^9}},
 CellLabel->"In[83]:=",ExpressionUUID->"354c36f1-bcba-4151-8118-4f68b53cf150"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["a", "2"], " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "-", "c"}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", "a", " ", 
    SuperscriptBox["b", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
   RowBox[{"2", " ", "a", " ", "b", " ", 
    RowBox[{"(", 
     RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]}], "}"}]], "Output",\

 CellChangeTimes->{{3.860669758847571*^9, 3.8606698113731327`*^9}, 
   3.861097512400812*^9, 3.861097934789382*^9},
 CellLabel->"Out[83]=",ExpressionUUID->"6d9a8438-79e9-4582-81da-7b7e51667be0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F2", "=", 
  RowBox[{"F", "/", 
   RowBox[{"(", 
    RowBox[{"2", "a", " ", "b"}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.860669815966339*^9, 3.860669836276082*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"bb371ab0-27e2-4e0e-9887-9d8236ea9a71"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "-", "c"}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", "b"}], " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]}], "}"}]], "Output",\

 CellChangeTimes->{{3.86066982948701*^9, 3.860669837239705*^9}, 
   3.861097515589467*^9, 3.861097934829605*^9},
 CellLabel->"Out[84]=",ExpressionUUID->"d5932f19-d3b0-402c-8964-b79363e3d01d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"area", " ", "BCF"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}], "BC", "*", "FQ"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "/", "2"}], ")"}], "FQ"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"so", " ", "FQ"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"[", "BCF", "]"}], "*", 
     RowBox[{"(", 
      RowBox[{"2", "/", "a"}], ")"}]}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.860670131534824*^9, 3.860670224123826*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"92697046-2522-46ef-96a5-00ef56a74801"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FQ", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"baryArea", "[", 
      RowBox[{"ptB", ",", "ptC", ",", "F2"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{"2", "/", "a"}], ")"}]}], "/.", 
    RowBox[{"K", "->", 
     RowBox[{"a", " ", 
      RowBox[{"b", "/", "2"}]}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.8606698798472853`*^9, 3.860670000643343*^9}, {
   3.86067026765411*^9, 3.860670276788249*^9}, 3.8606706806145372`*^9},
 CellLabel->"In[86]:=",ExpressionUUID->"b5c592c6-75b7-4f62-aa52-bc28789c5ff5"],

Cell[BoxData[
 FractionBox[
  RowBox[{"a", " ", "b"}], 
  RowBox[{"a", "-", "b", "+", "c"}]]], "Output",
 CellChangeTimes->{{3.860669948942638*^9, 3.8606700017907753`*^9}, 
   3.860670278384112*^9, 3.8606706817436028`*^9, 3.861097524283489*^9, 
   3.861097934883915*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"705fa393-aa52-4d95-a60a-6063647cb1fa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FP", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"baryArea", "[", 
      RowBox[{"ptA", ",", "F2", ",", "ptC"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{"2", "/", "b"}], ")"}]}], "/.", 
    RowBox[{"K", "->", 
     RowBox[{"a", " ", 
      RowBox[{"b", "/", "2"}]}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.860670021515637*^9, 3.860670044555706*^9}, {
   3.86067028454974*^9, 3.8606702954844017`*^9}, 3.860670686662631*^9, {
   3.860671013376193*^9, 3.8606710229588327`*^9}, {3.860671061544276*^9, 
   3.86067108246309*^9}},
 CellLabel->"In[87]:=",ExpressionUUID->"1c3a58d7-5635-4843-a904-c3e212ec6b20"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"a", " ", "b"}], 
   RowBox[{"a", "-", "b", "-", "c"}]]}]], "Output",
 CellChangeTimes->{
  3.860670045975214*^9, 3.8606702993152637`*^9, 3.860670687932988*^9, 
   3.860671025249881*^9, {3.860671069418133*^9, 3.860671083657564*^9}, 
   3.86109752934112*^9, 3.861097934895254*^9},
 CellLabel->"Out[87]=",ExpressionUUID->"f47b30a4-9853-4a7f-8ec1-ccdbb1dfcfcb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sum", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"FP", "+", "FQ"}], "//", "Together"}], "//", 
   "ExpandAll"}]}]], "Input",
 CellChangeTimes->{{3.860670053706151*^9, 3.860670061787334*^9}, {
  3.860670337525744*^9, 3.8606704045084887`*^9}, {3.860670482406147*^9, 
  3.860670568477214*^9}, {3.860671142864359*^9, 3.860671194128881*^9}},
 CellLabel->"In[88]:=",ExpressionUUID->"f99fb1c2-bb6f-411e-bda4-9abc44436c23"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", "a", " ", "b", " ", "c"}], 
   RowBox[{
    SuperscriptBox["a", "2"], "-", 
    RowBox[{"2", " ", "a", " ", "b"}], "+", 
    SuperscriptBox["b", "2"], "-", 
    SuperscriptBox["c", "2"]}]]}]], "Output",
 CellChangeTimes->{
  3.860670062846181*^9, 3.860670304918202*^9, {3.860670340527206*^9, 
   3.8606704055412827`*^9}, 3.8606704853195333`*^9, {3.860670538319693*^9, 
   3.860670569393882*^9}, 3.860670693592229*^9, 3.860671090066671*^9, {
   3.860671145882092*^9, 3.860671195254889*^9}, 3.8610975378565683`*^9, 
   3.861097934939093*^9},
 CellLabel->"Out[88]=",ExpressionUUID->"744d0b97-5b3a-4dff-a3e1-3963fd39aaf3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sum", "/.", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "^", "2"}], "+", 
    RowBox[{"b", "^", "2"}]}], "\[Rule]", 
   RowBox[{"c", "^", "2"}]}]}]], "Input",
 CellChangeTimes->{{3.860671203041733*^9, 3.860671212815119*^9}},
 CellLabel->"In[89]:=",ExpressionUUID->"cd9660b8-9f44-46cd-8519-094a61bc2258"],

Cell[BoxData["c"], "Output",
 CellChangeTimes->{3.8606712135579767`*^9, 3.861097541447608*^9, 
  3.861097934951078*^9},
 CellLabel->"Out[89]=",ExpressionUUID->"9325f60f-8c24-47cb-a0d1-dff5834aacf0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"product", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"FP", "*", "FQ"}], "/.", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"a", "^", "2"}], "+", 
       RowBox[{"b", "^", "2"}]}], "]"}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.8610975490725183`*^9, 3.861097562289871*^9}, {
  3.861097635060514*^9, 3.861097642850163*^9}},
 CellLabel->"In[90]:=",ExpressionUUID->"c85ebb44-c58b-4fa8-8a8b-197d53fc310a"],

Cell[BoxData[
 FractionBox[
  RowBox[{"a", " ", "b"}], "2"]], "Output",
 CellChangeTimes->{
  3.861097563707013*^9, {3.861097636984456*^9, 3.861097643949806*^9}, 
   3.861097934996037*^9},
 CellLabel->"Out[90]=",ExpressionUUID->"4b8f73af-76ea-49fe-b90a-98260853f5e0"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Proposition 7.20 for X(84)", "Subsubsection",
 CellChangeTimes->{{3.860669617752452*^9, 3.8606696379733267`*^9}, {
  3.8606712433112993`*^9, 3.8606712500231113`*^9}, {3.860678559174946*^9, 
  3.860678559518382*^9}, {3.861088034971642*^9, 3.861088040715427*^9}, {
  3.861092184616624*^9, 
  3.861092187576666*^9}},ExpressionUUID->"31a20017-3f76-4a14-aa99-\
a70617396042"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x84", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"84", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.861086497181162*^9, 3.861086514792322*^9}},
 CellLabel->"In[91]:=",ExpressionUUID->"8172549d-b095-4b20-ab50-b3aa6e290547"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "3"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "3"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "3"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "3"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "3"]}], ")"}]}], ",", 
   RowBox[{"b", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "3"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "3"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "3"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "3"]}], ")"}]}], ",", 
   RowBox[{"c", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "3"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "3"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "3"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "3"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.861086509389062*^9, 3.861086515794133*^9}, 
   3.861097935008902*^9},
 CellLabel->"Out[91]=",ExpressionUUID->"b28db607-5ee2-48ec-9324-a11db31559a7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"etc84", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "^", "3"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"b", "-", "c"}], ")"}], "^", "2"}]}], ")"}], "^", "2"}]}], 
   "-", 
   RowBox[{"a", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"b", "-", "c"}], ")"}], "^", "2"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", "^", "2"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"b", "+", "c"}], ")"}], "^", "2"}]}], ")"}], "^", 
     "2"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8610865842257433`*^9, 3.861086624135104*^9}, 
   3.861086686104641*^9, 3.861086757840691*^9},
 CellLabel->"In[92]:=",ExpressionUUID->"062be80f-d86d-41d9-a0c7-c2f18a396796"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "-", "c"}], ")"}], "2"]}], ")"}], "2"]}], "-", 
  RowBox[{"a", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}], ")"}], "2"]}]}]], "Output",
 CellChangeTimes->{{3.861086604957635*^9, 3.861086625077635*^9}, 
   3.861086686691229*^9, 3.861086759346591*^9, 3.8610979350512657`*^9},
 CellLabel->"Out[92]=",ExpressionUUID->"a75bf9f0-6746-4b19-b3b2-4657d7ffc92c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "confirm", " ", "that", " ", "our", " ", "value", " ", "for", " ", "X84", 
   " ", "agrees", " ", "with", " ", "the", " ", "one", " ", "in", " ", 
   "ETC"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.861086769083762*^9, 3.861086785271595*^9}},
 CellLabel->"In[93]:=",ExpressionUUID->"2d8f19a8-ca7b-4679-a807-f146a5971917"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"etc84", "-", 
   RowBox[{"x84", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.861086634446786*^9, 3.861086643502926*^9}},
 CellLabel->"In[94]:=",ExpressionUUID->"857183d2-455b-494f-ae05-8aa0a9d9b750"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.861086638123076*^9, 3.8610866445302067`*^9}, 
   3.861086689178617*^9, 3.861086762564528*^9, 3.861097935101829*^9},
 CellLabel->"Out[94]=",ExpressionUUID->"821e70e4-4acc-4336-b2fc-d32ea64d021a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ptA", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptB", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptC", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ptF", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ETC1", "[", 
     RowBox[{"[", 
      RowBox[{"84", ",", "2"}], "]"}], "]"}], "/.", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"a", "^", "2"}], "+", 
       RowBox[{"b", "^", "2"}]}], "]"}]}]}], "//", "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.860669669250484*^9, 3.8606697322743692`*^9}, {
   3.860678564239655*^9, 3.860678573512237*^9}, 3.8606891016822577`*^9},
 CellLabel->"In[95]:=",ExpressionUUID->"2453005f-0845-4ad2-81ee-83b09ba9caa3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"8", " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox["b", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}], ")"}]}], ",", 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox["b", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}]]}], ")"}]}], ",", 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox["b", "3"], " ", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.8606696959950237`*^9, 3.8606697332694902`*^9}, {
   3.860678568455172*^9, 3.860678575002658*^9}, 3.860689104870472*^9, 
   3.860690464542612*^9, 3.861097935147456*^9},
 CellLabel->"Out[98]=",ExpressionUUID->"b687ee77-6157-44b6-ad79-93ae6d75a7a0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F", "=", 
  RowBox[{
   RowBox[{"ptF", "/.", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "^", "2"}], "+", 
      RowBox[{"b", "^", "2"}]}], "\[Rule]", 
     RowBox[{"c", "^", "2"}]}]}], "//", "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.86066974684604*^9, 3.860669810524342*^9}, {
  3.860678578671349*^9, 3.860678582151061*^9}, {3.860689108849821*^9, 
  3.860689112784618*^9}},
 CellLabel->"In[99]:=",ExpressionUUID->"ba7da1a1-b591-441b-b943-c676b04da678"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"8", " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox["b", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"b", "-", "c"}], ")"}]}], ",", 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox["b", "3"], " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "c"}], ")"}]}], ",", 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox["b", "3"], " ", "c"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.860669758847571*^9, 3.8606698113731327`*^9}, 
   3.8606785833399153`*^9, 3.860689113763138*^9, 3.8606904728634663`*^9, 
   3.861097935158505*^9},
 CellLabel->"Out[99]=",ExpressionUUID->"45b86ac2-cfe1-4cc5-b0dc-4f35a82e151f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"F2", "=", 
  RowBox[{"F", "/", 
   RowBox[{"(", 
    RowBox[{"8", 
     RowBox[{"a", "^", "3"}], 
     RowBox[{"b", "^", "3"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.860669815966339*^9, 3.860669836276082*^9}, {
  3.860678588247737*^9, 3.860678604334737*^9}, {3.8606891172817097`*^9, 
  3.860689120536672*^9}},
 CellLabel->
  "In[100]:=",ExpressionUUID->"3eade57d-8abc-4901-83cb-42a57757edfd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"b", "-", "c"}], ",", 
   RowBox[{"a", "-", "c"}], ",", "c"}], "}"}]], "Output",
 CellChangeTimes->{{3.86066982948701*^9, 3.860669837239705*^9}, 
   3.860678605178685*^9, 3.8606891215583067`*^9, 3.860690476000852*^9, 
   3.8610979351998987`*^9},
 CellLabel->
  "Out[100]=",ExpressionUUID->"1fbae315-fc3a-4e4f-b4c8-13bd5cfaf5de"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"area", " ", "BFC"}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}], "BC", "*", "PF"}], " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "/", "2"}], ")"}], "PF"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{"so", " ", "PF"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"[", "BFC", "]"}], "*", 
     RowBox[{"(", 
      RowBox[{"2", "/", "a"}], ")"}]}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.860670131534824*^9, 3.860670224123826*^9}, {
  3.860678627959282*^9, 3.860678643350933*^9}, {3.860689050880579*^9, 
  3.8606890820004*^9}, {3.860689128304358*^9, 3.8606891308084087`*^9}, {
  3.860690486180751*^9, 3.860690486524665*^9}, {3.860690516725286*^9, 
  3.8606905170288763`*^9}},
 CellLabel->
  "In[101]:=",ExpressionUUID->"9489e855-7eb6-4a92-a3af-df91a51c4f30"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"baryArea", "[", 
   RowBox[{"ptB", ",", "F2", ",", "ptC"}], "]"}], "//", "Simplify"}]], "Input",\

 CellChangeTimes->{{3.860688279926961*^9, 3.860688282485606*^9}, 
   3.860689139241893*^9, 3.860689857315991*^9, {3.860690258205627*^9, 
   3.860690261915888*^9}},
 CellLabel->
  "In[102]:=",ExpressionUUID->"069be70a-7e12-4f6b-9993-0ffb9e8f5a09"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "b"}], "+", "c"}], ")"}], " ", "K"}], 
  RowBox[{"a", "+", "b", "-", "c"}]]], "Output",
 CellChangeTimes->{{3.8606882766529922`*^9, 3.860688283497793*^9}, 
   3.860689141283903*^9, 3.860689731877746*^9, 3.8606898584198027`*^9, 
   3.860690263043944*^9, 3.860690524984774*^9, 3.861097935250382*^9},
 CellLabel->
  "Out[102]=",ExpressionUUID->"2e4fcce1-574b-4956-8695-ab2c8b9a24d5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PF", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"baryArea", "[", 
      RowBox[{"ptB", ",", "F2", ",", "ptC"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{"2", "/", "a"}], ")"}]}], "/.", 
    RowBox[{"K", "->", 
     RowBox[{"a", " ", 
      RowBox[{"b", "/", "2"}]}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.8606698798472853`*^9, 3.860670000643343*^9}, {
   3.86067026765411*^9, 3.860670276788249*^9}, 3.8606706806145372`*^9, {
   3.86067865074398*^9, 3.860678655662888*^9}, {3.860689211970191*^9, 
   3.8606892303046923`*^9}, {3.8606906496148043`*^9, 3.8606906538613234`*^9}},
 
 CellLabel->
  "In[103]:=",ExpressionUUID->"50efbea1-80d0-4528-b5b9-8fc9ac6ca7d3"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"b", " ", 
    RowBox[{"(", 
     RowBox[{"b", "-", "c"}], ")"}]}], 
   RowBox[{"a", "+", "b", "-", "c"}]]}]], "Output",
 CellChangeTimes->{{3.860669948942638*^9, 3.8606700017907753`*^9}, 
   3.860670278384112*^9, 3.8606706817436028`*^9, 3.8606786572808447`*^9, {
   3.860689213189721*^9, 3.860689231693152*^9}, 3.860689434939762*^9, 
   3.860689743971229*^9, {3.86069063409582*^9, 3.86069065491575*^9}, 
   3.861097935262516*^9},
 CellLabel->
  "Out[103]=",ExpressionUUID->"65e30e63-cdf1-49ae-b353-4d2bdc84374d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"QF", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"baryArea", "[", 
      RowBox[{"ptA", ",", "ptC", ",", "F2"}], "]"}], "*", 
     RowBox[{"(", 
      RowBox[{"2", "/", "b"}], ")"}]}], "/.", 
    RowBox[{"K", "->", 
     RowBox[{"a", " ", 
      RowBox[{"b", "/", "2"}]}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.860670021515637*^9, 3.860670044555706*^9}, {
   3.86067028454974*^9, 3.8606702954844017`*^9}, 3.860670686662631*^9, {
   3.860671013376193*^9, 3.8606710229588327`*^9}, {3.860671061544276*^9, 
   3.86067108246309*^9}, {3.860678663191951*^9, 3.860678668223394*^9}, {
   3.860690010220743*^9, 3.8606900331234426`*^9}, {3.8606903672633047`*^9, 
   3.860690371596715*^9}},
 CellLabel->
  "In[104]:=",ExpressionUUID->"c5cdd15c-2940-4a2d-bcfe-7a0b71eaafe8"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{"a", "-", "c"}], ")"}]}], 
   RowBox[{"a", "+", "b", "-", "c"}]]}]], "Output",
 CellChangeTimes->{
  3.860670045975214*^9, 3.8606702993152637`*^9, 3.860670687932988*^9, 
   3.860671025249881*^9, {3.860671069418133*^9, 3.860671083657564*^9}, 
   3.860678669990464*^9, 3.860690036640683*^9, 3.8606901350960503`*^9, 
   3.860690372849709*^9, 3.860690403549327*^9, 3.8606906686798973`*^9, 
   3.861097935310245*^9},
 CellLabel->
  "Out[104]=",ExpressionUUID->"06fbb8c8-6432-4126-85a2-ef757080b41a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sum", "=", 
  RowBox[{
   RowBox[{"PF", "+", "QF"}], "//", "Together"}]}]], "Input",
 CellChangeTimes->{{3.860670053706151*^9, 3.860670061787334*^9}, {
  3.860670337525744*^9, 3.8606704045084887`*^9}, {3.860670482406147*^9, 
  3.860670568477214*^9}, {3.860671142864359*^9, 3.860671194128881*^9}, {
  3.8606786750082893`*^9, 3.860678688405656*^9}, {3.860690043524781*^9, 
  3.8606900569729147`*^9}},
 CellLabel->
  "In[105]:=",ExpressionUUID->"b6f73bb7-8227-4899-8c70-f19dfc9d3c69"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["a", "2"]}], "-", 
   SuperscriptBox["b", "2"], "+", 
   RowBox[{"a", " ", "c"}], "+", 
   RowBox[{"b", " ", "c"}]}], 
  RowBox[{"a", "+", "b", "-", "c"}]]], "Output",
 CellChangeTimes->{
  3.860670062846181*^9, 3.860670304918202*^9, {3.860670340527206*^9, 
   3.8606704055412827`*^9}, 3.8606704853195333`*^9, {3.860670538319693*^9, 
   3.860670569393882*^9}, 3.860670693592229*^9, 3.860671090066671*^9, {
   3.860671145882092*^9, 3.860671195254889*^9}, 3.860678689470821*^9, {
   3.8606900472412167`*^9, 3.860690058049921*^9}, 3.8606903783126087`*^9, 
   3.8606906722932367`*^9, 3.861097935321446*^9},
 CellLabel->
  "Out[105]=",ExpressionUUID->"d3b8c2d7-03a7-44b0-bcc1-5acd91517e0d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sum", "/.", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"a", "^", "2"}]}], "-", 
     RowBox[{"b", "^", "2"}]}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"c", "^", "2"}]}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.860671203041733*^9, 3.860671212815119*^9}, {
   3.860678709936322*^9, 3.860678719151038*^9}, 3.8606900609007673`*^9, {
   3.860690691982622*^9, 3.86069069837346*^9}},
 CellLabel->
  "In[106]:=",ExpressionUUID->"6a1ac0ef-f7ba-4d5b-824f-8b2d0b167604"],

Cell[BoxData["c"], "Output",
 CellChangeTimes->{
  3.8606712135579767`*^9, {3.860678713573374*^9, 3.86067872014662*^9}, 
   3.860690061917345*^9, {3.860690680410763*^9, 3.8606906993789997`*^9}, 
   3.861097935364987*^9},
 CellLabel->
  "Out[106]=",ExpressionUUID->"d3252340-39be-4cb4-96d8-9d38aac232cb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PF", "*", "QF"}]], "Input",
 CellChangeTimes->{{3.86069084869718*^9, 3.860690850629814*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"75a2d2b9-c460-484d-9e12-4f580c19edf1"],

Cell[BoxData[
 FractionBox[
  RowBox[{"a", " ", "b", " ", 
   RowBox[{"(", 
    RowBox[{"a", "-", "c"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"b", "-", "c"}], ")"}]}], 
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"a", "+", "b", "-", "c"}], ")"}], "2"]]], "Output",
 CellChangeTimes->{3.8606908534773693`*^9, 3.861097935423522*^9},
 CellLabel->
  "Out[107]=",ExpressionUUID->"9f6347ec-be83-4483-ae76-c631a9726f66"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"prod", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"PF", "*", "QF"}], "//", "ExpandDenominator"}], "//", 
   "ExpandNumerator"}]}]], "Input",
 CellChangeTimes->{{3.860690875574205*^9, 3.8606909475021257`*^9}},
 CellLabel->
  "In[108]:=",ExpressionUUID->"361b179a-0031-4d74-962c-3b7486f04b16"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox["b", "2"]}], "-", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
   RowBox[{"a", " ", 
    SuperscriptBox["b", "2"], " ", "c"}], "+", 
   RowBox[{"a", " ", "b", " ", 
    SuperscriptBox["c", "2"]}]}], 
  RowBox[{
   SuperscriptBox["a", "2"], "+", 
   RowBox[{"2", " ", "a", " ", "b"}], "+", 
   SuperscriptBox["b", "2"], "-", 
   RowBox[{"2", " ", "a", " ", "c"}], "-", 
   RowBox[{"2", " ", "b", " ", "c"}], "+", 
   SuperscriptBox["c", "2"]}]]], "Output",
 CellChangeTimes->{{3.860690880030531*^9, 3.860690910083622*^9}, 
   3.860690948645529*^9, 3.861097935433869*^9},
 CellLabel->
  "Out[108]=",ExpressionUUID->"e54e17bb-7022-47ec-b638-8093e74816e3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"prod", "/.", 
   RowBox[{
    RowBox[{"c", "^", "2"}], "\[Rule]", 
    RowBox[{
     RowBox[{"a", "^", "2"}], "+", 
     RowBox[{"b", "^", "2"}]}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.860690913968625*^9, 3.8606909163983583`*^9}, {
  3.860690994702578*^9, 3.8606910098541727`*^9}},
 CellLabel->
  "In[109]:=",ExpressionUUID->"5d99dedb-4c1d-4c73-bfdc-9b7d11cc4141"],

Cell[BoxData[
 FractionBox[
  RowBox[{"a", " ", "b"}], "2"]], "Output",
 CellChangeTimes->{{3.8606910035208883`*^9, 3.86069101093148*^9}, 
   3.861097935478361*^9},
 CellLabel->
  "Out[109]=",ExpressionUUID->"fcd8aa29-aeda-4469-bdfe-fde43c0f9481"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Section 7.5 - Rectangles", "Subsection",
 CellChangeTimes->{{3.859405671041423*^9, 3.859405678673934*^9}, {
  3.859405773238845*^9, 3.85940578635047*^9}, {3.8610899219217167`*^9, 
  3.8610899258736897`*^9}},ExpressionUUID->"f50f109f-1fc4-4f2a-a4ab-\
b48d2a93f3f4"],

Cell[CellGroupData[{

Cell["Theorem 7.26 for X(395)", "Subsubsection",
 CellChangeTimes->{{3.8590267048883963`*^9, 3.859026727459972*^9}, {
   3.861089969818034*^9, 3.861089975745613*^9}, 
   3.861092196760558*^9},ExpressionUUID->"ccc9f8cb-a605-4c03-99cf-\
a3ba19de81f4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"p", ",", "q", ",", "r"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptA", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptB", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptC", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptD", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptE", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", "2"}], ",", "0", ",", 
     RowBox[{"1", "/", "2"}]}], "}"}]}], ";"}]}], "Input",
 CellLabel->
  "In[110]:=",ExpressionUUID->"e4b465cb-fa21-401a-a4d4-bb595b3b33e9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"lenAB", "=", "c"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lenBC", "=", "a"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lenAE", "=", 
   RowBox[{"b", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lenBE", "=", 
   RowBox[{"b", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lenCE", "=", 
   RowBox[{"b", "/", "2"}]}], ";"}]}], "Input",
 CellLabel->
  "In[116]:=",ExpressionUUID->"841719af-6a8c-43ff-8499-751ded3c9f7f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x395", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"395", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858786060921858*^9, 3.858786181361096*^9}, {
  3.8587863905711937`*^9, 3.858786410594088*^9}, {3.8587881675849857`*^9, 
  3.8587881747443943`*^9}},
 CellLabel->
  "In[121]:=",ExpressionUUID->"ebe56187-cfa4-41de-8d6a-34d826178c23"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SqrtBox["3"], " ", 
     SuperscriptBox["a", "2"]}], "-", 
    RowBox[{"2", " ", "S"}]}], ",", 
   RowBox[{
    RowBox[{
     SqrtBox["3"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    RowBox[{"2", " ", "S"}]}], ",", 
   RowBox[{
    RowBox[{
     SqrtBox["3"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", "S"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8587881756168213`*^9, 3.85902618993408*^9, 
  3.859909415380006*^9, 3.860832646383442*^9, 3.861097935535557*^9},
 CellLabel->
  "Out[121]=",ExpressionUUID->"3e46321d-ab05-4dfa-89b5-3756c8d0475d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptF", "=", 
  RowBox[{"centerABE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x395", ".", 
      RowBox[{"{", 
       RowBox[{"ptA", ",", "ptB", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenAE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenAB"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858785708664339*^9, 3.858785752208427*^9}, {
   3.858785901049223*^9, 3.8587859885123568`*^9}, {3.85878628204163*^9, 
   3.858786292089315*^9}, {3.858786357153858*^9, 3.858786360769568*^9}, {
   3.858786421793996*^9, 3.858786495154055*^9}, {3.8587867030365143`*^9, 
   3.858786704658731*^9}, {3.858788182793332*^9, 3.858788194031535*^9}, 
   3.858788246343902*^9},
 CellLabel->
  "In[122]:=",ExpressionUUID->"7b3f8b05-7bd1-4336-8661-03372c17d72a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", "a"}], "+", 
         RowBox[{
          SqrtBox["3"], " ", "c"}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["b", "2"]}], "4"], "-", 
    RowBox[{"a", " ", "c"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", "c"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8587864233685513`*^9, {3.8587864696808767`*^9, 3.858786496037889*^9}, 
   3.8587867069184437`*^9, 3.858786755813157*^9, 3.8587870936108103`*^9, 
   3.8587882474445353`*^9, 3.859026189973741*^9, 3.85990941542138*^9, 
   3.860832676299837*^9, 3.860832880239646*^9, 3.861097935580223*^9},
 CellLabel->
  "Out[122]=",ExpressionUUID->"9fec80a6-8107-4a35-800d-be49e2af00c1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptG", "=", 
  RowBox[{"centerBCE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x395", ".", 
      RowBox[{"{", 
       RowBox[{"ptB", ",", "ptC", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenCE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenBC"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8587865148663816`*^9, 3.858786564610229*^9}, {
  3.8587866148666897`*^9, 3.858786628154747*^9}, {3.858788263305393*^9, 
  3.858788287137041*^9}},
 CellLabel->
  "In[123]:=",ExpressionUUID->"11f832d1-8588-46f3-b7a5-9e3de17b2d66"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["3"], " ", "a"}], "-", "c"}], ")"}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["b", "2"]}], "4"], "-", 
    RowBox[{"a", " ", "c"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["a", "2"]}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"6", " ", "a", " ", "c"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.858788288448888*^9, 3.8590261899851227`*^9, 
  3.859909415433075*^9, 3.860832920043413*^9, 3.861097935626318*^9},
 CellLabel->
  "Out[123]=",ExpressionUUID->"3f20fade-0eb8-4ca3-b109-472d1c576f04"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptE", ",", "ptF", ",", "ptG"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "\[Equal]", 
    RowBox[{"b", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.858786777987032*^9, 3.858786801250679*^9}, {
  3.858788317610319*^9, 3.85878834253583*^9}},
 CellLabel->
  "In[124]:=",ExpressionUUID->"9547adb8-8e55-4f83-b084-4952c3d29654"],

Cell[BoxData[
 FractionBox["K", "12"]], "Output",
 CellChangeTimes->{{3.858786793627717*^9, 3.8587868022970963`*^9}, 
   3.8587882951268663`*^9, 3.858788343593449*^9, 3.859026190074284*^9, 
   3.859909415525416*^9, 3.8610979357490253`*^9},
 CellLabel->
  "Out[124]=",ExpressionUUID->"0b858f7e-66a2-4cbe-adc4-eb7f2c84cf32"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 7.27 for X(396)", "Subsubsection",
 CellChangeTimes->{{3.8590267048883963`*^9, 3.859026727459972*^9}, 
   3.8590276561031523`*^9, {3.861090030685443*^9, 3.861090038729651*^9}, 
   3.8610922007045803`*^9},ExpressionUUID->"976e2a37-7b08-44a4-9b07-\
52c74fe73d4b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x396", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"396", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858786060921858*^9, 3.858786181361096*^9}, {
  3.8587863905711937`*^9, 3.858786410594088*^9}, {3.8587881675849857`*^9, 
  3.8587881747443943`*^9}, {3.8590276603278913`*^9, 3.859027662646915*^9}},
 CellLabel->
  "In[125]:=",ExpressionUUID->"c24769c4-6677-4d23-83fd-81b785e6cbd3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SqrtBox["3"], " ", 
     SuperscriptBox["a", "2"]}], "+", 
    RowBox[{"2", " ", "S"}]}], ",", 
   RowBox[{
    RowBox[{
     SqrtBox["3"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    RowBox[{"2", " ", "S"}]}], ",", 
   RowBox[{
    RowBox[{
     SqrtBox["3"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"2", " ", "S"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8587881756168213`*^9, 3.85902618993408*^9, 
  3.859027663621985*^9, 3.85990941553579*^9, 3.8610979357607117`*^9},
 CellLabel->
  "Out[125]=",ExpressionUUID->"b1b68cb1-e5b0-4635-9c2b-616c722162fd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptF", "=", 
  RowBox[{"centerABE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x396", ".", 
      RowBox[{"{", 
       RowBox[{"ptA", ",", "ptB", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenAE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenAB"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858785708664339*^9, 3.858785752208427*^9}, {
   3.858785901049223*^9, 3.8587859885123568`*^9}, {3.85878628204163*^9, 
   3.858786292089315*^9}, {3.858786357153858*^9, 3.858786360769568*^9}, {
   3.858786421793996*^9, 3.858786495154055*^9}, {3.8587867030365143`*^9, 
   3.858786704658731*^9}, {3.858788182793332*^9, 3.858788194031535*^9}, 
   3.858788246343902*^9, 3.859027669840116*^9},
 CellLabel->
  "In[126]:=",ExpressionUUID->"74e23c4b-3427-45e0-ba6c-95483c892772"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "a"}], "+", 
         RowBox[{
          SqrtBox["3"], " ", "c"}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["b", "2"]}], "4"], "+", 
    RowBox[{"a", " ", "c"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{"a", "+", 
      RowBox[{
       SqrtBox["3"], " ", "c"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8587864233685513`*^9, {3.8587864696808767`*^9, 3.858786496037889*^9}, 
   3.8587867069184437`*^9, 3.858786755813157*^9, 3.8587870936108103`*^9, 
   3.8587882474445353`*^9, 3.859026189973741*^9, 3.859027670500546*^9, 
   3.8599094155769873`*^9, 3.861097935804044*^9},
 CellLabel->
  "Out[126]=",ExpressionUUID->"fb93bbd2-eca0-4bfa-96a8-99e8b8e98783"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptG", "=", 
  RowBox[{"centerBCE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x396", ".", 
      RowBox[{"{", 
       RowBox[{"ptB", ",", "ptC", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenCE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenBC"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8587865148663816`*^9, 3.858786564610229*^9}, {
   3.8587866148666897`*^9, 3.858786628154747*^9}, {3.858788263305393*^9, 
   3.858788287137041*^9}, 3.859027676232143*^9},
 CellLabel->
  "In[127]:=",ExpressionUUID->"7f7b6ecb-b0f2-4dd7-8548-fd991172ecc7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SqrtBox["3"], " ", "a"}], "+", "c"}], ")"}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["b", "2"]}], "4"], "+", 
    RowBox[{"a", " ", "c"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["a", "2"]}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"6", " ", "a", " ", "c"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.858788288448888*^9, 3.8590261899851227`*^9, 
  3.859027677347439*^9, 3.8599094155886917`*^9, 3.86109793584933*^9},
 CellLabel->
  "Out[127]=",ExpressionUUID->"6f296718-a7cc-4434-a946-c101162efe92"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptE", ",", "ptF", ",", "ptG"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "\[Equal]", 
    RowBox[{"b", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.858786777987032*^9, 3.858786801250679*^9}, {
  3.858788317610319*^9, 3.85878834253583*^9}},
 CellLabel->
  "In[128]:=",ExpressionUUID->"50bc0c8a-95fa-4eb1-b325-64d667aefa2b"],

Cell[BoxData[
 FractionBox["K", "12"]], "Output",
 CellChangeTimes->{{3.858786793627717*^9, 3.8587868022970963`*^9}, 
   3.8587882951268663`*^9, 3.858788343593449*^9, 3.859026190074284*^9, 
   3.859027688655547*^9, 3.859909415655442*^9, 3.8610979359646893`*^9},
 CellLabel->
  "Out[128]=",ExpressionUUID->"668bc71d-4ee8-49ba-8183-661d40f7a6fe"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 7.29 for X(616)", "Subsubsection",
 CellChangeTimes->{{3.8590267048883963`*^9, 3.859026727459972*^9}, 
   3.8590276561031523`*^9, {3.859042356310068*^9, 3.859042356790008*^9}, {
   3.861090070394148*^9, 3.861090078337948*^9}, 
   3.861092202928553*^9},ExpressionUUID->"d0046373-2984-4859-8f72-\
326ffc0fefcc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x616", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"616", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858786060921858*^9, 3.858786181361096*^9}, {
  3.8587863905711937`*^9, 3.858786410594088*^9}, {3.8587881675849857`*^9, 
  3.8587881747443943`*^9}, {3.8590276603278913`*^9, 3.859027662646915*^9}, {
  3.859042362414756*^9, 3.859042368246148*^9}},
 CellLabel->
  "In[129]:=",ExpressionUUID->"7506da5a-ba41-4b04-a0cf-06edf922bc21"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "5"}], " ", 
     SuperscriptBox["a", "4"]}], "+", 
    SuperscriptBox["b", "4"], "+", 
    SuperscriptBox["c", "4"], "+", 
    RowBox[{"2", " ", 
     SqrtBox["3"], " ", 
     SuperscriptBox["c", "2"], " ", "S"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", 
        SuperscriptBox["b", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["c", "2"]}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["3"], " ", "S"}]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["c", "2"], "-", 
       RowBox[{
        SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["a", "4"], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["b", "2"]}], "-", 
       SuperscriptBox["c", "2"], "+", 
       RowBox[{
        SqrtBox["3"], " ", "S"}]}], ")"}]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"5", " ", 
        SuperscriptBox["b", "2"]}], "+", 
       SuperscriptBox["c", "2"], "+", 
       RowBox[{"2", " ", 
        SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
   RowBox[{
    SuperscriptBox["a", "4"], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["b", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["c", "2"]}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["3"], " ", "S"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       RowBox[{"5", " ", 
        SuperscriptBox["c", "2"]}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["3"], " ", "S"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8587881756168213`*^9, 3.85902618993408*^9, 
  3.859027663621985*^9, 3.8590423702523117`*^9, 3.859909415666065*^9, 
  3.861097935975753*^9},
 CellLabel->
  "Out[129]=",ExpressionUUID->"b73713f8-4706-4ee7-a57d-b71732d9fe36"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptF", "=", 
  RowBox[{"centerABE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x616", ".", 
      RowBox[{"{", 
       RowBox[{"ptA", ",", "ptB", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenAE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenAB"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858785708664339*^9, 3.858785752208427*^9}, {
   3.858785901049223*^9, 3.8587859885123568`*^9}, {3.85878628204163*^9, 
   3.858786292089315*^9}, {3.858786357153858*^9, 3.858786360769568*^9}, {
   3.858786421793996*^9, 3.858786495154055*^9}, {3.8587867030365143`*^9, 
   3.858786704658731*^9}, {3.858788182793332*^9, 3.858788194031535*^9}, 
   3.858788246343902*^9, 3.859027669840116*^9, {3.859042382319257*^9, 
   3.8590423832220087`*^9}},
 CellLabel->
  "In[130]:=",ExpressionUUID->"97d0268c-efac-49f9-8807-0eee67bfa23e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         SuperscriptBox["c", "2"]}], ")"}]}], "+", 
      RowBox[{
       SqrtBox["3"], " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "2"]}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SqrtBox["3"], " ", "a"}], "+", "c"}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"10", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{
       SqrtBox["3"], " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "2"]}]}], ")"}]}]}], ")"}]}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.8587864233685513`*^9, {3.8587864696808767`*^9, 3.858786496037889*^9}, 
   3.8587867069184437`*^9, 3.858786755813157*^9, 3.8587870936108103`*^9, 
   3.8587882474445353`*^9, 3.859026189973741*^9, 3.859027670500546*^9, 
   3.8590423848575172`*^9, 3.8599094157113733`*^9, 3.861097936059243*^9},
 CellLabel->
  "Out[130]=",ExpressionUUID->"01986c69-b959-4b37-bf5d-2c0a063fbc62"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptG", "=", 
  RowBox[{"centerBCE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x616", ".", 
      RowBox[{"{", 
       RowBox[{"ptB", ",", "ptC", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenCE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenBC"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8587865148663816`*^9, 3.858786564610229*^9}, {
   3.8587866148666897`*^9, 3.858786628154747*^9}, {3.858788263305393*^9, 
   3.858788287137041*^9}, 3.859027676232143*^9, {3.859042391407422*^9, 
   3.859042391830041*^9}},
 CellLabel->
  "In[131]:=",ExpressionUUID->"16ef0102-186d-4f22-a818-7532517c6773"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "10"}], " ", 
       SuperscriptBox["a", "3"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["a", "2"], " ", "c"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}]}], ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["a", "4"], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "2"], "+", 
    RowBox[{
     SqrtBox["3"], " ", 
     SuperscriptBox["a", "3"], " ", "c"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       SuperscriptBox["a", "3"]}], "+", 
      RowBox[{"6", " ", "a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["a", "2"], " ", "c"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.858788288448888*^9, 3.8590261899851227`*^9, 
  3.859027677347439*^9, 3.859042393161137*^9, 3.859909415753799*^9, 
  3.861097936147051*^9},
 CellLabel->
  "Out[131]=",ExpressionUUID->"94233189-72ff-4a6b-93ed-51fe306acf90"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptE", ",", "ptF", ",", "ptG"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "\[Equal]", 
    RowBox[{"b", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.858786777987032*^9, 3.858786801250679*^9}, {
  3.858788317610319*^9, 3.85878834253583*^9}},
 CellLabel->
  "In[132]:=",ExpressionUUID->"8ff5b48c-5e1f-4ac2-a1cc-7f0de2345af0"],

Cell[BoxData[
 FractionBox["K", "3"]], "Output",
 CellChangeTimes->{{3.858786793627717*^9, 3.8587868022970963`*^9}, 
   3.8587882951268663`*^9, 3.858788343593449*^9, 3.859026190074284*^9, 
   3.859027688655547*^9, 3.859042401266765*^9, 3.859909415896008*^9, 
   3.861097936319824*^9},
 CellLabel->
  "Out[132]=",ExpressionUUID->"70507645-d145-4e75-80ee-8981fbd963e3"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 7.29 for X(617)", "Subsubsection",
 CellChangeTimes->{{3.8590267048883963`*^9, 3.859026727459972*^9}, 
   3.8590276561031523`*^9, {3.859042356310068*^9, 3.859042356790008*^9}, 
   3.8590426390870533`*^9, {3.861090087586233*^9, 3.861090093905986*^9}, 
   3.86109220460052*^9},ExpressionUUID->"ad790a4d-acb3-41e0-8d6f-\
d443f1e96a2d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x617", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"617", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858786060921858*^9, 3.858786181361096*^9}, {
  3.8587863905711937`*^9, 3.858786410594088*^9}, {3.8587881675849857`*^9, 
  3.8587881747443943`*^9}, {3.8590276603278913`*^9, 3.859027662646915*^9}, {
  3.859042362414756*^9, 3.859042368246148*^9}, {3.8590426420638123`*^9, 
  3.859042644462646*^9}},
 CellLabel->
  "In[133]:=",ExpressionUUID->"907ccbda-af39-4e74-b442-8c2e0d5b368b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"5", " ", 
     SuperscriptBox["a", "4"]}], "-", 
    SuperscriptBox["b", "4"], "-", 
    SuperscriptBox["c", "4"], "+", 
    RowBox[{"2", " ", 
     SqrtBox["3"], " ", 
     SuperscriptBox["c", "2"], " ", "S"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       RowBox[{
        SqrtBox["3"], " ", "S"}]}], ")"}]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["b", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["c", "2"]}], "+", 
       RowBox[{
        SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"5", " ", 
        SuperscriptBox["b", "2"]}], "+", 
       SuperscriptBox["c", "2"], "-", 
       RowBox[{"2", " ", 
        SqrtBox["3"], " ", "S"}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["b", "2"]}], "+", 
       SuperscriptBox["c", "2"], "+", 
       RowBox[{
        SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "-", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       RowBox[{"5", " ", 
        SuperscriptBox["c", "2"]}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["3"], " ", "S"}]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["c", "2"]}], "+", 
       RowBox[{
        SqrtBox["3"], " ", "S"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8587881756168213`*^9, 3.85902618993408*^9, 
  3.859027663621985*^9, 3.8590423702523117`*^9, 3.859042645706134*^9, 
  3.859909415907052*^9, 3.8610979363624363`*^9},
 CellLabel->
  "Out[133]=",ExpressionUUID->"feafa3e4-020f-437a-a0e1-6c4d7446bd09"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptF", "=", 
  RowBox[{"centerABE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x617", ".", 
      RowBox[{"{", 
       RowBox[{"ptA", ",", "ptB", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenAE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenAB"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858785708664339*^9, 3.858785752208427*^9}, {
   3.858785901049223*^9, 3.8587859885123568`*^9}, {3.85878628204163*^9, 
   3.858786292089315*^9}, {3.858786357153858*^9, 3.858786360769568*^9}, {
   3.858786421793996*^9, 3.858786495154055*^9}, {3.8587867030365143`*^9, 
   3.858786704658731*^9}, {3.858788182793332*^9, 3.858788194031535*^9}, 
   3.858788246343902*^9, 3.859027669840116*^9, {3.859042382319257*^9, 
   3.8590423832220087`*^9}, 3.8590426501198273`*^9},
 CellLabel->
  "In[134]:=",ExpressionUUID->"0a6c84b4-9fc6-4090-bc7b-2d66dfceb2ff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{
       SqrtBox["3"], " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "2"]}]}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"2", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           SqrtBox["3"]}], " ", "a"}], "+", "c"}], ")"}]}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", "c", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{
       SqrtBox["3"], " ", "a", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "2"]}]}], ")"}]}]}], ")"}]}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.8587864233685513`*^9, {3.8587864696808767`*^9, 3.858786496037889*^9}, 
   3.8587867069184437`*^9, 3.858786755813157*^9, 3.8587870936108103`*^9, 
   3.8587882474445353`*^9, 3.859026189973741*^9, 3.859027670500546*^9, 
   3.8590423848575172`*^9, 3.859042650686679*^9, 3.8599094159501743`*^9, 
   3.861097936436973*^9},
 CellLabel->
  "Out[134]=",ExpressionUUID->"cf2f6614-24b0-445b-bf2a-62ac9021af5c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptG", "=", 
  RowBox[{"centerBCE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x617", ".", 
      RowBox[{"{", 
       RowBox[{"ptB", ",", "ptC", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenCE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenBC"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8587865148663816`*^9, 3.858786564610229*^9}, {
   3.8587866148666897`*^9, 3.858786628154747*^9}, {3.858788263305393*^9, 
   3.858788287137041*^9}, 3.859027676232143*^9, {3.859042391407422*^9, 
   3.859042391830041*^9}, 3.859042654781164*^9},
 CellLabel->
  "In[135]:=",ExpressionUUID->"13618b1f-7df6-4237-8b3b-eb69acdb3bf4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "4"], " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"10", " ", 
       SuperscriptBox["a", "3"]}], "-", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["a", "2"], " ", "c"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "2"]}], " ", 
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", 
       SqrtBox["3"], " ", "a", " ", "c"}]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", "a", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", 
       SuperscriptBox["a", "3"]}], "-", 
      RowBox[{"6", " ", "a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["a", "2"], " ", "c"}], "+", 
      RowBox[{
       SqrtBox["3"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.858788288448888*^9, 3.8590261899851227`*^9, 
  3.859027677347439*^9, 3.859042393161137*^9, 3.8590426552914457`*^9, 
  3.859909415994711*^9, 3.8610979365183372`*^9},
 CellLabel->
  "Out[135]=",ExpressionUUID->"d03c9a2c-f568-4d4c-be56-57e36b0d9439"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptE", ",", "ptF", ",", "ptG"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "\[Equal]", 
    RowBox[{"b", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.858786777987032*^9, 3.858786801250679*^9}, {
  3.858788317610319*^9, 3.85878834253583*^9}},
 CellLabel->
  "In[136]:=",ExpressionUUID->"630b78eb-f4b5-4306-8ea8-beb8003ef4eb"],

Cell[BoxData[
 FractionBox["K", "3"]], "Output",
 CellChangeTimes->{{3.858786793627717*^9, 3.8587868022970963`*^9}, 
   3.8587882951268663`*^9, 3.858788343593449*^9, 3.859026190074284*^9, 
   3.859027688655547*^9, 3.859042401266765*^9, 3.859042659120059*^9, 
   3.859909416118535*^9, 3.861097936709234*^9},
 CellLabel->
  "Out[136]=",ExpressionUUID->"479c7365-b6bf-416e-9d43-ef0949cf365d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 7.32 for X(146)", "Subsubsection",
 CellChangeTimes->{{3.8590267048883963`*^9, 3.859026727459972*^9}, 
   3.8590276561031523`*^9, {3.859042356310068*^9, 3.859042356790008*^9}, 
   3.8590426390870533`*^9, {3.8590447361657467`*^9, 3.859044737189307*^9}, {
   3.861090135626151*^9, 3.86109013978616*^9}, 
   3.861092206856554*^9},ExpressionUUID->"bb08997d-7014-49b0-abd9-\
391e0cc0a303"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x146", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"146", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858786060921858*^9, 3.858786181361096*^9}, {
  3.8587863905711937`*^9, 3.858786410594088*^9}, {3.8587881675849857`*^9, 
  3.8587881747443943`*^9}, {3.8590276603278913`*^9, 3.859027662646915*^9}, {
  3.859042362414756*^9, 3.859042368246148*^9}, {3.8590426420638123`*^9, 
  3.859042644462646*^9}, {3.859044740382359*^9, 3.8590447452773867`*^9}},
 CellLabel->
  "In[137]:=",ExpressionUUID->"1c42f395-236e-4a68-85f9-d987e4bc64c9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "10"], "+", 
    RowBox[{
     SuperscriptBox["a", "8"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "4"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "6"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "8"]}], "-", 
    SuperscriptBox["b", "10"], "+", 
    RowBox[{
     SuperscriptBox["a", "8"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"9", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"7", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["b", "8"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"16", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"7", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "8"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "8"]}], "-", 
    SuperscriptBox["c", "10"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "10"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "8"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "4"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "8"]}], "+", 
    SuperscriptBox["b", "10"], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "8"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"7", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"9", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "8"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"16", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"7", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "8"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "8"]}], "-", 
    SuperscriptBox["c", "10"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "10"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "8"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "6"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "8"]}], "-", 
    SuperscriptBox["b", "10"], "-", 
    RowBox[{
     SuperscriptBox["a", "8"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"7", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"16", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"7", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "8"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"9", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "8"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "8"]}], "+", 
    SuperscriptBox["c", "10"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8587881756168213`*^9, 3.85902618993408*^9, 
  3.859027663621985*^9, 3.8590423702523117`*^9, 3.859042645706134*^9, 
  3.8590447458071947`*^9, 3.8599094161311903`*^9, 3.861097936722991*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"7cee9093-0db1-4a35-8a9d-854d83a18794"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptF", "=", 
  RowBox[{"centerABE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x146", ".", 
      RowBox[{"{", 
       RowBox[{"ptA", ",", "ptB", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenAE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenAB"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858785708664339*^9, 3.858785752208427*^9}, {
   3.858785901049223*^9, 3.8587859885123568`*^9}, {3.85878628204163*^9, 
   3.858786292089315*^9}, {3.858786357153858*^9, 3.858786360769568*^9}, {
   3.858786421793996*^9, 3.858786495154055*^9}, {3.8587867030365143`*^9, 
   3.858786704658731*^9}, {3.858788182793332*^9, 3.858788194031535*^9}, 
   3.858788246343902*^9, 3.859027669840116*^9, {3.859042382319257*^9, 
   3.8590423832220087`*^9}, 3.8590426501198273`*^9, {3.859044752350841*^9, 
   3.859044753373679*^9}},
 CellLabel->
  "In[138]:=",ExpressionUUID->"5ed0dbb5-8124-4b2e-b3b4-170d15e15cd9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["c", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["c", "2"]}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "16"]}], " ", 
    SuperscriptBox["c", "6"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["c", "2"]}]}], ")"}], "2"]}], ",", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["c", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["c", "2"]}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8587864233685513`*^9, {3.8587864696808767`*^9, 3.858786496037889*^9}, 
   3.8587867069184437`*^9, 3.858786755813157*^9, 3.8587870936108103`*^9, 
   3.8587882474445353`*^9, 3.859026189973741*^9, 3.859027670500546*^9, 
   3.8590423848575172`*^9, 3.859042650686679*^9, 3.8590447547233887`*^9, 
   3.859909416171184*^9, 3.861097936767992*^9},
 CellLabel->
  "Out[138]=",ExpressionUUID->"50245e89-5ae5-41fb-890e-0ee1d1527e27"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptG", "=", 
  RowBox[{"centerBCE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x146", ".", 
      RowBox[{"{", 
       RowBox[{"ptB", ",", "ptC", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenCE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenBC"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8587865148663816`*^9, 3.858786564610229*^9}, {
   3.8587866148666897`*^9, 3.858786628154747*^9}, {3.858788263305393*^9, 
   3.858788287137041*^9}, 3.859027676232143*^9, {3.859042391407422*^9, 
   3.859042391830041*^9}, 3.859042654781164*^9, {3.859044768519006*^9, 
   3.859044769565692*^9}},
 CellLabel->
  "In[139]:=",ExpressionUUID->"768e57a8-58ad-4707-bb73-fa8ab16cb5d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "32"], " ", 
    SuperscriptBox["a", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "16"]}], " ", 
    SuperscriptBox["a", "6"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "32"]}], " ", 
    SuperscriptBox["a", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"]}], ")"}], "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.858788288448888*^9, 3.8590261899851227`*^9, 
  3.859027677347439*^9, 3.859042393161137*^9, 3.8590426552914457`*^9, 
  3.859044770167042*^9, 3.859909416231501*^9, 3.8610979368299637`*^9},
 CellLabel->
  "Out[139]=",ExpressionUUID->"47bde273-e20d-44a5-8dfb-a8c993963628"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptE", ",", "ptF", ",", "ptG"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "\[Equal]", 
    RowBox[{"b", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.858786777987032*^9, 3.858786801250679*^9}, {
  3.858788317610319*^9, 3.85878834253583*^9}},
 CellLabel->
  "In[140]:=",ExpressionUUID->"ca7b7b5a-2ecd-4261-95f2-5def058f5a37"],

Cell[BoxData["K"], "Output",
 CellChangeTimes->{{3.858786793627717*^9, 3.8587868022970963`*^9}, 
   3.8587882951268663`*^9, 3.858788343593449*^9, 3.859026190074284*^9, 
   3.859027688655547*^9, 3.859042401266765*^9, 3.859042659120059*^9, 
   3.859044782025463*^9, 3.859909416273966*^9, 3.861097936876124*^9},
 CellLabel->
  "Out[140]=",ExpressionUUID->"a27e723e-1196-4568-a25a-04fb6d954466"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 7.32 for X(147)", "Subsubsection",
 CellChangeTimes->{{3.8590267048883963`*^9, 3.859026727459972*^9}, 
   3.8590276561031523`*^9, {3.859042356310068*^9, 3.859042356790008*^9}, 
   3.8590426390870533`*^9, {3.8590447361657467`*^9, 3.859044737189307*^9}, 
   3.859044857862288*^9, 3.8610901507470903`*^9, 
   3.861092208728591*^9},ExpressionUUID->"9f17204f-a935-48b4-9347-\
af6013b7e006"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x147", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"147", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858786060921858*^9, 3.858786181361096*^9}, {
  3.8587863905711937`*^9, 3.858786410594088*^9}, {3.8587881675849857`*^9, 
  3.8587881747443943`*^9}, {3.8590276603278913`*^9, 3.859027662646915*^9}, {
  3.859042362414756*^9, 3.859042368246148*^9}, {3.8590426420638123`*^9, 
  3.859042644462646*^9}, {3.859044740382359*^9, 3.8590447452773867`*^9}, {
  3.859044866006941*^9, 3.859044872166421*^9}},
 CellLabel->
  "In[141]:=",ExpressionUUID->"1bb652cc-81d2-4b0e-8dc4-82da9407bf0e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "8"], "+", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "6"]}], "-", 
    SuperscriptBox["b", "8"], "+", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    SuperscriptBox["c", "8"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "8"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "6"]}], "+", 
    SuperscriptBox["b", "8"], "+", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    SuperscriptBox["c", "8"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "8"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "6"]}], "-", 
    SuperscriptBox["b", "8"], "+", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    SuperscriptBox["c", "8"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8587881756168213`*^9, 3.85902618993408*^9, 
  3.859027663621985*^9, 3.8590423702523117`*^9, 3.859042645706134*^9, 
  3.8590447458071947`*^9, 3.859044875164279*^9, 3.8599094162873583`*^9, 
  3.861097936888878*^9},
 CellLabel->
  "Out[141]=",ExpressionUUID->"9bcbc869-fa07-4c93-9d24-d177db7b70ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptF", "=", 
  RowBox[{"centerABE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x147", ".", 
      RowBox[{"{", 
       RowBox[{"ptA", ",", "ptB", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenAE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenAB"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858785708664339*^9, 3.858785752208427*^9}, {
   3.858785901049223*^9, 3.8587859885123568`*^9}, {3.85878628204163*^9, 
   3.858786292089315*^9}, {3.858786357153858*^9, 3.858786360769568*^9}, {
   3.858786421793996*^9, 3.858786495154055*^9}, {3.8587867030365143`*^9, 
   3.858786704658731*^9}, {3.858788182793332*^9, 3.858788194031535*^9}, 
   3.858788246343902*^9, 3.859027669840116*^9, {3.859042382319257*^9, 
   3.8590423832220087`*^9}, 3.8590426501198273`*^9, {3.859044752350841*^9, 
   3.859044753373679*^9}, 3.859044879415017*^9},
 CellLabel->
  "In[142]:=",ExpressionUUID->"23b3d934-81a7-4fac-9ea6-68119d998f95"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "32"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["b", "2"], " ", "c"}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["c", "3"]}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "16"]}], " ", 
    SuperscriptBox["c", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["c", "2"]}]}], ")"}], "2"]}], ",", 
   RowBox[{
    FractionBox["1", "32"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["b", "2"], " ", "c"}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["c", "3"]}]}], ")"}], "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8587864233685513`*^9, {3.8587864696808767`*^9, 3.858786496037889*^9}, 
   3.8587867069184437`*^9, 3.858786755813157*^9, 3.8587870936108103`*^9, 
   3.8587882474445353`*^9, 3.859026189973741*^9, 3.859027670500546*^9, 
   3.8590423848575172`*^9, 3.859042650686679*^9, 3.8590447547233887`*^9, 
   3.859044880014617*^9, 3.859909416330288*^9, 3.8610979369348297`*^9},
 CellLabel->
  "Out[142]=",ExpressionUUID->"9bdf446d-d7dd-4ec2-826b-9cdf9820c146"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptG", "=", 
  RowBox[{"centerBCE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x147", ".", 
      RowBox[{"{", 
       RowBox[{"ptB", ",", "ptC", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenCE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenBC"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8587865148663816`*^9, 3.858786564610229*^9}, {
   3.8587866148666897`*^9, 3.858786628154747*^9}, {3.858788263305393*^9, 
   3.858788287137041*^9}, 3.859027676232143*^9, {3.859042391407422*^9, 
   3.859042391830041*^9}, 3.859042654781164*^9, {3.859044768519006*^9, 
   3.859044769565692*^9}, 3.859044885903104*^9},
 CellLabel->
  "In[143]:=",ExpressionUUID->"8993f150-0627-4fe5-a0f4-3056976e56de"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "32"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SuperscriptBox["a", "3"]}], "+", 
       RowBox[{"a", " ", 
        SuperscriptBox["b", "2"]}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "16"]}], " ", 
    SuperscriptBox["a", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SuperscriptBox["a", "2"]}], "+", 
       SuperscriptBox["b", "2"]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "32"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        SuperscriptBox["a", "3"]}], "+", 
       RowBox[{"a", " ", 
        SuperscriptBox["b", "2"]}]}], ")"}], "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.858788288448888*^9, 3.8590261899851227`*^9, 
  3.859027677347439*^9, 3.859042393161137*^9, 3.8590426552914457`*^9, 
  3.859044770167042*^9, 3.859044886882308*^9, 3.8599094163453197`*^9, 
  3.861097936985882*^9},
 CellLabel->
  "Out[143]=",ExpressionUUID->"f03624df-7b30-466f-9c51-2c01e31fbf44"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptE", ",", "ptF", ",", "ptG"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "\[Equal]", 
    RowBox[{"b", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.858786777987032*^9, 3.858786801250679*^9}, {
  3.858788317610319*^9, 3.85878834253583*^9}},
 CellLabel->
  "In[144]:=",ExpressionUUID->"1f0b5c6a-f503-4833-b53e-618fee01d588"],

Cell[BoxData["K"], "Output",
 CellChangeTimes->{{3.858786793627717*^9, 3.8587868022970963`*^9}, 
   3.8587882951268663`*^9, 3.858788343593449*^9, 3.859026190074284*^9, 
   3.859027688655547*^9, 3.859042401266765*^9, 3.859042659120059*^9, 
   3.859044782025463*^9, 3.859044895832169*^9, 3.8599094163865633`*^9, 
   3.861097937032836*^9},
 CellLabel->
  "Out[144]=",ExpressionUUID->"c93c71c1-e472-4a77-8acd-fcfceef4c97a"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 7.32 for X(150)", "Subsubsection",
 CellChangeTimes->{{3.8590267048883963`*^9, 3.859026727459972*^9}, 
   3.8590276561031523`*^9, {3.859042356310068*^9, 3.859042356790008*^9}, 
   3.8590426390870533`*^9, {3.8590447361657467`*^9, 3.859044737189307*^9}, {
   3.859044910742312*^9, 3.859044911045905*^9}, 3.861090154267125*^9, 
   3.861092210400671*^9},ExpressionUUID->"74b698cb-b9ee-4266-9b66-\
2bcc8e23feea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x150", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"150", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858786060921858*^9, 3.858786181361096*^9}, {
  3.8587863905711937`*^9, 3.858786410594088*^9}, {3.8587881675849857`*^9, 
  3.8587881747443943`*^9}, {3.8590276603278913`*^9, 3.859027662646915*^9}, {
  3.859042362414756*^9, 3.859042368246148*^9}, {3.8590426420638123`*^9, 
  3.859042644462646*^9}, {3.859044740382359*^9, 3.8590447452773867`*^9}, {
  3.85904491431075*^9, 3.859044918878051*^9}},
 CellLabel->
  "In[145]:=",ExpressionUUID->"3a45b50d-1352-4807-9b10-64e6417279b5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "4"], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "b"}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "3"]}], "-", 
    SuperscriptBox["b", "4"], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["b", "3"], " ", "c"}], "-", 
    RowBox[{"a", " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "3"]}], "-", 
    SuperscriptBox["c", "4"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "b"}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "3"]}], "+", 
    SuperscriptBox["b", "4"], "+", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["b", "3"], " ", "c"}], "-", 
    RowBox[{"a", " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "3"]}], "-", 
    SuperscriptBox["c", "4"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "b"}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "3"]}], "-", 
    SuperscriptBox["b", "4"], "+", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["b", "3"], " ", "c"}], "+", 
    RowBox[{"a", " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "3"]}], "+", 
    SuperscriptBox["c", "4"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8587881756168213`*^9, 3.85902618993408*^9, 
  3.859027663621985*^9, 3.8590423702523117`*^9, 3.859042645706134*^9, 
  3.8590447458071947`*^9, 3.8590449199286747`*^9, 3.859909416397592*^9, 
  3.86109793708181*^9},
 CellLabel->
  "Out[145]=",ExpressionUUID->"664181ee-5e8a-47ef-9791-a75ec13ab6ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptF", "=", 
  RowBox[{"centerABE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x150", ".", 
      RowBox[{"{", 
       RowBox[{"ptA", ",", "ptB", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenAE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenAB"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858785708664339*^9, 3.858785752208427*^9}, {
   3.858785901049223*^9, 3.8587859885123568`*^9}, {3.85878628204163*^9, 
   3.858786292089315*^9}, {3.858786357153858*^9, 3.858786360769568*^9}, {
   3.858786421793996*^9, 3.858786495154055*^9}, {3.8587867030365143`*^9, 
   3.858786704658731*^9}, {3.858788182793332*^9, 3.858788194031535*^9}, 
   3.858788246343902*^9, 3.859027669840116*^9, {3.859042382319257*^9, 
   3.8590423832220087`*^9}, 3.8590426501198273`*^9, {3.859044752350841*^9, 
   3.859044753373679*^9}, {3.859044924479558*^9, 3.859044924734539*^9}},
 CellLabel->
  "In[146]:=",ExpressionUUID->"3d562128-095b-4412-a36e-b3c017f10a6d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "8"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", 
       RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", 
       RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "2"]}], ",", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", 
       RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8587864233685513`*^9, {3.8587864696808767`*^9, 3.858786496037889*^9}, 
   3.8587867069184437`*^9, 3.858786755813157*^9, 3.8587870936108103`*^9, 
   3.8587882474445353`*^9, 3.859026189973741*^9, 3.859027670500546*^9, 
   3.8590423848575172`*^9, 3.859042650686679*^9, 3.8590447547233887`*^9, 
   3.859044925845641*^9, 3.859909416439583*^9, 3.861097937127899*^9},
 CellLabel->
  "Out[146]=",ExpressionUUID->"38edfd7b-e4f6-4116-995e-973c8775bd62"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptG", "=", 
  RowBox[{"centerBCE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x150", ".", 
      RowBox[{"{", 
       RowBox[{"ptB", ",", "ptC", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenCE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenBC"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8587865148663816`*^9, 3.858786564610229*^9}, {
   3.8587866148666897`*^9, 3.858786628154747*^9}, {3.858788263305393*^9, 
   3.858788287137041*^9}, 3.859027676232143*^9, {3.859042391407422*^9, 
   3.859042391830041*^9}, 3.859042654781164*^9, {3.859044768519006*^9, 
   3.859044769565692*^9}, {3.8590449338556967`*^9, 3.859044934102459*^9}},
 CellLabel->
  "In[147]:=",ExpressionUUID->"b370ef14-e4bc-4fc9-bd8b-fbd558b426a8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b"}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b"}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "8"]}], " ", 
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b"}], ")"}], "2"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.858788288448888*^9, 3.8590261899851227`*^9, 
  3.859027677347439*^9, 3.859042393161137*^9, 3.8590426552914457`*^9, 
  3.859044770167042*^9, 3.859044935200601*^9, 3.8599094164840508`*^9, 
  3.861097937179235*^9},
 CellLabel->
  "Out[147]=",ExpressionUUID->"b056c503-2c0c-4e78-9739-98b11ea72d54"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptE", ",", "ptF", ",", "ptG"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "\[Equal]", 
    RowBox[{"b", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.858786777987032*^9, 3.858786801250679*^9}, {
  3.858788317610319*^9, 3.85878834253583*^9}},
 CellLabel->
  "In[148]:=",ExpressionUUID->"5c365c94-6724-4e79-9573-2791a943c2c5"],

Cell[BoxData["K"], "Output",
 CellChangeTimes->{{3.858786793627717*^9, 3.8587868022970963`*^9}, 
   3.8587882951268663`*^9, 3.858788343593449*^9, 3.859026190074284*^9, 
   3.859027688655547*^9, 3.859042401266765*^9, 3.859042659120059*^9, 
   3.859044782025463*^9, 3.859044938329708*^9, 3.859909416494575*^9, 
   3.861097937225511*^9},
 CellLabel->
  "Out[148]=",ExpressionUUID->"6321edfd-6e21-4ce9-b37f-b55016bfaa6d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 7.32 for X(151)", "Subsubsection",
 CellChangeTimes->{{3.8590267048883963`*^9, 3.859026727459972*^9}, 
   3.8590276561031523`*^9, {3.859042356310068*^9, 3.859042356790008*^9}, 
   3.8590426390870533`*^9, {3.8590447361657467`*^9, 3.859044737189307*^9}, {
   3.859044910742312*^9, 3.859044911045905*^9}, 3.8590449512304087`*^9, 
   3.861090158203286*^9, 
   3.861092213152686*^9},ExpressionUUID->"ac1a83d0-835a-46e5-b4f2-\
fbb027e73ec3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x151", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"151", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858786060921858*^9, 3.858786181361096*^9}, {
  3.8587863905711937`*^9, 3.858786410594088*^9}, {3.8587881675849857`*^9, 
  3.8587881747443943`*^9}, {3.8590276603278913`*^9, 3.859027662646915*^9}, {
  3.859042362414756*^9, 3.859042368246148*^9}, {3.8590426420638123`*^9, 
  3.859042644462646*^9}, {3.859044740382359*^9, 3.8590447452773867`*^9}, {
  3.85904491431075*^9, 3.859044918878051*^9}, {3.859044953302846*^9, 
  3.859044955854165*^9}},
 CellLabel->
  "In[149]:=",ExpressionUUID->"b584d897-e52c-4f81-b164-50a442ed7630"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "10"], "-", 
    RowBox[{
     SuperscriptBox["a", "9"], " ", "b"}], "+", 
    RowBox[{
     SuperscriptBox["a", "8"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "7"], " ", 
     SuperscriptBox["b", "3"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "4"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "6"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "7"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "8"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "9"]}], "-", 
    SuperscriptBox["b", "10"], "-", 
    RowBox[{
     SuperscriptBox["a", "9"], " ", "c"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "8"], " ", "b", " ", "c"}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "7"], " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "3"], " ", "c"}], "+", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "4"], " ", "c"}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "5"], " ", "c"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "6"], " ", "c"}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "7"], " ", "c"}], "-", 
    RowBox[{"3", " ", "a", " ", 
     SuperscriptBox["b", "8"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["b", "9"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "8"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "7"], " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"16", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"18", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["b", "8"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "7"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", "b", " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"24", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"14", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"8", " ", "a", " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["b", "7"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "5"], " ", "b", " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"14", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"26", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"6", " ", "a", " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "4"], " ", "b", " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{"18", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"6", " ", "a", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"8", " ", "a", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["c", "7"]}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["c", "7"]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "7"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "8"]}], "-", 
    RowBox[{"3", " ", "a", " ", "b", " ", 
     SuperscriptBox["c", "8"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "8"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "9"]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "9"]}], "-", 
    SuperscriptBox["c", "10"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "10"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "9"], " ", "b"}], "-", 
    RowBox[{
     SuperscriptBox["a", "8"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "7"], " ", 
     SuperscriptBox["b", "3"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "4"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "6"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "7"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "8"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "9"]}], "+", 
    SuperscriptBox["b", "10"], "+", 
    RowBox[{
     SuperscriptBox["a", "9"], " ", "c"}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "8"], " ", "b", " ", "c"}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "7"], " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "3"], " ", "c"}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "4"], " ", "c"}], "+", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "5"], " ", "c"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "6"], " ", "c"}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "7"], " ", "c"}], "+", 
    RowBox[{"3", " ", "a", " ", 
     SuperscriptBox["b", "8"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["b", "9"], " ", "c"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "8"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"18", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"16", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"6", " ", "a", " ", 
     SuperscriptBox["b", "7"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "8"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["a", "7"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "6"], " ", "b", " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"14", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"24", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"2", " ", "a", " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "7"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "5"], " ", "b", " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"26", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"14", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"12", " ", "a", " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "4"], " ", "b", " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{"18", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"12", " ", "a", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"2", " ", "a", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["c", "7"]}], "+", 
    RowBox[{"6", " ", "a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "7"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "7"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "8"]}], "-", 
    RowBox[{"3", " ", "a", " ", "b", " ", 
     SuperscriptBox["c", "8"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "8"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "9"]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "9"]}], "-", 
    SuperscriptBox["c", "10"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "10"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "9"], " ", "b"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "8"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["a", "7"], " ", 
     SuperscriptBox["b", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "4"]}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "5"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "6"]}], "-", 
    RowBox[{"4", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "7"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "8"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "9"]}], "-", 
    SuperscriptBox["b", "10"], "+", 
    RowBox[{
     SuperscriptBox["a", "9"], " ", "c"}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "8"], " ", "b", " ", "c"}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "3"], " ", "c"}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "4"], " ", "c"}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "5"], " ", "c"}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "6"], " ", "c"}], "-", 
    RowBox[{"3", " ", "a", " ", 
     SuperscriptBox["b", "8"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["b", "9"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "8"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "7"], " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"26", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"6", " ", "a", " ", 
     SuperscriptBox["b", "7"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "8"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "7"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", "b", " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"18", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"14", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"14", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"18", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"2", " ", "a", " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "7"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "5"], " ", "b", " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"24", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"12", " ", "a", " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"8", " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "4"], " ", "b", " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"12", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{"12", " ", "a", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"16", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"2", " ", "a", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"8", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["c", "7"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["c", "7"]}], "-", 
    RowBox[{"6", " ", "a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "7"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "7"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "8"]}], "+", 
    RowBox[{"3", " ", "a", " ", "b", " ", 
     SuperscriptBox["c", "8"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "8"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "9"]}], "-", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "9"]}], "+", 
    SuperscriptBox["c", "10"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8587881756168213`*^9, 3.85902618993408*^9, 
  3.859027663621985*^9, 3.8590423702523117`*^9, 3.859042645706134*^9, 
  3.8590447458071947`*^9, 3.8590449199286747`*^9, 3.859044956578836*^9, 
  3.859909416545951*^9, 3.861097937247407*^9},
 CellLabel->
  "Out[149]=",ExpressionUUID->"5c41ce3a-aa7d-4bb0-a0bb-d7cf86fb333d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptF", "=", 
  RowBox[{"centerABE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x151", ".", 
      RowBox[{"{", 
       RowBox[{"ptA", ",", "ptB", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenAE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenAB"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858785708664339*^9, 3.858785752208427*^9}, {
   3.858785901049223*^9, 3.8587859885123568`*^9}, {3.85878628204163*^9, 
   3.858786292089315*^9}, {3.858786357153858*^9, 3.858786360769568*^9}, {
   3.858786421793996*^9, 3.858786495154055*^9}, {3.8587867030365143`*^9, 
   3.858786704658731*^9}, {3.858788182793332*^9, 3.858788194031535*^9}, 
   3.858788246343902*^9, 3.859027669840116*^9, {3.859042382319257*^9, 
   3.8590423832220087`*^9}, 3.8590426501198273`*^9, {3.859044752350841*^9, 
   3.859044753373679*^9}, {3.859044924479558*^9, 3.859044924734539*^9}, 
   3.8590449623833027`*^9},
 CellLabel->
  "In[150]:=",ExpressionUUID->"29c8b74f-cea6-40bc-a8f2-eccac2e3f312"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", 
       RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", 
       RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "8"]}], ",", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", 
       RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8587864233685513`*^9, {3.8587864696808767`*^9, 3.858786496037889*^9}, 
   3.8587867069184437`*^9, 3.858786755813157*^9, 3.8587870936108103`*^9, 
   3.8587882474445353`*^9, 3.859026189973741*^9, 3.859027670500546*^9, 
   3.8590423848575172`*^9, 3.859042650686679*^9, 3.8590447547233887`*^9, 
   3.859044925845641*^9, 3.859044963575554*^9, 3.859909416591305*^9, 
   3.861097937297393*^9},
 CellLabel->
  "Out[150]=",ExpressionUUID->"d181f1b7-8fa8-44b4-ab65-6e1e86a9fcf1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptG", "=", 
  RowBox[{"centerBCE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x151", ".", 
      RowBox[{"{", 
       RowBox[{"ptB", ",", "ptC", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenCE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenBC"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8587865148663816`*^9, 3.858786564610229*^9}, {
   3.8587866148666897`*^9, 3.858786628154747*^9}, {3.858788263305393*^9, 
   3.858788287137041*^9}, 3.859027676232143*^9, {3.859042391407422*^9, 
   3.859042391830041*^9}, 3.859042654781164*^9, {3.859044768519006*^9, 
   3.859044769565692*^9}, {3.8590449338556967`*^9, 3.859044934102459*^9}, 
   3.8590449728554173`*^9},
 CellLabel->
  "In[151]:=",ExpressionUUID->"60a601be-16c4-4424-8e43-89317be7d95b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox["a", "6"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    SuperscriptBox["a", "8"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b"}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "8"]}], " ", 
    SuperscriptBox["a", "6"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.858788288448888*^9, 3.8590261899851227`*^9, 
  3.859027677347439*^9, 3.859042393161137*^9, 3.8590426552914457`*^9, 
  3.859044770167042*^9, 3.859044935200601*^9, 3.8590449743495827`*^9, 
  3.859909416639144*^9, 3.861097937343318*^9},
 CellLabel->
  "Out[151]=",ExpressionUUID->"0b9337f4-63e1-4683-9a32-bbd06cbeef36"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptE", ",", "ptF", ",", "ptG"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "\[Equal]", 
    RowBox[{"b", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.858786777987032*^9, 3.858786801250679*^9}, {
  3.858788317610319*^9, 3.85878834253583*^9}},
 CellLabel->
  "In[152]:=",ExpressionUUID->"b05f1a13-aa8f-4b2a-a3b0-fec484c9f1be"],

Cell[BoxData["K"], "Output",
 CellChangeTimes->{{3.858786793627717*^9, 3.8587868022970963`*^9}, 
   3.8587882951268663`*^9, 3.858788343593449*^9, 3.859026190074284*^9, 
   3.859027688655547*^9, 3.859042401266765*^9, 3.859042659120059*^9, 
   3.859044782025463*^9, 3.859044938329708*^9, 3.859044978714787*^9, 
   3.8599094166876593`*^9, 3.861097937391889*^9},
 CellLabel->
  "Out[152]=",ExpressionUUID->"4bde0875-9159-48d6-b46e-c4e9b9c0f064"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 7.32 for X(152)", "Subsubsection",
 CellChangeTimes->{{3.8590267048883963`*^9, 3.859026727459972*^9}, 
   3.8590276561031523`*^9, {3.859042356310068*^9, 3.859042356790008*^9}, 
   3.8590426390870533`*^9, {3.8590447361657467`*^9, 3.859044737189307*^9}, {
   3.859044910742312*^9, 3.859044911045905*^9}, 3.859044985718574*^9, 
   3.861090160675356*^9, 
   3.861092214808617*^9},ExpressionUUID->"466f562e-5536-4cb7-ae0d-\
23406d1e39ca"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x152", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"152", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858786060921858*^9, 3.858786181361096*^9}, {
  3.8587863905711937`*^9, 3.858786410594088*^9}, {3.8587881675849857`*^9, 
  3.8587881747443943`*^9}, {3.8590276603278913`*^9, 3.859027662646915*^9}, {
  3.859042362414756*^9, 3.859042368246148*^9}, {3.8590426420638123`*^9, 
  3.859042644462646*^9}, {3.859044740382359*^9, 3.8590447452773867`*^9}, {
  3.85904491431075*^9, 3.859044918878051*^9}, {3.859044988014936*^9, 
  3.859044990414597*^9}},
 CellLabel->
  "In[153]:=",ExpressionUUID->"d14e7844-35ac-472d-9a53-13e50aeecddb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "8"], "-", 
    RowBox[{
     SuperscriptBox["a", "7"], " ", "b"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "3"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "5"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "6"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "7"]}], "-", 
    SuperscriptBox["b", "8"], "-", 
    RowBox[{
     SuperscriptBox["a", "7"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", "b", " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "3"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "4"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "5"], " ", "c"}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "6"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["b", "7"], " ", "c"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "5"], " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"3", " ", "a", " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "4"], " ", "b", " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"10", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"3", " ", "a", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"3", " ", "a", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"3", " ", "a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"a", " ", "b", " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "7"]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "7"]}], "-", 
    SuperscriptBox["c", "8"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "8"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "7"], " ", "b"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "3"]}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "5"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "6"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "7"]}], "+", 
    SuperscriptBox["b", "8"], "+", 
    RowBox[{
     SuperscriptBox["a", "7"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", "b", " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "3"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "4"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "5"], " ", "c"}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "6"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["b", "7"], " ", "c"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "5"], " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "4"], " ", "b", " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"10", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"a", " ", "b", " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "7"]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "7"]}], "-", 
    SuperscriptBox["c", "8"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "8"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "7"], " ", "b"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "4"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "5"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "6"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "7"]}], "-", 
    SuperscriptBox["b", "8"], "+", 
    RowBox[{
     SuperscriptBox["a", "7"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", "b", " ", "c"}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "3"], " ", "c"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "4"], " ", "c"}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "5"], " ", "c"}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "6"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["b", "7"], " ", "c"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "6"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "5"], " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"10", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "6"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "4"], " ", "b", " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"a", " ", "b", " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "7"]}], "-", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "7"]}], "+", 
    SuperscriptBox["c", "8"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8587881756168213`*^9, 3.85902618993408*^9, 
  3.859027663621985*^9, 3.8590423702523117`*^9, 3.859042645706134*^9, 
  3.8590447458071947`*^9, 3.8590449199286747`*^9, 3.859044991366724*^9, 
  3.859909416707922*^9, 3.861097937408841*^9},
 CellLabel->
  "Out[153]=",ExpressionUUID->"2528f025-4cc3-4d61-b483-de03827dafa4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptF", "=", 
  RowBox[{"centerABE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x152", ".", 
      RowBox[{"{", 
       RowBox[{"ptA", ",", "ptB", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenAE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenAB"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858785708664339*^9, 3.858785752208427*^9}, {
   3.858785901049223*^9, 3.8587859885123568`*^9}, {3.85878628204163*^9, 
   3.858786292089315*^9}, {3.858786357153858*^9, 3.858786360769568*^9}, {
   3.858786421793996*^9, 3.858786495154055*^9}, {3.8587867030365143`*^9, 
   3.858786704658731*^9}, {3.858788182793332*^9, 3.858788194031535*^9}, 
   3.858788246343902*^9, 3.859027669840116*^9, {3.859042382319257*^9, 
   3.8590423832220087`*^9}, 3.8590426501198273`*^9, {3.859044752350841*^9, 
   3.859044753373679*^9}, {3.859044924479558*^9, 3.859044924734539*^9}, 
   3.8590449967435837`*^9},
 CellLabel->
  "In[154]:=",ExpressionUUID->"e1e660c3-c3ac-4b1c-a8d9-60c4a6414016"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", 
       RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", 
       RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "6"]}], ",", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", 
       RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8587864233685513`*^9, {3.8587864696808767`*^9, 3.858786496037889*^9}, 
   3.8587867069184437`*^9, 3.858786755813157*^9, 3.8587870936108103`*^9, 
   3.8587882474445353`*^9, 3.859026189973741*^9, 3.859027670500546*^9, 
   3.8590423848575172`*^9, 3.859042650686679*^9, 3.8590447547233887`*^9, 
   3.859044925845641*^9, 3.859044998187661*^9, 3.859909416756754*^9, 
   3.861097937453761*^9},
 CellLabel->
  "Out[154]=",ExpressionUUID->"af9c21b9-2589-49e2-997f-21977f144425"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptG", "=", 
  RowBox[{"centerBCE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x152", ".", 
      RowBox[{"{", 
       RowBox[{"ptB", ",", "ptC", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenCE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenBC"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8587865148663816`*^9, 3.858786564610229*^9}, {
   3.8587866148666897`*^9, 3.858786628154747*^9}, {3.858788263305393*^9, 
   3.858788287137041*^9}, 3.859027676232143*^9, {3.859042391407422*^9, 
   3.859042391830041*^9}, 3.859042654781164*^9, {3.859044768519006*^9, 
   3.859044769565692*^9}, {3.8590449338556967`*^9, 3.859044934102459*^9}, 
   3.859045001871667*^9},
 CellLabel->
  "In[155]:=",ExpressionUUID->"5063e10a-f0aa-4fd4-a02c-bb212c54480e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox["a", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    SuperscriptBox["a", "6"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b"}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "8"]}], " ", 
    SuperscriptBox["a", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.858788288448888*^9, 3.8590261899851227`*^9, 
  3.859027677347439*^9, 3.859042393161137*^9, 3.8590426552914457`*^9, 
  3.859044770167042*^9, 3.859044935200601*^9, 3.8590450025055027`*^9, 
  3.8599094168062897`*^9, 3.861097937520245*^9},
 CellLabel->
  "Out[155]=",ExpressionUUID->"7057ec0e-be55-468c-8e15-2980d89dce8f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptE", ",", "ptF", ",", "ptG"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "\[Equal]", 
    RowBox[{"b", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.858786777987032*^9, 3.858786801250679*^9}, {
  3.858788317610319*^9, 3.85878834253583*^9}},
 CellLabel->
  "In[156]:=",ExpressionUUID->"540a1099-2a15-496a-ab97-08ff57296ddd"],

Cell[BoxData["K"], "Output",
 CellChangeTimes->{{3.858786793627717*^9, 3.8587868022970963`*^9}, 
   3.8587882951268663`*^9, 3.858788343593449*^9, 3.859026190074284*^9, 
   3.859027688655547*^9, 3.859042401266765*^9, 3.859042659120059*^9, 
   3.859044782025463*^9, 3.859044938329708*^9, 3.859045007078032*^9, 
   3.859909416820175*^9, 3.86109793756748*^9},
 CellLabel->
  "Out[156]=",ExpressionUUID->"49a3d817-be8d-44c2-acd1-acdaeb205621"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 7.32 for X(153)", "Subsubsection",
 CellChangeTimes->{{3.8590267048883963`*^9, 3.859026727459972*^9}, 
   3.8590276561031523`*^9, {3.859042356310068*^9, 3.859042356790008*^9}, 
   3.8590426390870533`*^9, {3.8590447361657467`*^9, 3.859044737189307*^9}, {
   3.859044910742312*^9, 3.859044911045905*^9}, 3.859045018758669*^9, 
   3.861090164603449*^9, 
   3.861092216168879*^9},ExpressionUUID->"2136fb2c-be89-435e-b259-\
eb87f4c72114"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x153", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"153", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.858786060921858*^9, 3.858786181361096*^9}, {
  3.8587863905711937`*^9, 3.858786410594088*^9}, {3.8587881675849857`*^9, 
  3.8587881747443943`*^9}, {3.8590276603278913`*^9, 3.859027662646915*^9}, {
  3.859042362414756*^9, 3.859042368246148*^9}, {3.8590426420638123`*^9, 
  3.859042644462646*^9}, {3.859044740382359*^9, 3.8590447452773867`*^9}, {
  3.85904491431075*^9, 3.859044918878051*^9}, {3.85904502149552*^9, 
  3.8590450236146173`*^9}},
 CellLabel->
  "In[157]:=",ExpressionUUID->"f1817b25-1fb6-4c7b-b6cb-39830d90a507"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "7"], "-", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", "b"}], "-", 
    RowBox[{
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "3"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "5"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "6"]}], "-", 
    SuperscriptBox["b", "7"], "-", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", "c"}], "+", 
    RowBox[{"7", " ", 
     SuperscriptBox["a", "5"], " ", "b", " ", "c"}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "3"], " ", "c"}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", "c"}], "-", 
    RowBox[{"5", " ", "a", " ", 
     SuperscriptBox["b", "5"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["b", "6"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "4"], " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"10", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"10", " ", "a", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"5", " ", "a", " ", "b", " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "6"]}], "-", 
    SuperscriptBox["c", "7"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "7"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", "b"}], "+", 
    RowBox[{
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "4"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "5"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "6"]}], "+", 
    SuperscriptBox["b", "7"], "+", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", "c"}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "5"], " ", "b", " ", "c"}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "3"], " ", "c"}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", "c"}], "+", 
    RowBox[{"7", " ", "a", " ", 
     SuperscriptBox["b", "5"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["b", "6"], " ", "c"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "4"], " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"10", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"5", " ", "a", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"10", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"2", " ", "a", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"5", " ", "a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"5", " ", "a", " ", "b", " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "6"]}], "+", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "6"]}], "-", 
    SuperscriptBox["c", "7"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "7"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", "b"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "3"]}], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "4"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "5"]}], "+", 
    RowBox[{"a", " ", 
     SuperscriptBox["b", "6"]}], "-", 
    SuperscriptBox["b", "7"], "+", 
    RowBox[{
     SuperscriptBox["a", "6"], " ", "c"}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "5"], " ", "b", " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["b", "2"], " ", "c"}], "+", 
    RowBox[{"10", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "3"], " ", "c"}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "4"], " ", "c"}], "-", 
    RowBox[{"5", " ", "a", " ", 
     SuperscriptBox["b", "5"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["b", "6"], " ", "c"}], "+", 
    RowBox[{
     SuperscriptBox["a", "5"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "4"], " ", "b", " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"5", " ", "a", " ", 
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "5"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "4"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "3"], " ", "b", " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{"10", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{"2", " ", "a", " ", 
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "3"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "4"], " ", 
     SuperscriptBox["c", "3"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "3"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"5", " ", 
     SuperscriptBox["a", "2"], " ", "b", " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{"5", " ", "a", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "3"], " ", 
     SuperscriptBox["c", "4"]}], "-", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "5"]}], "+", 
    RowBox[{"7", " ", "a", " ", "b", " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "5"]}], "-", 
    RowBox[{"a", " ", 
     SuperscriptBox["c", "6"]}], "-", 
    RowBox[{"b", " ", 
     SuperscriptBox["c", "6"]}], "+", 
    SuperscriptBox["c", "7"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8587881756168213`*^9, 3.85902618993408*^9, 
  3.859027663621985*^9, 3.8590423702523117`*^9, 3.859042645706134*^9, 
  3.8590447458071947`*^9, 3.8590449199286747`*^9, 3.8590450244492807`*^9, 
  3.859909416869396*^9, 3.861097937584326*^9},
 CellLabel->
  "Out[157]=",ExpressionUUID->"12b6bd83-3453-4163-aa35-e60152f99337"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptF", "=", 
  RowBox[{"centerABE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x153", ".", 
      RowBox[{"{", 
       RowBox[{"ptA", ",", "ptB", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenAE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenAB"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.858785708664339*^9, 3.858785752208427*^9}, {
   3.858785901049223*^9, 3.8587859885123568`*^9}, {3.85878628204163*^9, 
   3.858786292089315*^9}, {3.858786357153858*^9, 3.858786360769568*^9}, {
   3.858786421793996*^9, 3.858786495154055*^9}, {3.8587867030365143`*^9, 
   3.858786704658731*^9}, {3.858788182793332*^9, 3.858788194031535*^9}, 
   3.858788246343902*^9, 3.859027669840116*^9, {3.859042382319257*^9, 
   3.8590423832220087`*^9}, 3.8590426501198273`*^9, {3.859044752350841*^9, 
   3.859044753373679*^9}, {3.859044924479558*^9, 3.859044924734539*^9}, 
   3.8590450292155533`*^9},
 CellLabel->
  "In[158]:=",ExpressionUUID->"66420ba0-ed48-4e4c-9e0e-333e071ac3a1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", 
       RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      SuperscriptBox["c", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", 
       RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "5"]}], ",", 
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"b", "-", 
       RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
    SuperscriptBox["c", "3"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8587864233685513`*^9, {3.8587864696808767`*^9, 3.858786496037889*^9}, 
   3.8587867069184437`*^9, 3.858786755813157*^9, 3.8587870936108103`*^9, 
   3.8587882474445353`*^9, 3.859026189973741*^9, 3.859027670500546*^9, 
   3.8590423848575172`*^9, 3.859042650686679*^9, 3.8590447547233887`*^9, 
   3.859044925845641*^9, 3.859045030009522*^9, 3.85990941691296*^9, 
   3.86109793763104*^9},
 CellLabel->
  "Out[158]=",ExpressionUUID->"8686ea5a-12fa-45c1-a9b9-0af3f5cec659"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptG", "=", 
  RowBox[{"centerBCE", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"x153", ".", 
      RowBox[{"{", 
       RowBox[{"ptB", ",", "ptC", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "lenCE"}], ",", 
       RowBox[{"b", "\[Rule]", "lenBE"}], ",", 
       RowBox[{"c", "\[Rule]", "lenBC"}], ",", 
       RowBox[{"S", "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"c", "/", "2"}]}]}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8587865148663816`*^9, 3.858786564610229*^9}, {
   3.8587866148666897`*^9, 3.858786628154747*^9}, {3.858788263305393*^9, 
   3.858788287137041*^9}, 3.859027676232143*^9, {3.859042391407422*^9, 
   3.859042391830041*^9}, 3.859042654781164*^9, {3.859044768519006*^9, 
   3.859044769565692*^9}, {3.8590449338556967`*^9, 3.859044934102459*^9}, 
   3.859045033039527*^9},
 CellLabel->
  "In[159]:=",ExpressionUUID->"83c5d417-a304-4a50-8b97-89f31c4eb412"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    FractionBox["1", "8"], " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "4"]}], " ", 
    SuperscriptBox["a", "5"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b"}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     FractionBox["1", "8"]}], " ", 
    SuperscriptBox["a", "3"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "a"}], "+", "b"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.858788288448888*^9, 3.8590261899851227`*^9, 
  3.859027677347439*^9, 3.859042393161137*^9, 3.8590426552914457`*^9, 
  3.859044770167042*^9, 3.859044935200601*^9, 3.859045033667819*^9, 
  3.8599094169845047`*^9, 3.861097937678585*^9},
 CellLabel->
  "Out[159]=",ExpressionUUID->"db88960a-b462-4275-b969-2342ffb2ea41"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptE", ",", "ptF", ",", "ptG"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"a", "^", "2"}], "+", 
     RowBox[{"c", "^", "2"}]}], "\[Equal]", 
    RowBox[{"b", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.858786777987032*^9, 3.858786801250679*^9}, {
  3.858788317610319*^9, 3.85878834253583*^9}},
 CellLabel->
  "In[160]:=",ExpressionUUID->"2d1b1e62-37f7-4ba7-bb12-a8f968cf0176"],

Cell[BoxData["K"], "Output",
 CellChangeTimes->{{3.858786793627717*^9, 3.8587868022970963`*^9}, 
   3.8587882951268663`*^9, 3.858788343593449*^9, 3.859026190074284*^9, 
   3.859027688655547*^9, 3.859042401266765*^9, 3.859042659120059*^9, 
   3.859044782025463*^9, 3.859044938329708*^9, 3.859045036750456*^9, 
   3.859909417085133*^9, 3.8610979377250566`*^9},
 CellLabel->
  "Out[160]=",ExpressionUUID->"c14a3478-16de-405e-8bbe-330fbf4628a1"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Squares", "Subsection",
 CellChangeTimes->{{3.8594059038583107`*^9, 
  3.859405913483205*^9}},ExpressionUUID->"806362de-4648-42d4-b529-\
fe243a62ed6f"],

Cell[CellGroupData[{

Cell["miscellaneous", "Subsubsection",
 CellChangeTimes->{{3.859406031346599*^9, 3.859406037971991*^9}, {
  3.861092021016653*^9, 
  3.8610920248962107`*^9}},ExpressionUUID->"4a77c34f-b15c-4e24-bf4f-\
85b2f82558c7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"coincidesWithM", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"onLineAtInfinity", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"atInfinitWhenIsosceles", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"transcendental", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"coincidesWithA", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"coincidesWithAsq", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"coincidesWithMsq", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"atInfinitWhenSquare", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rational", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"squareRational", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptA", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptM", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"n", "=", "1"}], ",", 
    RowBox[{"n", "\[LessEqual]", "1000"}], ",", 
    RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"\"\<n=\>\"", ",", "n"}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"coords", "=", 
      RowBox[{"ETC1", "[", 
       RowBox[{"[", 
        RowBox[{"n", ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"ignore", " ", "transcendental", " ", "centers"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"coords", "\[Equal]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"transcendental", ",", "n"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
      RowBox[{"ptX", "=", 
       RowBox[{"coords", "/.", 
        RowBox[{"S", "->", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}]}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"ignore", " ", "points", " ", "at", " ", "infinity"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{"u", "+", "v", "+", "w"}], "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"onLineAtInfinity", ",", "n"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Continue", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{
          RowBox[{"u", "+", "v", "+", "w"}], "/.", 
          RowBox[{"c", "\[Rule]", "b"}]}], "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"atInfinitWhenIsosceles", ",", "n"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Continue", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{"u", "/.", 
          RowBox[{"c", "\[Rule]", "b"}]}], "]"}], "\[Equal]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"coincidesWithM", ",", "n"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Continue", "[", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"ratio", " ", "=", " ", 
       RowBox[{"XM", "/", "AM"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"ratio", "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"u", "/", 
         RowBox[{"(", 
          RowBox[{"u", "+", 
           RowBox[{"2", "v"}]}], ")"}]}], "/.", 
        RowBox[{"c", "\[Rule]", "b"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"(*", " ", 
      RowBox[{
      "ignore", " ", "points", " ", "that", " ", "coincide", " ", "with", " ",
        "A"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ratio", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"coincidesWithA", ",", "n"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Continue", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"NumericQ", "[", "ratio", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<n=\>\"", ",", "n", ",", "\"\<   \>\"", ",", "ptX", ",", 
          "\"\<   XM/AM=\>\"", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"ratio", ",", "Red"}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"rational", ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "ratio"}], "}"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Continue", "[", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"ratio", "=", 
      RowBox[{
       RowBox[{"Simplify", "[", 
        RowBox[{"ratio", "/.", 
         RowBox[{"a", "\[Rule]", 
          RowBox[{"b", " ", 
           RowBox[{"Sqrt", "[", "2", "]"}]}]}]}], "]"}], "//", "Quiet"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ratio", "===", "ComplexInfinity"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"atInfinitWhenSquare", ",", "n"}], "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ratio", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"coincidesWithAsq", ",", "n"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Continue", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ratio", "\[Equal]", "0"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"coincidesWithMsq", ",", "n"}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Continue", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"NumericQ", "[", "ratio", "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<n=\>\"", ",", "n", ",", "\"\<   \>\"", ",", "ptX", ",", 
          "\"\<   XM/AM=\>\"", ",", 
          RowBox[{"Style", "[", 
           RowBox[{"ratio", ",", "Blue"}], "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"squareRational", ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "ratio"}], "}"}]}], "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.85823859791429*^9, 3.85823861081002*^9}, {
   3.858238666170635*^9, 3.858238671842203*^9}, {3.8582387034349937`*^9, 
   3.858238879946652*^9}, {3.8582389657328787`*^9, 3.8582389797310667`*^9}, {
   3.8582392486772118`*^9, 3.8582392767083197`*^9}, {3.858239316526222*^9, 
   3.858239316940321*^9}, {3.8582393919104853`*^9, 3.858239410404519*^9}, {
   3.858331060436795*^9, 3.8583310835636053`*^9}, {3.8583311335560627`*^9, 
   3.8583312056613417`*^9}, {3.858331353269075*^9, 3.858331361757183*^9}, {
   3.85833142168615*^9, 3.858331476637041*^9}, {3.8583315261749496`*^9, 
   3.858331647885808*^9}, 3.858331679870125*^9, {3.858331841511511*^9, 
   3.858331889799799*^9}, {3.858331948776697*^9, 3.858331950886672*^9}, {
   3.858332138091186*^9, 3.858332168351516*^9}, {3.8583598800744762`*^9, 
   3.858359881256414*^9}, {3.8590572502474737`*^9, 3.859057297806314*^9}, {
   3.859057346582951*^9, 3.859057445855009*^9}, {3.859057654764593*^9, 
   3.859057672008007*^9}, {3.859057728585338*^9, 3.8590577494402647`*^9}, {
   3.8590578014496107`*^9, 3.859057898193756*^9}, {3.859057958193616*^9, 
   3.8590579702170258`*^9}, {3.8590580079943*^9, 3.859058022673209*^9}, {
   3.8590581266503973`*^9, 3.8590581393538837`*^9}, {3.8591099751016607`*^9, 
   3.859110043172707*^9}, {3.859110184262834*^9, 3.8591102137013683`*^9}, {
   3.859110250494644*^9, 3.8591102538301773`*^9}, {3.859110286463319*^9, 
   3.859110291237661*^9}},
 CellLabel->
  "In[161]:=",ExpressionUUID->"1f601afd-4d8e-4850-b494-11213f28173a"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["n=", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938598386*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"424ce6a4-95f1-47b7-8e19-66a703bf6195"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 1, "   ", {$CellContext`a, $CellContext`b, $CellContext`c}, 
   "   XM/AM=", 
   Style[-1 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938599234*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"60806bc5-1385-463e-a1f0-4aea5b859fee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["n=", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938602477*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"123efc4d-4e24-4ed1-a68a-c3368021f9c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1", ",", "1"}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "3"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm["n=", 2, "   ", {1, 1, 1}, "   XM/AM=", 
   Style[
    Rational[1, 3], 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938603581*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"03483b21-8a72-488f-98b7-05668a04a6eb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "3"}],
  SequenceForm["n=", 3],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386047277`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8fba131c-c01c-4fea-bb16-346769de3710"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "4"}],
  SequenceForm["n=", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386057568`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"503c6680-ab2a-415f-8cbe-c5b6dc0ab9a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "5"}],
  SequenceForm["n=", 5],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386068773`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e2581352-7979-43cc-acf2-7a74f222ca66"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "2"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 5, "   ", {-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - \
$CellContext`a^2 $CellContext`b^2 - 
    2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4, $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2}, "   XM/AM=", 
   Style[
    Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938608412*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f72b230d-4ac2-4bb8-8e17-3ef4e7cee6f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "6"}],
  SequenceForm["n=", 6],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938610093*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8d1aa0f5-297a-44e3-90e9-3c4bad27e0c6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["a", "2"], ",", 
     SuperscriptBox["b", "2"], ",", 
     SuperscriptBox["c", "2"]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "2"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 6, "   ", {$CellContext`a^2, $CellContext`b^2, $CellContext`c^2}, 
   "   XM/AM=", 
   Style[
    Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938611253*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8fe7e7f1-9cf1-43e9-9358-9003087bf803"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "7"}],
  SequenceForm["n=", 7],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386123543`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e65c35d1-533a-454d-a209-0998daece8a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 7, "   ", {($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c), ($CellContext`a + \
$CellContext`b - $CellContext`c) (-$CellContext`a + $CellContext`b + \
$CellContext`c), ($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 7] (1 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938613586*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3618a02c-e427-4d30-9a31-5a2ef850aa71"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "8"}],
  SequenceForm["n=", 8],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386148643`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"088037b8-00f7-4d41-a7e5-ef32c71a7622"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "-", "b", "-", "c"}], ",", 
     RowBox[{
      RowBox[{"-", "a"}], "+", "b", "-", "c"}], ",", 
     RowBox[{
      RowBox[{"-", "a"}], "-", "b", "+", "c"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"3", "-", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 8, "   ", {$CellContext`a - $CellContext`b - $CellContext`c, \
-$CellContext`a + $CellContext`b - $CellContext`c, -$CellContext`a - \
$CellContext`b + $CellContext`c}, "   XM/AM=", 
   Style[3 - 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793861614*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cbe9f8b3-acf8-41af-8c4a-cf2e615788f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "9"}],
  SequenceForm["n=", 9],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938617442*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"61db27b9-6bf5-452b-a82c-e1aaa20c9b82"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 9, "   ", {$CellContext`a ($CellContext`a - $CellContext`b - \
$CellContext`c), $CellContext`b (-$CellContext`a + $CellContext`b - \
$CellContext`c), $CellContext`c (-$CellContext`a - $CellContext`b + \
$CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 7] (3 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938618684*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"98874294-390d-4452-b9cf-88b3f2a37fb1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "10"}],
  SequenceForm["n=", 10],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386199703`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7ccffebb-0dc3-40e1-925e-de18c0f66b2a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", "+", "c"}], ",", 
     RowBox[{"a", "+", "c"}], ",", 
     RowBox[{"a", "+", "b"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"2", "+", 
      SqrtBox["2"]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 10, 
   "   ", {$CellContext`b + $CellContext`c, $CellContext`a + $CellContext`c, \
$CellContext`a + $CellContext`b}, "   XM/AM=", 
   Style[(2 + 2^Rational[1, 2])^(-1), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938621379*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7d9dac93-17ee-4ecf-8be0-978697c1df1c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "11"}],
  SequenceForm["n=", 11],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938622525*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5d0a3600-bf7a-4450-91fa-b7cb3ae908d2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "12"}],
  SequenceForm["n=", 12],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386235*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"522ca8f1-448b-44e9-b728-e709e9f21955"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", "7"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "3"}], "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 12, 
   "   ", {($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a - \
$CellContext`b + $CellContext`c) ($CellContext`b + $CellContext`c)^2, \
($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a + \
$CellContext`c)^2 (-$CellContext`a + $CellContext`b + $CellContext`c), \
($CellContext`a + $CellContext`b)^2 ($CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c)}, 
   "   XM/AM=", 
   Style[Rational[-2, 7] (-3 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386248083`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b549daf0-08d8-47d7-a1c8-d9e765e8de4b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "13"}],
  SequenceForm["n=", 13],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386261044`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7a1a6c72-7e96-4b20-82f6-a7a164dba007"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "14"}],
  SequenceForm["n=", 14],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938627101*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"578f01aa-4746-4c9d-8c9b-48c9376ae058"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "15"}],
  SequenceForm["n=", 15],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386280947`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"79d028cc-b52d-41d6-8d52-0eb84b8298e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "16"}],
  SequenceForm["n=", 16],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938629084*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c7a1bc50-db15-4a76-8405-92d05f944943"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "17"}],
  SequenceForm["n=", 17],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386300583`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e9ab77c7-1a97-4d98-8594-eb71f0819bef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "18"}],
  SequenceForm["n=", 18],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938631028*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a8867059-2695-41ac-aa78-5367a11adbe3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "19"}],
  SequenceForm["n=", 19],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938631999*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1617dc21-353c-411a-a326-917399ac1afc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "20"}],
  SequenceForm["n=", 20],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938632963*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"13f4af50-99d9-4cbe-a5c4-fd882717b5f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "20", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 20, "   ", {
   3 $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + 3 $CellContext`b^4 + 
    2 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`c^2 - 2 $CellContext`b^2 $CellContext`c^2 + 
    3 $CellContext`c^4}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938634486*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8d0346e3-8a40-4d0a-84c2-69f74c6432ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "21"}],
  SequenceForm["n=", 21],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386358137`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0dc35bcc-93df-49cf-a863-e3170efefa14"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "21", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 21, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`a - \
$CellContext`b - $CellContext`c) ($CellContext`a + $CellContext`c), \
$CellContext`b ($CellContext`a + $CellContext`b) (-$CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`b + $CellContext`c), \
$CellContext`c ($CellContext`a + $CellContext`c) (-$CellContext`a - \
$CellContext`b + $CellContext`c) ($CellContext`b + $CellContext`c)}, 
   "   XM/AM=", 
   Style[Rational[1, 7] (-1 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938637083*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2dec7cec-30c2-42ce-9daf-c9c2789a6649"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "22"}],
  SequenceForm["n=", 22],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938638296*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"79e75b8a-24bc-4c92-9158-c5305f8058bb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "22", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        SuperscriptBox["b", "4"], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 22, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - $CellContext`b^4 - \
$CellContext`c^4), $CellContext`b^2 (-$CellContext`a^4 + $CellContext`b^4 - \
$CellContext`c^4), $CellContext`c^2 (-$CellContext`a^4 - $CellContext`b^4 + \
$CellContext`c^4)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938639472*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2c107739-1e8b-456f-9b01-1df245c63963"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "23"}],
  SequenceForm["n=", 23],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938640635*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8a542d14-967e-4fc4-8bb3-97f63042f55a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox["3",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 23, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - $CellContext`b^4 + \
$CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), $CellContext`b^2 \
(-$CellContext`a^4 + $CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 - \
$CellContext`c^4), $CellContext`c^2 (-$CellContext`a^4 + $CellContext`a^2 \
$CellContext`b^2 - $CellContext`b^4 + $CellContext`c^4)}, "   XM/AM=", 
   Style[3, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938641939*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0d4e7760-8044-4d3f-97a1-79831009e668"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "24"}],
  SequenceForm["n=", 24],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938643276*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c9f17cfa-937a-4fa8-96c1-acbd80e09968"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm["n=", 25],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938644392*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"269cd1bc-97d5-4665-a87f-d27ec35deace"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "26"}],
  SequenceForm["n=", 26],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793864564*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d2036a4c-0252-4a57-8a69-bf2d998f3aa1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "27"}],
  SequenceForm["n=", 27],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938646777*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"932643cb-fd58-4e7d-b155-34cf5ed7446f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "28"}],
  SequenceForm["n=", 28],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938647773*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"18f3c47b-2204-4818-91bf-8f9c53b40e27"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "29"}],
  SequenceForm["n=", 29],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386489*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"02f414cb-42d5-4267-ae94-c9bbb8762b1c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "30"}],
  SequenceForm["n=", 30],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938650053*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f0b52c3f-eb4e-4247-8e56-9df74d2449e1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "31"}],
  SequenceForm["n=", 31],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938651396*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5fad6241-a2e4-40fd-84d8-3d7b1a8bc877"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "31", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["a", "3"], ",", 
     SuperscriptBox["b", "3"], ",", 
     SuperscriptBox["c", "3"]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"2", "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 31, "   ", {$CellContext`a^3, $CellContext`b^3, $CellContext`c^3}, 
   "   XM/AM=", 
   Style[2 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386528063`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e2ea7745-681e-4626-92a8-58779ca92c99"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "32"}],
  SequenceForm["n=", 32],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386540537`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a2e647c3-29b7-420a-a5fa-5c5085ec8575"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["a", "4"], ",", 
     SuperscriptBox["b", "4"], ",", 
     SuperscriptBox["c", "4"]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 32, "   ", {$CellContext`a^4, $CellContext`b^4, $CellContext`c^4}, 
   "   XM/AM=", 
   Style[
    Rational[2, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938655267*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f3a82601-a615-4123-beb4-a10ddaa3b8b1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "33"}],
  SequenceForm["n=", 33],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938656707*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9edb0959-833b-4b22-a956-fe5c0965d065"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "34"}],
  SequenceForm["n=", 34],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938658222*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ab9d527c-37a7-4089-be3e-9b708d172af4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "35"}],
  SequenceForm["n=", 35],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938659486*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fb9f1969-bff1-467c-99b8-3c19e9b32ec9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 35, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`b $CellContext`c - $CellContext`c^2), $CellContext`b^2 \
(-$CellContext`a^2 + $CellContext`b^2 - $CellContext`a $CellContext`c - \
$CellContext`c^2), $CellContext`c^2 (-$CellContext`a^2 - $CellContext`a \
$CellContext`b - $CellContext`b^2 + $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 7] (3 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793866082*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2b917bd2-3a69-4316-9eee-eea3b3edee17"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "36"}],
  SequenceForm["n=", 36],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938662094*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cc46c660-5745-432e-8c1f-22d61915008b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "36", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 36, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 - $CellContext`b^2 + \
$CellContext`b $CellContext`c - $CellContext`c^2), $CellContext`b^2 \
(-$CellContext`a^2 + $CellContext`b^2 + $CellContext`a $CellContext`c - \
$CellContext`c^2), $CellContext`c^2 (-$CellContext`a^2 + $CellContext`a \
$CellContext`b - $CellContext`b^2 + $CellContext`c^2)}, "   XM/AM=", 
   Style[1 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938663374*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"93c591f4-079e-4641-8b32-5b7cc15f3a63"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "37"}],
  SequenceForm["n=", 37],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793866469*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"abf263e6-0f1f-474f-9ec3-65367f917cab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "37", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", "c"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 37, 
   "   ", {$CellContext`a ($CellContext`b + $CellContext`c), $CellContext`b \
($CellContext`a + $CellContext`c), ($CellContext`a + $CellContext`b) \
$CellContext`c}, "   XM/AM=", 
   Style[Rational[1, 7] (4 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386658792`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f3ea4a23-ae2a-4ea2-a897-0b1cb093ca34"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "38"}],
  SequenceForm["n=", 38],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938667172*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8c5ea486-a4ef-4d49-9f79-e2b0c91dbff6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "38", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", "c"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", 
       RowBox[{"3", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 38, 
   "   ", {$CellContext`a ($CellContext`b^2 + $CellContext`c^2), \
$CellContext`b ($CellContext`a^2 + $CellContext`c^2), ($CellContext`a^2 + \
$CellContext`b^2) $CellContext`c}, "   XM/AM=", 
   Style[Rational[1, 7] (-2 + 3 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938668401*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"02f8bf6f-42f4-405d-93f9-b1fdf2185d3f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "39"}],
  SequenceForm["n=", 39],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938669611*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f0e8cbf4-506c-4736-b6e4-82dc97f73d1b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "39", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", "5"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 39, 
   "   ", {$CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2), \
$CellContext`b^2 ($CellContext`a^2 + $CellContext`c^2), ($CellContext`a^2 + \
$CellContext`b^2) $CellContext`c^2}, "   XM/AM=", 
   Style[
    Rational[2, 5], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386708593`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7358a143-133d-4032-a86c-6363af182125"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "40"}],
  SequenceForm["n=", 40],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938672076*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0e1cf711-2e67-4770-8c28-1202039ffad0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 40, 
   "   ", {$CellContext`a ($CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), $CellContext`b (-$CellContext`a^3 - \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), $CellContext`c (-$CellContext`a^3 + \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 - \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[1 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938673623*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"90eb361c-2578-4ebe-9e13-6495e01d02e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "41"}],
  SequenceForm["n=", 41],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938675042*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2159859e-9223-4a18-b591-286f89d816f1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "41", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 41, 
   "   ", {$CellContext`a^3 ($CellContext`a - $CellContext`b - \
$CellContext`c), $CellContext`b^3 (-$CellContext`a + $CellContext`b - \
$CellContext`c), $CellContext`c^3 (-$CellContext`a - $CellContext`b + \
$CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 7] (4 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386762877`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"03352f43-4c48-4a0a-941d-a078dd2ab482"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "42"}],
  SequenceForm["n=", 42],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938677518*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f10b31d4-2f23-4057-bd0d-01ff874a3ac9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "42", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      SuperscriptBox["c", "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", 
     RowBox[{"3", "+", 
      SqrtBox["2"]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 42, 
   "   ", {$CellContext`a^2 ($CellContext`b + $CellContext`c), \
$CellContext`b^2 ($CellContext`a + $CellContext`c), ($CellContext`a + \
$CellContext`b) $CellContext`c^2}, "   XM/AM=", 
   Style[2/(3 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386787243`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"363fe076-c38a-4e45-905e-b2ecd398adf6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "43"}],
  SequenceForm["n=", 43],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386800127`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fa35cff0-ac0b-4f06-8033-b499bb77f5f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "43", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"11", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 43, 
   "   ", {$CellContext`a ($CellContext`a $CellContext`b + $CellContext`a \
$CellContext`c - $CellContext`b $CellContext`c), $CellContext`b \
($CellContext`a $CellContext`b - $CellContext`a $CellContext`c + \
$CellContext`b $CellContext`c), $CellContext`c (-$CellContext`a \
$CellContext`b + $CellContext`a $CellContext`c + $CellContext`b \
$CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 17] (11 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938681294*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"22235675-479d-4a73-8c62-f13c9182469a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "44"}],
  SequenceForm["n=", 44],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938682535*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4a3d5d03-77c8-4ee0-be20-71c2895f6280"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "44", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a"}], "-", "b", "-", "c"}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", 
        RowBox[{"2", " ", "b"}], "-", "c"}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", 
        RowBox[{"2", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"2", "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 44, 
   "   ", {$CellContext`a (
     2 $CellContext`a - $CellContext`b - $CellContext`c), $CellContext`b \
(-$CellContext`a + 
     2 $CellContext`b - $CellContext`c), $CellContext`c (-$CellContext`a - \
$CellContext`b + 2 $CellContext`c)}, "   XM/AM=", 
   Style[2 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938683769*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"16cc39b8-1a6f-4bec-bce7-d4c090f9476d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "45"}],
  SequenceForm["n=", 45],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938685025*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8dd6d15d-f51b-4ecd-8385-a81cf5c83180"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "45", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", 
        RowBox[{"2", " ", "b"}], "-", 
        RowBox[{"2", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a"}], "+", "b", "-", 
        RowBox[{"2", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a"}], "-", 
        RowBox[{"2", " ", "b"}], "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "8"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 45, 
   "   ", {$CellContext`a ($CellContext`a - 2 $CellContext`b - 
     2 $CellContext`c), $CellContext`b ((-2) $CellContext`a + $CellContext`b - 
     2 $CellContext`c), $CellContext`c ((-2) $CellContext`a - 
     2 $CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 8] (4 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386863623`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7d9ee4a5-eb53-40b2-a2ac-53570c6957c7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "46"}],
  SequenceForm["n=", 46],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386876593`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d1e6f408-9177-450c-870a-b565e0050e83"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "47"}],
  SequenceForm["n=", 47],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386886883`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"071f29f9-09fe-4993-bbac-5701944806e8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "48"}],
  SequenceForm["n=", 48],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979386896887`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"429892d4-d9ee-482b-afe6-6ff6b7d89b45"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "49"}],
  SequenceForm["n=", 49],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938690761*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"12d71520-3e46-4442-92d4-39df0049b81a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "50"}],
  SequenceForm["n=", 50],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938691803*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"401cee13-da71-42ed-887e-330d4254be7b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "51"}],
  SequenceForm["n=", 51],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793869291*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d12baa10-3e54-402d-b0c0-196cdbc98c14"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "51", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 51, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), \
$CellContext`b^2 (-$CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - \
$CellContext`c^4), $CellContext`c^2 (-$CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[
    Rational[2, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938694415*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dcf398dc-8535-4a20-8654-0a060b3899ac"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "52"}],
  SequenceForm["n=", 52],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938695808*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f23de30e-eee5-4173-9482-4c265dd8ef94"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "53"}],
  SequenceForm["n=", 53],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938696875*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f348457d-018c-4f8b-a8de-96d3827a7e23"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "54"}],
  SequenceForm["n=", 54],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938697914*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"812174b8-f79a-4fff-9f25-0223eb2466a6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "54", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 54, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) \
($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4), $CellContext`b^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) \
(-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`c^2 (-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[1, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938699584*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"59f4cac2-4898-43a7-b616-e5d77d3b9925"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "55"}],
  SequenceForm["n=", 55],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938701173*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7e91b8dd-3304-45be-8a6f-d8ba83a58847"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "55", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "-", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 55, 
   "   ", {$CellContext`a^2 ($CellContext`a - $CellContext`b - \
$CellContext`c), $CellContext`b^2 (-$CellContext`a + $CellContext`b - \
$CellContext`c), $CellContext`c^2 (-$CellContext`a - $CellContext`b + \
$CellContext`c)}, "   XM/AM=", 
   Style[1 - 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938702429*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1d2d4cb1-758a-4d6d-aab5-90960b967d6c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "56"}],
  SequenceForm["n=", 56],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979387036343`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"88f4296e-a436-4bab-81d8-2c3d84365e7b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "56", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     SqrtBox["2"]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 56, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a - $CellContext`b + $CellContext`c), \
$CellContext`b^2 ($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c), $CellContext`c^2 \
($CellContext`a - $CellContext`b + $CellContext`c) (-$CellContext`a + \
$CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979387048893`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"97886cd3-4edd-4d2b-bae8-4a5df86f7e42"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "57"}],
  SequenceForm["n=", 57],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979387062397`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c4367e4d-5791-4cd8-8465-962a95ab308c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "57", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 57, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c), $CellContext`b \
($CellContext`a + $CellContext`b - $CellContext`c) (-$CellContext`a + \
$CellContext`b + $CellContext`c), $CellContext`c ($CellContext`a - \
$CellContext`b + $CellContext`c) (-$CellContext`a + $CellContext`b + \
$CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 7] (3 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938707572*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9909bec2-8128-48b3-abc8-43ca2a5f35fd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "58"}],
  SequenceForm["n=", 58],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979387088537`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b26ffa10-9306-49e6-9d51-55fea53e2bcf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "58", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 58, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c), $CellContext`b^2 ($CellContext`a + $CellContext`b) \
($CellContext`b + $CellContext`c), $CellContext`c^2 ($CellContext`a + \
$CellContext`c) ($CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 7] (1 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938710127*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"894966c4-3ec2-4658-9454-5337c943c2cd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "59"}],
  SequenceForm["n=", 59],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979387115593`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5d4cf0e1-cd30-4b79-ae3f-c216fc2d41ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "60"}],
  SequenceForm["n=", 60],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938712738*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dd24dae8-b57d-43f2-b674-79bc6d10b1a4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "23"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 60, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b)^2 \
($CellContext`a - $CellContext`b - $CellContext`c) ($CellContext`a + \
$CellContext`c)^2, $CellContext`b^2 ($CellContext`a + $CellContext`b)^2 \
(-$CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`b + \
$CellContext`c)^2, $CellContext`c^2 ($CellContext`a + $CellContext`c)^2 \
(-$CellContext`a - $CellContext`b + $CellContext`c) ($CellContext`b + \
$CellContext`c)^2}, "   XM/AM=", 
   Style[Rational[1, 23] (3 + 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938714252*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"12cc8230-3729-4a48-8787-920dfe6ffd0b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "61"}],
  SequenceForm["n=", 61],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979387156343`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"86018b45-a0f8-46e3-b813-687fd361d6c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "62"}],
  SequenceForm["n=", 62],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938717003*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f618f488-7d4a-4015-9f7b-d7c857c38a4d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "63"}],
  SequenceForm["n=", 63],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938718244*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d8df3ea7-baea-4fc6-8b75-d1ccb0b6fbe8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "64"}],
  SequenceForm["n=", 64],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938719633*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0f81b2e1-bd10-487c-a60e-0073315a43e7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "65"}],
  SequenceForm["n=", 65],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979387208*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"31b006db-c60d-497d-a3bd-d06b2097f7ea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"2", "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 65, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c) ($CellContext`b + \
$CellContext`c), $CellContext`b ($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a + $CellContext`c) (-$CellContext`a + \
$CellContext`b + $CellContext`c), ($CellContext`a + $CellContext`b) \
$CellContext`c ($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[2 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979387222557`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ea8a76c5-8add-4cdb-9e7f-cbcc3d136e2c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "66"}],
  SequenceForm["n=", 66],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793872406*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"632fa184-b0a7-4496-b26c-911527d53fac"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "67"}],
  SequenceForm["n=", 67],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938725503*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"075cce28-02c2-40fd-8019-fbabbd2f1c8b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", "2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 67, 
   "   ", {($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 - $CellContext`c^4) ($CellContext`a^4 - $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 + $CellContext`c^4), ($CellContext`a^4 - \
$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - $CellContext`c^4) \
(-$CellContext`a^4 + $CellContext`b^4 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4), ($CellContext`a^4 - $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 + $CellContext`c^4) (-$CellContext`a^4 + $CellContext`b^4 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938727544*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"78886b45-39f0-4739-a03d-ac283cc2a9e1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "68"}],
  SequenceForm["n=", 68],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938729458*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"20256040-78a3-4e18-b4ee-7753bec41749"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "69"}],
  SequenceForm["n=", 69],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938730948*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"248a9e60-9d3e-47a1-9133-47fbab963829"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "70"}],
  SequenceForm["n=", 70],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938732445*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"37f7a08d-8694-43d8-adf3-d262c22f5dff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "70", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        SuperscriptBox["c", "8"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        SuperscriptBox["c", "8"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "8"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "8"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 70, 
   "   ", {($CellContext`a^8 - 2 $CellContext`a^6 $CellContext`b^2 + 
     2 $CellContext`a^4 $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 - 
     2 $CellContext`a^6 $CellContext`c^2 - 
     2 $CellContext`b^6 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`c^6 + 
     2 $CellContext`b^2 $CellContext`c^6 - $CellContext`c^8) \
($CellContext`a^8 - 2 $CellContext`a^6 $CellContext`b^2 + 
     2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 - 
     2 $CellContext`a^6 $CellContext`c^2 + 
     2 $CellContext`b^6 $CellContext`c^2 + 
     2 $CellContext`a^4 $CellContext`c^4 - 
     2 $CellContext`a^2 $CellContext`c^6 - 
     2 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8), \
($CellContext`a^8 - 2 $CellContext`a^6 $CellContext`b^2 + 
     2 $CellContext`a^4 $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 - 
     2 $CellContext`a^6 $CellContext`c^2 - 
     2 $CellContext`b^6 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`c^6 + 
     2 $CellContext`b^2 $CellContext`c^6 - $CellContext`c^8) \
(-$CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 + 
     2 $CellContext`a^6 $CellContext`c^2 - 
     2 $CellContext`b^6 $CellContext`c^2 + 
     2 $CellContext`b^4 $CellContext`c^4 - 
     2 $CellContext`a^2 $CellContext`c^6 - 
     2 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8), \
($CellContext`a^8 - 2 $CellContext`a^6 $CellContext`b^2 + 
     2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 - 
     2 $CellContext`a^6 $CellContext`c^2 + 
     2 $CellContext`b^6 $CellContext`c^2 + 
     2 $CellContext`a^4 $CellContext`c^4 - 
     2 $CellContext`a^2 $CellContext`c^6 - 
     2 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) \
(-$CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 + 
     2 $CellContext`a^6 $CellContext`c^2 - 
     2 $CellContext`b^6 $CellContext`c^2 + 
     2 $CellContext`b^4 $CellContext`c^4 - 
     2 $CellContext`a^2 $CellContext`c^6 - 
     2 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979387358847`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0f91c55e-ead1-4d63-8007-5459b924f442"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "71"}],
  SequenceForm["n=", 71],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793873909*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a8cd29e9-6a8c-4e22-9aa7-b780f6880d79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "72"}],
  SequenceForm["n=", 72],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938740481*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bf6350a3-e5e0-41a1-bc05-52ad2671ef61"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "73"}],
  SequenceForm["n=", 73],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938741666*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4cda1e34-56a3-4378-bb9b-0ca832c2e751"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "74"}],
  SequenceForm["n=", 74],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979387428207`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c178e9ab-8ed5-4dae-8f23-a2873ead0dd2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 74, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`c^4) ($CellContext`a^4 + $CellContext`a^2 \
$CellContext`b^2 - 2 $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4), $CellContext`b^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`c^4) ((-2) $CellContext`a^4 + $CellContext`a^2 \
$CellContext`b^2 + $CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`c^2 ((-2) $CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 - 2 $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938744636*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bb440a8a-1252-4d84-8b59-306505566943"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "75"}],
  SequenceForm["n=", 75],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938746335*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cb60cc51-bf6b-490e-8936-d9067617c95d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "75", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", "c"}], ",", 
     RowBox[{"a", " ", "c"}], ",", 
     RowBox[{"a", " ", "b"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 75, 
   "   ", {$CellContext`b $CellContext`c, $CellContext`a $CellContext`c, \
$CellContext`a $CellContext`b}, "   XM/AM=", 
   Style[(1 + 2 2^Rational[1, 2])^(-1), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938747551*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f2bcb83a-09db-4be2-b723-2f86d93539e9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "76"}],
  SequenceForm["n=", 76],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979387487698`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9d998c17-7ddf-48a1-9f9c-db6e7e4d7a5d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "76", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "5"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 76, 
   "   ", {$CellContext`b^2 $CellContext`c^2, $CellContext`a^2 \
$CellContext`c^2, $CellContext`a^2 $CellContext`b^2}, "   XM/AM=", 
   Style[
    Rational[1, 5], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938750091*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8c26d848-386c-4c09-bcea-1445b8677c61"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "77"}],
  SequenceForm["n=", 77],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793875181*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"681d764e-a5c1-4c1e-9172-f072ee33c6c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "78"}],
  SequenceForm["n=", 78],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938752923*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"16672548-9cb6-4caf-9ba6-91ecc315897f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "79"}],
  SequenceForm["n=", 79],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938754113*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0bdedcc7-4a28-410f-942e-3d82250acc96"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 79, 
   "   ", {($CellContext`a^2 + $CellContext`a $CellContext`b + \
$CellContext`b^2 - $CellContext`c^2) ($CellContext`a^2 - $CellContext`b^2 + \
$CellContext`a $CellContext`c + $CellContext`c^2), ($CellContext`a^2 + \
$CellContext`a $CellContext`b + $CellContext`b^2 - $CellContext`c^2) \
(-$CellContext`a^2 + $CellContext`b^2 + $CellContext`b $CellContext`c + \
$CellContext`c^2), ($CellContext`a^2 - $CellContext`b^2 + $CellContext`a \
$CellContext`c + $CellContext`c^2) (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`b $CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 7] (3 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938755711*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e88a210e-a05f-4f15-8a64-a36c3a2681c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "80"}],
  SequenceForm["n=", 80],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938757303*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"47307d44-bb60-4297-b1e5-d5fcde83df7b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 80, 
   "   ", {($CellContext`a^2 - $CellContext`a $CellContext`b + \
$CellContext`b^2 - $CellContext`c^2) ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`a $CellContext`c + $CellContext`c^2), ($CellContext`a^2 - \
$CellContext`a $CellContext`b + $CellContext`b^2 - $CellContext`c^2) \
(-$CellContext`a^2 + $CellContext`b^2 - $CellContext`b $CellContext`c + \
$CellContext`c^2), ($CellContext`a^2 - $CellContext`b^2 - $CellContext`a \
$CellContext`c + $CellContext`c^2) (-$CellContext`a^2 + $CellContext`b^2 - \
$CellContext`b $CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[1 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938758935*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"be7a87b8-b7a9-4680-b19c-ff0a324079a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "81"}],
  SequenceForm["n=", 81],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979387605753`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"84d5a05c-e5d3-4a42-b626-868182b8d2e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "81", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 81, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c), $CellContext`b ($CellContext`a + $CellContext`b) \
($CellContext`b + $CellContext`c), $CellContext`c ($CellContext`a + \
$CellContext`c) ($CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 17] (5 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938761983*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8998f67f-d08d-4a31-9fc2-427a72fb8458"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "82"}],
  SequenceForm["n=", 82],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938763281*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0eff2d1a-50b4-4387-b0bd-43a3c45789f2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "82", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"9", "-", 
     RowBox[{"6", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 82, 
   "   ", {$CellContext`a ($CellContext`a^2 + $CellContext`b^2) \
($CellContext`a^2 + $CellContext`c^2), $CellContext`b ($CellContext`a^2 + \
$CellContext`b^2) ($CellContext`b^2 + $CellContext`c^2), $CellContext`c \
($CellContext`a^2 + $CellContext`c^2) ($CellContext`b^2 + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[9 - 6 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938764756*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f7ce5fc3-3d70-45df-a8a4-9c3a73054683"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "83"}],
  SequenceForm["n=", 83],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938766313*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"62053529-1d2d-4e1f-bc53-15b0d926acde"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "83", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "7"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 83, 
   "   ", {($CellContext`a^2 + $CellContext`b^2) ($CellContext`a^2 + \
$CellContext`c^2), ($CellContext`a^2 + $CellContext`b^2) ($CellContext`b^2 + \
$CellContext`c^2), ($CellContext`a^2 + $CellContext`c^2) ($CellContext`b^2 + \
$CellContext`c^2)}, "   XM/AM=", 
   Style[
    Rational[3, 7], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938767804*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e9b723ab-a02e-4a75-bbb8-bd15686dbdb8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "84"}],
  SequenceForm["n=", 84],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938769454*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"180e8179-8ad5-4a2d-9eb6-328380f58c13"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "84", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 84, 
   "   ", {$CellContext`a ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`b ($CellContext`a^3 - \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) (-$CellContext`a^3 - $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`c (-$CellContext`a^3 - \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[1 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938771826*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5fd3d6e7-808e-463d-95ca-e076e81f4ded"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "85"}],
  SequenceForm["n=", 85],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938773943*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6ec0dca9-6c6a-45ed-b18c-7a13994a843a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "85", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"a", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 85, 
   "   ", {$CellContext`b (-$CellContext`a + $CellContext`b - $CellContext`c) \
$CellContext`c (-$CellContext`a - $CellContext`b + $CellContext`c), \
$CellContext`a ($CellContext`a - $CellContext`b - $CellContext`c) \
$CellContext`c (-$CellContext`a - $CellContext`b + $CellContext`c), \
$CellContext`a $CellContext`b ($CellContext`a - $CellContext`b - \
$CellContext`c) (-$CellContext`a + $CellContext`b - $CellContext`c)}, 
   "   XM/AM=", 
   Style[Rational[1, 17] (5 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938775341*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fe12eea6-0df5-4104-a81b-8a6605cac1a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "86"}],
  SequenceForm["n=", 86],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979387766848`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2df0dc22-433b-487b-997b-46780541904f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "86", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "23"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 86, 
   "   ", {($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c), ($CellContext`a + $CellContext`b) ($CellContext`b + \
$CellContext`c), ($CellContext`a + $CellContext`c) ($CellContext`b + \
$CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 23] (3 + 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388124437`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fe5ef645-4580-4df4-8baf-17734029dde6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "87"}],
  SequenceForm["n=", 87],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388141603`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"30bd1631-a5dc-4385-803d-bd424d7e6ae6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "87", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "23"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 87, 
   "   ", {$CellContext`a ($CellContext`a $CellContext`b - $CellContext`a \
$CellContext`c - $CellContext`b $CellContext`c) (-$CellContext`a \
$CellContext`b + $CellContext`a $CellContext`c - $CellContext`b \
$CellContext`c), $CellContext`b ($CellContext`a $CellContext`b - \
$CellContext`a $CellContext`c - $CellContext`b $CellContext`c) \
(-$CellContext`a $CellContext`b - $CellContext`a $CellContext`c + \
$CellContext`b $CellContext`c), $CellContext`c (-$CellContext`a \
$CellContext`b + $CellContext`a $CellContext`c - $CellContext`b \
$CellContext`c) (-$CellContext`a $CellContext`b - $CellContext`a \
$CellContext`c + $CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 23] (5 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938815645*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9cd0dd67-50f6-4f48-ba87-1ade4015f719"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "88"}],
  SequenceForm["n=", 88],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938817031*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"aaf78a81-8dff-49dc-b907-afcb244291ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", 
        RowBox[{"2", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", 
        RowBox[{"2", " ", "b"}], "+", "c"}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", 
        RowBox[{"2", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", 
        RowBox[{"2", " ", "b"}], "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}]}], 
    "}"}], "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 88, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b - 
     2 $CellContext`c) ($CellContext`a - 
     2 $CellContext`b + $CellContext`c), $CellContext`b ($CellContext`a + \
$CellContext`b - 
     2 $CellContext`c) ((-2) $CellContext`a + $CellContext`b + \
$CellContext`c), $CellContext`c ($CellContext`a - 
     2 $CellContext`b + $CellContext`c) ((-2) $CellContext`a + $CellContext`b + \
$CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 7] (-1 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793881845*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"544e99fd-57e0-42e1-a7d8-3b1da82be018"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "89"}],
  SequenceForm["n=", 89],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793881986*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7fa094c2-cd14-4783-82b6-704cf8cd31a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "89", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a"}], "+", 
        RowBox[{"2", " ", "b"}], "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a"}], "-", "b", "+", 
        RowBox[{"2", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a"}], "+", 
        RowBox[{"2", " ", "b"}], "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", 
        RowBox[{"2", " ", "b"}], "+", 
        RowBox[{"2", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a"}], "-", "b", "+", 
        RowBox[{"2", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", 
        RowBox[{"2", " ", "b"}], "+", 
        RowBox[{"2", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "71"], " ", 
     RowBox[{"(", 
      RowBox[{"25", "+", 
       RowBox[{"8", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 89, 
   "   ", {$CellContext`a (2 $CellContext`a + 
     2 $CellContext`b - $CellContext`c) (2 $CellContext`a - $CellContext`b + 
     2 $CellContext`c), $CellContext`b (2 $CellContext`a + 
     2 $CellContext`b - $CellContext`c) (-$CellContext`a + 2 $CellContext`b + 
     2 $CellContext`c), $CellContext`c (2 $CellContext`a - $CellContext`b + 
     2 $CellContext`c) (-$CellContext`a + 2 $CellContext`b + 
     2 $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 71] (25 + 8 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793882127*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3d9ad199-2565-436c-b429-9085d19b108d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "90"}],
  SequenceForm["n=", 90],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938822604*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9427fcd5-a196-4303-8876-5f48a2d7de15"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "91"}],
  SequenceForm["n=", 91],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938823716*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f41739a2-8187-4dc2-8b9a-7cace5295de7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "92"}],
  SequenceForm["n=", 92],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938825013*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7674844f-e79f-46f6-9052-84fe414a098c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "93"}],
  SequenceForm["n=", 93],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388262463`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9ec84b58-d43e-4f0e-9ad9-5513bc89ff1d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "94"}],
  SequenceForm["n=", 94],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388274727`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e73c6bdf-1a05-4a9e-8cdc-64660ca7dd6a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "94", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 94, 
   "   ", {$CellContext`b^2 $CellContext`c^2 ($CellContext`a^2 - \
$CellContext`a $CellContext`b + $CellContext`b^2 - $CellContext`c^2) \
($CellContext`a^2 + $CellContext`a $CellContext`b + $CellContext`b^2 - \
$CellContext`c^2) ($CellContext`a^2 - $CellContext`b^2 - $CellContext`a \
$CellContext`c + $CellContext`c^2) ($CellContext`a^2 - $CellContext`b^2 + \
$CellContext`a $CellContext`c + $CellContext`c^2), $CellContext`a^2 \
$CellContext`c^2 ($CellContext`a^2 - $CellContext`a $CellContext`b + \
$CellContext`b^2 - $CellContext`c^2) ($CellContext`a^2 + $CellContext`a \
$CellContext`b + $CellContext`b^2 - $CellContext`c^2) (-$CellContext`a^2 + \
$CellContext`b^2 - $CellContext`b $CellContext`c + $CellContext`c^2) \
(-$CellContext`a^2 + $CellContext`b^2 + $CellContext`b $CellContext`c + \
$CellContext`c^2), $CellContext`a^2 $CellContext`b^2 ($CellContext`a^2 - \
$CellContext`b^2 - $CellContext`a $CellContext`c + $CellContext`c^2) \
($CellContext`a^2 - $CellContext`b^2 + $CellContext`a $CellContext`c + \
$CellContext`c^2) (-$CellContext`a^2 + $CellContext`b^2 - $CellContext`b \
$CellContext`c + $CellContext`c^2) (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`b $CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938829486*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"48b43764-8302-4dfa-8638-1bf7a3e5c7f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "95"}],
  SequenceForm["n=", 95],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938831376*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5388e781-b05c-491f-b7b5-74185c14e1d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "95", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "5"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 95, 
   "   ", {($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) \
($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4), ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) \
(-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
(-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[1, 5], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938833284*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4122fda2-1a78-494c-99c1-ad300b023cf6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "96"}],
  SequenceForm["n=", 96],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938834992*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ae344921-dbf9-4e0b-ba61-a024605324b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "97"}],
  SequenceForm["n=", 97],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938836104*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"92e0a467-7c6f-4530-9eec-bcd9a0aa2cb1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "98"}],
  SequenceForm["n=", 98],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388371973`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4eb002ba-2c03-494e-b11f-7f473bab44c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "98", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 98, 
   "   ", {($CellContext`a^4 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) ($CellContext`a^4 - \
$CellContext`a^2 $CellContext`b^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4), ($CellContext`a^4 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) (-$CellContext`a^2 \
$CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 + \
$CellContext`c^4), (-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 + $CellContext`c^4) ($CellContext`a^4 - \
$CellContext`a^2 $CellContext`b^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388387537`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d4b0c781-209e-4471-81d9-9041268c3165"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "99"}],
  SequenceForm["n=", 99],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938840242*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"928028ad-eddb-4df8-9164-4940b7b9cdf7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "100"}],
  SequenceForm["n=", 100],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938841363*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"99cbda87-6f0e-4cfd-99e5-9167379e4d65"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "101"}],
  SequenceForm["n=", 101],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793884247*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bb2a0c2e-9892-4f6c-a29b-1e3a5dc4f61d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "102"}],
  SequenceForm["n=", 102],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938843547*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1640a2bf-b523-430e-8b2c-44fba46047d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "102", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 102, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^3 $CellContext`c + $CellContext`a^2 $CellContext`b \
$CellContext`c + $CellContext`a $CellContext`b^2 $CellContext`c - \
$CellContext`b^3 $CellContext`c + $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`a $CellContext`c^3 + $CellContext`b \
$CellContext`c^3 - 
     2 $CellContext`c^4) ($CellContext`a^4 - $CellContext`a^3 $CellContext`b + \
$CellContext`a^2 $CellContext`b^2 + $CellContext`a $CellContext`b^3 - 
     2 $CellContext`b^4 + $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - $CellContext`b \
$CellContext`c^3 + $CellContext`c^4), $CellContext`b^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^3 $CellContext`c + $CellContext`a^2 $CellContext`b \
$CellContext`c + $CellContext`a $CellContext`b^2 $CellContext`c - \
$CellContext`b^3 $CellContext`c + $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`a $CellContext`c^3 + $CellContext`b \
$CellContext`c^3 - 
     2 $CellContext`c^4) ((-2) $CellContext`a^4 + $CellContext`a^3 \
$CellContext`b + $CellContext`a^2 $CellContext`b^2 - $CellContext`a \
$CellContext`b^3 + $CellContext`b^4 + $CellContext`a^3 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`b^2 $CellContext`c + $CellContext`a^2 $CellContext`c^2 + \
$CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`a $CellContext`c^3 + \
$CellContext`c^4), $CellContext`c^2 ((-2) $CellContext`a^4 + $CellContext`a^3 \
$CellContext`b + $CellContext`a^2 $CellContext`b^2 - $CellContext`a \
$CellContext`b^3 + $CellContext`b^4 + $CellContext`a^3 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`b^2 $CellContext`c + $CellContext`a^2 $CellContext`c^2 + \
$CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`a $CellContext`c^3 + \
$CellContext`c^4) ($CellContext`a^4 - $CellContext`a^3 $CellContext`b + \
$CellContext`a^2 $CellContext`b^2 + $CellContext`a $CellContext`b^3 - 
     2 $CellContext`b^4 + $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - $CellContext`b \
$CellContext`c^3 + $CellContext`c^4)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938846051*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a3700dec-c1cf-4cc0-b129-4d95c1dfb108"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "103"}],
  SequenceForm["n=", 103],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938848225*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"120b1561-fdef-443f-82cf-ec0114f53662"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "103", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 103, 
   "   ", {$CellContext`a^2 ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2 - 
     2 $CellContext`c^3) ($CellContext`a^3 + $CellContext`a $CellContext`b^2 - 
     2 $CellContext`b^3 - $CellContext`a^2 $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3), \
$CellContext`b^2 ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`a \
$CellContext`c^2 + $CellContext`b $CellContext`c^2 - 
     2 $CellContext`c^3) ((-2) $CellContext`a^3 + $CellContext`a^2 \
$CellContext`b + $CellContext`b^3 + $CellContext`a^2 $CellContext`c - \
$CellContext`b^2 $CellContext`c - $CellContext`b $CellContext`c^2 + \
$CellContext`c^3), $CellContext`c^2 ($CellContext`a^3 + $CellContext`a \
$CellContext`b^2 - 
     2 $CellContext`b^3 - $CellContext`a^2 $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3) ((-2) \
$CellContext`a^3 + $CellContext`a^2 $CellContext`b + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c - $CellContext`b^2 $CellContext`c - \
$CellContext`b $CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938850017*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a5614611-646d-4954-b1f0-5a3869390628"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "104"}],
  SequenceForm["n=", 104],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938851623*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2b2de884-e619-4474-8766-a6e314f933e1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "104", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 104, 
   "   ", {$CellContext`a ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2) ($CellContext`a^3 - \
$CellContext`a $CellContext`b^2 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3), \
$CellContext`b ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2) (-$CellContext`a^2 \
$CellContext`b + $CellContext`b^3 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`b $CellContext`c^2 + $CellContext`c^3), \
$CellContext`c ($CellContext`a^3 - $CellContext`a $CellContext`b^2 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3) \
(-$CellContext`a^2 $CellContext`b + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`b $CellContext`c^2 + $CellContext`c^3)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938853385*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a5cfa3e1-37bc-40a8-afec-928ab1d4258f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "105"}],
  SequenceForm["n=", 105],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388549957`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9600fb82-6611-46a8-8660-97eb1ecd29ff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "105", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 105, 
   "   ", {$CellContext`a ($CellContext`a^2 + $CellContext`b^2 - \
$CellContext`a $CellContext`c - $CellContext`b $CellContext`c) \
($CellContext`a^2 - $CellContext`a $CellContext`b - $CellContext`b \
$CellContext`c + $CellContext`c^2), $CellContext`b ($CellContext`a^2 + \
$CellContext`b^2 - $CellContext`a $CellContext`c - $CellContext`b \
$CellContext`c) (-$CellContext`a $CellContext`b + $CellContext`b^2 - \
$CellContext`a $CellContext`c + $CellContext`c^2), $CellContext`c \
(-$CellContext`a $CellContext`b + $CellContext`b^2 - $CellContext`a \
$CellContext`c + $CellContext`c^2) ($CellContext`a^2 - $CellContext`a \
$CellContext`b - $CellContext`b $CellContext`c + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938856429*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"898a7033-be37-476c-9b6a-446f3d6253f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "106"}],
  SequenceForm["n=", 106],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938857771*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9d135c43-49e6-46d8-8827-a980238298d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "106", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", 
        RowBox[{"2", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", 
        RowBox[{"2", " ", "b"}], "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", 
        RowBox[{"2", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", 
        RowBox[{"2", " ", "b"}], "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}]}], 
    "}"}], "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 106, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b - 
     2 $CellContext`c) ($CellContext`a - 
     2 $CellContext`b + $CellContext`c), $CellContext`b^2 ($CellContext`a + \
$CellContext`b - 
     2 $CellContext`c) ((-2) $CellContext`a + $CellContext`b + \
$CellContext`c), $CellContext`c^2 ($CellContext`a - 
     2 $CellContext`b + $CellContext`c) ((-2) $CellContext`a + $CellContext`b + \
$CellContext`c)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938859076*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a7ac71df-575b-43e5-90c2-34dd94bb64dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "107"}],
  SequenceForm["n=", 107],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388604097`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"02c12e9f-4698-48b2-b810-ca9dd53bb769"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "108"}],
  SequenceForm["n=", 108],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938861478*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a11c073a-8af9-4e04-9caa-1baa0579b312"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "109"}],
  SequenceForm["n=", 109],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938862546*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"78e72e7b-4b12-4e87-89db-89c5dd75b3aa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "110"}],
  SequenceForm["n=", 110],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938863606*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"af30f489-3af0-4f47-aec6-2a5e41caf95a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "111"}],
  SequenceForm["n=", 111],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388646708`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1e81873f-c364-4881-8665-2ec09a157e9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "111", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 111, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 + $CellContext`b^2 - 
     2 $CellContext`c^2) ($CellContext`a^2 - 
     2 $CellContext`b^2 + $CellContext`c^2), $CellContext`b^2 \
($CellContext`a^2 + $CellContext`b^2 - 
     2 $CellContext`c^2) ((-2) $CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2), $CellContext`c^2 ($CellContext`a^2 - 
     2 $CellContext`b^2 + $CellContext`c^2) ((-2) $CellContext`a^2 + \
$CellContext`b^2 + $CellContext`c^2)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793886605*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7b13667c-e774-48a7-9ef5-a4d303e6c356"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "112"}],
  SequenceForm["n=", 112],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388674183`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0c0aec3b-0cfd-4252-b5e0-43534917b428"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "113"}],
  SequenceForm["n=", 113],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388684597`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c9ad7577-fe77-4669-9198-4ff3f071c50b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "114"}],
  SequenceForm["n=", 114],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388694983`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"19834269-9f97-4dfe-ad4a-b6250d436bd2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "115"}],
  SequenceForm["n=", 115],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938870557*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7f495590-44f1-4580-a510-7e2545afe374"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "116"}],
  SequenceForm["n=", 116],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938871606*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2203fb3d-c934-4a9c-91d1-82d416c834a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "117"}],
  SequenceForm["n=", 117],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938872652*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"485d1fac-e84e-4e04-b6af-423fe29c589a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "118"}],
  SequenceForm["n=", 118],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938873725*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ce13a429-c650-4363-aee0-d84b5fa826da"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "119"}],
  SequenceForm["n=", 119],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938874819*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"96d202cc-37c9-4541-870a-f21bd0b30194"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "120"}],
  SequenceForm["n=", 120],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938875881*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"306e7695-c2b7-41ba-af8b-6f365f181be5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "121"}],
  SequenceForm["n=", 121],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388769207`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7863921d-c554-487d-b9ee-eb59540d4814"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "122"}],
  SequenceForm["n=", 122],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388779583`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2431f9bf-29c0-455b-b880-c3ee7fa04cf5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "123"}],
  SequenceForm["n=", 123],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938879012*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a0732156-87e9-49d1-ae9c-35dcfdea82ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "124"}],
  SequenceForm["n=", 124],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388800592`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"87164327-e440-4f61-bd2d-1b06e0be7acd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "125"}],
  SequenceForm["n=", 125],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388811007`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8e3cfdea-14ed-479d-915c-6180389d1b03"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "126"}],
  SequenceForm["n=", 126],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388823442`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ef12ce19-9a73-451b-92ab-a735476c41f8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "127"}],
  SequenceForm["n=", 127],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938883484*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ef258d72-b844-4532-ae29-c2ced517f661"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "128"}],
  SequenceForm["n=", 128],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938884577*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"409f840e-d564-4f3f-b347-dadc059fc402"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "129"}],
  SequenceForm["n=", 129],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938885644*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"aee5d8cf-33b0-47d7-aa8f-a6fa2fbcc36d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "130"}],
  SequenceForm["n=", 130],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938886718*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b43881be-88c4-4f46-9482-dd118b8d9d0f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "131"}],
  SequenceForm["n=", 131],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938887796*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b74733c8-42ad-41fc-bb8d-cbd5de9a3fe0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "132"}],
  SequenceForm["n=", 132],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938888878*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"861475cb-86da-4fea-a980-627045d114c2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "133"}],
  SequenceForm["n=", 133],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938889948*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c9957821-c973-44df-833c-8e610f2414ae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "134"}],
  SequenceForm["n=", 134],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938891019*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5cbec0e8-1ced-4265-b127-8acb8409555b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "135"}],
  SequenceForm["n=", 135],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793889214*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b8416c47-b8fe-4cf8-9d25-8d187c84332b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "136"}],
  SequenceForm["n=", 136],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979388932257`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a97cebc5-db01-4961-91ac-796d422f6797"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "137"}],
  SequenceForm["n=", 137],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938894309*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3968a1b7-155b-4470-981a-81b389368c23"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "138"}],
  SequenceForm["n=", 138],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938895382*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b4de687a-d490-4f1d-bc73-a7ba4fd6b1aa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "139"}],
  SequenceForm["n=", 139],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938896468*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5e9e8f3b-db2d-4f9e-833a-f5187a1bff1b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "140"}],
  SequenceForm["n=", 140],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793889758*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a30efa3c-0b8b-4237-a524-5db21b0fa7e2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "140", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "4"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 140, "   ", {
   2 $CellContext`a^4 - 
    3 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    3 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - 
    3 $CellContext`a^2 $CellContext`b^2 + 2 $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`c^2 - 
    3 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    3 $CellContext`a^2 $CellContext`c^2 - 3 $CellContext`b^2 $CellContext`c^2 + 
    2 $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[1, 4], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938899033*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"aeef31c2-aac6-40be-8011-b61e5ab322d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "141"}],
  SequenceForm["n=", 141],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938900486*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e1846d12-c837-4207-950b-a66ddb339d88"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "141", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "4"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 141, 
   "   ", {$CellContext`b^2 + $CellContext`c^2, $CellContext`a^2 + \
$CellContext`c^2, $CellContext`a^2 + $CellContext`b^2}, "   XM/AM=", 
   Style[
    Rational[1, 4], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938901802*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"12518b44-aed2-4eea-a1e7-dc71beb0f3b2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "142"}],
  SequenceForm["n=", 142],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938903048*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"67f02c12-6216-47af-9ca3-96e255fdcb16"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "142", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "b"}], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"a", " ", "c"}], "-", 
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"a", " ", "b"}], "-", 
      RowBox[{"2", " ", "a", " ", "c"}], "-", 
      RowBox[{"b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "b"}], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"a", " ", "c"}], "-", 
      RowBox[{"b", " ", "c"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"4", "-", 
      SqrtBox["2"]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 142, 
   "   ", {-$CellContext`a $CellContext`b + $CellContext`b^2 - $CellContext`a \
$CellContext`c - 
    2 $CellContext`b $CellContext`c + $CellContext`c^2, $CellContext`a^2 - \
$CellContext`a $CellContext`b - 
    2 $CellContext`a $CellContext`c - $CellContext`b $CellContext`c + \
$CellContext`c^2, $CellContext`a^2 - 
    2 $CellContext`a $CellContext`b + $CellContext`b^2 - $CellContext`a \
$CellContext`c - $CellContext`b $CellContext`c}, "   XM/AM=", 
   Style[(4 - 2^Rational[1, 2])^(-1), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938904728*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fd53ad82-c52e-446b-907a-0025f6d1b22e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "143"}],
  SequenceForm["n=", 143],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938906322*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"93e057d3-9fdb-48a6-a7d0-7efb49d5af47"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "143", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "4"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 143, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4) \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4), $CellContext`b^2 (-$CellContext`a^4 + $CellContext`a^2 \
$CellContext`b^2 + 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - \
$CellContext`c^4) ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`c^2 (-$CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2) \
($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[3, 4], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938908661*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"afde3554-c1ff-4711-99d3-dc636944dbff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "144"}],
  SequenceForm["n=", 144],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938910852*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e4fd3928-1e74-4602-ba90-bad6e0faa176"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "144", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", "b"}], "-", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "c"}], "+", 
      RowBox[{"2", " ", "b", " ", "c"}], "-", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", "b"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", "c"}], "-", 
      RowBox[{"2", " ", "b", " ", "c"}], "-", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", "b"}], "-", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "c"}], "-", 
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "2"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "-", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 144, "   ", {
   3 $CellContext`a^2 - 2 $CellContext`a $CellContext`b - $CellContext`b^2 - 
    2 $CellContext`a $CellContext`c + 
    2 $CellContext`b $CellContext`c - $CellContext`c^2, -$CellContext`a^2 - 
    2 $CellContext`a $CellContext`b + 3 $CellContext`b^2 + 
    2 $CellContext`a $CellContext`c - 
    2 $CellContext`b $CellContext`c - $CellContext`c^2, -$CellContext`a^2 + 
    2 $CellContext`a $CellContext`b - $CellContext`b^2 - 
    2 $CellContext`a $CellContext`c - 2 $CellContext`b $CellContext`c + 
    3 $CellContext`c^2}, "   XM/AM=", 
   Style[Rational[1, 7] (5 - 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938912571*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"06a0c80d-78cf-49e8-851c-539c67186cdd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "145"}],
  SequenceForm["n=", 145],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938914461*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1b183894-4318-4657-9cfd-97d7c63aae7c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "145", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"3", " ", "a"}], "-", "b", "-", "c"}], ",", 
     RowBox[{
      RowBox[{"-", "a"}], "+", 
      RowBox[{"3", " ", "b"}], "-", "c"}], ",", 
     RowBox[{
      RowBox[{"-", "a"}], "-", "b", "+", 
      RowBox[{"3", " ", "c"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "5"}], "+", 
     RowBox[{"4", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 145, "   ", {
   3 $CellContext`a - $CellContext`b - $CellContext`c, -$CellContext`a + 
    3 $CellContext`b - $CellContext`c, -$CellContext`a - $CellContext`b + 
    3 $CellContext`c}, "   XM/AM=", 
   Style[-5 + 4 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938915896*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"44b044e9-ec4d-4f8f-a74a-690ab13bed21"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "146"}],
  SequenceForm["n=", 146],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979389172087`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4d9beaf2-2566-47c2-9c9c-0202cd4fa908"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "146", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "10"], "+", 
      RowBox[{
       SuperscriptBox["a", "8"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "6"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "8"]}], "-", 
      SuperscriptBox["b", "10"], "+", 
      RowBox[{
       SuperscriptBox["a", "8"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"9", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "8"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "8"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "8"]}], "-", 
      SuperscriptBox["c", "10"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "10"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "8"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "6"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "8"]}], "+", 
      SuperscriptBox["b", "10"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "8"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"9", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "8"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "8"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "8"]}], "-", 
      SuperscriptBox["c", "10"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "10"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "8"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "6"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "8"]}], "-", 
      SuperscriptBox["b", "10"], "-", 
      RowBox[{
       SuperscriptBox["a", "8"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "8"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"9", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "8"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "8"]}], "+", 
      SuperscriptBox["c", "10"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox["3",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 146, 
   "   ", {$CellContext`a^10 + $CellContext`a^8 $CellContext`b^2 - 
    8 $CellContext`a^6 $CellContext`b^4 + 
    8 $CellContext`a^4 $CellContext`b^6 - $CellContext`a^2 $CellContext`b^8 - \
$CellContext`b^10 + $CellContext`a^8 $CellContext`c^2 + 
    9 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 - 
    6 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 - 
    7 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 + 
    3 $CellContext`b^8 $CellContext`c^2 - 8 $CellContext`a^6 $CellContext`c^4 - 
    6 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 + 
    16 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 - 
    2 $CellContext`b^6 $CellContext`c^4 + 8 $CellContext`a^4 $CellContext`c^6 - 
    7 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 - 
    2 $CellContext`b^4 $CellContext`c^6 - $CellContext`a^2 $CellContext`c^8 + 
    3 $CellContext`b^2 $CellContext`c^8 - $CellContext`c^10, \
-$CellContext`a^10 - $CellContext`a^8 $CellContext`b^2 + 
    8 $CellContext`a^6 $CellContext`b^4 - 
    8 $CellContext`a^4 $CellContext`b^6 + $CellContext`a^2 $CellContext`b^8 + \
$CellContext`b^10 + 3 $CellContext`a^8 $CellContext`c^2 - 
    7 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 - 
    6 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 + 
    9 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 + $CellContext`b^8 \
$CellContext`c^2 - 2 $CellContext`a^6 $CellContext`c^4 + 
    16 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 - 
    6 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 - 
    8 $CellContext`b^6 $CellContext`c^4 - 2 $CellContext`a^4 $CellContext`c^6 - 
    7 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 + 
    8 $CellContext`b^4 $CellContext`c^6 + 
    3 $CellContext`a^2 $CellContext`c^8 - $CellContext`b^2 $CellContext`c^8 - \
$CellContext`c^10, -$CellContext`a^10 + 3 $CellContext`a^8 $CellContext`b^2 - 
    2 $CellContext`a^6 $CellContext`b^4 - 2 $CellContext`a^4 $CellContext`b^6 + 
    3 $CellContext`a^2 $CellContext`b^8 - $CellContext`b^10 - \
$CellContext`a^8 $CellContext`c^2 - 
    7 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 + 
    16 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 - 
    7 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 - $CellContext`b^8 \
$CellContext`c^2 + 8 $CellContext`a^6 $CellContext`c^4 - 
    6 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 - 
    6 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 + 
    8 $CellContext`b^6 $CellContext`c^4 - 8 $CellContext`a^4 $CellContext`c^6 + 
    9 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 - 
    8 $CellContext`b^4 $CellContext`c^6 + $CellContext`a^2 $CellContext`c^8 + \
$CellContext`b^2 $CellContext`c^8 + $CellContext`c^10}, "   XM/AM=", 
   Style[3, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938919867*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"80efc043-7f3d-449b-ad12-30bbea8eb5ff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "147"}],
  SequenceForm["n=", 147],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938922606*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"85de3362-4388-4c5c-a82d-a9718189ee6c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "147", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "8"], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "-", 
      SuperscriptBox["b", "8"], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      SuperscriptBox["c", "8"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "8"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "+", 
      SuperscriptBox["b", "8"], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      SuperscriptBox["c", "8"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "8"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "-", 
      SuperscriptBox["b", "8"], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      SuperscriptBox["c", "8"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox["3",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 147, 
   "   ", {$CellContext`a^8 + $CellContext`a^6 $CellContext`b^2 - 
    2 $CellContext`a^4 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^6 - \
$CellContext`b^8 + $CellContext`a^6 $CellContext`c^2 - 
    3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + $CellContext`a^2 \
$CellContext`b^4 $CellContext`c^2 + $CellContext`b^6 $CellContext`c^2 - 
    2 $CellContext`a^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^4 + $CellContext`a^2 $CellContext`c^6 + $CellContext`b^2 \
$CellContext`c^6 - $CellContext`c^8, -$CellContext`a^8 + $CellContext`a^6 \
$CellContext`b^2 - 
    2 $CellContext`a^4 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^6 + \
$CellContext`b^8 + $CellContext`a^6 $CellContext`c^2 + $CellContext`a^4 \
$CellContext`b^2 $CellContext`c^2 - 
    3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + $CellContext`b^6 \
$CellContext`c^2 + $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
    2 $CellContext`b^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^6 + \
$CellContext`b^2 $CellContext`c^6 - $CellContext`c^8, -$CellContext`a^8 + \
$CellContext`a^6 $CellContext`b^2 + $CellContext`a^2 $CellContext`b^6 - \
$CellContext`b^8 + $CellContext`a^6 $CellContext`c^2 + $CellContext`a^4 \
$CellContext`b^2 $CellContext`c^2 + $CellContext`a^2 $CellContext`b^4 \
$CellContext`c^2 + $CellContext`b^6 $CellContext`c^2 - 
    2 $CellContext`a^4 $CellContext`c^4 - 
    3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
    2 $CellContext`b^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^6 + \
$CellContext`b^2 $CellContext`c^6 + $CellContext`c^8}, "   XM/AM=", 
   Style[3, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938925374*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4bebea59-594e-41fa-96a7-a6e776c28987"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "148"}],
  SequenceForm["n=", 148],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938927535*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a2c7f76b-223f-4318-9c30-8b6d706d1188"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "148", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 148, 
   "   ", {$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 + 
    3 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 - \
$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
    3 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 - \
$CellContext`c^4, -$CellContext`a^4 + 
    3 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109793892913*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"de6321ce-0fba-4c75-99d4-0fc5a1fe14ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "149"}],
  SequenceForm["n=", 149],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979389306602`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1b3ca52c-2db5-4935-8baa-15297aec3172"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "149", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "3"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", "b", " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "3"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "3"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", "b", " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "3"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "3"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", "b", " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "3"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 149, 
   "   ", {$CellContext`a^3 - $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c + \
$CellContext`b^2 $CellContext`c + $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2 - $CellContext`c^3, -$CellContext`a^3 + \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c - $CellContext`b^2 $CellContext`c + \
$CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2 - \
$CellContext`c^3, -$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c + \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2 + $CellContext`c^3}, "   XM/AM=", 
   Style[-1, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979389324417`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ed07be22-09d8-48cf-9c4a-fb91b02e16a6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "150"}],
  SequenceForm["n=", 150],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938934116*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"84ca9f10-2d9d-4e33-879d-59f78f7d7d66"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "150", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 150, 
   "   ", {$CellContext`a^4 - $CellContext`a^3 $CellContext`b + \
$CellContext`a $CellContext`b^3 - $CellContext`b^4 - $CellContext`a^3 \
$CellContext`c + $CellContext`a^2 $CellContext`b $CellContext`c - \
$CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c^2 + \
$CellContext`a $CellContext`c^3 + $CellContext`b $CellContext`c^3 - \
$CellContext`c^4, -$CellContext`a^4 + $CellContext`a^3 $CellContext`b - \
$CellContext`a $CellContext`b^3 + $CellContext`b^4 + $CellContext`a^3 \
$CellContext`c - $CellContext`a^2 $CellContext`b $CellContext`c + \
$CellContext`a $CellContext`b^2 $CellContext`c - $CellContext`b^3 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c^2 + \
$CellContext`a $CellContext`c^3 + $CellContext`b $CellContext`c^3 - \
$CellContext`c^4, -$CellContext`a^4 + $CellContext`a^3 $CellContext`b + \
$CellContext`a $CellContext`b^3 - $CellContext`b^4 + $CellContext`a^3 \
$CellContext`c - $CellContext`a^2 $CellContext`b $CellContext`c - \
$CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c + $CellContext`a $CellContext`b $CellContext`c^2 - \
$CellContext`a $CellContext`c^3 - $CellContext`b $CellContext`c^3 + \
$CellContext`c^4}, "   XM/AM=", 
   Style[-1, 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938936005*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f67cca86-b93d-44c0-939a-83d24189c909"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "151"}],
  SequenceForm["n=", 151],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979389377317`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"da250596-cc5a-4509-aef3-fa0c92bf207c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "151", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "10"], "-", 
      RowBox[{
       SuperscriptBox["a", "9"], " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "8"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "7"], " ", 
       SuperscriptBox["b", "3"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "6"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "7"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "8"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "9"]}], "-", 
      SuperscriptBox["b", "10"], "-", 
      RowBox[{
       SuperscriptBox["a", "9"], " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "8"], " ", "b", " ", "c"}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "7"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "4"], " ", "c"}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "5"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "6"], " ", "c"}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "7"], " ", "c"}], "-", 
      RowBox[{"3", " ", "a", " ", 
       SuperscriptBox["b", "8"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "9"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "8"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "7"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "8"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "7"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"24", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"14", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"8", " ", "a", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "7"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "5"], " ", "b", " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"14", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"26", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"6", " ", "a", " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"6", " ", "a", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"8", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["c", "7"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "7"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "7"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "8"]}], "-", 
      RowBox[{"3", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "8"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "8"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "9"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "9"]}], "-", 
      SuperscriptBox["c", "10"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "10"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "9"], " ", "b"}], "-", 
      RowBox[{
       SuperscriptBox["a", "8"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "7"], " ", 
       SuperscriptBox["b", "3"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "6"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "7"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "8"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "9"]}], "+", 
      SuperscriptBox["b", "10"], "+", 
      RowBox[{
       SuperscriptBox["a", "9"], " ", "c"}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "8"], " ", "b", " ", "c"}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "7"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "4"], " ", "c"}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "5"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "6"], " ", "c"}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "7"], " ", "c"}], "+", 
      RowBox[{"3", " ", "a", " ", 
       SuperscriptBox["b", "8"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "9"], " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "8"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"6", " ", "a", " ", 
       SuperscriptBox["b", "7"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "8"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "7"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "6"], " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"14", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"24", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "7"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "5"], " ", "b", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"26", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"14", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"12", " ", "a", " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"12", " ", "a", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["c", "7"]}], "+", 
      RowBox[{"6", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "7"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "7"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "8"]}], "-", 
      RowBox[{"3", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "8"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "8"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "9"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "9"]}], "-", 
      SuperscriptBox["c", "10"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "10"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "9"], " ", "b"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "8"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "7"], " ", 
       SuperscriptBox["b", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "5"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "6"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "7"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "8"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "9"]}], "-", 
      SuperscriptBox["b", "10"], "+", 
      RowBox[{
       SuperscriptBox["a", "9"], " ", "c"}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "8"], " ", "b", " ", "c"}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "4"], " ", "c"}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "5"], " ", "c"}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "6"], " ", "c"}], "-", 
      RowBox[{"3", " ", "a", " ", 
       SuperscriptBox["b", "8"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "9"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "8"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "7"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"26", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"6", " ", "a", " ", 
       SuperscriptBox["b", "7"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "8"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "7"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"14", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"14", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"18", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "7"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "5"], " ", "b", " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"24", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"12", " ", "a", " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"12", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"12", " ", "a", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"16", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["c", "7"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "7"]}], "-", 
      RowBox[{"6", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "7"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "7"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "8"]}], "+", 
      RowBox[{"3", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "8"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "8"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "9"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "9"]}], "+", 
      SuperscriptBox["c", "10"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox["3",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 151, 
   "   ", {$CellContext`a^10 - $CellContext`a^9 $CellContext`b + \
$CellContext`a^8 $CellContext`b^2 + 2 $CellContext`a^7 $CellContext`b^3 - 
    8 $CellContext`a^6 $CellContext`b^4 + 8 $CellContext`a^4 $CellContext`b^6 - 
    2 $CellContext`a^3 $CellContext`b^7 - $CellContext`a^2 $CellContext`b^8 + \
$CellContext`a $CellContext`b^9 - $CellContext`b^10 - $CellContext`a^9 \
$CellContext`c + 3 $CellContext`a^8 $CellContext`b $CellContext`c - 
    6 $CellContext`a^7 $CellContext`b^2 $CellContext`c + 
    2 $CellContext`a^6 $CellContext`b^3 $CellContext`c + 
    12 $CellContext`a^5 $CellContext`b^4 $CellContext`c - 
    12 $CellContext`a^4 $CellContext`b^5 $CellContext`c - 
    2 $CellContext`a^3 $CellContext`b^6 $CellContext`c + 
    6 $CellContext`a^2 $CellContext`b^7 $CellContext`c - 
    3 $CellContext`a $CellContext`b^8 $CellContext`c + $CellContext`b^9 \
$CellContext`c + $CellContext`a^8 $CellContext`c^2 - 
    6 $CellContext`a^7 $CellContext`b $CellContext`c^2 + 
    16 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 - 
    12 $CellContext`a^5 $CellContext`b^3 $CellContext`c^2 - 
    8 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 + 
    18 $CellContext`a^3 $CellContext`b^5 $CellContext`c^2 - 
    12 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 + 
    3 $CellContext`b^8 $CellContext`c^2 + 2 $CellContext`a^7 $CellContext`c^3 + 
    2 $CellContext`a^6 $CellContext`b $CellContext`c^3 - 
    12 $CellContext`a^5 $CellContext`b^2 $CellContext`c^3 + 
    24 $CellContext`a^4 $CellContext`b^3 $CellContext`c^3 - 
    14 $CellContext`a^3 $CellContext`b^4 $CellContext`c^3 - 
    6 $CellContext`a^2 $CellContext`b^5 $CellContext`c^3 + 
    8 $CellContext`a $CellContext`b^6 $CellContext`c^3 - 
    4 $CellContext`b^7 $CellContext`c^3 - 8 $CellContext`a^6 $CellContext`c^4 + 
    12 $CellContext`a^5 $CellContext`b $CellContext`c^4 - 
    8 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 - 
    14 $CellContext`a^3 $CellContext`b^3 $CellContext`c^4 + 
    26 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 - 
    6 $CellContext`a $CellContext`b^5 $CellContext`c^4 - 
    2 $CellContext`b^6 $CellContext`c^4 - 
    12 $CellContext`a^4 $CellContext`b $CellContext`c^5 + 
    18 $CellContext`a^3 $CellContext`b^2 $CellContext`c^5 - 
    6 $CellContext`a^2 $CellContext`b^3 $CellContext`c^5 - 
    6 $CellContext`a $CellContext`b^4 $CellContext`c^5 + 
    6 $CellContext`b^5 $CellContext`c^5 + 8 $CellContext`a^4 $CellContext`c^6 - 
    2 $CellContext`a^3 $CellContext`b $CellContext`c^6 - 
    12 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 + 
    8 $CellContext`a $CellContext`b^3 $CellContext`c^6 - 
    2 $CellContext`b^4 $CellContext`c^6 - 2 $CellContext`a^3 $CellContext`c^7 + 
    6 $CellContext`a^2 $CellContext`b $CellContext`c^7 - 
    4 $CellContext`b^3 $CellContext`c^7 - $CellContext`a^2 $CellContext`c^8 - 
    3 $CellContext`a $CellContext`b $CellContext`c^8 + 
    3 $CellContext`b^2 $CellContext`c^8 + $CellContext`a $CellContext`c^9 + \
$CellContext`b $CellContext`c^9 - $CellContext`c^10, -$CellContext`a^10 + \
$CellContext`a^9 $CellContext`b - $CellContext`a^8 $CellContext`b^2 - 
    2 $CellContext`a^7 $CellContext`b^3 + 8 $CellContext`a^6 $CellContext`b^4 - 
    8 $CellContext`a^4 $CellContext`b^6 + 
    2 $CellContext`a^3 $CellContext`b^7 + $CellContext`a^2 $CellContext`b^8 - \
$CellContext`a $CellContext`b^9 + $CellContext`b^10 + $CellContext`a^9 \
$CellContext`c - 3 $CellContext`a^8 $CellContext`b $CellContext`c + 
    6 $CellContext`a^7 $CellContext`b^2 $CellContext`c - 
    2 $CellContext`a^6 $CellContext`b^3 $CellContext`c - 
    12 $CellContext`a^5 $CellContext`b^4 $CellContext`c + 
    12 $CellContext`a^4 $CellContext`b^5 $CellContext`c + 
    2 $CellContext`a^3 $CellContext`b^6 $CellContext`c - 
    6 $CellContext`a^2 $CellContext`b^7 $CellContext`c + 
    3 $CellContext`a $CellContext`b^8 $CellContext`c - $CellContext`b^9 \
$CellContext`c + 3 $CellContext`a^8 $CellContext`c^2 - 
    12 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 + 
    18 $CellContext`a^5 $CellContext`b^3 $CellContext`c^2 - 
    8 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 - 
    12 $CellContext`a^3 $CellContext`b^5 $CellContext`c^2 + 
    16 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 - 
    6 $CellContext`a $CellContext`b^7 $CellContext`c^2 + $CellContext`b^8 \
$CellContext`c^2 - 4 $CellContext`a^7 $CellContext`c^3 + 
    8 $CellContext`a^6 $CellContext`b $CellContext`c^3 - 
    6 $CellContext`a^5 $CellContext`b^2 $CellContext`c^3 - 
    14 $CellContext`a^4 $CellContext`b^3 $CellContext`c^3 + 
    24 $CellContext`a^3 $CellContext`b^4 $CellContext`c^3 - 
    12 $CellContext`a^2 $CellContext`b^5 $CellContext`c^3 + 
    2 $CellContext`a $CellContext`b^6 $CellContext`c^3 + 
    2 $CellContext`b^7 $CellContext`c^3 - 2 $CellContext`a^6 $CellContext`c^4 - 
    6 $CellContext`a^5 $CellContext`b $CellContext`c^4 + 
    26 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 - 
    14 $CellContext`a^3 $CellContext`b^3 $CellContext`c^4 - 
    8 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 + 
    12 $CellContext`a $CellContext`b^5 $CellContext`c^4 - 
    8 $CellContext`b^6 $CellContext`c^4 + 6 $CellContext`a^5 $CellContext`c^5 - 
    6 $CellContext`a^4 $CellContext`b $CellContext`c^5 - 
    6 $CellContext`a^3 $CellContext`b^2 $CellContext`c^5 + 
    18 $CellContext`a^2 $CellContext`b^3 $CellContext`c^5 - 
    12 $CellContext`a $CellContext`b^4 $CellContext`c^5 - 
    2 $CellContext`a^4 $CellContext`c^6 + 
    8 $CellContext`a^3 $CellContext`b $CellContext`c^6 - 
    12 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 - 
    2 $CellContext`a $CellContext`b^3 $CellContext`c^6 + 
    8 $CellContext`b^4 $CellContext`c^6 - 4 $CellContext`a^3 $CellContext`c^7 + 
    6 $CellContext`a $CellContext`b^2 $CellContext`c^7 - 
    2 $CellContext`b^3 $CellContext`c^7 + 3 $CellContext`a^2 $CellContext`c^8 - 
    3 $CellContext`a $CellContext`b $CellContext`c^8 - $CellContext`b^2 \
$CellContext`c^8 + $CellContext`a $CellContext`c^9 + $CellContext`b \
$CellContext`c^9 - $CellContext`c^10, -$CellContext`a^10 + $CellContext`a^9 \
$CellContext`b + 3 $CellContext`a^8 $CellContext`b^2 - 
    4 $CellContext`a^7 $CellContext`b^3 - 2 $CellContext`a^6 $CellContext`b^4 + 
    6 $CellContext`a^5 $CellContext`b^5 - 2 $CellContext`a^4 $CellContext`b^6 - 
    4 $CellContext`a^3 $CellContext`b^7 + 
    3 $CellContext`a^2 $CellContext`b^8 + $CellContext`a $CellContext`b^9 - \
$CellContext`b^10 + $CellContext`a^9 $CellContext`c - 
    3 $CellContext`a^8 $CellContext`b $CellContext`c + 
    8 $CellContext`a^6 $CellContext`b^3 $CellContext`c - 
    6 $CellContext`a^5 $CellContext`b^4 $CellContext`c - 
    6 $CellContext`a^4 $CellContext`b^5 $CellContext`c + 
    8 $CellContext`a^3 $CellContext`b^6 $CellContext`c - 
    3 $CellContext`a $CellContext`b^8 $CellContext`c + $CellContext`b^9 \
$CellContext`c - $CellContext`a^8 $CellContext`c^2 + 
    6 $CellContext`a^7 $CellContext`b $CellContext`c^2 - 
    12 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 - 
    6 $CellContext`a^5 $CellContext`b^3 $CellContext`c^2 + 
    26 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 - 
    6 $CellContext`a^3 $CellContext`b^5 $CellContext`c^2 - 
    12 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 + 
    6 $CellContext`a $CellContext`b^7 $CellContext`c^2 - $CellContext`b^8 \
$CellContext`c^2 - 2 $CellContext`a^7 $CellContext`c^3 - 
    2 $CellContext`a^6 $CellContext`b $CellContext`c^3 + 
    18 $CellContext`a^5 $CellContext`b^2 $CellContext`c^3 - 
    14 $CellContext`a^4 $CellContext`b^3 $CellContext`c^3 - 
    14 $CellContext`a^3 $CellContext`b^4 $CellContext`c^3 + 
    18 $CellContext`a^2 $CellContext`b^5 $CellContext`c^3 - 
    2 $CellContext`a $CellContext`b^6 $CellContext`c^3 - 
    2 $CellContext`b^7 $CellContext`c^3 + 8 $CellContext`a^6 $CellContext`c^4 - 
    12 $CellContext`a^5 $CellContext`b $CellContext`c^4 - 
    8 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 + 
    24 $CellContext`a^3 $CellContext`b^3 $CellContext`c^4 - 
    8 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 - 
    12 $CellContext`a $CellContext`b^5 $CellContext`c^4 + 
    8 $CellContext`b^6 $CellContext`c^4 + 
    12 $CellContext`a^4 $CellContext`b $CellContext`c^5 - 
    12 $CellContext`a^3 $CellContext`b^2 $CellContext`c^5 - 
    12 $CellContext`a^2 $CellContext`b^3 $CellContext`c^5 + 
    12 $CellContext`a $CellContext`b^4 $CellContext`c^5 - 
    8 $CellContext`a^4 $CellContext`c^6 + 
    2 $CellContext`a^3 $CellContext`b $CellContext`c^6 + 
    16 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 + 
    2 $CellContext`a $CellContext`b^3 $CellContext`c^6 - 
    8 $CellContext`b^4 $CellContext`c^6 + 2 $CellContext`a^3 $CellContext`c^7 - 
    6 $CellContext`a^2 $CellContext`b $CellContext`c^7 - 
    6 $CellContext`a $CellContext`b^2 $CellContext`c^7 + 
    2 $CellContext`b^3 $CellContext`c^7 + $CellContext`a^2 $CellContext`c^8 + 
    3 $CellContext`a $CellContext`b $CellContext`c^8 + $CellContext`b^2 \
$CellContext`c^8 - $CellContext`a $CellContext`c^9 - $CellContext`b \
$CellContext`c^9 + $CellContext`c^10}, "   XM/AM=", 
   Style[3, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938943675*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"75cf250d-3e25-49c1-a240-a4dd28db53fd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "152"}],
  SequenceForm["n=", 152],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938948979*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fd49f28f-2caa-447a-b6bb-4ea231bf2b26"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "152", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "8"], "-", 
      RowBox[{
       SuperscriptBox["a", "7"], " ", "b"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "3"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "5"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "7"]}], "-", 
      SuperscriptBox["b", "8"], "-", 
      RowBox[{
       SuperscriptBox["a", "7"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", "b", " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "4"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "5"], " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "6"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "7"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "5"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", "a", " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"3", " ", "a", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"3", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"3", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "7"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "7"]}], "-", 
      SuperscriptBox["c", "8"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "8"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "7"], " ", "b"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "3"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "5"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "7"]}], "+", 
      SuperscriptBox["b", "8"], "+", 
      RowBox[{
       SuperscriptBox["a", "7"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", "b", " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "4"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "5"], " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "6"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "7"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "5"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "7"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "7"]}], "-", 
      SuperscriptBox["c", "8"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "8"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "7"], " ", "b"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "5"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "7"]}], "-", 
      SuperscriptBox["b", "8"], "+", 
      RowBox[{
       SuperscriptBox["a", "7"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", "b", " ", "c"}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "4"], " ", "c"}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "5"], " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "6"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "7"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "5"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "7"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "7"]}], "+", 
      SuperscriptBox["c", "8"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox["3",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 152, 
   "   ", {$CellContext`a^8 - $CellContext`a^7 $CellContext`b + 
    2 $CellContext`a^6 $CellContext`b^2 - 5 $CellContext`a^5 $CellContext`b^3 + 
    5 $CellContext`a^3 $CellContext`b^5 - 
    2 $CellContext`a^2 $CellContext`b^6 + $CellContext`a $CellContext`b^7 - \
$CellContext`b^8 - $CellContext`a^7 $CellContext`c + $CellContext`a^6 \
$CellContext`b $CellContext`c + $CellContext`a^5 $CellContext`b^2 \
$CellContext`c - $CellContext`a^4 $CellContext`b^3 $CellContext`c + \
$CellContext`a^3 $CellContext`b^4 $CellContext`c - $CellContext`a^2 \
$CellContext`b^5 $CellContext`c - $CellContext`a $CellContext`b^6 \
$CellContext`c + $CellContext`b^7 $CellContext`c + 
    2 $CellContext`a^6 $CellContext`c^2 + $CellContext`a^5 $CellContext`b \
$CellContext`c^2 + 6 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
    6 $CellContext`a^3 $CellContext`b^3 $CellContext`c^2 - 
    2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
    3 $CellContext`a $CellContext`b^5 $CellContext`c^2 + 
    2 $CellContext`b^6 $CellContext`c^2 - 
    5 $CellContext`a^5 $CellContext`c^3 - $CellContext`a^4 $CellContext`b \
$CellContext`c^3 - 6 $CellContext`a^3 $CellContext`b^2 $CellContext`c^3 + 
    10 $CellContext`a^2 $CellContext`b^3 $CellContext`c^3 + 
    3 $CellContext`a $CellContext`b^4 $CellContext`c^3 - $CellContext`b^5 \
$CellContext`c^3 + $CellContext`a^3 $CellContext`b $CellContext`c^4 - 
    2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
    3 $CellContext`a $CellContext`b^3 $CellContext`c^4 - 
    2 $CellContext`b^4 $CellContext`c^4 + 
    5 $CellContext`a^3 $CellContext`c^5 - $CellContext`a^2 $CellContext`b \
$CellContext`c^5 - 
    3 $CellContext`a $CellContext`b^2 $CellContext`c^5 - $CellContext`b^3 \
$CellContext`c^5 - 
    2 $CellContext`a^2 $CellContext`c^6 - $CellContext`a $CellContext`b \
$CellContext`c^6 + 
    2 $CellContext`b^2 $CellContext`c^6 + $CellContext`a $CellContext`c^7 + \
$CellContext`b $CellContext`c^7 - $CellContext`c^8, -$CellContext`a^8 + \
$CellContext`a^7 $CellContext`b - 2 $CellContext`a^6 $CellContext`b^2 + 
    5 $CellContext`a^5 $CellContext`b^3 - 5 $CellContext`a^3 $CellContext`b^5 + 
    2 $CellContext`a^2 $CellContext`b^6 - $CellContext`a $CellContext`b^7 + \
$CellContext`b^8 + $CellContext`a^7 $CellContext`c - $CellContext`a^6 \
$CellContext`b $CellContext`c - $CellContext`a^5 $CellContext`b^2 \
$CellContext`c + $CellContext`a^4 $CellContext`b^3 $CellContext`c - \
$CellContext`a^3 $CellContext`b^4 $CellContext`c + $CellContext`a^2 \
$CellContext`b^5 $CellContext`c + $CellContext`a $CellContext`b^6 \
$CellContext`c - $CellContext`b^7 $CellContext`c + 
    2 $CellContext`a^6 $CellContext`c^2 - 
    3 $CellContext`a^5 $CellContext`b $CellContext`c^2 - 
    2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
    6 $CellContext`a^3 $CellContext`b^3 $CellContext`c^2 + 
    6 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + $CellContext`a \
$CellContext`b^5 $CellContext`c^2 + 
    2 $CellContext`b^6 $CellContext`c^2 - $CellContext`a^5 $CellContext`c^3 + 
    3 $CellContext`a^4 $CellContext`b $CellContext`c^3 + 
    10 $CellContext`a^3 $CellContext`b^2 $CellContext`c^3 - 
    6 $CellContext`a^2 $CellContext`b^3 $CellContext`c^3 - $CellContext`a \
$CellContext`b^4 $CellContext`c^3 - 5 $CellContext`b^5 $CellContext`c^3 - 
    2 $CellContext`a^4 $CellContext`c^4 + 
    3 $CellContext`a^3 $CellContext`b $CellContext`c^4 - 
    2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + $CellContext`a \
$CellContext`b^3 $CellContext`c^4 - $CellContext`a^3 $CellContext`c^5 - 
    3 $CellContext`a^2 $CellContext`b $CellContext`c^5 - $CellContext`a \
$CellContext`b^2 $CellContext`c^5 + 5 $CellContext`b^3 $CellContext`c^5 + 
    2 $CellContext`a^2 $CellContext`c^6 - $CellContext`a $CellContext`b \
$CellContext`c^6 - 
    2 $CellContext`b^2 $CellContext`c^6 + $CellContext`a $CellContext`c^7 + \
$CellContext`b $CellContext`c^7 - $CellContext`c^8, -$CellContext`a^8 + \
$CellContext`a^7 $CellContext`b + 
    2 $CellContext`a^6 $CellContext`b^2 - $CellContext`a^5 $CellContext`b^3 - 
    2 $CellContext`a^4 $CellContext`b^4 - $CellContext`a^3 $CellContext`b^5 + 
    2 $CellContext`a^2 $CellContext`b^6 + $CellContext`a $CellContext`b^7 - \
$CellContext`b^8 + $CellContext`a^7 $CellContext`c - $CellContext`a^6 \
$CellContext`b $CellContext`c - 
    3 $CellContext`a^5 $CellContext`b^2 $CellContext`c + 
    3 $CellContext`a^4 $CellContext`b^3 $CellContext`c + 
    3 $CellContext`a^3 $CellContext`b^4 $CellContext`c - 
    3 $CellContext`a^2 $CellContext`b^5 $CellContext`c - $CellContext`a \
$CellContext`b^6 $CellContext`c + $CellContext`b^7 $CellContext`c - 
    2 $CellContext`a^6 $CellContext`c^2 - $CellContext`a^5 $CellContext`b \
$CellContext`c^2 - 2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
    10 $CellContext`a^3 $CellContext`b^3 $CellContext`c^2 - 
    2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - $CellContext`a \
$CellContext`b^5 $CellContext`c^2 - 2 $CellContext`b^6 $CellContext`c^2 + 
    5 $CellContext`a^5 $CellContext`c^3 + $CellContext`a^4 $CellContext`b \
$CellContext`c^3 - 6 $CellContext`a^3 $CellContext`b^2 $CellContext`c^3 - 
    6 $CellContext`a^2 $CellContext`b^3 $CellContext`c^3 + $CellContext`a \
$CellContext`b^4 $CellContext`c^3 + 
    5 $CellContext`b^5 $CellContext`c^3 - $CellContext`a^3 $CellContext`b \
$CellContext`c^4 + 
    6 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - $CellContext`a \
$CellContext`b^3 $CellContext`c^4 - 
    5 $CellContext`a^3 $CellContext`c^5 + $CellContext`a^2 $CellContext`b \
$CellContext`c^5 + $CellContext`a $CellContext`b^2 $CellContext`c^5 - 
    5 $CellContext`b^3 $CellContext`c^5 + 
    2 $CellContext`a^2 $CellContext`c^6 + $CellContext`a $CellContext`b \
$CellContext`c^6 + 
    2 $CellContext`b^2 $CellContext`c^6 - $CellContext`a $CellContext`c^7 - \
$CellContext`b $CellContext`c^7 + $CellContext`c^8}, "   XM/AM=", 
   Style[3, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979389536*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"314f3435-bf8b-48ae-b907-7e206b27bc5c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "153"}],
  SequenceForm["n=", 153],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938957272*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ddd7dcf1-7318-4ed6-8a75-eb40206aafd2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "153", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "7"], "-", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", "b"}], "-", 
      RowBox[{
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "5"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "6"]}], "-", 
      SuperscriptBox["b", "7"], "-", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", "c"}], "+", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "5"], " ", "b", " ", "c"}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", "c"}], "-", 
      RowBox[{"5", " ", "a", " ", 
       SuperscriptBox["b", "5"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "6"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"10", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"5", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "6"]}], "-", 
      SuperscriptBox["c", "7"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "7"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "5"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "6"]}], "+", 
      SuperscriptBox["b", "7"], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", "c"}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "5"], " ", "b", " ", "c"}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", "c"}], "+", 
      RowBox[{"7", " ", "a", " ", 
       SuperscriptBox["b", "5"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "6"], " ", "c"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"5", " ", "a", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"5", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"5", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "6"]}], "-", 
      SuperscriptBox["c", "7"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "7"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", "b"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "5"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "6"]}], "-", 
      SuperscriptBox["b", "7"], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", "c"}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "5"], " ", "b", " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", "c"}], "-", 
      RowBox[{"5", " ", "a", " ", 
       SuperscriptBox["b", "5"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "6"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"5", " ", "a", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"10", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"5", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"7", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "6"]}], "+", 
      SuperscriptBox["c", "7"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox["3",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 153, 
   "   ", {$CellContext`a^7 - $CellContext`a^6 $CellContext`b - \
$CellContext`a^5 $CellContext`b^2 + $CellContext`a^4 $CellContext`b^3 - \
$CellContext`a^3 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^5 + \
$CellContext`a $CellContext`b^6 - $CellContext`b^7 - $CellContext`a^6 \
$CellContext`c + 7 $CellContext`a^5 $CellContext`b $CellContext`c - 
    5 $CellContext`a^4 $CellContext`b^2 $CellContext`c - 
    2 $CellContext`a^3 $CellContext`b^3 $CellContext`c + 
    5 $CellContext`a^2 $CellContext`b^4 $CellContext`c - 
    5 $CellContext`a $CellContext`b^5 $CellContext`c + $CellContext`b^6 \
$CellContext`c - $CellContext`a^5 $CellContext`c^2 - 
    5 $CellContext`a^4 $CellContext`b $CellContext`c^2 + 
    10 $CellContext`a^3 $CellContext`b^2 $CellContext`c^2 - 
    6 $CellContext`a^2 $CellContext`b^3 $CellContext`c^2 - $CellContext`a \
$CellContext`b^4 $CellContext`c^2 + 
    3 $CellContext`b^5 $CellContext`c^2 + $CellContext`a^4 $CellContext`c^3 - 
    2 $CellContext`a^3 $CellContext`b $CellContext`c^3 - 
    6 $CellContext`a^2 $CellContext`b^2 $CellContext`c^3 + 
    10 $CellContext`a $CellContext`b^3 $CellContext`c^3 - 
    3 $CellContext`b^4 $CellContext`c^3 - $CellContext`a^3 $CellContext`c^4 + 
    5 $CellContext`a^2 $CellContext`b $CellContext`c^4 - $CellContext`a \
$CellContext`b^2 $CellContext`c^4 - 
    3 $CellContext`b^3 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^5 - 
    5 $CellContext`a $CellContext`b $CellContext`c^5 + 
    3 $CellContext`b^2 $CellContext`c^5 + $CellContext`a $CellContext`c^6 + \
$CellContext`b $CellContext`c^6 - $CellContext`c^7, -$CellContext`a^7 + \
$CellContext`a^6 $CellContext`b + $CellContext`a^5 $CellContext`b^2 - \
$CellContext`a^4 $CellContext`b^3 + $CellContext`a^3 $CellContext`b^4 - \
$CellContext`a^2 $CellContext`b^5 - $CellContext`a $CellContext`b^6 + \
$CellContext`b^7 + $CellContext`a^6 $CellContext`c - 
    5 $CellContext`a^5 $CellContext`b $CellContext`c + 
    5 $CellContext`a^4 $CellContext`b^2 $CellContext`c - 
    2 $CellContext`a^3 $CellContext`b^3 $CellContext`c - 
    5 $CellContext`a^2 $CellContext`b^4 $CellContext`c + 
    7 $CellContext`a $CellContext`b^5 $CellContext`c - $CellContext`b^6 \
$CellContext`c + 
    3 $CellContext`a^5 $CellContext`c^2 - $CellContext`a^4 $CellContext`b \
$CellContext`c^2 - 6 $CellContext`a^3 $CellContext`b^2 $CellContext`c^2 + 
    10 $CellContext`a^2 $CellContext`b^3 $CellContext`c^2 - 
    5 $CellContext`a $CellContext`b^4 $CellContext`c^2 - $CellContext`b^5 \
$CellContext`c^2 - 3 $CellContext`a^4 $CellContext`c^3 + 
    10 $CellContext`a^3 $CellContext`b $CellContext`c^3 - 
    6 $CellContext`a^2 $CellContext`b^2 $CellContext`c^3 - 
    2 $CellContext`a $CellContext`b^3 $CellContext`c^3 + $CellContext`b^4 \
$CellContext`c^3 - 
    3 $CellContext`a^3 $CellContext`c^4 - $CellContext`a^2 $CellContext`b \
$CellContext`c^4 + 
    5 $CellContext`a $CellContext`b^2 $CellContext`c^4 - $CellContext`b^3 \
$CellContext`c^4 + 3 $CellContext`a^2 $CellContext`c^5 - 
    5 $CellContext`a $CellContext`b $CellContext`c^5 + $CellContext`b^2 \
$CellContext`c^5 + $CellContext`a $CellContext`c^6 + $CellContext`b \
$CellContext`c^6 - $CellContext`c^7, -$CellContext`a^7 + $CellContext`a^6 \
$CellContext`b + 3 $CellContext`a^5 $CellContext`b^2 - 
    3 $CellContext`a^4 $CellContext`b^3 - 3 $CellContext`a^3 $CellContext`b^4 + 
    3 $CellContext`a^2 $CellContext`b^5 + $CellContext`a $CellContext`b^6 - \
$CellContext`b^7 + $CellContext`a^6 $CellContext`c - 
    5 $CellContext`a^5 $CellContext`b $CellContext`c - $CellContext`a^4 \
$CellContext`b^2 $CellContext`c + 
    10 $CellContext`a^3 $CellContext`b^3 $CellContext`c - $CellContext`a^2 \
$CellContext`b^4 $CellContext`c - 
    5 $CellContext`a $CellContext`b^5 $CellContext`c + $CellContext`b^6 \
$CellContext`c + $CellContext`a^5 $CellContext`c^2 + 
    5 $CellContext`a^4 $CellContext`b $CellContext`c^2 - 
    6 $CellContext`a^3 $CellContext`b^2 $CellContext`c^2 - 
    6 $CellContext`a^2 $CellContext`b^3 $CellContext`c^2 + 
    5 $CellContext`a $CellContext`b^4 $CellContext`c^2 + $CellContext`b^5 \
$CellContext`c^2 - $CellContext`a^4 $CellContext`c^3 - 
    2 $CellContext`a^3 $CellContext`b $CellContext`c^3 + 
    10 $CellContext`a^2 $CellContext`b^2 $CellContext`c^3 - 
    2 $CellContext`a $CellContext`b^3 $CellContext`c^3 - $CellContext`b^4 \
$CellContext`c^3 + $CellContext`a^3 $CellContext`c^4 - 
    5 $CellContext`a^2 $CellContext`b $CellContext`c^4 - 
    5 $CellContext`a $CellContext`b^2 $CellContext`c^4 + $CellContext`b^3 \
$CellContext`c^4 - $CellContext`a^2 $CellContext`c^5 + 
    7 $CellContext`a $CellContext`b $CellContext`c^5 - $CellContext`b^2 \
$CellContext`c^5 - $CellContext`a $CellContext`c^6 - $CellContext`b \
$CellContext`c^6 + $CellContext`c^7}, "   XM/AM=", 
   Style[3, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938960987*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"256ca2d7-b5ca-4717-8b48-8b976c72c584"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "154"}],
  SequenceForm["n=", 154],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938964344*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a0f61774-a7d9-4a8b-a5a9-cc6d9d389bd0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "155"}],
  SequenceForm["n=", 155],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938965609*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"902dedb7-6d17-486b-9db0-27c4af1fc3af"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "156"}],
  SequenceForm["n=", 156],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979389668303`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"47355131-9a58-4976-9fcd-95b156332986"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "157"}],
  SequenceForm["n=", 157],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979389679832`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"68f0c73e-ce25-40ed-abd1-7a453eacac3a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "158"}],
  SequenceForm["n=", 158],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938969162*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"200a0f91-52e7-4a03-a6a6-39170935139b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "159"}],
  SequenceForm["n=", 159],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979389703608`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c9d59bf2-70f8-48a9-a587-53c2818c8d6f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "160"}],
  SequenceForm["n=", 160],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938971533*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2d718167-8eaa-448c-9408-af4f697002ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "160", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 160, 
   "   ", {$CellContext`a^4 ($CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2 - $CellContext`c^4), $CellContext`b^4 (-$CellContext`a^4 + \
$CellContext`a^2 $CellContext`b^2 - $CellContext`a^2 $CellContext`c^2 + \
$CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), $CellContext`c^4 \
(-$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938973404*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4fc6ec18-4ba4-4b09-a298-09b10a3793ef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "161"}],
  SequenceForm["n=", 161],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938975162*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"60f0927f-0980-4458-8010-276c6d92f440"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "162"}],
  SequenceForm["n=", 162],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938976404*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dfafd102-4f3e-4aee-975a-67fdd705bba4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "163"}],
  SequenceForm["n=", 163],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097938977693*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"18614846-c110-4a94-ac08-2b7f06bb424f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "164"}],
  SequenceForm["n=", 164],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979389788933`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"07227088-0b5a-4600-a990-d8f9e5b08675"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "164", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], "-", 
        SqrtBox[
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]], "-", 
        SqrtBox[
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], 
     ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox[
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]]}], "+", 
        SqrtBox[
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]], "-", 
        SqrtBox[
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], 
     ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox[
          RowBox[{"a", " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]]}], "-", 
        SqrtBox[
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]], "+", 
        SqrtBox[
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}]}], 
    "}"}], "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{
      SqrtBox["2"], "-", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}], 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      SqrtBox["2"], "-", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 164, 
   "   ", {$CellContext`a (($CellContext`a ($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a - $CellContext`b + $CellContext`c))^
      Rational[1, 
        2] - ($CellContext`b ($CellContext`a + $CellContext`b - \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c))^
     Rational[1, 
       2] - ($CellContext`c ($CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c))^
     Rational[1, 
       2]), $CellContext`b (-($CellContext`a ($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a - $CellContext`b + $CellContext`c))^
       Rational[
        1, 2] + ($CellContext`b ($CellContext`a + $CellContext`b - \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[1, 
        2] - ($CellContext`c ($CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c))^
     Rational[1, 
       2]), $CellContext`c (-($CellContext`a ($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a - $CellContext`b + $CellContext`c))^
       Rational[
        1, 2] - ($CellContext`b ($CellContext`a + $CellContext`b - \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c))^
     Rational[1, 
       2] + ($CellContext`c ($CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[1, 2])}, "   XM/AM=", 
   Style[(-2 + 2^Rational[1, 2] - 
      2 (2 - 2^Rational[1, 2])^Rational[1, 2])^(-1) (2^Rational[1, 2] - 
     2 (2 - 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097939018805*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a6d7747f-4fa5-40ec-aa21-7bc549931ef7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "165"}],
  SequenceForm["n=", 165],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097939021242*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9cab8fa7-76ff-4c54-a9c1-565e48153eb0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "165", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 165, 
   "   ", {$CellContext`a (3 $CellContext`a^2 - 
     2 $CellContext`a $CellContext`b - $CellContext`b^2 - 
     2 $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c - $CellContext`c^2), $CellContext`b \
(-$CellContext`a^2 - 2 $CellContext`a $CellContext`b + 3 $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c - 
     2 $CellContext`b $CellContext`c - $CellContext`c^2), $CellContext`c \
(-$CellContext`a^2 + 2 $CellContext`a $CellContext`b - $CellContext`b^2 - 
     2 $CellContext`a $CellContext`c - 2 $CellContext`b $CellContext`c + 
     3 $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 3] (1 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097939056851*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6c867f42-f39c-41cc-85d9-8a5025bff966"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "166"}],
  SequenceForm["n=", 166],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097939060294*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"49ae287b-815e-4d4d-88e5-73c65da41852"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "167"}],
  SequenceForm["n=", 167],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979398019543`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"827cd299-52d7-4b39-b350-67de707c1b68"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "168"}],
  SequenceForm["n=", 168],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940036869*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1dd35fc8-e1d9-4e2c-8789-0af4f005c6db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "169"}],
  SequenceForm["n=", 169],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940274024*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"90201050-c21a-498e-abb6-f1eb4d6dfbe0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "169", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "2"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 169, 
   "   ", {$CellContext`a ($CellContext`a^3 - $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c + $CellContext`b^2 $CellContext`c + $CellContext`a \
$CellContext`c^2 + $CellContext`b $CellContext`c^2 - $CellContext`c^3), \
$CellContext`b (-$CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c - $CellContext`b^2 $CellContext`c + $CellContext`a \
$CellContext`c^2 + $CellContext`b $CellContext`c^2 - $CellContext`c^3), \
$CellContext`c (-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c + $CellContext`b^2 $CellContext`c - $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2 + $CellContext`c^3)}, 
   "   XM/AM=", 
   Style[
    Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979402801456`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fa05db61-7fb6-41e4-b7b9-b6b5f8f1b643"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "170"}],
  SequenceForm["n=", 170],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940282207*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cbd9fc59-5040-4ed7-9d64-bb959a0ec275"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "170", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "5"]}], " ", "b"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["3", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"3", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 170, 
   "   ", {$CellContext`a ($CellContext`a^5 $CellContext`b - 
     4 $CellContext`a^4 $CellContext`b^2 + 
     6 $CellContext`a^3 $CellContext`b^3 - 
     4 $CellContext`a^2 $CellContext`b^4 + $CellContext`a $CellContext`b^5 + \
$CellContext`a^5 $CellContext`c - $CellContext`a^4 $CellContext`b \
$CellContext`c - 2 $CellContext`a^3 $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`b^3 $CellContext`c + $CellContext`a \
$CellContext`b^4 $CellContext`c - $CellContext`b^5 $CellContext`c - 
     4 $CellContext`a^4 $CellContext`c^2 - 
     2 $CellContext`a^3 $CellContext`b $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b^3 $CellContext`c^2 + 
     4 $CellContext`b^4 $CellContext`c^2 + 
     6 $CellContext`a^3 $CellContext`c^3 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c^3 - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c^3 - 
     6 $CellContext`b^3 $CellContext`c^3 - 
     4 $CellContext`a^2 $CellContext`c^4 + $CellContext`a $CellContext`b \
$CellContext`c^4 + 
     4 $CellContext`b^2 $CellContext`c^4 + $CellContext`a $CellContext`c^5 - \
$CellContext`b $CellContext`c^5), $CellContext`b ($CellContext`a^5 \
$CellContext`b - 4 $CellContext`a^4 $CellContext`b^2 + 
     6 $CellContext`a^3 $CellContext`b^3 - 
     4 $CellContext`a^2 $CellContext`b^4 + $CellContext`a $CellContext`b^5 - \
$CellContext`a^5 $CellContext`c + $CellContext`a^4 $CellContext`b \
$CellContext`c + 2 $CellContext`a^3 $CellContext`b^2 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`b^3 $CellContext`c - $CellContext`a \
$CellContext`b^4 $CellContext`c + $CellContext`b^5 $CellContext`c + 
     4 $CellContext`a^4 $CellContext`c^2 - 
     2 $CellContext`a^3 $CellContext`b $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b^3 $CellContext`c^2 - 
     4 $CellContext`b^4 $CellContext`c^2 - 
     6 $CellContext`a^3 $CellContext`c^3 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c^3 + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c^3 + 
     6 $CellContext`b^3 $CellContext`c^3 + 
     4 $CellContext`a^2 $CellContext`c^4 + $CellContext`a $CellContext`b \
$CellContext`c^4 - 
     4 $CellContext`b^2 $CellContext`c^4 - $CellContext`a $CellContext`c^5 + \
$CellContext`b $CellContext`c^5), $CellContext`c (-$CellContext`a^5 \
$CellContext`b + 4 $CellContext`a^4 $CellContext`b^2 - 
     6 $CellContext`a^3 $CellContext`b^3 + 
     4 $CellContext`a^2 $CellContext`b^4 - $CellContext`a $CellContext`b^5 + \
$CellContext`a^5 $CellContext`c + $CellContext`a^4 $CellContext`b \
$CellContext`c - 2 $CellContext`a^3 $CellContext`b^2 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`b^3 $CellContext`c + $CellContext`a \
$CellContext`b^4 $CellContext`c + $CellContext`b^5 $CellContext`c - 
     4 $CellContext`a^4 $CellContext`c^2 + 
     2 $CellContext`a^3 $CellContext`b $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b^3 $CellContext`c^2 - 
     4 $CellContext`b^4 $CellContext`c^2 + 
     6 $CellContext`a^3 $CellContext`c^3 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c^3 - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c^3 + 
     6 $CellContext`b^3 $CellContext`c^3 - 
     4 $CellContext`a^2 $CellContext`c^4 - $CellContext`a $CellContext`b \
$CellContext`c^4 - 
     4 $CellContext`b^2 $CellContext`c^4 + $CellContext`a $CellContext`c^5 + \
$CellContext`b $CellContext`c^5)}, "   XM/AM=", 
   Style[Rational[3, 17] (1 - 3 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940316308*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4977d45a-29bf-4042-a56a-e97b13cbcc23"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "171"}],
  SequenceForm["n=", 171],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794031949*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"af5c0fd3-995e-41c8-bb33-89cf8d49214d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "171", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["3", "23"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "5"}], "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 171, 
   "   ", {$CellContext`a ($CellContext`a^2 + $CellContext`b $CellContext`c), \
$CellContext`b ($CellContext`b^2 + $CellContext`a $CellContext`c), \
$CellContext`c ($CellContext`a $CellContext`b + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[Rational[-3, 23] (-5 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940320912*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5c41e648-ecf0-470d-b93f-8406b1fbafce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "172"}],
  SequenceForm["n=", 172],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979403224287`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cee09fb9-d82c-44c3-bd18-6430a1828b51"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "172", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", 
     RowBox[{"4", "+", 
      SqrtBox["2"]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 172, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 + $CellContext`b \
$CellContext`c), $CellContext`b^2 ($CellContext`b^2 + $CellContext`a \
$CellContext`c), $CellContext`c^2 ($CellContext`a $CellContext`b + \
$CellContext`c^2)}, "   XM/AM=", 
   Style[3/(4 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940323832*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f0b44a56-3f8d-494c-a900-b68916369396"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "173"}],
  SequenceForm["n=", 173],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979403252497`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"01ea50aa-bd82-4803-b533-7b263a2e928f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "173", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]]}], "-", 
        SqrtBox[
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], "+", 
        SqrtBox[
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], 
     ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]]}], "+", 
        SqrtBox[
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], "-", 
        SqrtBox[
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], 
     ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]], "-", 
        SqrtBox[
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], "-", 
        SqrtBox[
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}]}], 
    "}"}], "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox[
         RowBox[{"2", "-", 
          SqrtBox["2"]}]]}], ")"}]}], 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SqrtBox["2"]}], "+", 
      SqrtBox[
       RowBox[{"4", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}]], "-", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 173, 
   "   ", {$CellContext`a (-(($CellContext`a + $CellContext`b - \
$CellContext`c) $CellContext`c)^
       Rational[
        1, 2] - ($CellContext`b ($CellContext`a - $CellContext`b + \
$CellContext`c))^
     Rational[1, 
       2] + ($CellContext`a (-$CellContext`a + $CellContext`b + \
$CellContext`c))^
      Rational[1, 
        2]), $CellContext`b (-(($CellContext`a + $CellContext`b - \
$CellContext`c) $CellContext`c)^
       Rational[
        1, 2] + ($CellContext`b ($CellContext`a - $CellContext`b + \
$CellContext`c))^
      Rational[1, 
        2] - ($CellContext`a (-$CellContext`a + $CellContext`b + \
$CellContext`c))^
     Rational[1, 
       2]), $CellContext`c ((($CellContext`a + $CellContext`b - \
$CellContext`c) $CellContext`c)^
      Rational[1, 
        2] - ($CellContext`b ($CellContext`a - $CellContext`b + \
$CellContext`c))^
     Rational[1, 
       2] - ($CellContext`a (-$CellContext`a + $CellContext`b + \
$CellContext`c))^Rational[1, 2])}, "   XM/AM=", 
   Style[2^
     Rational[1, 2] ((-2) 2^Rational[1, 2] + (4 - 2 2^Rational[1, 2])^
       Rational[1, 2] - 
      2 (2 - 2^Rational[1, 2])^Rational[1, 2])^(-1) (-2 + (2 - 2^
       Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940425427*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"80fb240a-af66-4566-84eb-5a628c309213"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "174"}],
  SequenceForm["n=", 174],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940428281*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"df0667bc-5351-49d3-9082-cf135ada2eae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "174", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], ",", 
     SqrtBox[
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]], ",", 
     SqrtBox[
      RowBox[{"c", " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SqrtBox["2"], 
     RowBox[{
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 174, 
   "   ", {($CellContext`a ($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c))^
    Rational[1, 
      2], ($CellContext`b ($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
    Rational[1, 
      2], ($CellContext`c ($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^Rational[1, 2]}, 
   "   XM/AM=", 
   Style[2^Rational[1, 2]/(2^Rational[1, 2] + 
    2 (2 - 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940461577*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e94cfece-55d0-47fa-b64e-1b885e1eae9e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "175"}],
  SequenceForm["n=", 175],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940463883*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"71295953-e0b4-4cbb-941b-524207e90501"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "176"}],
  SequenceForm["n=", 176],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940513369*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2372d605-3e1b-4845-879b-ea0ded575733"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "177"}],
  SequenceForm["n=", 177],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979405514708`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ec6c7c64-ca92-4f84-ae9c-1900dbd3bb0a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "177", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]], "+", 
        SqrtBox[
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]]}], ")"}]}], ",", 
     RowBox[{
      SqrtBox[
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]], "+", 
        SqrtBox[
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], 
     ",", 
     RowBox[{
      SqrtBox[
       RowBox[{"c", " ", 
        RowBox[{"(", 
         RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], "+", 
        SqrtBox[
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}]}], 
    "}"}], "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SqrtBox["2"], 
     RowBox[{"2", "+", 
      SqrtBox[
       RowBox[{"2", "-", 
        SqrtBox["2"]}]]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 177, 
   "   ", {($CellContext`a ($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c))^
     Rational[1, 
       2] ((($CellContext`a + $CellContext`b - $CellContext`c) \
$CellContext`c)^
      Rational[1, 
        2] + ($CellContext`b ($CellContext`a - $CellContext`b + \
$CellContext`c))^
      Rational[1, 
        2]), ($CellContext`b ($CellContext`a + $CellContext`b - \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c))^
     Rational[1, 
       2] ((($CellContext`a + $CellContext`b - $CellContext`c) \
$CellContext`c)^
      Rational[1, 
        2] + ($CellContext`a (-$CellContext`a + $CellContext`b + \
$CellContext`c))^
      Rational[1, 
        2]), ($CellContext`c ($CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c))^
     Rational[1, 
       2] (($CellContext`b ($CellContext`a - $CellContext`b + \
$CellContext`c))^
      Rational[1, 
        2] + ($CellContext`a (-$CellContext`a + $CellContext`b + \
$CellContext`c))^Rational[1, 2])}, "   XM/AM=", 
   Style[2^Rational[1, 2]/(2 + (2 - 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940609641*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"812e6988-b0b2-422c-b883-1d6eca0a2a7b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "178"}],
  SequenceForm["n=", 178],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979406117897`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5c5dec5a-0723-48ad-a6ec-b3f66abc77a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "178", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]], "+", 
      SqrtBox[
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]]}], ",", 
     RowBox[{
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]], "+", 
      SqrtBox[
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ",", 
     RowBox[{
      SqrtBox[
       RowBox[{"b", " ", 
        RowBox[{"(", 
         RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], "+", 
      SqrtBox[
       RowBox[{"a", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"2", "+", 
      SqrtBox[
       RowBox[{"2", "-", 
        SqrtBox["2"]}]]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 178, 
   "   ", {(($CellContext`a + $CellContext`b - $CellContext`c) \
$CellContext`c)^
     Rational[1, 
       2] + ($CellContext`b ($CellContext`a - $CellContext`b + \
$CellContext`c))^
     Rational[1, 
       2], (($CellContext`a + $CellContext`b - $CellContext`c) \
$CellContext`c)^
     Rational[1, 
       2] + ($CellContext`a (-$CellContext`a + $CellContext`b + \
$CellContext`c))^
     Rational[1, 
       2], ($CellContext`b ($CellContext`a - $CellContext`b + \
$CellContext`c))^
     Rational[
      1, 2] + ($CellContext`a (-$CellContext`a + $CellContext`b + \
$CellContext`c))^Rational[1, 2]}, "   XM/AM=", 
   Style[(2 + (2 - 2^Rational[1, 2])^Rational[1, 2])^(-1), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940650569*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"91430612-ff35-4163-bd16-6d6bd5bd6a54"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "179"}],
  SequenceForm["n=", 179],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097940653373*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c2ff204b-5b0b-43d4-9720-0ba627e21482"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "180"}],
  SequenceForm["n=", 180],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794076818*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5cdb1669-b7e7-4bed-9e64-513e28601448"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "181"}],
  SequenceForm["n=", 181],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979445456*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"148a63ab-b960-4abe-a114-9470e75ab7d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "181", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["4", "23"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "5"}], "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 181, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a - $CellContext`b + $CellContext`c) \
($CellContext`b + $CellContext`c)^2, $CellContext`b^2 ($CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a + $CellContext`c)^2 \
(-$CellContext`a + $CellContext`b + $CellContext`c), ($CellContext`a + \
$CellContext`b)^2 $CellContext`c^2 ($CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c)}, 
   "   XM/AM=", 
   Style[Rational[-4, 23] (-5 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944582966*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b0cb241a-07c4-4782-92fa-d42715d80afb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "182"}],
  SequenceForm["n=", 182],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944585032*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3f1d9762-9372-46af-869c-03e4f4c5f9a5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "182", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "4"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 182, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - $CellContext`a^2 \
$CellContext`b^2 - $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2), $CellContext`b^2 \
(-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2), $CellContext`c^2 ((-2) $CellContext`a^2 $CellContext`b^2 - \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[1, 4], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979445867*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4c7a7ae5-aab7-4682-a4c4-82920c2ea40f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "183"}],
  SequenceForm["n=", 183],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944588407*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2986f96e-d608-476d-bcd4-f752869dcbf6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "183", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "7"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 183, 
   "   ", {$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2, -$CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2, \
(-2) $CellContext`a^2 $CellContext`b^2 - $CellContext`a^2 $CellContext`c^2 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[1, 7], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944590026*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"860e2360-9874-467e-a00f-503bf189ea40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "184"}],
  SequenceForm["n=", 184],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944592272*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"88aec533-fc51-4189-95e0-b6bc4323d2ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "185"}],
  SequenceForm["n=", 185],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944593639*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"eb701827-2be2-4229-a9a9-134b2e6db3f2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "186"}],
  SequenceForm["n=", 186],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979445950317`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"97c56e2d-780b-420d-9343-9fa62fa8fc1c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "187"}],
  SequenceForm["n=", 187],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944596586*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b501c19a-8759-472d-8f30-c298ef55df93"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "187", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox["2",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 187, 
   "   ", {$CellContext`a^2 (
     2 $CellContext`a^2 - $CellContext`b^2 - $CellContext`c^2), \
$CellContext`b^2 (-$CellContext`a^2 + 
     2 $CellContext`b^2 - $CellContext`c^2), $CellContext`c^2 \
(-$CellContext`a^2 - $CellContext`b^2 + 2 $CellContext`c^2)}, "   XM/AM=", 
   Style[2, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944598724*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"15eb4da7-d256-4bec-bb72-6ac4fb2a01bb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "188"}],
  SequenceForm["n=", 188],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944600472*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7baea0b9-ca05-494d-896c-678347a72da2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "188", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{"a", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]], ",", 
     SqrtBox[
      RowBox[{"b", " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], ",", 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SqrtBox[
      RowBox[{"2", "-", 
       SqrtBox["2"]}]], 
     RowBox[{"2", "+", 
      SqrtBox[
       RowBox[{"2", "-", 
        SqrtBox["2"]}]]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 188, 
   "   ", {($CellContext`a (-$CellContext`a + $CellContext`b + \
$CellContext`c))^
    Rational[1, 
      2], ($CellContext`b ($CellContext`a - $CellContext`b + $CellContext`c))^
    Rational[1, 
      2], (($CellContext`a + $CellContext`b - $CellContext`c) $CellContext`c)^
    Rational[1, 2]}, "   XM/AM=", 
   Style[(2 - 2^Rational[1, 2])^Rational[1, 2]/(
    2 + (2 - 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944605576*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5b67ac84-c7d6-4cc5-9562-db2b6b29bd1a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "189"}],
  SequenceForm["n=", 189],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944607707*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8b7ab2f2-4db8-471a-aa16-4012b201e275"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "189", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"3", "+", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 189, 
   "   ", {($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) (-$CellContext`a^3 - $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), (-$CellContext`a^3 - $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[3 + 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944642399*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dff85a27-2999-429e-9043-9b028f2d93e2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "190"}],
  SequenceForm["n=", 190],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944645692*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ca5aab45-13e0-407d-a696-7d9dadf327ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "191"}],
  SequenceForm["n=", 191],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944647588*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f587e2b4-806d-4537-9fef-b60c947cc634"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "191", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "-", 
       RowBox[{"3", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 191, 
   "   ", {$CellContext`a ($CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c - \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2 - $CellContext`c^3), $CellContext`b \
(-$CellContext`a^3 - $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 $CellContext`c - \
$CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), $CellContext`c (-$CellContext`a^3 - \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 - \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c - $CellContext`b^2 $CellContext`c + \
$CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2 + \
$CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 7] (5 - 3 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944650415*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"41a952b4-2cc6-4e3e-9a55-587aefafef02"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "192"}],
  SequenceForm["n=", 192],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944653449*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a92589d3-547b-448a-82c9-b569fb726219"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "192", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "b"}], "-", 
      RowBox[{"a", " ", "c"}], "+", 
      RowBox[{"b", " ", "c"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "b"}], "+", 
      RowBox[{"a", " ", "c"}], "-", 
      RowBox[{"b", " ", "c"}]}], ",", 
     RowBox[{
      RowBox[{"a", " ", "b"}], "-", 
      RowBox[{"a", " ", "c"}], "-", 
      RowBox[{"b", " ", "c"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"9", "-", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 192, 
   "   ", {-$CellContext`a $CellContext`b - $CellContext`a $CellContext`c + \
$CellContext`b $CellContext`c, -$CellContext`a $CellContext`b + \
$CellContext`a $CellContext`c - $CellContext`b $CellContext`c, $CellContext`a \
$CellContext`b - $CellContext`a $CellContext`c - $CellContext`b \
$CellContext`c}, "   XM/AM=", 
   Style[Rational[1, 7] (9 - 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944655594*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ca3ceca8-025e-4a3a-b6ac-035488ec8b7e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "193"}],
  SequenceForm["n=", 193],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944658038*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5c665a55-4376-4ce1-afa5-5be1ad5c213b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "194"}],
  SequenceForm["n=", 194],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944659787*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"18b939a3-0014-4844-886c-b50903b5e6fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "194", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "5"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 194, 
   "   ", {-$CellContext`a^2 $CellContext`b^2 - $CellContext`a^2 \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^2, -$CellContext`a^2 \
$CellContext`b^2 + $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2, $CellContext`a^2 $CellContext`b^2 - $CellContext`a^2 \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2}, "   XM/AM=", 
   Style[
    Rational[3, 5], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944662056*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"de57ef61-20e7-416e-b6b9-fcd30ed6bf30"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "195"}],
  SequenceForm["n=", 195],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979446643467`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8cf908a9-e0a5-483f-956a-cf6baed49eb9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "195", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 195, 
   "   ", {$CellContext`a^2 ($CellContext`a^8 - 
     4 $CellContext`a^6 $CellContext`b^2 + 
     6 $CellContext`a^4 $CellContext`b^4 - 
     4 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 - 
     4 $CellContext`a^6 $CellContext`c^2 + 
     5 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + $CellContext`a^2 \
$CellContext`b^4 $CellContext`c^2 - 2 $CellContext`b^6 $CellContext`c^2 + 
     6 $CellContext`a^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^4 + 2 $CellContext`b^4 $CellContext`c^4 - 
     4 $CellContext`a^2 $CellContext`c^6 - 
     2 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8), \
$CellContext`b^2 ($CellContext`a^8 - 4 $CellContext`a^6 $CellContext`b^2 + 
     6 $CellContext`a^4 $CellContext`b^4 - 
     4 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 - 
     2 $CellContext`a^6 $CellContext`c^2 + $CellContext`a^4 $CellContext`b^2 \
$CellContext`c^2 + 5 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
     4 $CellContext`b^6 $CellContext`c^2 + 
     2 $CellContext`a^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^4 + 6 $CellContext`b^4 $CellContext`c^4 - 
     2 $CellContext`a^2 $CellContext`c^6 - 
     4 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8), \
$CellContext`c^2 ($CellContext`a^8 - 2 $CellContext`a^6 $CellContext`b^2 + 
     2 $CellContext`a^4 $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 - 
     4 $CellContext`a^6 $CellContext`c^2 + $CellContext`a^4 $CellContext`b^2 \
$CellContext`c^2 + $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
     4 $CellContext`b^6 $CellContext`c^2 + 
     6 $CellContext`a^4 $CellContext`c^4 + 
     5 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     6 $CellContext`b^4 $CellContext`c^4 - 
     4 $CellContext`a^2 $CellContext`c^6 - 
     4 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8)}, "   XM/AM=", 
   Style[
    Rational[2, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944667605*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"db7e6bf9-2822-4855-bb8e-1f50a34e2a81"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "196"}],
  SequenceForm["n=", 196],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944670106*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"49db7a6b-1659-412a-b6d9-f9ac4a512d8d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "197"}],
  SequenceForm["n=", 197],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979446714478`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3f06f4e4-006a-4f2b-9b4a-8ca93454da27"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "197", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 197, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), \
$CellContext`b^2 (-$CellContext`a^4 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`c^4), \
$CellContext`c^2 (-$CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`c^4)}, 
   "   XM/AM=", 
   Style[-2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979446732273`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"eb544c6e-540d-42be-b9af-5d3ca5d969e2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "198"}],
  SequenceForm["n=", 198],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794467492*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c86e9c45-6c72-4b4c-a65b-18e6e44e82d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "198", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 198, 
   "   ", {$CellContext`a^2 ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), $CellContext`b^2 (-$CellContext`a^3 - \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), $CellContext`c^2 (-$CellContext`a^3 + \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 - \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[-2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944684856*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"717be07b-a86d-4edb-9749-cc3384771b76"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "199"}],
  SequenceForm["n=", 199],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944687193*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7213a0e0-517b-40df-b20c-b9ff9a164959"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "199", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "2"], "-", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 199, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 + $CellContext`a^3 \
$CellContext`b - $CellContext`a $CellContext`b^3 - $CellContext`b^4 + \
$CellContext`a^3 $CellContext`c + $CellContext`a^2 $CellContext`b \
$CellContext`c - $CellContext`a $CellContext`b^2 $CellContext`c - \
$CellContext`b^3 $CellContext`c - $CellContext`a $CellContext`b \
$CellContext`c^2 - $CellContext`a $CellContext`c^3 - $CellContext`b \
$CellContext`c^3 - $CellContext`c^4), $CellContext`b^2 (-$CellContext`a^4 - \
$CellContext`a^3 $CellContext`b + $CellContext`a $CellContext`b^3 + \
$CellContext`b^4 - $CellContext`a^3 $CellContext`c - $CellContext`a^2 \
$CellContext`b $CellContext`c + $CellContext`a $CellContext`b^2 \
$CellContext`c + $CellContext`b^3 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c^2 - $CellContext`a $CellContext`c^3 - \
$CellContext`b $CellContext`c^3 - $CellContext`c^4), $CellContext`c^2 \
(-$CellContext`a^4 - $CellContext`a^3 $CellContext`b - $CellContext`a \
$CellContext`b^3 - $CellContext`b^4 - $CellContext`a^3 $CellContext`c - \
$CellContext`a^2 $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`b^2 $CellContext`c - $CellContext`b^3 $CellContext`c + \
$CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`a \
$CellContext`c^3 + $CellContext`b $CellContext`c^3 + $CellContext`c^4)}, 
   "   XM/AM=", 
   Style[Rational[1, 2] - 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794472125*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"661ee9e7-fd17-479d-b522-757c8b87ee9f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "200"}],
  SequenceForm["n=", 200],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944723567*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e2f79e39-9b0f-4608-b11b-af09a08e708f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "200", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "-", 
       RowBox[{"3", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 200, 
   "   ", {$CellContext`a ($CellContext`a - $CellContext`b - \
$CellContext`c)^2, $CellContext`b (-$CellContext`a + $CellContext`b - \
$CellContext`c)^2, $CellContext`c (-$CellContext`a - $CellContext`b + \
$CellContext`c)^2}, "   XM/AM=", 
   Style[Rational[1, 7] (5 - 3 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794472503*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"01b82fdc-cec2-4575-9e93-d55e3e5c576c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "201"}],
  SequenceForm["n=", 201],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944726592*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3b037879-b114-4e14-97f4-cbe0cce8cf4a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "202"}],
  SequenceForm["n=", 202],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944728002*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"222e7fd0-5d80-4d83-8394-d106dd81c492"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "203"}],
  SequenceForm["n=", 203],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944868783*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7319168e-fffb-4880-b9aa-5ab3823f4c78"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "204"}],
  SequenceForm["n=", 204],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097944980424*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0eb6e242-fab6-4221-a701-fd06a4a8512e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "205"}],
  SequenceForm["n=", 205],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979449857407`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4e23acf7-3ae9-4f0a-8f4e-8ef833f95787"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "205", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 205, 
   "   ", {$CellContext`a^3 ($CellContext`a^4 - $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), \
$CellContext`b^3 (-$CellContext`a^4 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`c^4), \
$CellContext`c^3 (-$CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`c^4)}, 
   "   XM/AM=", 
   Style[(-2) (1 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979450216417`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d3f0e582-11ca-437a-a9e1-d0c51624d015"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "206"}],
  SequenceForm["n=", 206],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945023816*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"755d36ba-bacc-4767-b797-e1f222c49def"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "207"}],
  SequenceForm["n=", 207],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945025078*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"694b7461-e978-47da-8c7c-869ab5b8f8ff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "208"}],
  SequenceForm["n=", 208],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945026312*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c07d6efc-de23-4eb1-8d62-994d6b23ec05"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "209"}],
  SequenceForm["n=", 209],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945027906*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f11fc1ab-e69e-4bb9-ae8a-49b5c5a8d9ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "210"}],
  SequenceForm["n=", 210],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979450293207`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"844ea55d-9da9-475d-a8b9-2f01756c2f14"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "210", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 210, 
   "   ", {$CellContext`a ($CellContext`a - $CellContext`b - $CellContext`c) \
($CellContext`b + $CellContext`c), $CellContext`b (-$CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a + $CellContext`c), \
($CellContext`a + $CellContext`b) $CellContext`c (-$CellContext`a - \
$CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 3] (2 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945031283*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a716f608-0b32-4010-874f-68182d44666e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "211"}],
  SequenceForm["n=", 211],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945032989*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a8ae8276-dcb3-4a27-942f-ef25784401c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "212"}],
  SequenceForm["n=", 212],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979450348673`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cc534cd7-44b3-445c-832b-8b6402dde8a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "213"}],
  SequenceForm["n=", 213],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945036577*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e56ce8c6-8ca9-4e36-af04-6055250e8cdc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "213", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      SuperscriptBox["c", "3"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", "17"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "6"}], "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 213, 
   "   ", {$CellContext`a^3 ($CellContext`b + $CellContext`c), \
$CellContext`b^3 ($CellContext`a + $CellContext`c), ($CellContext`a + \
$CellContext`b) $CellContext`c^3}, "   XM/AM=", 
   Style[Rational[-2, 17] (-6 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979450699778`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"44952c49-5b94-4d32-9588-9b0fd11ba8a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "214"}],
  SequenceForm["n=", 214],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979450720663`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"92cd81cf-7e14-478a-90ee-2d85a1e47508"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "214", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a"}], "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", 
        RowBox[{"2", " ", "b"}], "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", 
        RowBox[{"2", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     SqrtBox["2"]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 214, 
   "   ", {$CellContext`a (
     2 $CellContext`a - $CellContext`b - $CellContext`c) ($CellContext`a^2 - \
$CellContext`b^2 + $CellContext`b $CellContext`c - $CellContext`c^2), \
$CellContext`b (-$CellContext`a + 
     2 $CellContext`b - $CellContext`c) (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`a $CellContext`c - $CellContext`c^2), $CellContext`c \
(-$CellContext`a - $CellContext`b + 
     2 $CellContext`c) (-$CellContext`a^2 + $CellContext`a $CellContext`b - \
$CellContext`b^2 + $CellContext`c^2)}, "   XM/AM=", 
   Style[2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979450739326`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"44056a51-e697-40b6-9972-6fac7f4b834d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "215"}],
  SequenceForm["n=", 215],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979450758123`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3eef0a47-2c85-4d18-a242-37feefd5e322"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "215", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "-", 
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"b", " ", "c"}], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox["b", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], "+", 
         SuperscriptBox["b", "2"], "+", 
         RowBox[{"a", " ", "c"}], "-", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox["c", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], "+", 
         RowBox[{"a", " ", "b"}], "-", 
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"]}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     SqrtBox["2"]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 215, 
   "   ", {$CellContext`a^4 ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`a^2 - $CellContext`b^2 + $CellContext`b \
$CellContext`c - $CellContext`c^2)^2, $CellContext`b^4 (-$CellContext`a + \
$CellContext`b - $CellContext`c) (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`a $CellContext`c - $CellContext`c^2)^2, $CellContext`c^4 \
(-$CellContext`a - $CellContext`b + $CellContext`c) (-$CellContext`a^2 + \
$CellContext`a $CellContext`b - $CellContext`b^2 + $CellContext`c^2)^2}, 
   "   XM/AM=", 
   Style[2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945077723*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"55512347-bfa3-476c-8d95-26d449a90317"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "216"}],
  SequenceForm["n=", 216],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945080068*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f6d1163a-0c56-4d20-9522-e0802154f088"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "217"}],
  SequenceForm["n=", 217],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794508158*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"beeca184-8582-41ff-b04f-7077866e9b7b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "218"}],
  SequenceForm["n=", 218],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945082963*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"be11cb74-2c4f-4f36-ba89-62be638b1f25"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "218", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 218, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 - 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 - 
     2 $CellContext`a $CellContext`c + $CellContext`c^2), $CellContext`b^2 \
($CellContext`a^2 - 2 $CellContext`a $CellContext`b + $CellContext`b^2 - 
     2 $CellContext`b $CellContext`c + $CellContext`c^2), $CellContext`c^2 \
($CellContext`a^2 + $CellContext`b^2 - 2 $CellContext`a $CellContext`c - 
     2 $CellContext`b $CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[
    Rational[2, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794508469*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"10ddc38d-7e79-4b9e-997f-1bf52a80f2ae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "219"}],
  SequenceForm["n=", 219],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979450866833`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1b17d887-2610-4aa7-ab1e-f143110c490a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "220"}],
  SequenceForm["n=", 220],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979450882072`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9074ca5c-2a73-439d-b60d-afe30e8561bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "220", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 220, 
   "   ", {$CellContext`a^2 ($CellContext`a - $CellContext`b - \
$CellContext`c)^2, $CellContext`b^2 (-$CellContext`a + $CellContext`b - \
$CellContext`c)^2, $CellContext`c^2 (-$CellContext`a - $CellContext`b + \
$CellContext`c)^2}, "   XM/AM=", 
   Style[Rational[1, 4] (2 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945093173*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4d165aa5-b4cb-4820-b080-391d61d149dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "221"}],
  SequenceForm["n=", 221],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945095583*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a9f06b5d-ae24-4b1a-8ae6-78368c3fd98f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "222"}],
  SequenceForm["n=", 222],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945097031*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8ac18be1-b88b-4433-be06-49eec5880a83"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "223"}],
  SequenceForm["n=", 223],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945098516*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"009918e2-471c-47dd-8d0f-f56c3583369d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "223", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 223, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c) ($CellContext`a^3 + \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 - \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), $CellContext`b ($CellContext`a + \
$CellContext`b - $CellContext`c) (-$CellContext`a + $CellContext`b + \
$CellContext`c) (-$CellContext`a^3 - $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), $CellContext`c ($CellContext`a - \
$CellContext`b + $CellContext`c) (-$CellContext`a + $CellContext`b + \
$CellContext`c) (-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[-1 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979451322803`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dbae63dc-2250-43fd-9934-c7ef2008bf34"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "224"}],
  SequenceForm["n=", 224],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979451347237`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"93a18f8a-cb58-418b-8e66-56f4ece14e1e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "224", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     SqrtBox["2"]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 224, 
   "   ", {$CellContext`a ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`c^2) ($CellContext`a^4 - 2 $CellContext`a^3 $CellContext`b + 
     2 $CellContext`a $CellContext`b^3 - $CellContext`b^4 - 
     2 $CellContext`a^3 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`c^3 - $CellContext`c^4), $CellContext`b \
(-$CellContext`a^2 + $CellContext`b^2 - $CellContext`c^2) (-$CellContext`a^4 + 
     2 $CellContext`a^3 $CellContext`b - 
     2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`b^3 $CellContext`c + 2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b $CellContext`c^3 - $CellContext`c^4), $CellContext`c \
(-$CellContext`a^2 - $CellContext`b^2 + $CellContext`c^2) (-$CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + 
     2 $CellContext`a^3 $CellContext`c + 2 $CellContext`b^3 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`a $CellContext`c^3 - 
     2 $CellContext`b $CellContext`c^3 + $CellContext`c^4)}, "   XM/AM=", 
   Style[2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945136677*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"286a0e0a-b278-480a-801f-84b7a7f590b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "225"}],
  SequenceForm["n=", 225],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945138502*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a308199b-53cc-456f-a803-9040297a444d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "226"}],
  SequenceForm["n=", 226],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945139876*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"06fab6f5-148a-4de5-8fb0-7c3d390dd82e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "226", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "2"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 226, 
   "   ", {($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a - \
$CellContext`b + $CellContext`c) ($CellContext`b + $CellContext`c), \
($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c), \
($CellContext`a + $CellContext`b) ($CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c)}, 
   "   XM/AM=", 
   Style[
    Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945141386*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f74ead31-ccb4-411b-a828-7c4fab0367d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "227"}],
  SequenceForm["n=", 227],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979451428223`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bb453a80-51ac-4744-9706-38efbc6514ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "227", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 227, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c) ($CellContext`b + \
$CellContext`c) ($CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), $CellContext`b ($CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c) (-$CellContext`a^3 - \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), ($CellContext`a + $CellContext`b) \
$CellContext`c ($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c) (-$CellContext`a^3 + \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 - \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[-2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945145185*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5b72f46f-47f4-4b45-a423-8f60eb6176c2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "228"}],
  SequenceForm["n=", 228],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945147436*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"80171790-57bd-41f6-85cf-8219cc7fdd13"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "229"}],
  SequenceForm["n=", 229],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945148982*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"31e04e2d-7846-4a00-830e-9afc2cdf1a9b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "229", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 229, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c) ($CellContext`a^4 - $CellContext`b^4 + $CellContext`a^2 \
$CellContext`b $CellContext`c + $CellContext`a $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`b $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), $CellContext`b \
($CellContext`a + $CellContext`b) ($CellContext`b + $CellContext`c) \
(-$CellContext`a^4 + $CellContext`b^4 + $CellContext`a^2 $CellContext`b \
$CellContext`c + $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 - $CellContext`c^4), $CellContext`c ($CellContext`a + \
$CellContext`c) ($CellContext`b + $CellContext`c) (-$CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
$CellContext`a^2 $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`b^2 $CellContext`c + $CellContext`a $CellContext`b \
$CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[Rational[1, 3] (-1 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945151129*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1ee9c17e-52d3-44b7-80db-64a5e5935736"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "230"}],
  SequenceForm["n=", 230],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945153021*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5de85d77-2706-44cc-9d97-a96e2238820d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "231"}],
  SequenceForm["n=", 231],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945154442*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b69c6c7e-7dc7-414b-9870-317582db5a56"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "232"}],
  SequenceForm["n=", 232],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945155959*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5e3e6695-53fc-48d4-81c4-37c6e5cd2b8f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "233"}],
  SequenceForm["n=", 233],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945157248*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ea9ff7c2-3b27-4fa2-9deb-894225b63ff1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "233", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", "5"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 233, 
   "   ", {($CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4) (
     2 $CellContext`a^4 - 
     3 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
(-$CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - \
$CellContext`c^4) ($CellContext`a^4 - 3 $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`b^4 - 2 $CellContext`a^2 $CellContext`c^2 - 
     3 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
(-$CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2) \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`c^2 - 
     3 $CellContext`b^2 $CellContext`c^2 + 2 $CellContext`c^4)}, "   XM/AM=", 
   
   Style[
    Rational[2, 5], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945159329*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"11cb14ab-ed56-4326-a47d-02d51b708b05"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "234"}],
  SequenceForm["n=", 234],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945161337*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7b60b894-0f1f-43d3-ac70-f28c0728c537"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "235"}],
  SequenceForm["n=", 235],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794522229*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b78faaa7-5445-4343-a298-6626c0e28431"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "236"}],
  SequenceForm["n=", 236],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945228849*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e1ee56ee-9412-4070-8699-529896240b42"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "237"}],
  SequenceForm["n=", 237],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945304894*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4408f436-8867-4657-88a6-ad049deb9af7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "237", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox["2",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 237, 
   "   ", {$CellContext`a^4 ($CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 - $CellContext`c^4), \
$CellContext`b^4 (-$CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), $CellContext`c^4 \
(-$CellContext`a^4 - $CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + \
$CellContext`b^2 $CellContext`c^2)}, "   XM/AM=", 
   Style[2, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945307414*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c5a6cb11-aa2f-4868-a722-766c45b2b55a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "238"}],
  SequenceForm["n=", 238],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979453092337`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"51382ead-a4d6-49dd-b554-7c9e6f2bc53a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "238", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 238, 
   "   ", {$CellContext`a ($CellContext`a^2 - $CellContext`b $CellContext`c), \
$CellContext`b ($CellContext`b^2 - $CellContext`a $CellContext`c), \
$CellContext`c (-$CellContext`a $CellContext`b + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[1 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945314294*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a0837c02-21b7-4ea7-adb0-f3ba72d441ce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "239"}],
  SequenceForm["n=", 239],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979453162947`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"12d22f2c-3485-41d3-a153-043e2e3f5619"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "239", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"b", " ", "c"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"a", " ", "c"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "a"}], " ", "b"}], "+", 
      SuperscriptBox["c", "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"3", "+", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 239, 
   "   ", {$CellContext`a^2 - $CellContext`b $CellContext`c, $CellContext`b^2 - \
$CellContext`a $CellContext`c, -$CellContext`a $CellContext`b + \
$CellContext`c^2}, "   XM/AM=", 
   Style[3 + 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945349128*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f30adc5e-714a-4b4c-8373-06bac7520675"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "240"}],
  SequenceForm["n=", 240],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794535148*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"58d7cb7d-07be-4397-b028-98342e3ea861"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "241"}],
  SequenceForm["n=", 241],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945353297*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"de20ab84-946c-446d-af4b-bfa762e60d53"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "241", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "+", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 241, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c) ($CellContext`a \
$CellContext`b - $CellContext`b^2 + $CellContext`a $CellContext`c - \
$CellContext`c^2), $CellContext`b ($CellContext`a + $CellContext`b - \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c) \
(-$CellContext`a^2 + $CellContext`a $CellContext`b + $CellContext`b \
$CellContext`c - $CellContext`c^2), $CellContext`c ($CellContext`a - \
$CellContext`b + $CellContext`c) (-$CellContext`a + $CellContext`b + \
$CellContext`c) (-$CellContext`a^2 - $CellContext`b^2 + $CellContext`a \
$CellContext`c + $CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[1 + 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979453551407`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"14f22f81-26b1-42e3-b72b-23f3919fbdb4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "242"}],
  SequenceForm["n=", 242],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945356798*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8b2570e9-4517-4b62-a6fb-e3a908c1337a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "243"}],
  SequenceForm["n=", 243],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945358574*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0cce9d06-a821-4607-bdb1-b54d395d16ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "244"}],
  SequenceForm["n=", 244],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945359935*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2bd52b36-a715-4503-b128-b0359d2458e0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "245"}],
  SequenceForm["n=", 245],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945361589*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e1cf9257-9e4b-4c74-abb0-4c40c35fb0ef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "246"}],
  SequenceForm["n=", 246],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945363402*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f8cd5c74-8fea-4ef5-b26d-dd665e1ae889"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "247"}],
  SequenceForm["n=", 247],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945364871*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"50b913c8-199e-4211-af52-1ec16d67d5a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "248"}],
  SequenceForm["n=", 248],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945366199*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"67ec631e-9815-4264-b19e-18207f69eed2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "249"}],
  SequenceForm["n=", 249],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979453675137`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9d94d5e8-04a2-45d0-abb7-4d9355b27de7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "250"}],
  SequenceForm["n=", 250],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945368869*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"335297b6-f578-4f32-88bd-62b0e04943e4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "251"}],
  SequenceForm["n=", 251],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945370397*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"50b73e62-a268-4ea8-bd7b-4d603a880a61"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "251", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "5"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 251, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 + $CellContext`b^2) \
($CellContext`a^2 + $CellContext`c^2), $CellContext`b^2 ($CellContext`a^2 + \
$CellContext`b^2) ($CellContext`b^2 + $CellContext`c^2), $CellContext`c^2 \
($CellContext`a^2 + $CellContext`c^2) ($CellContext`b^2 + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[
    Rational[3, 5], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945372562*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fbc6ef28-059a-4f44-a948-381af93ae706"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "252"}],
  SequenceForm["n=", 252],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979453747883`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bdd59463-3575-4a27-af51-29ee33f0e2fc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "252", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "7"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 252, 
   "   ", {($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) \
($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4), ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) \
($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
(-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4), ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
(-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4) ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[1, 7], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945378125*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8a7936e1-f6f0-4b55-a555-0684146d8957"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "253"}],
  SequenceForm["n=", 253],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945381535*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"86062456-9a6b-47c4-ad0b-5cf08939e375"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "253", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 253, 
   "   ", {($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - 
     3 $CellContext`c^4) ($CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - 3 $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - 
     3 $CellContext`c^4) ((-3) $CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), ((-3) \
$CellContext`a^4 + 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 + 2 $CellContext`a^2 $CellContext`b^2 - 3 $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945383689*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3f355569-0641-4dd8-887e-7547e6ee4ffb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "254"}],
  SequenceForm["n=", 254],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945385766*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1e57bbb0-5dea-453f-b145-e33c6edda52c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "255"}],
  SequenceForm["n=", 255],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945387217*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"60142560-8765-4e5a-a287-91f5afdea32b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "256"}],
  SequenceForm["n=", 256],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794538855*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ad076a7d-9b4b-42e6-b8e7-cd1a4df48350"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "256", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "31"], " ", 
     RowBox[{"(", 
      RowBox[{"7", "+", 
       RowBox[{"3", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 256, 
   "   ", {$CellContext`a ($CellContext`b^2 + $CellContext`a $CellContext`c) \
($CellContext`a $CellContext`b + $CellContext`c^2), $CellContext`b \
($CellContext`a^2 + $CellContext`b $CellContext`c) ($CellContext`a \
$CellContext`b + $CellContext`c^2), $CellContext`c ($CellContext`b^2 + \
$CellContext`a $CellContext`c) ($CellContext`a^2 + $CellContext`b \
$CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 31] (7 + 3 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979453903227`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e9d5d0a0-9d7a-4b04-b7e5-4b9493cf86d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "257"}],
  SequenceForm["n=", 257],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945392007*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"64c95578-a3cc-4a88-9859-0b2fa073d569"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "257", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "47"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "+", 
       RowBox[{"6", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 257, 
   "   ", {($CellContext`b^2 + $CellContext`a $CellContext`c) ($CellContext`a \
$CellContext`b + $CellContext`c^2), ($CellContext`a^2 + $CellContext`b \
$CellContext`c) ($CellContext`a $CellContext`b + $CellContext`c^2), \
($CellContext`b^2 + $CellContext`a $CellContext`c) ($CellContext`a^2 + \
$CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 47] (5 + 6 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945427004*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"47bfbf71-b992-400d-a3c8-7e2a1f271475"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "258"}],
  SequenceForm["n=", 258],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945429927*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ec084309-4fa8-4b48-a57f-88af37803ffd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "259"}],
  SequenceForm["n=", 259],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945497013*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a4193b0e-bd68-40c1-96df-36ed6f785330"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "259", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]], ",", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["b", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], ",", 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
       SuperscriptBox["c", "3"]}]]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SqrtBox[
      RowBox[{"4", "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}]], 
     RowBox[{"2", "+", 
      SqrtBox[
       RowBox[{"4", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}]]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 259, 
   "   ", {($CellContext`a^3 (-$CellContext`a + $CellContext`b + \
$CellContext`c))^
    Rational[1, 
      2], ($CellContext`b^3 ($CellContext`a - $CellContext`b + \
$CellContext`c))^
    Rational[1, 
      2], (($CellContext`a + $CellContext`b - $CellContext`c) \
$CellContext`c^3)^Rational[1, 2]}, "   XM/AM=", 
   Style[(4 - 2 2^Rational[1, 2])^Rational[1, 2]/(
    2 + (4 - 2 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945535034*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"010c5753-99cc-417d-b42c-b491491065f4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "260"}],
  SequenceForm["n=", 260],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945537284*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"176b1ea3-e38e-4a77-b0d2-5cd8248e4b0c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "260", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", 
       RowBox[{"3", "/", "2"}]], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]], "+", 
        SqrtBox[
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ")"}], " ", 
      
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], "+", 
        SqrtBox[
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], 
     ",", 
     RowBox[{
      SuperscriptBox["b", 
       RowBox[{"3", "/", "2"}]], " ", 
      SqrtBox[
       RowBox[{"a", "-", "b", "+", "c"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]], "+", 
        SqrtBox[
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], "+", 
        SqrtBox[
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], 
     ",", 
     RowBox[{
      SqrtBox[
       RowBox[{"a", "+", "b", "-", "c"}]], " ", 
      SuperscriptBox["c", 
       RowBox[{"3", "/", "2"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]], "+", 
        SqrtBox[
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}]], "+", 
        SqrtBox[
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}]}], 
    "}"}], "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}], "+", 
      SqrtBox[
       RowBox[{"4", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}]]}], 
     RowBox[{"2", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}], "+", 
      SqrtBox[
       RowBox[{"4", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}]]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 260, 
   "   ", {$CellContext`a^
     Rational[3, 2] (-$CellContext`a + $CellContext`b + $CellContext`c)^
     Rational[1, 
       2] ((($CellContext`a + $CellContext`b - $CellContext`c) \
$CellContext`c)^
      Rational[1, 
        2] + ($CellContext`a (-$CellContext`a + $CellContext`b + \
$CellContext`c))^
      Rational[1, 
        2]) (($CellContext`b ($CellContext`a - $CellContext`b + \
$CellContext`c))^
      Rational[1, 
        2] + ($CellContext`a (-$CellContext`a + $CellContext`b + \
$CellContext`c))^Rational[1, 2]), $CellContext`b^
     Rational[3, 2] ($CellContext`a - $CellContext`b + $CellContext`c)^
     Rational[1, 
       2] ((($CellContext`a + $CellContext`b - $CellContext`c) \
$CellContext`c)^
      Rational[1, 
        2] + ($CellContext`b ($CellContext`a - $CellContext`b + \
$CellContext`c))^
      Rational[1, 
        2]) (($CellContext`b ($CellContext`a - $CellContext`b + \
$CellContext`c))^
      Rational[1, 
        2] + ($CellContext`a (-$CellContext`a + $CellContext`b + \
$CellContext`c))^
      Rational[1, 2]), ($CellContext`a + $CellContext`b - $CellContext`c)^
     Rational[1, 2] $CellContext`c^
     Rational[3, 
       2] ((($CellContext`a + $CellContext`b - $CellContext`c) \
$CellContext`c)^
      Rational[1, 
        2] + ($CellContext`b ($CellContext`a - $CellContext`b + \
$CellContext`c))^
      Rational[1, 
        2]) ((($CellContext`a + $CellContext`b - $CellContext`c) \
$CellContext`c)^
      Rational[1, 
        2] + ($CellContext`a (-$CellContext`a + $CellContext`b + \
$CellContext`c))^Rational[1, 2])}, "   XM/AM=", 
   Style[(-2 + 2 2^Rational[1, 2] + (4 - 2 2^Rational[1, 2])^Rational[1, 2])/(
    2 + 2 2^Rational[1, 2] + (4 - 2 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945650157*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e5cf615e-bd06-469b-82bd-f443f8598d8e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "261"}],
  SequenceForm["n=", 261],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979456531763`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"79b6800f-97c2-4890-966d-5cea54767618"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "261", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "79"], " ", 
     RowBox[{"(", 
      RowBox[{"7", "+", 
       RowBox[{"8", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 261, 
   "   ", {($CellContext`a + $CellContext`b)^2 ($CellContext`a - \
$CellContext`b - $CellContext`c) ($CellContext`a + $CellContext`c)^2, \
($CellContext`a + $CellContext`b)^2 (-$CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`b + $CellContext`c)^2, ($CellContext`a + \
$CellContext`c)^2 (-$CellContext`a - $CellContext`b + $CellContext`c) \
($CellContext`b + $CellContext`c)^2}, "   XM/AM=", 
   Style[Rational[1, 79] (7 + 8 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979456876993`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1062ab32-4c00-42f9-bcbf-c39d31b08c71"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "262"}],
  SequenceForm["n=", 262],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945689885*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6d7ed5c2-0286-4a6f-8ab0-3f2ab09dbbfe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "262", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "5"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 262, 
   "   ", {($CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2) \
(2 $CellContext`a^2 $CellContext`b^2 + $CellContext`a^2 $CellContext`c^2 + \
$CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), (-$CellContext`a^4 + \
$CellContext`a^2 $CellContext`b^2 + $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2) (
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`a^2 $CellContext`c^2 + \
$CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), ($CellContext`a^2 \
$CellContext`b^2 - $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2) \
(-$CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 + $CellContext`a^2 \
$CellContext`c^2 + 2 $CellContext`b^2 $CellContext`c^2)}, "   XM/AM=", 
   Style[
    Rational[3, 5], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945691787*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f7595d67-bf41-44fc-8317-a2672bed4181"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "263"}],
  SequenceForm["n=", 263],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945693922*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ade5152f-f1e1-4abd-8349-e999678c6d3a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "263", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "4"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 263, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2) \
(2 $CellContext`a^2 $CellContext`b^2 + $CellContext`a^2 $CellContext`c^2 + \
$CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), $CellContext`b^2 \
(-$CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 + $CellContext`a^2 \
$CellContext`c^2 + 2 $CellContext`b^2 $CellContext`c^2) (
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`a^2 $CellContext`c^2 + \
$CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), $CellContext`c^2 \
($CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2) \
(-$CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 + $CellContext`a^2 \
$CellContext`c^2 + 2 $CellContext`b^2 $CellContext`c^2)}, "   XM/AM=", 
   Style[
    Rational[3, 4], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979456962214`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0aa3d95a-4763-44c4-913d-bf489183fbc6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "264"}],
  SequenceForm["n=", 264],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945698324*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9cc4b346-b23b-4d49-9380-d38b4c1eb6c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "265"}],
  SequenceForm["n=", 265],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945699738*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"741ae08a-7d27-4eba-a77a-b62b63909989"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "266"}],
  SequenceForm["n=", 266],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945701117*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f00db44d-4eeb-44b9-b6b2-3efc13458814"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "266", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", 
       RowBox[{"3", "/", "2"}]], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]]}], ",", 
     RowBox[{
      SuperscriptBox["b", 
       RowBox[{"3", "/", "2"}]], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ",", 
     RowBox[{
      SuperscriptBox["c", 
       RowBox[{"3", "/", "2"}]], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"1", "+", 
      SqrtBox[
       RowBox[{"2", "-", 
        SqrtBox["2"]}]]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 266, 
   "   ", {$CellContext`a^
     Rational[3, 
       2] (($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a - \
$CellContext`b + $CellContext`c))^Rational[1, 2], $CellContext`b^
     Rational[3, 
       2] (($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
     Rational[1, 2], $CellContext`c^
     Rational[3, 
       2] (($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^Rational[1, 2]}, 
   "   XM/AM=", 
   Style[(1 + (2 - 2^Rational[1, 2])^Rational[1, 2])^(-1), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979457354403`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"07274a37-c526-43a9-af40-76b55e5ca1db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "267"}],
  SequenceForm["n=", 267],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979457376823`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c7141bec-fd51-4a18-9688-e19604ea9f57"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "267", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 267, 
   "   ", {$CellContext`a ($CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c + $CellContext`a $CellContext`b $CellContext`c + \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2 - $CellContext`c^3) ($CellContext`a^3 + \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 - \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c + $CellContext`a \
$CellContext`b $CellContext`c - $CellContext`b^2 $CellContext`c + \
$CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2 + \
$CellContext`c^3), $CellContext`b ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c + $CellContext`a $CellContext`b \
$CellContext`c + $CellContext`b^2 $CellContext`c - $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2 - $CellContext`c^3) \
(-$CellContext`a^3 - $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 $CellContext`c + \
$CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`c ($CellContext`a^3 + \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 - \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c + $CellContext`a \
$CellContext`b $CellContext`c - $CellContext`b^2 $CellContext`c + \
$CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2 + \
$CellContext`c^3) (-$CellContext`a^3 - $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c + $CellContext`a $CellContext`b $CellContext`c + \
$CellContext`b^2 $CellContext`c + $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 3] (1 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979457404003`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1efb87c0-0c69-4c2f-870b-026422206f71"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "268"}],
  SequenceForm["n=", 268],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945742745*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a18e29f9-477f-4595-a791-c37bab7912c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "269"}],
  SequenceForm["n=", 269],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945744581*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4ee0d389-f0e2-42c7-beba-a156accd1dc6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "269", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 269, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b - \
$CellContext`c)^2 ($CellContext`a - $CellContext`b + $CellContext`c)^2, \
$CellContext`b ($CellContext`a + $CellContext`b - $CellContext`c)^2 \
(-$CellContext`a + $CellContext`b + $CellContext`c)^2, $CellContext`c \
($CellContext`a - $CellContext`b + $CellContext`c)^2 (-$CellContext`a + \
$CellContext`b + $CellContext`c)^2}, "   XM/AM=", 
   Style[Rational[1, 3] (1 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945746808*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d3bdb38f-7630-41f7-b98c-b33be8a84389"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "270"}],
  SequenceForm["n=", 270],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945748908*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"29995b0a-e409-4816-be13-95dbb250c165"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "271"}],
  SequenceForm["n=", 271],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945750352*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"750dde33-6b41-4bc5-b1ec-e1743b7ecf8f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "272"}],
  SequenceForm["n=", 272],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945751751*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"21bbc277-0542-412c-8ef3-02d0be421cb1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "273"}],
  SequenceForm["n=", 273],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945753113*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bdc783d1-90e8-4340-97e8-9349940b6db8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "274"}],
  SequenceForm["n=", 274],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945754537*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"719f8145-23f4-4b14-980f-395f86ac146d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "274", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"a", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "49"], " ", 
     RowBox[{"(", 
      RowBox[{"9", "+", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 274, 
   "   ", {$CellContext`b ($CellContext`a + $CellContext`b) $CellContext`c \
($CellContext`a + $CellContext`c), $CellContext`a ($CellContext`a + \
$CellContext`b) $CellContext`c ($CellContext`b + $CellContext`c), \
$CellContext`a $CellContext`b ($CellContext`a + $CellContext`c) \
($CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 49] (9 + 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945788517*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"16074bd8-2bb0-4f5d-8fe7-9d473ae7453f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "275"}],
  SequenceForm["n=", 275],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945790777*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"20c7eea0-d331-4f0a-8492-81d0a8866983"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "276"}],
  SequenceForm["n=", 276],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945792139*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"70cc638b-cc3e-4752-8a56-54ba5b2ab6be"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "277"}],
  SequenceForm["n=", 277],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945793487*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f50c8abf-faee-46c6-b980-dffd3dca96f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "277", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "5"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 277, 
   "   ", {($CellContext`a^2 - 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 - 
     2 $CellContext`b $CellContext`c + $CellContext`c^2) ($CellContext`a^2 + \
$CellContext`b^2 - 2 $CellContext`a $CellContext`c - 
     2 $CellContext`b $CellContext`c + $CellContext`c^2), ($CellContext`a^2 - 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 - 
     2 $CellContext`a $CellContext`c + $CellContext`c^2) ($CellContext`a^2 + \
$CellContext`b^2 - 2 $CellContext`a $CellContext`c - 
     2 $CellContext`b $CellContext`c + $CellContext`c^2), ($CellContext`a^2 - 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 - 
     2 $CellContext`a $CellContext`c + $CellContext`c^2) ($CellContext`a^2 - 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 - 
     2 $CellContext`b $CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[
    Rational[1, 5], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945795479*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d7d6d250-dda6-41dd-8d85-e9f09aec986f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "278"}],
  SequenceForm["n=", 278],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945797311*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cafa5243-be28-44f1-98cd-068a4fc6a43a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "279"}],
  SequenceForm["n=", 279],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945798842*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"94b47b77-704f-4379-82c4-8f303f73acc5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "279", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"7", "+", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 279, 
   "   ", {($CellContext`a + $CellContext`b - $CellContext`c)^2 \
($CellContext`a - $CellContext`b + $CellContext`c)^2, ($CellContext`a + \
$CellContext`b - $CellContext`c)^2 (-$CellContext`a + $CellContext`b + \
$CellContext`c)^2, ($CellContext`a - $CellContext`b + $CellContext`c)^2 \
(-$CellContext`a + $CellContext`b + $CellContext`c)^2}, "   XM/AM=", 
   Style[Rational[1, 17] (7 + 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945800597*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"93e3b98b-1a72-4237-b7b2-2e8f2fe25cea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "280"}],
  SequenceForm["n=", 280],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945802759*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a4c4b3e2-b546-4189-a5da-7a07de871125"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "280", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 280, 
   "   ", {($CellContext`a - $CellContext`b - $CellContext`c) \
($CellContext`a^3 - $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), (-$CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) (-$CellContext`a^3 - $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), (-$CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a^3 - $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945840748*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a05ce5bf-327f-4a3a-9c2e-8cd09c1a4b1c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "281"}],
  SequenceForm["n=", 281],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945843749*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f8af33a5-4da0-42d6-ba5a-ef35f4fbc991"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "282"}],
  SequenceForm["n=", 282],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945845448*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a6425d0e-35e1-493f-8e85-2c6fe8727ee7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "282", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 282, 
   "   ", {$CellContext`a ($CellContext`a - $CellContext`b - $CellContext`c) \
($CellContext`a^3 - $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`b (-$CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) (-$CellContext`a^3 - $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`c (-$CellContext`a - \
$CellContext`b + $CellContext`c) (-$CellContext`a^3 - $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[-1 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945848132*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d76e9edd-dabe-4cd1-8331-2f56cd50f1c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "283"}],
  SequenceForm["n=", 283],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945850486*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c5b790fe-6416-4cee-bbb4-d01ec78004a7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "284"}],
  SequenceForm["n=", 284],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945851879*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"74684ac1-0e89-4245-bbf7-f7cf4fdb1247"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "284", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 284, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b) ($CellContext`a - \
$CellContext`b - $CellContext`c) ($CellContext`a + $CellContext`c), \
$CellContext`b^2 ($CellContext`a + $CellContext`b) (-$CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`b + $CellContext`c), \
$CellContext`c^2 ($CellContext`a + $CellContext`c) (-$CellContext`a - \
$CellContext`b + $CellContext`c) ($CellContext`b + $CellContext`c)}, 
   "   XM/AM=", 
   Style[
    Rational[1, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979458537683`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"18113a9c-9cc9-47d6-8fe9-94432851f950"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "285"}],
  SequenceForm["n=", 285],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945855644*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"eb62840e-df10-4bed-950a-0ff48556676b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "285", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "3"}], "-", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 285, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`a - \
$CellContext`b - $CellContext`c) ($CellContext`a + $CellContext`c) \
($CellContext`a^3 - $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`b ($CellContext`a + \
$CellContext`b) (-$CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`b + $CellContext`c) ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) (-$CellContext`a^3 - $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`c ($CellContext`a + \
$CellContext`c) (-$CellContext`a - $CellContext`b + $CellContext`c) \
($CellContext`b + $CellContext`c) (-$CellContext`a^3 - $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[-3 - 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979458588133`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f558dc1f-a6a5-42a7-97e1-37ac62022d4a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "286"}],
  SequenceForm["n=", 286],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945861104*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9be85843-979f-494f-acb2-054a15f36fd2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "287"}],
  SequenceForm["n=", 287],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794586252*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"93ecd33d-e789-4726-8aaf-953e0fa2976d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "288"}],
  SequenceForm["n=", 288],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945863861*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"67c10975-06e4-4b53-85de-6babd6756408"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "288", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "7"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 288, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) \
($CellContext`a^4 - 3 $CellContext`a^2 $CellContext`b^2 + 2 $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - 
     3 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4) ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`c^2 - 
     3 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`c^4), $CellContext`b^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) (
     2 $CellContext`a^4 - 
     3 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
(-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`c^2 - 
     3 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`c^4), $CellContext`c^2 ($CellContext`a^4 - 
     3 $CellContext`a^2 $CellContext`b^2 + 2 $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - 
     3 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) (
     2 $CellContext`a^4 - 
     3 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
(-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[3, 7], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979458664637`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e09ea3f7-6984-4eda-afbc-7c0c60414424"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "289"}],
  SequenceForm["n=", 289],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945869051*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"579a1ee7-d718-43b9-b89e-7d3c1571be5c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "290"}],
  SequenceForm["n=", 290],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945953147*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d787a4e4-b00f-45c2-a216-8a0f176bcf01"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "290", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", "3"]}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 290, 
   "   ", {$CellContext`b^2 $CellContext`c^2 ($CellContext`a^4 + \
$CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2) ($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), $CellContext`a^2 \
$CellContext`c^2 ($CellContext`a^4 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) (-$CellContext`a^2 \
$CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 + \
$CellContext`c^4), $CellContext`a^2 $CellContext`b^2 (-$CellContext`a^2 \
$CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 + \
$CellContext`c^4) ($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[-1, 3], 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945955778*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a22bcbd7-91a5-4b57-a3a5-852c9067b151"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "291"}],
  SequenceForm["n=", 291],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945957672*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bc9755ae-f4f0-441d-8cc6-10083cf3d804"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "291", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 291, 
   "   ", {$CellContext`a (-$CellContext`b^2 + $CellContext`a $CellContext`c) \
($CellContext`a $CellContext`b - $CellContext`c^2), $CellContext`b \
(-$CellContext`a^2 + $CellContext`b $CellContext`c) ($CellContext`a \
$CellContext`b - $CellContext`c^2), $CellContext`c (-$CellContext`b^2 + \
$CellContext`a $CellContext`c) (-$CellContext`a^2 + $CellContext`b \
$CellContext`c)}, "   XM/AM=", 
   Style[1 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979459635153`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d3564f8c-6632-4690-bdff-de9a8d95967d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "292"}],
  SequenceForm["n=", 292],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945966052*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3676c641-9ae3-424d-90ad-ea5deee1e68b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "292", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 292, 
   "   ", {$CellContext`a^2 (-$CellContext`b^2 + $CellContext`a \
$CellContext`c) ($CellContext`a $CellContext`b - $CellContext`c^2), \
$CellContext`b^2 (-$CellContext`a^2 + $CellContext`b $CellContext`c) \
($CellContext`a $CellContext`b - $CellContext`c^2), $CellContext`c^2 \
(-$CellContext`b^2 + $CellContext`a $CellContext`c) (-$CellContext`a^2 + \
$CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[-2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945967993*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8c1577d2-1362-48ab-8777-5d762cd50442"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "293"}],
  SequenceForm["n=", 293],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945969987*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"24096d6f-43dc-44a0-8cdc-d8cb8d320ac5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "294"}],
  SequenceForm["n=", 294],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097945971719*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b29163f9-3f46-4cd4-9d66-8f48712cd79e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "294", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 294, 
   "   ", {$CellContext`a ($CellContext`a - $CellContext`b - $CellContext`c) \
($CellContext`a^2 + $CellContext`b^2 - $CellContext`a $CellContext`c - \
$CellContext`b $CellContext`c) ($CellContext`a^2 - $CellContext`a \
$CellContext`b - $CellContext`b $CellContext`c + $CellContext`c^2), \
$CellContext`b (-$CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a^2 + $CellContext`b^2 - $CellContext`a $CellContext`c - \
$CellContext`b $CellContext`c) (-$CellContext`a $CellContext`b + \
$CellContext`b^2 - $CellContext`a $CellContext`c + $CellContext`c^2), \
$CellContext`c (-$CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a $CellContext`b + $CellContext`b^2 - $CellContext`a \
$CellContext`c + $CellContext`c^2) ($CellContext`a^2 - $CellContext`a \
$CellContext`b - $CellContext`b $CellContext`c + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[Rational[1, 7] (1 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946005295*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"874d56ec-f75a-4367-81b0-cd7324af4c4d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "295"}],
  SequenceForm["n=", 295],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946007676*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"adc7fbc4-c012-4310-8453-0efc5e96a95f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "296"}],
  SequenceForm["n=", 296],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946009069*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"91375344-143d-4f92-90bd-8559dcadb8ea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "297"}],
  SequenceForm["n=", 297],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946010686*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e8ac3745-2416-4149-8899-b5c00c73cd39"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "298"}],
  SequenceForm["n=", 298],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946012288*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"21ec6c22-3470-4501-99d4-d2d7c78005b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "299"}],
  SequenceForm["n=", 299],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946049968*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"62a00e5f-ceeb-4ad9-bf93-717ad4344b92"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "300"}],
  SequenceForm["n=", 300],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946055808*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2381b5cc-6ea8-4003-bb6c-0dbc18d85ffe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "301"}],
  SequenceForm["n=", 301],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946099703*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b2b72c14-6df5-4809-bccc-d6d8db8cd368"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "302"}],
  SequenceForm["n=", 302],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946133649*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0f279507-efe2-4930-911f-6e2534cd11c6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "303"}],
  SequenceForm["n=", 303],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946171916*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a466dceb-1876-4a42-b427-4cc9b118800d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "304"}],
  SequenceForm["n=", 304],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979462067337`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"10ffc00e-e923-49e4-9fd2-73d6c357ccd0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "305"}],
  SequenceForm["n=", 305],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946208681*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ec1a85c7-0106-482d-8cc0-14c048678b40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "306"}],
  SequenceForm["n=", 306],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946210374*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"83d259ba-4cd0-4164-98ea-66dd2fe4d027"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "307"}],
  SequenceForm["n=", 307],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946212614*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"96983d1a-3934-420b-97cb-f5801f49e613"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "308"}],
  SequenceForm["n=", 308],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946214892*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"486b3d32-d4f9-4c0c-86ed-11959dedcac4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "308", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "11"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 308, 
   "   ", {$CellContext`b^2 ($CellContext`a^2 + $CellContext`b^2) \
$CellContext`c^2 ($CellContext`a^2 + $CellContext`c^2), $CellContext`a^2 \
($CellContext`a^2 + $CellContext`b^2) $CellContext`c^2 ($CellContext`b^2 + \
$CellContext`c^2), $CellContext`a^2 $CellContext`b^2 ($CellContext`a^2 + \
$CellContext`c^2) ($CellContext`b^2 + $CellContext`c^2)}, "   XM/AM=", 
   Style[
    Rational[3, 11], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946217359*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9533d487-0852-4946-97a5-35389aa0ec5e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "309"}],
  SequenceForm["n=", 309],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946219688*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"157331d8-9038-4a78-b1db-c2ee0f210e0a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "309", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"a", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"a", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "3"}], "-", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 309, 
   "   ", {$CellContext`b $CellContext`c ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`a $CellContext`c \
($CellContext`a^3 - $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) (-$CellContext`a^3 - $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`a $CellContext`b \
(-$CellContext`a^3 - $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[-3 - 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946223617*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6324f719-a5bf-461e-8f07-b21292319288"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "310"}],
  SequenceForm["n=", 310],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946226849*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"52e0751d-86ca-403c-bbb2-a02bfe52fdb8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "310", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "79"], " ", 
     RowBox[{"(", 
      RowBox[{"7", "+", 
       RowBox[{"8", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 310, 
   "   ", {$CellContext`b^2 ($CellContext`a + $CellContext`b) \
$CellContext`c^2 ($CellContext`a + $CellContext`c), $CellContext`a^2 \
($CellContext`a + $CellContext`b) $CellContext`c^2 ($CellContext`b + \
$CellContext`c), $CellContext`a^2 $CellContext`b^2 ($CellContext`a + \
$CellContext`c) ($CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 79] (7 + 8 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946229207*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5775ee99-8eb7-4a64-b5e7-56d082843dcb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "311"}],
  SequenceForm["n=", 311],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946231138*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"38c8d04f-510c-47e7-ba8d-c0e9f26a2d6a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "311", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 311, 
   "   ", {$CellContext`b^2 $CellContext`c^2 (-$CellContext`a^2 \
$CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`a^2 $CellContext`c^2 ($CellContext`a^4 - $CellContext`a^2 \
$CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4), $CellContext`a^2 $CellContext`b^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[
    Rational[1, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946233042*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"33191216-504a-4daf-8f26-2375867b8f37"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "312"}],
  SequenceForm["n=", 312],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946234859*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8121741f-db97-4af6-8970-8e30e62426b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "312", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"a", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"a", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 312, 
   "   ", {$CellContext`b $CellContext`c (-$CellContext`a + $CellContext`b + \
$CellContext`c), $CellContext`a $CellContext`c ($CellContext`a - \
$CellContext`b + $CellContext`c), $CellContext`a $CellContext`b \
($CellContext`a + $CellContext`b - $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 17] (5 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946236733*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8ee70194-db20-48c6-83b7-670a38b7f395"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "313"}],
  SequenceForm["n=", 313],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946238337*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b6f57e9e-00e7-4f33-8620-a2722c2ebd45"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "313", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"3", "-", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 313, 
   "   ", {$CellContext`b^2 $CellContext`c^2 ($CellContext`b + \
$CellContext`c), $CellContext`a^2 $CellContext`c^2 ($CellContext`a + \
$CellContext`c), $CellContext`a^2 $CellContext`b^2 ($CellContext`a + \
$CellContext`b)}, "   XM/AM=", 
   Style[3 - 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946243927*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fad40cc4-d0d6-4ae7-ad10-da47cfe19c09"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "314"}],
  SequenceForm["n=", 314],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979462462883`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8a89e601-6e64-48fe-93eb-8be1e2244368"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "314", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"a", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "31"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 314, 
   "   ", {$CellContext`b ($CellContext`a + $CellContext`b) $CellContext`c \
($CellContext`a + $CellContext`c) (-$CellContext`a + $CellContext`b + \
$CellContext`c), $CellContext`a ($CellContext`a + $CellContext`b) \
$CellContext`c ($CellContext`a - $CellContext`b + $CellContext`c) \
($CellContext`b + $CellContext`c), $CellContext`a $CellContext`b \
($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a + \
$CellContext`c) ($CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 31] (-1 + 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946280612*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7b17f2ff-f26d-4512-acac-22981d191a88"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "315"}],
  SequenceForm["n=", 315],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946283139*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b9b8cf44-b85d-4c58-b7ca-297e1d2e8727"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "315", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      SuperscriptBox["b", "4"], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", "3"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 315, 
   "   ", {$CellContext`a^4 - $CellContext`b^4 - $CellContext`c^4, \
-$CellContext`a^4 + $CellContext`b^4 - $CellContext`c^4, -$CellContext`a^4 - \
$CellContext`b^4 + $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[-1, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946284833*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cbbb40a4-6cb8-4220-a595-af008f4ad901"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "316"}],
  SequenceForm["n=", 316],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946286578*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7c180919-da20-42c5-8a3e-2a9852462357"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "316", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "3"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 316, 
   "   ", {$CellContext`a^4 - $CellContext`b^4 + $CellContext`b^2 \
$CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 + $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 + \
$CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + $CellContext`c^4}, 
   "   XM/AM=", 
   Style[-3, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946288559*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e30e3623-f4b1-4f9e-b3f3-e4f098ae829e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "317"}],
  SequenceForm["n=", 317],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946290224*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"77b78e82-6ca4-4158-9f91-0747f3094b80"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "318"}],
  SequenceForm["n=", 318],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979462916327`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f0355589-33a7-49a2-9bba-0f3872bd7829"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "319"}],
  SequenceForm["n=", 319],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946293026*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bfad4bf5-986f-487c-8f81-7601f07c5db2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "319", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"b", " ", "c"}], "-", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"a", " ", "c"}], "-", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"a", " ", "b"}], "-", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"5", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 319, 
   "   ", {$CellContext`a^2 - $CellContext`b^2 - $CellContext`b \
$CellContext`c - $CellContext`c^2, -$CellContext`a^2 + $CellContext`b^2 - \
$CellContext`a $CellContext`c - $CellContext`c^2, -$CellContext`a^2 - \
$CellContext`a $CellContext`b - $CellContext`b^2 + $CellContext`c^2}, 
   "   XM/AM=", 
   Style[(5 + 2 2^Rational[1, 2])^(-1), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946294715*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ab66bffa-2e4e-42d7-9f8d-4c24ef6f5c68"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "320"}],
  SequenceForm["n=", 320],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979462972116`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"851ebb1d-8e0a-4882-8c00-d7342137d4bd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "320", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"b", " ", "c"}], "-", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"a", " ", "c"}], "-", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "+", 
      RowBox[{"a", " ", "b"}], "-", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "3"}], "-", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 320, 
   "   ", {$CellContext`a^2 - $CellContext`b^2 + $CellContext`b \
$CellContext`c - $CellContext`c^2, -$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`a $CellContext`c - $CellContext`c^2, -$CellContext`a^2 + \
$CellContext`a $CellContext`b - $CellContext`b^2 + $CellContext`c^2}, 
   "   XM/AM=", 
   Style[-3 - 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979462992287`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6f8dc7d3-8445-4c9f-bcf4-1a78908f6cda"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "321"}],
  SequenceForm["n=", 321],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946301231*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c20ba21f-c16d-4297-ac65-245117d67aba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "321", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{"a", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{"a", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"3", "+", 
      SqrtBox["2"]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 321, 
   "   ", {$CellContext`b $CellContext`c ($CellContext`b + $CellContext`c), \
$CellContext`a $CellContext`c ($CellContext`a + $CellContext`c), \
$CellContext`a $CellContext`b ($CellContext`a + $CellContext`b)}, "   XM/AM=", 
   Style[(3 + 2^Rational[1, 2])^(-1), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946303603*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3621c02d-acd0-41a6-9554-7514d0c74d76"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "322"}],
  SequenceForm["n=", 322],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979463054953`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ec3d7069-9730-4eed-821d-4ea0907003f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "322", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"a", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"a", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "3"}], "+", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 322, 
   "   ", {$CellContext`b $CellContext`c (-$CellContext`a^3 - \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`a $CellContext`c \
($CellContext`a^3 + $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`a $CellContext`b \
($CellContext`a^3 - $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3)}, "   XM/AM=", 
   Style[-3 + 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946307702*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"50a5b0f6-3c51-4218-98be-77521c2c9789"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "323"}],
  SequenceForm["n=", 323],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946309656*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"46f8ac36-3f72-4176-be19-cb6148cabb48"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "323", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 323, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`b $CellContext`c - $CellContext`c^2) ($CellContext`a^2 - \
$CellContext`b^2 + $CellContext`b $CellContext`c - $CellContext`c^2), \
$CellContext`b^2 (-$CellContext`a^2 + $CellContext`b^2 - $CellContext`a \
$CellContext`c - $CellContext`c^2) (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`a $CellContext`c - $CellContext`c^2), $CellContext`c^2 \
(-$CellContext`a^2 - $CellContext`a $CellContext`b - $CellContext`b^2 + \
$CellContext`c^2) (-$CellContext`a^2 + $CellContext`a $CellContext`b - \
$CellContext`b^2 + $CellContext`c^2)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946311574*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7b1ee731-72a3-4114-a3d9-b44c4e332d2c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "324"}],
  SequenceForm["n=", 324],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979463133907`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b9afde1b-e796-4b56-89d3-7993c89a143a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "325"}],
  SequenceForm["n=", 325],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946314851*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8a9a8941-f23e-4e8c-a562-6ff9672ed4b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "325", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 325, 
   "   ", {-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - \
$CellContext`a^2 $CellContext`b^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4, $CellContext`a^4 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946316615*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ac9c9a22-48bf-4295-a5bc-9a46193eb59d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "326"}],
  SequenceForm["n=", 326],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946318306*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ddce47ea-49fc-45c4-a681-7ddf7a6dc94f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "327"}],
  SequenceForm["n=", 327],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946319791*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"14005ef7-b916-4662-b84e-80bc134b040b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "327", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "7"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 327, 
   "   ", {$CellContext`b^2 $CellContext`c^2 (-$CellContext`a^2 \
$CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) \
((-2) $CellContext`a^2 $CellContext`b^2 - $CellContext`a^2 $CellContext`c^2 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), $CellContext`a^2 \
$CellContext`c^2 ($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2) ((-2) $CellContext`a^2 \
$CellContext`b^2 - $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4), $CellContext`a^2 $CellContext`b^2 \
($CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - $CellContext`a^2 \
$CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2) (-$CellContext`a^2 $CellContext`b^2 + \
$CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2)}, "   XM/AM=", 
   Style[
    Rational[3, 7], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946322023*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"01e791e3-8737-4f82-9b2c-92502d7681ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "328"}],
  SequenceForm["n=", 328],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946324041*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"73fabea8-af04-4bf7-94fb-fd4299f0fe17"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "329"}],
  SequenceForm["n=", 329],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979463254757`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"da0f7a45-ebd4-46de-9ee4-67327fbfd122"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "329", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "3"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "3"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "3"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "3"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "3"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "3"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "3"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 329, 
   "   ", {$CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c - 
    2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 - $CellContext`c^3, -$CellContext`a^3 - $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c - 
    2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3, -$CellContext`a^3 + $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c - 
    2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3}, "   XM/AM=", 
   Style[Rational[1, 7] (1 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946327507*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"01ee6d72-bccf-4cde-99eb-63dad2e0d446"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "330"}],
  SequenceForm["n=", 330],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946329722*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9da1a101-8095-4b11-a28f-18e6ff31cdb6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "330", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 330, 
   "   ", {($CellContext`a $CellContext`b - $CellContext`a $CellContext`c - \
$CellContext`b $CellContext`c) (-$CellContext`a $CellContext`b + \
$CellContext`a $CellContext`c - $CellContext`b $CellContext`c), \
($CellContext`a $CellContext`b - $CellContext`a $CellContext`c - \
$CellContext`b $CellContext`c) (-$CellContext`a $CellContext`b - \
$CellContext`a $CellContext`c + $CellContext`b $CellContext`c), \
(-$CellContext`a $CellContext`b + $CellContext`a $CellContext`c - \
$CellContext`b $CellContext`c) (-$CellContext`a $CellContext`b - \
$CellContext`a $CellContext`c + $CellContext`b $CellContext`c)}, "   XM/AM=", 
   
   Style[(-1 + 4 2^Rational[1, 2])^(-1), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979463317413`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8179a83a-9d54-4117-9ca2-69460b2e9608"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "331"}],
  SequenceForm["n=", 331],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946333651*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ba6b287b-2321-4b5f-a044-9ee4d653393d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "332"}],
  SequenceForm["n=", 332],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946335155*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2ef32488-1c68-40df-9032-7639c7166746"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "333"}],
  SequenceForm["n=", 333],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946336705*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5e7cd583-e486-46a8-888c-250dc441d119"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "333", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "5"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 333, 
   "   ", {($CellContext`a + $CellContext`b) ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`a + $CellContext`c), ($CellContext`a + \
$CellContext`b) (-$CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`b + $CellContext`c), ($CellContext`a + $CellContext`c) \
(-$CellContext`a - $CellContext`b + $CellContext`c) ($CellContext`b + \
$CellContext`c)}, "   XM/AM=", 
   Style[
    Rational[1, 5], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946371772*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"39e0a773-55fb-427a-835d-bb9ecc02d638"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "334"}],
  SequenceForm["n=", 334],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946374153*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"281a6d16-50a7-48bd-8d9f-4c298d576f0f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "334", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"a", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"a", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "3"}], "+", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 334, 
   "   ", {$CellContext`b $CellContext`c ($CellContext`b^2 - $CellContext`a \
$CellContext`c) (-$CellContext`a $CellContext`b + $CellContext`c^2), \
$CellContext`a $CellContext`c ($CellContext`a^2 - $CellContext`b \
$CellContext`c) (-$CellContext`a $CellContext`b + $CellContext`c^2), \
$CellContext`a $CellContext`b ($CellContext`b^2 - $CellContext`a \
$CellContext`c) ($CellContext`a^2 - $CellContext`b $CellContext`c)}, 
   "   XM/AM=", 
   Style[-3 + 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794637595*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"208c434f-a362-4de7-8008-80d802f3a481"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "335"}],
  SequenceForm["n=", 335],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979463780317`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"69ca4076-489c-4165-8ee4-6979877dd4df"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "335", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 335, 
   "   ", {($CellContext`b^2 - $CellContext`a $CellContext`c) \
(-$CellContext`a $CellContext`b + $CellContext`c^2), ($CellContext`a^2 - \
$CellContext`b $CellContext`c) (-$CellContext`a $CellContext`b + \
$CellContext`c^2), ($CellContext`b^2 - $CellContext`a $CellContext`c) \
($CellContext`a^2 - $CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 7] (1 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946380456*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e3c9cb99-6e97-4df5-b9e4-28567bd8c1de"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "336"}],
  SequenceForm["n=", 336],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979463826723`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8d938587-da0d-4e8c-a9ec-820f564bafa6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "337"}],
  SequenceForm["n=", 337],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946384325*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0dcd2863-e9b2-495a-b170-4cd6f103cba8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "338"}],
  SequenceForm["n=", 338],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946386426*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f387d762-0b38-44f2-a1d1-2ddb9d3b61de"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "339"}],
  SequenceForm["n=", 339],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946388289*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"63433333-697b-4d99-ba5b-7d14f833b445"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "340"}],
  SequenceForm["n=", 340],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979463898363`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b8747bc7-d15d-49b6-8fac-15a277db4336"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "341"}],
  SequenceForm["n=", 341],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946391404*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6f7be15f-254b-4a4d-a467-2a9425859ffb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "341", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", "c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"a", " ", "c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "-", 
     FractionBox[
      RowBox[{"2", " ", 
       SqrtBox["2"]}], "3"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 341, 
   "   ", {$CellContext`b $CellContext`c (-$CellContext`a + $CellContext`b + \
$CellContext`c)^2, $CellContext`a $CellContext`c ($CellContext`a - \
$CellContext`b + $CellContext`c)^2, $CellContext`a $CellContext`b \
($CellContext`a + $CellContext`b - $CellContext`c)^2}, "   XM/AM=", 
   Style[1 + Rational[-2, 3] 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946393201*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5cdafa1d-abea-4f81-8c22-31ab21e30e5c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "342"}],
  SequenceForm["n=", 342],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946395027*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"136d2cc8-5089-4ff1-ad7e-9eda7bc04bfc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "343"}],
  SequenceForm["n=", 343],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946396558*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8befae4a-cc30-4002-8c5d-1a1356a3bcb3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "344"}],
  SequenceForm["n=", 344],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946398094*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2b324eba-a7bf-46cc-991f-f033e3dd2fb8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "344", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "b"}], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "c"}], "+", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "b"}], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "c"}], "-", 
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "2"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 344, 
   "   ", {$CellContext`a^2 - 
    2 $CellContext`a $CellContext`b + $CellContext`b^2 - 
    2 $CellContext`a $CellContext`c + $CellContext`c^2, $CellContext`a^2 - 
    2 $CellContext`a $CellContext`b + $CellContext`b^2 - 
    2 $CellContext`b $CellContext`c + $CellContext`c^2, $CellContext`a^2 + \
$CellContext`b^2 - 2 $CellContext`a $CellContext`c - 
    2 $CellContext`b $CellContext`c + $CellContext`c^2}, "   XM/AM=", 
   Style[
    Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946399797*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f0786ab4-6bc6-4469-9272-f901c207d345"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "345"}],
  SequenceForm["n=", 345],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946401444*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"200772f6-ff0a-4222-a0d3-b4ff3bec6c8c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "346"}],
  SequenceForm["n=", 346],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979464029913`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f5f82b55-4d84-4f25-bc50-ec660607e331"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "346", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], "2"]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"7", "-", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 346, 
   "   ", {($CellContext`a - $CellContext`b - $CellContext`c)^2, \
(-$CellContext`a + $CellContext`b - $CellContext`c)^2, (-$CellContext`a - \
$CellContext`b + $CellContext`c)^2}, "   XM/AM=", 
   Style[Rational[1, 17] (7 - 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979464086246`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3ccb8b41-1453-4104-8033-0d3e34094ed6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "347"}],
  SequenceForm["n=", 347],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946411027*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"85ee4f42-233b-43fa-b9ed-b61f36deaf1c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "347", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 347, 
   "   ", {($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a - \
$CellContext`b + $CellContext`c) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), ($CellContext`a + $CellContext`b - \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c) \
(-$CellContext`a^3 - $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), ($CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c) \
(-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 - $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979464132357`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6e88506b-2627-4554-9e06-d04d71ddd992"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "348"}],
  SequenceForm["n=", 348],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946415372*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"91102656-c8b1-4c93-be21-2534ba7752c6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "349"}],
  SequenceForm["n=", 349],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946416901*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d67c1764-24ef-46c2-a1bc-fa220f44fd40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "349", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 349, 
   "   ", {$CellContext`b^2 (-$CellContext`a + $CellContext`b - \
$CellContext`c) $CellContext`c^2 (-$CellContext`a - $CellContext`b + \
$CellContext`c) ($CellContext`b + $CellContext`c), $CellContext`a^2 \
($CellContext`a - $CellContext`b - $CellContext`c) $CellContext`c^2 \
($CellContext`a + $CellContext`c) (-$CellContext`a - $CellContext`b + \
$CellContext`c), $CellContext`a^2 $CellContext`b^2 ($CellContext`a + \
$CellContext`b) ($CellContext`a - $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b - $CellContext`c)}, "   XM/AM=", 
   Style[
    Rational[1, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979464186783`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1e8d510c-7765-41d7-b94f-3032aa9f59f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "350"}],
  SequenceForm["n=", 350],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946420348*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"35298271-b006-4747-af1a-1e10c7f3b1fa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "350", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"a", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"a", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "3"}], "-", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 350, 
   "   ", {$CellContext`b $CellContext`c (-$CellContext`a^2 + $CellContext`b \
$CellContext`c), $CellContext`a $CellContext`c (-$CellContext`b^2 + \
$CellContext`a $CellContext`c), $CellContext`a $CellContext`b ($CellContext`a \
$CellContext`b - $CellContext`c^2)}, "   XM/AM=", 
   Style[-3 - 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946422144*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f9b978a9-8a8f-4638-aaa0-db4b518de0ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "351"}],
  SequenceForm["n=", 351],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946423933*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"711664fe-d192-484b-9484-e1899fa787b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "352"}],
  SequenceForm["n=", 352],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946425461*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"12d19f96-cf6f-4e21-a44d-8ad7e48140a1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "352", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox["5",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 352, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     4 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     4 $CellContext`a^2 $CellContext`c^2 + 
     5 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`b^2 ($CellContext`a^4 - 
     4 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     5 $CellContext`a^2 $CellContext`c^2 - 
     4 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`c^2 ($CellContext`a^4 + 
     5 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     4 $CellContext`a^2 $CellContext`c^2 - 
     4 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[5, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946427812*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e50c0145-5de5-4ac7-8c35-c01915f64efc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "353"}],
  SequenceForm["n=", 353],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946429791*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"743a6701-a767-40c5-beb1-dec05032617c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "353", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "5"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 353, 
   "   ", {$CellContext`a^2 (4 $CellContext`a^4 - 
     4 $CellContext`a^2 $CellContext`b^2 - 2 $CellContext`b^4 - 
     4 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`c^4), $CellContext`b^2 ((-2) $CellContext`a^4 - 
     4 $CellContext`a^2 $CellContext`b^2 + 
     4 $CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 - 
     4 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`c^4), $CellContext`c^2 ((-2) $CellContext`a^4 - \
$CellContext`a^2 $CellContext`b^2 - 2 $CellContext`b^4 - 
     4 $CellContext`a^2 $CellContext`c^2 - 
     4 $CellContext`b^2 $CellContext`c^2 + 4 $CellContext`c^4)}, "   XM/AM=", 
   
   Style[
    Rational[1, 5], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946431786*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bf7fb261-ab63-45de-ab84-0a984efb1485"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "354"}],
  SequenceForm["n=", 354],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946434025*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b2b4cace-4500-438c-afb5-25e2f1455c98"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "354", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SqrtBox["2"], "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 354, 
   "   ", {$CellContext`a ($CellContext`a $CellContext`b - $CellContext`b^2 + \
$CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c - $CellContext`c^2), $CellContext`b \
(-$CellContext`a^2 + $CellContext`a $CellContext`b + 
     2 $CellContext`a $CellContext`c + $CellContext`b $CellContext`c - \
$CellContext`c^2), $CellContext`c (-$CellContext`a^2 + 
     2 $CellContext`a $CellContext`b - $CellContext`b^2 + $CellContext`a \
$CellContext`c + $CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 3] 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979464359837`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e8191bcc-7dfd-4809-aa88-23abd585e47b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "355"}],
  SequenceForm["n=", 355],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979464379797`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d059878d-dcbe-414f-b4bc-ded5a3ccccfc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "355", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"2", "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 355, 
   "   ", {$CellContext`a^4 - $CellContext`a^3 $CellContext`b + \
$CellContext`a $CellContext`b^3 - $CellContext`b^4 - $CellContext`a^3 \
$CellContext`c + 
    2 $CellContext`a^2 $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`b \
$CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`a $CellContext`c^3 - \
$CellContext`c^4, -$CellContext`a^4 + $CellContext`a^3 $CellContext`b - \
$CellContext`a $CellContext`b^3 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`b $CellContext`c + 
    2 $CellContext`a $CellContext`b^2 $CellContext`c - $CellContext`b^3 \
$CellContext`c + 
    2 $CellContext`a^2 $CellContext`c^2 - $CellContext`a $CellContext`b \
$CellContext`c^2 + $CellContext`b $CellContext`c^3 - $CellContext`c^4, \
-$CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + $CellContext`a^3 \
$CellContext`c - $CellContext`a^2 $CellContext`b $CellContext`c - \
$CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c + 
    2 $CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`a \
$CellContext`c^3 - $CellContext`b $CellContext`c^3 + $CellContext`c^4}, 
   "   XM/AM=", 
   Style[2 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979464402122`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"06c3e5b4-50bf-4801-ae80-a64df6d95f5d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "356"}],
  SequenceForm["n=", 356],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979464422607`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9e313773-5336-40e2-80c0-8bae51e3d7cc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "357"}],
  SequenceForm["n=", 357],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794644378*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c3c98a3a-a83c-4f0e-a91c-39ee65805d13"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "358"}],
  SequenceForm["n=", 358],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946445266*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4e12f0d7-ae1c-4e32-b6f7-29152bd5c99e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "359"}],
  SequenceForm["n=", 359],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946446673*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2e9a0de8-ebbe-44fc-bb1a-8fe90e329faf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "360"}],
  SequenceForm["n=", 360],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946448114*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"833ccdd4-0d41-408a-a6f4-fecab933296e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "361"}],
  SequenceForm["n=", 361],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946449828*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"eca3b39a-525f-4c83-b80e-15d90f9d7534"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "362"}],
  SequenceForm["n=", 362],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946570858*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b6cc92dd-a541-4f20-940d-ac58aabddef3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "363"}],
  SequenceForm["n=", 363],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097946704278*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8a1c2bc4-f9b4-469b-99ed-12f7ad1d754c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "364"}],
  SequenceForm["n=", 364],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979472226057`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"abacd4a6-272f-47bd-937f-143f835ec790"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "364", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SqrtBox["a"]}], "+", 
        SqrtBox["b"], "+", 
        SqrtBox["c"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox["a"], "-", 
        SqrtBox["b"], "+", 
        SqrtBox["c"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SqrtBox["a"], "+", 
        SqrtBox["b"], "-", 
        SqrtBox["c"]}], ")"}], " ", "c"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{
      SuperscriptBox["2", 
       RowBox[{"1", "/", "4"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SuperscriptBox["2", 
         RowBox[{"1", "/", "4"}]]}], ")"}]}], 
     RowBox[{
      RowBox[{"-", "2"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["2", 
        RowBox[{"1", "/", "4"}]]}], "+", 
      SqrtBox["2"]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 364, 
   "   ", {$CellContext`a (-$CellContext`a^Rational[1, 2] + $CellContext`b^
      Rational[1, 2] + $CellContext`c^
      Rational[1, 2]), $CellContext`b ($CellContext`a^
      Rational[1, 2] - $CellContext`b^
     Rational[1, 2] + $CellContext`c^Rational[1, 2]), ($CellContext`a^
      Rational[1, 2] + $CellContext`b^Rational[1, 2] - $CellContext`c^
     Rational[1, 2]) $CellContext`c}, "   XM/AM=", 
   Style[2^Rational[1, 4] (-2 + 2^Rational[1, 4])/(-2 - 2 2^Rational[1, 4] + 
    2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947257201*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4310e430-c02e-4fe2-adcc-191f298b94db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "365"}],
  SequenceForm["n=", 365],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947259941*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f4ec6a96-4ac4-40e6-8116-4d49d6e7eda1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "365", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["a", 
      RowBox[{"3", "/", "2"}]], ",", 
     SuperscriptBox["b", 
      RowBox[{"3", "/", "2"}]], ",", 
     SuperscriptBox["c", 
      RowBox[{"3", "/", "2"}]]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SuperscriptBox["2", 
      RowBox[{"3", "/", "4"}]], 
     RowBox[{"2", "+", 
      SuperscriptBox["2", 
       RowBox[{"3", "/", "4"}]]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 365, 
   "   ", {$CellContext`a^Rational[3, 2], $CellContext`b^
    Rational[3, 2], $CellContext`c^Rational[3, 2]}, "   XM/AM=", 
   Style[2^Rational[3, 4]/(2 + 2^Rational[3, 4]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979472619047`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"acb934f5-34d6-4e61-b70c-f12a8d3823a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "366"}],
  SequenceForm["n=", 366],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794726375*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"54711fa2-2418-45d3-ab56-a915fac780a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "366", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox["a"], ",", 
     SqrtBox["b"], ",", 
     SqrtBox["c"]}], "}"}], "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", 
   "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SuperscriptBox["2", 
      RowBox[{"1", "/", "4"}]], 
     RowBox[{"2", "+", 
      SuperscriptBox["2", 
       RowBox[{"1", "/", "4"}]]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 366, 
   "   ", {$CellContext`a^Rational[1, 2], $CellContext`b^
    Rational[1, 2], $CellContext`c^Rational[1, 2]}, "   XM/AM=", 
   Style[2^Rational[1, 4]/(2 + 2^Rational[1, 4]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947265415*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1153d3b5-801f-47a6-8ac1-20e61d607b92"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "367"}],
  SequenceForm["n=", 367],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947267138*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f7d3d7e0-2412-4345-b984-7a85e0325d26"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "367", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox["b"], "+", 
        SqrtBox["c"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox["a"], "+", 
        SqrtBox["c"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SqrtBox["a"], "+", 
        SqrtBox["b"]}], ")"}], " ", "c"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SqrtBox["2"], 
     RowBox[{"1", "+", 
      SuperscriptBox["2", 
       RowBox[{"1", "/", "4"}]], "+", 
      SqrtBox["2"]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 367, 
   "   ", {$CellContext`a ($CellContext`b^Rational[1, 2] + $CellContext`c^
      Rational[1, 2]), $CellContext`b ($CellContext`a^
      Rational[1, 2] + $CellContext`c^Rational[1, 2]), ($CellContext`a^
      Rational[1, 2] + $CellContext`b^Rational[1, 2]) $CellContext`c}, 
   "   XM/AM=", 
   Style[2^Rational[1, 2]/(1 + 2^Rational[1, 4] + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979472690268`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e87efdb4-f155-44ec-943f-1c1bb06b4e14"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "368"}],
  SequenceForm["n=", 368],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947271121*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"de1ec8a5-6f4a-4c1f-8ef1-055762f990c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "369"}],
  SequenceForm["n=", 369],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947272663*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"07455f57-3256-43cf-b2df-a4b362d35c00"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "370"}],
  SequenceForm["n=", 370],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947274269*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cac155bf-7415-4004-9fd8-566c3a966fad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "371"}],
  SequenceForm["n=", 371],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979472757263`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3c4d3976-757d-4ba3-a808-fb541a7d0f32"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "372"}],
  SequenceForm["n=", 372],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947311165*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"56d841cf-fa46-45c6-a3ee-65246cad5c87"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "373"}],
  SequenceForm["n=", 373],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947357332*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1af26fb4-efbb-428d-93ed-9f4f4f752ddc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "373", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["4", "9"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 373, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + 
     6 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), \
$CellContext`b^2 (-$CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 + 
     6 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - \
$CellContext`c^4), $CellContext`c^2 (-$CellContext`a^4 + 
     6 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[
    Rational[4, 9], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979473599777`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"92d5f925-d1ba-4ef0-afc0-4219591b64d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "374"}],
  SequenceForm["n=", 374],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947362656*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e15a597f-39b0-478c-bef4-9180393c5b21"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "374", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"5", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"5", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"6", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"5", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"5", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"6", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "21"], " ", 
     RowBox[{"(", 
      RowBox[{"10", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 374, 
   "   ", {$CellContext`a ($CellContext`a^3 $CellContext`b + $CellContext`a^2 \
$CellContext`b^2 - $CellContext`a $CellContext`b^3 - $CellContext`b^4 + \
$CellContext`a^3 $CellContext`c - 
     6 $CellContext`a^2 $CellContext`b $CellContext`c + 
     5 $CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`a^2 \
$CellContext`c^2 + 5 $CellContext`a $CellContext`b $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`a $CellContext`c^3 - \
$CellContext`c^4), $CellContext`b (-$CellContext`a^4 - $CellContext`a^3 \
$CellContext`b + $CellContext`a^2 $CellContext`b^2 + $CellContext`a \
$CellContext`b^3 + 5 $CellContext`a^2 $CellContext`b $CellContext`c - 
     6 $CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c + 2 $CellContext`a^2 $CellContext`c^2 + 
     5 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 - $CellContext`b $CellContext`c^3 - $CellContext`c^4), \
$CellContext`c (-$CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - \
$CellContext`a^3 $CellContext`c + 
     5 $CellContext`a^2 $CellContext`b $CellContext`c + 
     5 $CellContext`a $CellContext`b^2 $CellContext`c - $CellContext`b^3 \
$CellContext`c + $CellContext`a^2 $CellContext`c^2 - 
     6 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`a $CellContext`c^3 + $CellContext`b \
$CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 21] (10 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794736539*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"989f5572-1fb5-4507-846f-c52b532ec269"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "375"}],
  SequenceForm["n=", 375],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979473680058`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a81e9ec3-d5d5-4605-ab9f-52bcc40e7525"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "375", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "6"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 375, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 - $CellContext`a $CellContext`b^2 $CellContext`c + \
$CellContext`b^3 $CellContext`c + $CellContext`a^2 $CellContext`c^2 - \
$CellContext`a $CellContext`b $CellContext`c^2 + 
     4 $CellContext`b^2 $CellContext`c^2 + $CellContext`b $CellContext`c^3 - \
$CellContext`c^4), $CellContext`b^2 (-$CellContext`a^4 + $CellContext`a^2 \
$CellContext`b^2 + $CellContext`a^3 $CellContext`c - $CellContext`a^2 \
$CellContext`b $CellContext`c + 
     4 $CellContext`a^2 $CellContext`c^2 - $CellContext`a $CellContext`b \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 + $CellContext`a \
$CellContext`c^3 - $CellContext`c^4), $CellContext`c^2 (-$CellContext`a^4 + \
$CellContext`a^3 $CellContext`b + 
     4 $CellContext`a^2 $CellContext`b^2 + $CellContext`a $CellContext`b^3 - \
$CellContext`b^4 - $CellContext`a^2 $CellContext`b $CellContext`c - \
$CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`a^2 \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 6] (4 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947370229*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"66cf2b21-b800-4d6a-8a87-bed6c541bdba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "376"}],
  SequenceForm["n=", 376],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979473725557`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0564c2a9-5fcb-40c2-bf65-da3cc8486ea8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "376", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"5", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", "3"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 376, "   ", {
   5 $CellContext`a^4 - 
    4 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
    4 $CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 - 
    4 $CellContext`a^2 $CellContext`b^2 + 5 $CellContext`b^4 + 
    2 $CellContext`a^2 $CellContext`c^2 - 
    4 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
    4 $CellContext`a^2 $CellContext`c^2 - 4 $CellContext`b^2 $CellContext`c^2 + 
    5 $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[-1, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947375183*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f1c537c3-ec4e-4f09-ae06-7c1c376fd050"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "377"}],
  SequenceForm["n=", 377],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947377151*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"82577192-0dd1-4302-9173-b3aba932e69e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "377", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 377, 
   "   ", {$CellContext`a^4 - $CellContext`b^4 + 
    2 $CellContext`a^2 $CellContext`b $CellContext`c + 
    2 $CellContext`a $CellContext`b^2 $CellContext`c + 
    2 $CellContext`a $CellContext`b $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 + \
$CellContext`b^4 + 2 $CellContext`a^2 $CellContext`b $CellContext`c + 
    2 $CellContext`a $CellContext`b^2 $CellContext`c + 
    2 $CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`c^4, \
-$CellContext`a^4 + 2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + 
    2 $CellContext`a^2 $CellContext`b $CellContext`c + 
    2 $CellContext`a $CellContext`b^2 $CellContext`c + 
    2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`c^4}, 
   "   XM/AM=", 
   Style[-1 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947379396*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2e0c50f4-0a86-43ac-abe9-2b6bd03ff768"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "378"}],
  SequenceForm["n=", 378],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979473813477`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"58faae6e-c3e9-4757-a521-bca7a4530511"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "379"}],
  SequenceForm["n=", 379],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947382823*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a4578020-2612-4e79-af48-db2293109445"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "379", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "5"], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "4"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "4"]}], " ", "b"}], "+", 
      SuperscriptBox["b", "5"], "-", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "4"]}], " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "4"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "5"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 379, 
   "   ", {$CellContext`a^5 - $CellContext`a $CellContext`b^4 + \
$CellContext`a^2 $CellContext`b^2 $CellContext`c - $CellContext`b^4 \
$CellContext`c + $CellContext`a^2 $CellContext`b $CellContext`c^2 + 
    2 $CellContext`a $CellContext`b^2 $CellContext`c^2 + $CellContext`b^3 \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^3 - $CellContext`a \
$CellContext`c^4 - $CellContext`b $CellContext`c^4, -$CellContext`a^4 \
$CellContext`b + $CellContext`b^5 - $CellContext`a^4 $CellContext`c + \
$CellContext`a^2 $CellContext`b^2 $CellContext`c + $CellContext`a^3 \
$CellContext`c^2 + 
    2 $CellContext`a^2 $CellContext`b $CellContext`c^2 + $CellContext`a \
$CellContext`b^2 $CellContext`c^2 + $CellContext`a^2 $CellContext`c^3 - \
$CellContext`a $CellContext`c^4 - $CellContext`b $CellContext`c^4, \
-$CellContext`a^4 $CellContext`b + $CellContext`a^3 $CellContext`b^2 + \
$CellContext`a^2 $CellContext`b^3 - $CellContext`a $CellContext`b^4 - \
$CellContext`a^4 $CellContext`c + 
    2 $CellContext`a^2 $CellContext`b^2 $CellContext`c - $CellContext`b^4 \
$CellContext`c + $CellContext`a^2 $CellContext`b $CellContext`c^2 + \
$CellContext`a $CellContext`b^2 $CellContext`c^2 + $CellContext`c^5}, 
   "   XM/AM=", 
   Style[Rational[1, 7] (3 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947418853*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"852df1ac-0e87-46cd-92a6-cb6d944defef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "380"}],
  SequenceForm["n=", 380],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979474221983`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ed72ccf3-0f1a-49ef-bed1-c7757b44f844"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "380", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "5"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 380, 
   "   ", {$CellContext`a ($CellContext`a - $CellContext`b - $CellContext`c) (
     3 $CellContext`a^3 + 
     3 $CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + 3 $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`b (-$CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b + 3 $CellContext`a $CellContext`b^2 + 
     3 $CellContext`b^3 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + 
     3 $CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2 + $CellContext`c^3), $CellContext`c \
(-$CellContext`a - $CellContext`b + $CellContext`c) ($CellContext`a^3 - \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + 3 $CellContext`a $CellContext`c^2 + 
     3 $CellContext`b $CellContext`c^2 + 3 $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 5] (3 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794742502*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4856b7c1-c2f7-4a4f-a84d-6168ea54440f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "381"}],
  SequenceForm["n=", 381],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947427664*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"282bd872-7e22-4c67-a11d-1bd94429735c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "381", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 381, 
   "   ", {$CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 - 
    2 $CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + 
    4 $CellContext`b^2 $CellContext`c^2 - 
    2 $CellContext`c^4, (-2) $CellContext`a^4 + $CellContext`a^2 \
$CellContext`b^2 + $CellContext`b^4 + 
    4 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - 
    2 $CellContext`c^4, (-2) $CellContext`a^4 + 
    4 $CellContext`a^2 $CellContext`b^2 - 
    2 $CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[2, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794743019*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c507bfed-d1a0-40a2-87f9-98dd23552624"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "382"}],
  SequenceForm["n=", 382],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947432666*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a0c76553-aa77-4ce7-b996-b6bbb67d8c6f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "382", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox["2",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 382, "   ", {
   3 $CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - 
    2 $CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 + 
    4 $CellContext`b^2 $CellContext`c^2 - 
    2 $CellContext`c^4, (-2) $CellContext`a^4 - $CellContext`a^2 \
$CellContext`b^2 + 3 $CellContext`b^4 + 
    4 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 - 
    2 $CellContext`c^4, (-2) $CellContext`a^4 + 
    4 $CellContext`a^2 $CellContext`b^2 - 
    2 $CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2 + 3 $CellContext`c^4}, "   XM/AM=", 
   Style[2, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947435072*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2986bb61-9fb3-4185-b264-cd6f51e0fd44"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "383"}],
  SequenceForm["n=", 383],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794743758*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"03708aba-a52b-4507-8af9-657ce36cd211"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "384"}],
  SequenceForm["n=", 384],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979475135813`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cb69ed1a-fbe5-48f2-98cd-7c3fccd6010d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "384", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["5", "11"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 384, 
   "   ", {$CellContext`a^4 + $CellContext`b^2 $CellContext`c^2, \
$CellContext`b^4 + $CellContext`a^2 $CellContext`c^2, $CellContext`a^2 \
$CellContext`b^2 + $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[5, 11], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947516182*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ba65284b-06d6-47b7-9925-7bc6e7b69a93"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "385"}],
  SequenceForm["n=", 385],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947518111*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f0a7cb4a-1480-44cf-9db1-4f7567cfd3ae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "385", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox["3",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 385, 
   "   ", {($CellContext`a^2 - $CellContext`b $CellContext`c) \
($CellContext`a^2 + $CellContext`b $CellContext`c), ($CellContext`b^2 - \
$CellContext`a $CellContext`c) ($CellContext`b^2 + $CellContext`a \
$CellContext`c), (-$CellContext`a $CellContext`b + $CellContext`c^2) \
($CellContext`a $CellContext`b + $CellContext`c^2)}, "   XM/AM=", 
   Style[3, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947519959*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"66f0d1f6-b143-4c35-91bb-c512482115fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "386"}],
  SequenceForm["n=", 386],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979475216837`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4f49452b-a81c-4ba7-bfe8-3557452550ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "386", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 386, 
   "   ", {$CellContext`a^2 ($CellContext`a $CellContext`b + $CellContext`b^2 + \
$CellContext`a $CellContext`c + $CellContext`b $CellContext`c + \
$CellContext`c^2), $CellContext`b^2 ($CellContext`a^2 + $CellContext`a \
$CellContext`b + $CellContext`a $CellContext`c + $CellContext`b \
$CellContext`c + $CellContext`c^2), $CellContext`c^2 ($CellContext`a^2 + \
$CellContext`a $CellContext`b + $CellContext`b^2 + $CellContext`a \
$CellContext`c + $CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 17] (5 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947555459*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fdbf56e5-affe-48d3-ad75-146439dc3f72"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "387"}],
  SequenceForm["n=", 387],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947557906*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"457e004b-f8d9-4b26-bd25-10a3dc223bb9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "387", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"4", " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"9", "-", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 387, 
   "   ", {$CellContext`a^4 + 4 $CellContext`a^3 $CellContext`b + 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
    4 $CellContext`a^3 $CellContext`c + 
    4 $CellContext`a^2 $CellContext`b $CellContext`c + 
    2 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 + 
    4 $CellContext`a $CellContext`b^3 + $CellContext`b^4 + 
    4 $CellContext`a $CellContext`b^2 $CellContext`c + 
    4 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
    2 $CellContext`a^2 $CellContext`c^2 + 
    4 $CellContext`a $CellContext`b $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 + 4 $CellContext`a $CellContext`c^3 + 
    4 $CellContext`b $CellContext`c^3 + $CellContext`c^4}, "   XM/AM=", 
   Style[Rational[1, 7] (9 - 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794756017*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"640e2324-fc0e-49cb-9a7d-90193d0dc74d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "388"}],
  SequenceForm["n=", 388],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794756319*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"38bb1e0a-4f52-482a-a488-59104d6818f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "388", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"9", "-", 
     RowBox[{"6", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 388, 
   "   ", {($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a - \
$CellContext`b + $CellContext`c) ($CellContext`a^2 + $CellContext`b^2 + 
     2 $CellContext`b $CellContext`c + $CellContext`c^2), ($CellContext`a + \
$CellContext`b - $CellContext`c) (-$CellContext`a + $CellContext`b + \
$CellContext`c) ($CellContext`a^2 + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + $CellContext`c^2), ($CellContext`a - \
$CellContext`b + $CellContext`c) (-$CellContext`a + $CellContext`b + \
$CellContext`c) ($CellContext`a^2 + 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[9 - 6 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947565344*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c62e9387-ebb5-4859-b9bc-897d89797be7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "389"}],
  SequenceForm["n=", 389],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947567329*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fba7e480-14e6-4a6f-b220-9bd6b1c1b8fd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "389", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        SuperscriptBox["b", "8"], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "8"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "8"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        SuperscriptBox["b", "8"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "2"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 389, 
   "   ", {$CellContext`a^2 ($CellContext`a^6 $CellContext`b^2 - 
     3 $CellContext`a^4 $CellContext`b^4 + 
     3 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + \
$CellContext`a^6 $CellContext`c^2 - 
     3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + 
     2 $CellContext`b^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     2 $CellContext`b^4 $CellContext`c^4 + 
     3 $CellContext`a^2 $CellContext`c^6 + 
     2 $CellContext`b^2 $CellContext`c^6 - $CellContext`c^8), \
$CellContext`b^2 (-$CellContext`a^8 + 3 $CellContext`a^6 $CellContext`b^2 - 
     3 $CellContext`a^4 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^6 + 
     2 $CellContext`a^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + $CellContext`b^6 \
$CellContext`c^2 - 2 $CellContext`a^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     3 $CellContext`b^4 $CellContext`c^4 + 
     2 $CellContext`a^2 $CellContext`c^6 + 
     3 $CellContext`b^2 $CellContext`c^6 - $CellContext`c^8), \
$CellContext`c^2 (-$CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
     2 $CellContext`a^4 $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + 
     3 $CellContext`a^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + 
     3 $CellContext`b^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`c^4 - 
     3 $CellContext`b^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^6 + \
$CellContext`b^2 $CellContext`c^6)}, "   XM/AM=", 
   Style[
    Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794756988*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"60e9ac99-afec-4910-8d89-5c04bd3c1360"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "390"}],
  SequenceForm["n=", 390],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979475722322`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f4181851-f83f-4f9d-afe4-0fe24b6b38dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "390", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["3", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "5"}], "+", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 390, 
   "   ", {($CellContext`a - $CellContext`b - $CellContext`c) (
     3 $CellContext`a^2 + $CellContext`b^2 - 
     2 $CellContext`b $CellContext`c + $CellContext`c^2), (-$CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a^2 + 3 $CellContext`b^2 - 
     2 $CellContext`a $CellContext`c + $CellContext`c^2), (-$CellContext`a - \
$CellContext`b + $CellContext`c) ($CellContext`a^2 - 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 + 
     3 $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[3, 7] (-5 + 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947606835*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"33913b52-f74d-4126-9133-7949ff34a4a7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "391"}],
  SequenceForm["n=", 391],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947609424*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5d9de8d8-a74d-4a4a-b6ba-8ff6c09735d2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "391", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", 
        RowBox[{"3", " ", "b"}], "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", 
        RowBox[{"3", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "71"], " ", 
     RowBox[{"(", 
      RowBox[{"25", "-", 
       RowBox[{"8", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 391, 
   "   ", {($CellContext`a - $CellContext`b - $CellContext`c) (
     3 $CellContext`a + $CellContext`b + $CellContext`c), (-$CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a + 
     3 $CellContext`b + $CellContext`c), (-$CellContext`a - $CellContext`b + \
$CellContext`c) ($CellContext`a + $CellContext`b + 3 $CellContext`c)}, 
   "   XM/AM=", 
   Style[Rational[1, 71] (25 - 8 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947612302*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ea51ee15-84c4-482a-b2d4-f1fa4a1d8a20"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "392"}],
  SequenceForm["n=", 392],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794761465*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3bd0794f-0e0f-4920-a869-5929a7f25dfb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "392", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"4", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"4", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"4", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["2", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 392, 
   "   ", {$CellContext`a ($CellContext`a^2 $CellContext`b - $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c - 
     4 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`b $CellContext`c^2 - $CellContext`c^3), \
$CellContext`b (-$CellContext`a^3 + $CellContext`a $CellContext`b^2 - \
$CellContext`a^2 $CellContext`c - 
     4 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`c^3), \
$CellContext`c (-$CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 - 
     4 $CellContext`a $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`c^2 + $CellContext`b $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[2, 3] (-1 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947617066*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bc8631a8-4608-4a58-8f1f-0b3095d6dff8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "393"}],
  SequenceForm["n=", 393],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794761944*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d08ae32e-000b-4a3d-a32f-7e52c6b42964"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "394"}],
  SequenceForm["n=", 394],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947621029*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6e2fdf2b-6f91-456a-ad4e-5bea08a833a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "395"}],
  SequenceForm["n=", 395],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947622623*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2b81729e-8d46-4a89-9468-0dac5322f938"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "396"}],
  SequenceForm["n=", 396],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947656581*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0ea7c4f8-6a35-442a-8529-5f3c29176219"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "397"}],
  SequenceForm["n=", 397],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979476633177`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"70bacb4f-0925-4d8b-ab07-fa2c3c1e1331"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "398"}],
  SequenceForm["n=", 398],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947701837*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"19f8cb38-6c91-4171-a906-baf208d33f9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "399"}],
  SequenceForm["n=", 399],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947740571*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9963af1d-73b3-4201-9540-19232caed409"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "399", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox["2",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 399, 
   "   ", {$CellContext`a^2 ($CellContext`a^8 - 
     4 $CellContext`a^6 $CellContext`b^2 + 
     6 $CellContext`a^4 $CellContext`b^4 - 
     4 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 - 
     4 $CellContext`a^6 $CellContext`c^2 + $CellContext`a^4 $CellContext`b^2 \
$CellContext`c^2 + $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + 
     2 $CellContext`b^6 $CellContext`c^2 + 
     6 $CellContext`a^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^4 - 6 $CellContext`b^4 $CellContext`c^4 - 
     4 $CellContext`a^2 $CellContext`c^6 + 
     2 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8), \
$CellContext`b^2 ($CellContext`a^8 - 4 $CellContext`a^6 $CellContext`b^2 + 
     6 $CellContext`a^4 $CellContext`b^4 - 
     4 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 + 
     2 $CellContext`a^6 $CellContext`c^2 + $CellContext`a^4 $CellContext`b^2 \
$CellContext`c^2 + $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
     4 $CellContext`b^6 $CellContext`c^2 - 
     6 $CellContext`a^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^4 + 6 $CellContext`b^4 $CellContext`c^4 + 
     2 $CellContext`a^2 $CellContext`c^6 - 
     4 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8), \
$CellContext`c^2 ($CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
     6 $CellContext`a^4 $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 - 
     4 $CellContext`a^6 $CellContext`c^2 + $CellContext`a^4 $CellContext`b^2 \
$CellContext`c^2 + $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
     4 $CellContext`b^6 $CellContext`c^2 + 
     6 $CellContext`a^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^4 + 6 $CellContext`b^4 $CellContext`c^4 - 
     4 $CellContext`a^2 $CellContext`c^6 - 
     4 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8)}, "   XM/AM=", 
   Style[2, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947744405*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c093c7b0-ece9-4323-9bf0-e0887a1e20f3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "400"}],
  SequenceForm["n=", 400],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947747634*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"548f8bc3-2cb5-4ee9-9693-8916c092bff5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "401"}],
  SequenceForm["n=", 401],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947843334*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"343495f9-4bd3-4ffd-b9f3-376a62e6b74b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "401", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "8"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "+", 
      SuperscriptBox["b", "8"], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      SuperscriptBox["c", "8"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 401, 
   "   ", {$CellContext`a^8 - 
    2 $CellContext`a^6 $CellContext`b^2 + $CellContext`a^4 $CellContext`b^4 - 
    2 $CellContext`a^6 $CellContext`c^2 + $CellContext`a^4 $CellContext`b^2 \
$CellContext`c^2 + $CellContext`b^6 $CellContext`c^2 + $CellContext`a^4 \
$CellContext`c^4 - 
    2 $CellContext`b^4 $CellContext`c^4 + $CellContext`b^2 $CellContext`c^6, \
$CellContext`a^4 $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 + $CellContext`a^6 \
$CellContext`c^2 + $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
    2 $CellContext`b^6 $CellContext`c^2 - 
    2 $CellContext`a^4 $CellContext`c^4 + $CellContext`b^4 $CellContext`c^4 + \
$CellContext`a^2 $CellContext`c^6, $CellContext`a^6 $CellContext`b^2 - 
    2 $CellContext`a^4 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^6 + \
$CellContext`a^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^4 + $CellContext`b^4 $CellContext`c^4 - 
    2 $CellContext`a^2 $CellContext`c^6 - 
    2 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979478464108`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d160f047-c09c-4b8e-92dc-51b6759eb672"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "402"}],
  SequenceForm["n=", 402],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947848958*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9e115fdc-cbf0-4fda-927e-a91b5309d164"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "402", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "8"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "8"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        SuperscriptBox["b", "8"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"5", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 402, 
   "   ", {(2 $CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 - $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4) \
($CellContext`a^8 - $CellContext`a^6 $CellContext`b^2 - 
     2 $CellContext`a^4 $CellContext`b^4 + 
     3 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 - \
$CellContext`a^6 $CellContext`c^2 + 
     5 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - $CellContext`b^6 \
$CellContext`c^2 - 2 $CellContext`a^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     4 $CellContext`b^4 $CellContext`c^4 + 
     3 $CellContext`a^2 $CellContext`c^6 - $CellContext`b^2 $CellContext`c^6 - \
$CellContext`c^8), (-$CellContext`a^4 - $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 - \
$CellContext`c^4) (-$CellContext`a^8 + 3 $CellContext`a^6 $CellContext`b^2 - 
     2 $CellContext`a^4 $CellContext`b^4 - $CellContext`a^2 $CellContext`b^6 + \
$CellContext`b^8 - $CellContext`a^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
     5 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - $CellContext`b^6 \
$CellContext`c^2 + 4 $CellContext`a^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     2 $CellContext`b^4 $CellContext`c^4 - $CellContext`a^2 $CellContext`c^6 + 
     3 $CellContext`b^2 $CellContext`c^6 - $CellContext`c^8), \
(-$CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`c^4) (-$CellContext`a^8 - $CellContext`a^6 \
$CellContext`b^2 + 
     4 $CellContext`a^4 $CellContext`b^4 - $CellContext`a^2 $CellContext`b^6 - \
$CellContext`b^8 + 3 $CellContext`a^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + 
     3 $CellContext`b^6 $CellContext`c^2 - 
     2 $CellContext`a^4 $CellContext`c^4 + 
     5 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     2 $CellContext`b^4 $CellContext`c^4 - $CellContext`a^2 $CellContext`c^6 - \
$CellContext`b^2 $CellContext`c^6 + $CellContext`c^8)}, "   XM/AM=", 
   Style[
    Rational[1, 2], 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947852083*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1d8c05c9-40c2-4ceb-bcb2-52c9cc67aac0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "403"}],
  SequenceForm["n=", 403],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947854854*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e7fa5279-80cb-45d4-9c9e-d9789e92b0a7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "404"}],
  SequenceForm["n=", 404],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947856386*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b1fa26f3-f860-4736-a0dd-498b2f30bbe8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "404", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 404, 
   "   ", {$CellContext`a ($CellContext`a^3 - $CellContext`a $CellContext`b^2 + \
$CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2), $CellContext`b (-$CellContext`a^2 $CellContext`b + \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c + $CellContext`a \
$CellContext`b $CellContext`c + $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2), $CellContext`c ($CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 - $CellContext`a^2 \
$CellContext`c + $CellContext`a $CellContext`b $CellContext`c - \
$CellContext`b^2 $CellContext`c + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 17] (5 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979478622923`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"38ab70e5-dfb9-4a92-bf52-318a6377779f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "405"}],
  SequenceForm["n=", 405],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947864821*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d8554b17-a576-45ec-82e4-785ef19d2dba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "405", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "-", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 405, 
   "   ", {$CellContext`a ($CellContext`a^3 - $CellContext`a $CellContext`b^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c - 
     2 $CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - 
     2 $CellContext`b $CellContext`c^2), $CellContext`b (-$CellContext`a^2 \
$CellContext`b + $CellContext`b^3 - 2 $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2), \
$CellContext`c ((-2) $CellContext`a^2 $CellContext`b - 
     2 $CellContext`a $CellContext`b^2 - $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`c^3)}, "   XM/AM=", 
   Style[1 - 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979478989077`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"768c5223-45c6-4ffc-a93f-44e5800c5187"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "406"}],
  SequenceForm["n=", 406],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979479018583`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"303376d0-0c94-4a90-84a5-f6494041f0e4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "407"}],
  SequenceForm["n=", 407],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947903438*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3f20aa39-5803-47ab-8df1-03079fc574ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "408"}],
  SequenceForm["n=", 408],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979479052763`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2df795f1-f6b3-43aa-b7c7-c041e4bdb07c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "409"}],
  SequenceForm["n=", 409],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947907125*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8bd46c4d-9a72-45d9-8b09-b104f4c395dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "409", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["5", 
     RowBox[{"5", "+", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 409, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c) ($CellContext`a^4 - $CellContext`a^3 $CellContext`b + \
$CellContext`a $CellContext`b^3 - $CellContext`b^4 - $CellContext`a^3 \
$CellContext`c + $CellContext`a^2 $CellContext`b $CellContext`c + \
$CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c + $CellContext`a $CellContext`b $CellContext`c^2 + 
     4 $CellContext`b^2 $CellContext`c^2 + $CellContext`a $CellContext`c^3 + \
$CellContext`b $CellContext`c^3 - $CellContext`c^4), $CellContext`b \
($CellContext`a + $CellContext`b) ($CellContext`b + $CellContext`c) \
(-$CellContext`a^4 + $CellContext`a^3 $CellContext`b - $CellContext`a \
$CellContext`b^3 + $CellContext`b^4 + $CellContext`a^3 $CellContext`c + \
$CellContext`a^2 $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`b^2 $CellContext`c - $CellContext`b^3 $CellContext`c + 
     4 $CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 + $CellContext`a $CellContext`c^3 + $CellContext`b \
$CellContext`c^3 - $CellContext`c^4), $CellContext`c ($CellContext`a + \
$CellContext`c) ($CellContext`b + $CellContext`c) (-$CellContext`a^4 + \
$CellContext`a^3 $CellContext`b + 
     4 $CellContext`a^2 $CellContext`b^2 + $CellContext`a $CellContext`b^3 - \
$CellContext`b^4 + $CellContext`a^3 $CellContext`c + $CellContext`a^2 \
$CellContext`b $CellContext`c + $CellContext`a $CellContext`b^2 \
$CellContext`c + $CellContext`b^3 $CellContext`c + $CellContext`a \
$CellContext`b $CellContext`c^2 - $CellContext`a $CellContext`c^3 - \
$CellContext`b $CellContext`c^3 + $CellContext`c^4)}, "   XM/AM=", 
   Style[5/(5 + 6 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794790956*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e0f8aacd-3191-4a3e-bc97-b52d1c53a9ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "410"}],
  SequenceForm["n=", 410],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979479121447`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"02583476-ed68-4370-8702-5818d318451d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "411"}],
  SequenceForm["n=", 411],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947913926*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ba2cfc0a-4207-4220-a958-2802d5556ef4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "411", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "5"]}], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "+", 
        SuperscriptBox["b", "6"], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 411, 
   "   ", {$CellContext`a ($CellContext`a^6 - $CellContext`a^5 $CellContext`b - 
     2 $CellContext`a^4 $CellContext`b^2 + 
     2 $CellContext`a^3 $CellContext`b^3 + $CellContext`a^2 $CellContext`b^4 - \
$CellContext`a $CellContext`b^5 - $CellContext`a^5 $CellContext`c - \
$CellContext`a^4 $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`b^4 $CellContext`c + $CellContext`b^5 $CellContext`c - 
     2 $CellContext`a^4 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a^3 $CellContext`c^3 - 
     2 $CellContext`b^3 $CellContext`c^3 + $CellContext`a^2 $CellContext`c^4 + \
$CellContext`a $CellContext`b $CellContext`c^4 - $CellContext`a \
$CellContext`c^5 + $CellContext`b $CellContext`c^5), $CellContext`b \
(-$CellContext`a^5 $CellContext`b + $CellContext`a^4 $CellContext`b^2 + 
     2 $CellContext`a^3 $CellContext`b^3 - 
     2 $CellContext`a^2 $CellContext`b^4 - $CellContext`a $CellContext`b^5 + \
$CellContext`b^6 + $CellContext`a^5 $CellContext`c + $CellContext`a^4 \
$CellContext`b $CellContext`c - $CellContext`a $CellContext`b^4 \
$CellContext`c - $CellContext`b^5 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^4 $CellContext`c^2 - 
     2 $CellContext`a^3 $CellContext`c^3 + 
     2 $CellContext`b^3 $CellContext`c^3 + $CellContext`a $CellContext`b \
$CellContext`c^4 + $CellContext`b^2 $CellContext`c^4 + $CellContext`a \
$CellContext`c^5 - $CellContext`b $CellContext`c^5), $CellContext`c \
($CellContext`a^5 $CellContext`b - 
     2 $CellContext`a^3 $CellContext`b^3 + $CellContext`a $CellContext`b^5 - \
$CellContext`a^5 $CellContext`c + $CellContext`a^4 $CellContext`b \
$CellContext`c + $CellContext`a $CellContext`b^4 $CellContext`c - \
$CellContext`b^5 $CellContext`c + $CellContext`a^4 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + $CellContext`b^4 \
$CellContext`c^2 + 2 $CellContext`a^3 $CellContext`c^3 + 
     2 $CellContext`b^3 $CellContext`c^3 - 
     2 $CellContext`a^2 $CellContext`c^4 - $CellContext`a $CellContext`b \
$CellContext`c^4 - 
     2 $CellContext`b^2 $CellContext`c^4 - $CellContext`a $CellContext`c^5 - \
$CellContext`b $CellContext`c^5 + $CellContext`c^6)}, "   XM/AM=", 
   Style[Rational[1, 7] (-1 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947949677*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d2a28b65-d104-4e09-bd68-d2b3f19954f2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "412"}],
  SequenceForm["n=", 412],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979479534492`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3a751576-a046-4406-b7ae-23e9981a7070"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "413"}],
  SequenceForm["n=", 413],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947955278*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0e98a75b-ec10-45a9-8cfa-c39b0c794065"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "413", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "c"}], ")"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], "3"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "71"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"6", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 413, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`a - \
$CellContext`b - $CellContext`c)^3 ($CellContext`a + $CellContext`c) \
($CellContext`a^4 + $CellContext`a^3 $CellContext`b + $CellContext`a \
$CellContext`b^3 + $CellContext`b^4 + $CellContext`a^3 $CellContext`c + \
$CellContext`a^2 $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`b^2 $CellContext`c - $CellContext`b^3 $CellContext`c - \
$CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`a \
$CellContext`c^3 - $CellContext`b $CellContext`c^3 + $CellContext`c^4), \
$CellContext`b ($CellContext`a + $CellContext`b) (-$CellContext`a + \
$CellContext`b - $CellContext`c)^3 ($CellContext`b + $CellContext`c) \
($CellContext`a^4 + $CellContext`a^3 $CellContext`b + $CellContext`a \
$CellContext`b^3 + $CellContext`b^4 - $CellContext`a^3 $CellContext`c - \
$CellContext`a^2 $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`b^2 $CellContext`c + $CellContext`b^3 $CellContext`c - \
$CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`a \
$CellContext`c^3 + $CellContext`b $CellContext`c^3 + $CellContext`c^4), \
$CellContext`c ($CellContext`a + $CellContext`c) (-$CellContext`a - \
$CellContext`b + $CellContext`c)^3 ($CellContext`b + $CellContext`c) \
($CellContext`a^4 - $CellContext`a^3 $CellContext`b - $CellContext`a \
$CellContext`b^3 + $CellContext`b^4 + $CellContext`a^3 $CellContext`c - \
$CellContext`a^2 $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`b^2 $CellContext`c + $CellContext`b^3 $CellContext`c + \
$CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`a \
$CellContext`c^3 + $CellContext`b $CellContext`c^3 + $CellContext`c^4)}, 
   "   XM/AM=", 
   Style[Rational[1, 71] (-1 + 6 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947958117*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1cc9cade-0616-4d2f-b4d4-061f3688332d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "414"}],
  SequenceForm["n=", 414],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947960485*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7adbd482-3cc1-466f-a125-b7806ac5711b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "415"}],
  SequenceForm["n=", 415],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947993387*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5bfc1737-bbce-4c44-b33c-56141865dcae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "416"}],
  SequenceForm["n=", 416],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097947996237*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"626f7442-c4b2-4678-9777-cdf489b62d40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "416", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "7"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "5"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "7"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "7"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b", " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "7"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "7"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "7"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "7"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "5"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "7"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "7"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b", " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "7"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "7"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "7"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "5"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "7"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "7"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b", " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "7"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "7"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 416, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c) ($CellContext`a^7 $CellContext`b^2 - $CellContext`a^6 \
$CellContext`b^3 - 2 $CellContext`a^5 $CellContext`b^4 + 
     2 $CellContext`a^4 $CellContext`b^5 + $CellContext`a^3 $CellContext`b^6 - \
$CellContext`a^2 $CellContext`b^7 + $CellContext`a^7 $CellContext`b \
$CellContext`c - $CellContext`a^6 $CellContext`b^2 $CellContext`c - \
$CellContext`a^5 $CellContext`b^3 $CellContext`c + 
     2 $CellContext`a^4 $CellContext`b^4 $CellContext`c - $CellContext`a^3 \
$CellContext`b^5 $CellContext`c - $CellContext`a^2 $CellContext`b^6 \
$CellContext`c + $CellContext`a $CellContext`b^7 $CellContext`c + \
$CellContext`a^7 $CellContext`c^2 - $CellContext`a^6 $CellContext`b \
$CellContext`c^2 + $CellContext`a^5 $CellContext`b^2 $CellContext`c^2 - \
$CellContext`a^4 $CellContext`b^3 $CellContext`c^2 - $CellContext`a^3 \
$CellContext`b^4 $CellContext`c^2 + $CellContext`a^2 $CellContext`b^5 \
$CellContext`c^2 - $CellContext`a $CellContext`b^6 $CellContext`c^2 + \
$CellContext`b^7 $CellContext`c^2 - $CellContext`a^6 $CellContext`c^3 - \
$CellContext`a^5 $CellContext`b $CellContext`c^3 - $CellContext`a^4 \
$CellContext`b^2 $CellContext`c^3 + 
     2 $CellContext`a^3 $CellContext`b^3 $CellContext`c^3 + $CellContext`a^2 \
$CellContext`b^4 $CellContext`c^3 - $CellContext`a $CellContext`b^5 \
$CellContext`c^3 + $CellContext`b^6 $CellContext`c^3 - 
     2 $CellContext`a^5 $CellContext`c^4 + 
     2 $CellContext`a^4 $CellContext`b $CellContext`c^4 - $CellContext`a^3 \
$CellContext`b^2 $CellContext`c^4 + $CellContext`a^2 $CellContext`b^3 \
$CellContext`c^4 + 2 $CellContext`a $CellContext`b^4 $CellContext`c^4 - 
     2 $CellContext`b^5 $CellContext`c^4 + 
     2 $CellContext`a^4 $CellContext`c^5 - $CellContext`a^3 $CellContext`b \
$CellContext`c^5 + $CellContext`a^2 $CellContext`b^2 $CellContext`c^5 - \
$CellContext`a $CellContext`b^3 $CellContext`c^5 - 
     2 $CellContext`b^4 $CellContext`c^5 + $CellContext`a^3 $CellContext`c^6 - \
$CellContext`a^2 $CellContext`b $CellContext`c^6 - $CellContext`a \
$CellContext`b^2 $CellContext`c^6 + $CellContext`b^3 $CellContext`c^6 - \
$CellContext`a^2 $CellContext`c^7 + $CellContext`a $CellContext`b \
$CellContext`c^7 + $CellContext`b^2 $CellContext`c^7), $CellContext`b \
($CellContext`a + $CellContext`b) ($CellContext`b + $CellContext`c) \
(-$CellContext`a^7 $CellContext`b^2 + $CellContext`a^6 $CellContext`b^3 + 
     2 $CellContext`a^5 $CellContext`b^4 - 
     2 $CellContext`a^4 $CellContext`b^5 - $CellContext`a^3 $CellContext`b^6 + \
$CellContext`a^2 $CellContext`b^7 + $CellContext`a^7 $CellContext`b \
$CellContext`c - $CellContext`a^6 $CellContext`b^2 $CellContext`c - \
$CellContext`a^5 $CellContext`b^3 $CellContext`c + 
     2 $CellContext`a^4 $CellContext`b^4 $CellContext`c - $CellContext`a^3 \
$CellContext`b^5 $CellContext`c - $CellContext`a^2 $CellContext`b^6 \
$CellContext`c + $CellContext`a $CellContext`b^7 $CellContext`c + \
$CellContext`a^7 $CellContext`c^2 - $CellContext`a^6 $CellContext`b \
$CellContext`c^2 + $CellContext`a^5 $CellContext`b^2 $CellContext`c^2 - \
$CellContext`a^4 $CellContext`b^3 $CellContext`c^2 - $CellContext`a^3 \
$CellContext`b^4 $CellContext`c^2 + $CellContext`a^2 $CellContext`b^5 \
$CellContext`c^2 - $CellContext`a $CellContext`b^6 $CellContext`c^2 + \
$CellContext`b^7 $CellContext`c^2 + $CellContext`a^6 $CellContext`c^3 - \
$CellContext`a^5 $CellContext`b $CellContext`c^3 + $CellContext`a^4 \
$CellContext`b^2 $CellContext`c^3 + 
     2 $CellContext`a^3 $CellContext`b^3 $CellContext`c^3 - $CellContext`a^2 \
$CellContext`b^4 $CellContext`c^3 - $CellContext`a $CellContext`b^5 \
$CellContext`c^3 - $CellContext`b^6 $CellContext`c^3 - 
     2 $CellContext`a^5 $CellContext`c^4 + 
     2 $CellContext`a^4 $CellContext`b $CellContext`c^4 + $CellContext`a^3 \
$CellContext`b^2 $CellContext`c^4 - $CellContext`a^2 $CellContext`b^3 \
$CellContext`c^4 + 2 $CellContext`a $CellContext`b^4 $CellContext`c^4 - 
     2 $CellContext`b^5 $CellContext`c^4 - 
     2 $CellContext`a^4 $CellContext`c^5 - $CellContext`a^3 $CellContext`b \
$CellContext`c^5 + $CellContext`a^2 $CellContext`b^2 $CellContext`c^5 - \
$CellContext`a $CellContext`b^3 $CellContext`c^5 + 
     2 $CellContext`b^4 $CellContext`c^5 + $CellContext`a^3 $CellContext`c^6 - \
$CellContext`a^2 $CellContext`b $CellContext`c^6 - $CellContext`a \
$CellContext`b^2 $CellContext`c^6 + $CellContext`b^3 $CellContext`c^6 + \
$CellContext`a^2 $CellContext`c^7 + $CellContext`a $CellContext`b \
$CellContext`c^7 - $CellContext`b^2 $CellContext`c^7), $CellContext`c \
($CellContext`a + $CellContext`c) ($CellContext`b + $CellContext`c) \
($CellContext`a^7 $CellContext`b^2 + $CellContext`a^6 $CellContext`b^3 - 
     2 $CellContext`a^5 $CellContext`b^4 - 
     2 $CellContext`a^4 $CellContext`b^5 + $CellContext`a^3 $CellContext`b^6 + \
$CellContext`a^2 $CellContext`b^7 + $CellContext`a^7 $CellContext`b \
$CellContext`c - $CellContext`a^6 $CellContext`b^2 $CellContext`c - \
$CellContext`a^5 $CellContext`b^3 $CellContext`c + 
     2 $CellContext`a^4 $CellContext`b^4 $CellContext`c - $CellContext`a^3 \
$CellContext`b^5 $CellContext`c - $CellContext`a^2 $CellContext`b^6 \
$CellContext`c + $CellContext`a $CellContext`b^7 $CellContext`c - \
$CellContext`a^7 $CellContext`c^2 - $CellContext`a^6 $CellContext`b \
$CellContext`c^2 + $CellContext`a^5 $CellContext`b^2 $CellContext`c^2 + \
$CellContext`a^4 $CellContext`b^3 $CellContext`c^2 + $CellContext`a^3 \
$CellContext`b^4 $CellContext`c^2 + $CellContext`a^2 $CellContext`b^5 \
$CellContext`c^2 - $CellContext`a $CellContext`b^6 $CellContext`c^2 - \
$CellContext`b^7 $CellContext`c^2 + $CellContext`a^6 $CellContext`c^3 - \
$CellContext`a^5 $CellContext`b $CellContext`c^3 - $CellContext`a^4 \
$CellContext`b^2 $CellContext`c^3 + 
     2 $CellContext`a^3 $CellContext`b^3 $CellContext`c^3 - $CellContext`a^2 \
$CellContext`b^4 $CellContext`c^3 - $CellContext`a $CellContext`b^5 \
$CellContext`c^3 + $CellContext`b^6 $CellContext`c^3 + 
     2 $CellContext`a^5 $CellContext`c^4 + 
     2 $CellContext`a^4 $CellContext`b $CellContext`c^4 - $CellContext`a^3 \
$CellContext`b^2 $CellContext`c^4 - $CellContext`a^2 $CellContext`b^3 \
$CellContext`c^4 + 2 $CellContext`a $CellContext`b^4 $CellContext`c^4 + 
     2 $CellContext`b^5 $CellContext`c^4 - 
     2 $CellContext`a^4 $CellContext`c^5 - $CellContext`a^3 $CellContext`b \
$CellContext`c^5 + $CellContext`a^2 $CellContext`b^2 $CellContext`c^5 - \
$CellContext`a $CellContext`b^3 $CellContext`c^5 - 
     2 $CellContext`b^4 $CellContext`c^5 - $CellContext`a^3 $CellContext`c^6 - \
$CellContext`a^2 $CellContext`b $CellContext`c^6 - $CellContext`a \
$CellContext`b^2 $CellContext`c^6 - $CellContext`b^3 $CellContext`c^6 + \
$CellContext`a^2 $CellContext`c^7 + $CellContext`a $CellContext`b \
$CellContext`c^7 + $CellContext`b^2 $CellContext`c^7)}, "   XM/AM=", 
   Style[Rational[1, 7] (-1 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948002046*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3d02df3f-aecd-4875-a239-bb0cb5e4a5eb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "417"}],
  SequenceForm["n=", 417],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948007391*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"90040bcd-3d6a-4438-a3cd-195800636edf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "418"}],
  SequenceForm["n=", 418],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794800937*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"47abaa87-f607-4d31-913c-90b586bc2b06"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "419"}],
  SequenceForm["n=", 419],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979480110826`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"36ddd082-62e9-492a-b402-5cc2bda8c58e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "420"}],
  SequenceForm["n=", 420],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948012732*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"41a56a8b-8607-469c-8b1a-b26dff7a51bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "421"}],
  SequenceForm["n=", 421],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979480143127`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"abfcacf6-ac22-4772-80f6-727a13df5185"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "422"}],
  SequenceForm["n=", 422],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794801591*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"68a78233-15a2-49ae-8101-0c814d209b81"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "423"}],
  SequenceForm["n=", 423],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948017577*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"45e1991f-0fce-4584-bf65-02ea4b4eb98a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "424"}],
  SequenceForm["n=", 424],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948022645*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9b962e57-6bd7-4687-b3cc-66abf9502f39"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "425"}],
  SequenceForm["n=", 425],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948024951*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"811b9404-6f1a-4e10-b3c3-3513528026cd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "426"}],
  SequenceForm["n=", 426],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794805858*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"482c75ab-4e9b-4f14-89f1-2bbd5ae5a8b8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "427"}],
  SequenceForm["n=", 427],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948061082*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fc914689-165f-4bbc-b7a6-4adf4eff4dec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "428"}],
  SequenceForm["n=", 428],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948063291*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ee2ee484-7996-46e7-836d-3813927e34e2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "429"}],
  SequenceForm["n=", 429],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948065105*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"082569cc-7223-4d7d-8c9f-492aaa60fb52"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "430"}],
  SequenceForm["n=", 430],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948066886*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"56cec37a-103c-4f96-88cc-5232851dab93"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "431"}],
  SequenceForm["n=", 431],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948068758*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1522dcfe-d0c4-4252-abf6-53809073b2dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "432"}],
  SequenceForm["n=", 432],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948070752*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"71ee3204-e0a2-4def-b908-bd936bd00c04"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "433"}],
  SequenceForm["n=", 433],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948072377*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5054f1f8-1c89-4d4f-a534-259a393afe36"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "434"}],
  SequenceForm["n=", 434],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794807415*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3ce4610a-2e33-4fc3-ae3a-a7ea838c8a86"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "435"}],
  SequenceForm["n=", 435],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948075918*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"51538395-6ca2-49e0-a508-778155782260"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "436"}],
  SequenceForm["n=", 436],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948081149*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ff62cd7e-7c28-4b46-9baf-4b13b1405dfa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "437"}],
  SequenceForm["n=", 437],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979481149197`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"53ecd7a9-a9c1-46c1-bd64-c46cd82bf6b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "438"}],
  SequenceForm["n=", 438],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948117497*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"356ab676-1fe3-4b95-af76-21cabea21d14"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "439"}],
  SequenceForm["n=", 439],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948119759*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6cd01530-8e14-482b-8a0d-9bbec09d4fb9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "440"}],
  SequenceForm["n=", 440],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794812143*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"be2c47f8-27d0-4901-937b-c9b7b165d009"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "441"}],
  SequenceForm["n=", 441],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794812304*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0b426bea-9951-4339-b78a-2a73831d1c21"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "442"}],
  SequenceForm["n=", 442],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948124754*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"98d663c6-f9ff-4297-9a2e-b69f5f7edd46"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "442", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", 
     RowBox[{"4", "+", 
      SqrtBox["2"]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 442, 
   "   ", {($CellContext`b + $CellContext`c) (-$CellContext`a^2 \
$CellContext`b + $CellContext`b^3 - $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`b $CellContext`c^2 + $CellContext`c^3), \
($CellContext`a + $CellContext`c) ($CellContext`a^3 - $CellContext`a \
$CellContext`b^2 - $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3), \
($CellContext`a + $CellContext`b) ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2)}, "   XM/AM=", 
   Style[2/(4 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948126883*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"72932a66-e5f9-4b55-ae12-db8fbd37eeba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "443"}],
  SequenceForm["n=", 443],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979481294518`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4ef4d903-917d-4402-b13f-b76f498563cf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "443", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "23"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 443, 
   "   ", {$CellContext`a^4 - $CellContext`b^4 + 
    4 $CellContext`a^2 $CellContext`b $CellContext`c + 
    4 $CellContext`a $CellContext`b^2 $CellContext`c + 
    4 $CellContext`a $CellContext`b $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 + \
$CellContext`b^4 + 4 $CellContext`a^2 $CellContext`b $CellContext`c + 
    4 $CellContext`a $CellContext`b^2 $CellContext`c + 
    2 $CellContext`a^2 $CellContext`c^2 + 
    4 $CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`c^4, \
-$CellContext`a^4 + 2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + 
    4 $CellContext`a^2 $CellContext`b $CellContext`c + 
    4 $CellContext`a $CellContext`b^2 $CellContext`c + 
    4 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`c^4}, 
   "   XM/AM=", 
   Style[Rational[1, 23] (3 + 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948132043*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"36209484-9f98-4507-a0bc-5f309d75bd9c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "444"}],
  SequenceForm["n=", 444],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948134653*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3adfd37f-a796-4ace-a877-4623a9488946"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "445"}],
  SequenceForm["n=", 445],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794813649*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"722b695e-f1a3-4526-9a44-b45900d768f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "446"}],
  SequenceForm["n=", 446],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979481703997`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b2790862-a855-4cb9-a615-d4a2dac3b760"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "446", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "8"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "8"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "8"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "8"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "8"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "8"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "8"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "8"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "2"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 446, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 - $CellContext`c^4) \
($CellContext`a^8 $CellContext`b^2 - 
     2 $CellContext`a^6 $CellContext`b^4 + $CellContext`a^4 $CellContext`b^6 + \
$CellContext`a^8 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 + $CellContext`b^8 \
$CellContext`c^2 - 2 $CellContext`a^6 $CellContext`c^4 - 
     4 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 - $CellContext`b^6 \
$CellContext`c^4 + $CellContext`a^4 $CellContext`c^6 + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 - $CellContext`b^4 \
$CellContext`c^6 + $CellContext`b^2 $CellContext`c^8), $CellContext`b^2 \
(-$CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 + $CellContext`b^2 \
$CellContext`c^2 - $CellContext`c^4) ($CellContext`a^6 $CellContext`b^4 - 
     2 $CellContext`a^4 $CellContext`b^6 + $CellContext`a^2 $CellContext`b^8 + \
$CellContext`a^8 $CellContext`c^2 + 
     2 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 + $CellContext`b^8 \
$CellContext`c^2 - $CellContext`a^6 $CellContext`c^4 - 
     4 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 - 
     2 $CellContext`b^6 $CellContext`c^4 - $CellContext`a^4 $CellContext`c^6 + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 + $CellContext`b^4 \
$CellContext`c^6 + $CellContext`a^2 $CellContext`c^8), $CellContext`c^2 \
(-$CellContext`a^4 - $CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + \
$CellContext`b^2 $CellContext`c^2) ($CellContext`a^8 $CellContext`b^2 - \
$CellContext`a^6 $CellContext`b^4 - $CellContext`a^4 $CellContext`b^6 + \
$CellContext`a^2 $CellContext`b^8 + 
     2 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 - 
     4 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 + $CellContext`a^6 \
$CellContext`c^4 + $CellContext`b^6 $CellContext`c^4 - 
     2 $CellContext`a^4 $CellContext`c^6 - 
     2 $CellContext`b^4 $CellContext`c^6 + $CellContext`a^2 $CellContext`c^8 + \
$CellContext`b^2 $CellContext`c^8)}, "   XM/AM=", 
   Style[-2, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948173883*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"959f1c07-36dc-440f-8398-d7d6bf5a813a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "447"}],
  SequenceForm["n=", 447],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979481765137`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"96aca875-3b79-4b3d-8245-dd9ad512d5ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "448"}],
  SequenceForm["n=", 448],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948178569*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c2c17647-f705-45dd-bbe3-5b80bbe12113"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "448", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "+", 
        SuperscriptBox["b", "6"], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "3"}], "-", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 448, 
   "   ", {($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c) ($CellContext`a^6 - $CellContext`a^5 $CellContext`b - \
$CellContext`a^4 $CellContext`b^2 + $CellContext`a^3 $CellContext`b^3 - \
$CellContext`a^5 $CellContext`c - $CellContext`a^4 $CellContext`b \
$CellContext`c + $CellContext`a^3 $CellContext`b^2 $CellContext`c + \
$CellContext`b^5 $CellContext`c - $CellContext`a^4 $CellContext`c^2 + \
$CellContext`a^3 $CellContext`b $CellContext`c^2 + $CellContext`a^3 \
$CellContext`c^3 - 
     2 $CellContext`b^3 $CellContext`c^3 + $CellContext`b $CellContext`c^5), \
($CellContext`a + $CellContext`b) ($CellContext`b + $CellContext`c) \
($CellContext`a^3 $CellContext`b^3 - $CellContext`a^2 $CellContext`b^4 - \
$CellContext`a $CellContext`b^5 + $CellContext`b^6 + $CellContext`a^5 \
$CellContext`c + $CellContext`a^2 $CellContext`b^3 $CellContext`c - \
$CellContext`a $CellContext`b^4 $CellContext`c - $CellContext`b^5 \
$CellContext`c + $CellContext`a $CellContext`b^3 $CellContext`c^2 - \
$CellContext`b^4 $CellContext`c^2 - 
     2 $CellContext`a^3 $CellContext`c^3 + $CellContext`b^3 $CellContext`c^3 + \
$CellContext`a $CellContext`c^5), ($CellContext`a + $CellContext`c) \
($CellContext`b + $CellContext`c) ($CellContext`a^5 $CellContext`b - 
     2 $CellContext`a^3 $CellContext`b^3 + $CellContext`a $CellContext`b^5 + \
$CellContext`a^3 $CellContext`c^3 + $CellContext`a^2 $CellContext`b \
$CellContext`c^3 + $CellContext`a $CellContext`b^2 $CellContext`c^3 + \
$CellContext`b^3 $CellContext`c^3 - $CellContext`a^2 $CellContext`c^4 - \
$CellContext`a $CellContext`b $CellContext`c^4 - $CellContext`b^2 \
$CellContext`c^4 - $CellContext`a $CellContext`c^5 - $CellContext`b \
$CellContext`c^5 + $CellContext`c^6)}, "   XM/AM=", 
   Style[-3 - 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948181582*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"de5df6cc-e5b6-4d57-956a-1301dbb02d3d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "449"}],
  SequenceForm["n=", 449],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979481846323`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6ef7092c-2f52-4fdb-a120-545790f13722"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "449", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["a", "8"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "+", 
      SuperscriptBox["b", "8"], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "6"], " ", "b", " ", "c"}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "4"], " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "5"], " ", "c"}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "6"], " ", "c"}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "5"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"8", " ", "a", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"8", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "6"]}], "+", 
      SuperscriptBox["c", "8"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "8"], "-", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "6"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "8"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "6"], " ", "b", " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "4"], " ", "c"}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "5"], " ", "c"}], "-", 
      RowBox[{"8", " ", "a", " ", 
       SuperscriptBox["b", "6"], " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "5"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"8", " ", "a", " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "5"]}], "+", 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      SuperscriptBox["c", "8"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "8"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "4"]}], "+", 
      SuperscriptBox["b", "8"], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "6"], " ", "b", " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "5"], " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "4"], " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "5"], " ", "c"}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "6"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "5"], " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "5"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "6"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "4"], " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", "b", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "3"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      RowBox[{"8", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"8", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "5"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"8", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "6"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "6"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "8"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 449, "   ", {
   2 $CellContext`a^8 - 
    3 $CellContext`a^6 $CellContext`b^2 + $CellContext`a^4 $CellContext`b^4 - \
$CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 - 
    8 $CellContext`a^6 $CellContext`b $CellContext`c - 
    8 $CellContext`a^5 $CellContext`b^2 $CellContext`c + 
    4 $CellContext`a^4 $CellContext`b^3 $CellContext`c + 
    4 $CellContext`a^3 $CellContext`b^4 $CellContext`c + 
    4 $CellContext`a^2 $CellContext`b^5 $CellContext`c + 
    4 $CellContext`a $CellContext`b^6 $CellContext`c - 
    3 $CellContext`a^6 $CellContext`c^2 - 
    8 $CellContext`a^5 $CellContext`b $CellContext`c^2 + 
    2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
    4 $CellContext`a^3 $CellContext`b^3 $CellContext`c^2 + $CellContext`a^2 \
$CellContext`b^4 $CellContext`c^2 + 
    4 $CellContext`a $CellContext`b^5 $CellContext`c^2 + 
    4 $CellContext`a^4 $CellContext`b $CellContext`c^3 + 
    4 $CellContext`a^3 $CellContext`b^2 $CellContext`c^3 - 
    8 $CellContext`a^2 $CellContext`b^3 $CellContext`c^3 - 
    8 $CellContext`a $CellContext`b^4 $CellContext`c^3 + $CellContext`a^4 \
$CellContext`c^4 + 
    4 $CellContext`a^3 $CellContext`b $CellContext`c^4 + $CellContext`a^2 \
$CellContext`b^2 $CellContext`c^4 - 
    8 $CellContext`a $CellContext`b^3 $CellContext`c^4 - 
    2 $CellContext`b^4 $CellContext`c^4 + 
    4 $CellContext`a^2 $CellContext`b $CellContext`c^5 + 
    4 $CellContext`a $CellContext`b^2 $CellContext`c^5 - $CellContext`a^2 \
$CellContext`c^6 + 
    4 $CellContext`a $CellContext`b $CellContext`c^6 + $CellContext`c^8, \
$CellContext`a^8 - $CellContext`a^6 $CellContext`b^2 + $CellContext`a^4 \
$CellContext`b^4 - 3 $CellContext`a^2 $CellContext`b^6 + 2 $CellContext`b^8 + 
    4 $CellContext`a^6 $CellContext`b $CellContext`c + 
    4 $CellContext`a^5 $CellContext`b^2 $CellContext`c + 
    4 $CellContext`a^4 $CellContext`b^3 $CellContext`c + 
    4 $CellContext`a^3 $CellContext`b^4 $CellContext`c - 
    8 $CellContext`a^2 $CellContext`b^5 $CellContext`c - 
    8 $CellContext`a $CellContext`b^6 $CellContext`c + 
    4 $CellContext`a^5 $CellContext`b $CellContext`c^2 + $CellContext`a^4 \
$CellContext`b^2 $CellContext`c^2 + 
    4 $CellContext`a^3 $CellContext`b^3 $CellContext`c^2 + 
    2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
    8 $CellContext`a $CellContext`b^5 $CellContext`c^2 - 
    3 $CellContext`b^6 $CellContext`c^2 - 
    8 $CellContext`a^4 $CellContext`b $CellContext`c^3 - 
    8 $CellContext`a^3 $CellContext`b^2 $CellContext`c^3 + 
    4 $CellContext`a^2 $CellContext`b^3 $CellContext`c^3 + 
    4 $CellContext`a $CellContext`b^4 $CellContext`c^3 - 
    2 $CellContext`a^4 $CellContext`c^4 - 
    8 $CellContext`a^3 $CellContext`b $CellContext`c^4 + $CellContext`a^2 \
$CellContext`b^2 $CellContext`c^4 + 
    4 $CellContext`a $CellContext`b^3 $CellContext`c^4 + $CellContext`b^4 \
$CellContext`c^4 + 4 $CellContext`a^2 $CellContext`b $CellContext`c^5 + 
    4 $CellContext`a $CellContext`b^2 $CellContext`c^5 + 
    4 $CellContext`a $CellContext`b $CellContext`c^6 - $CellContext`b^2 \
$CellContext`c^6 + $CellContext`c^8, $CellContext`a^8 - 
    2 $CellContext`a^4 $CellContext`b^4 + $CellContext`b^8 + 
    4 $CellContext`a^6 $CellContext`b $CellContext`c + 
    4 $CellContext`a^5 $CellContext`b^2 $CellContext`c - 
    8 $CellContext`a^4 $CellContext`b^3 $CellContext`c - 
    8 $CellContext`a^3 $CellContext`b^4 $CellContext`c + 
    4 $CellContext`a^2 $CellContext`b^5 $CellContext`c + 
    4 $CellContext`a $CellContext`b^6 $CellContext`c - $CellContext`a^6 \
$CellContext`c^2 + 
    4 $CellContext`a^5 $CellContext`b $CellContext`c^2 + $CellContext`a^4 \
$CellContext`b^2 $CellContext`c^2 - 
    8 $CellContext`a^3 $CellContext`b^3 $CellContext`c^2 + $CellContext`a^2 \
$CellContext`b^4 $CellContext`c^2 + 
    4 $CellContext`a $CellContext`b^5 $CellContext`c^2 - $CellContext`b^6 \
$CellContext`c^2 + 4 $CellContext`a^4 $CellContext`b $CellContext`c^3 + 
    4 $CellContext`a^3 $CellContext`b^2 $CellContext`c^3 + 
    4 $CellContext`a^2 $CellContext`b^3 $CellContext`c^3 + 
    4 $CellContext`a $CellContext`b^4 $CellContext`c^3 + $CellContext`a^4 \
$CellContext`c^4 + 4 $CellContext`a^3 $CellContext`b $CellContext`c^4 + 
    2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
    4 $CellContext`a $CellContext`b^3 $CellContext`c^4 + $CellContext`b^4 \
$CellContext`c^4 - 8 $CellContext`a^2 $CellContext`b $CellContext`c^5 - 
    8 $CellContext`a $CellContext`b^2 $CellContext`c^5 - 
    3 $CellContext`a^2 $CellContext`c^6 - 
    8 $CellContext`a $CellContext`b $CellContext`c^6 - 
    3 $CellContext`b^2 $CellContext`c^6 + 2 $CellContext`c^8}, "   XM/AM=", 
   Style[(-2) (1 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948189148*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5b70b608-9fb5-4dcd-9cc0-8f28b96725fc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "450"}],
  SequenceForm["n=", 450],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948192864*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dea8441e-d0c7-4685-9891-24e35d891309"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "451"}],
  SequenceForm["n=", 451],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948194614*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"aa142e75-db34-49d7-8c0f-9332fafe9a61"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "452"}],
  SequenceForm["n=", 452],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948196271*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"20ff938a-2032-4e49-8b69-6633855d193e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "452", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "23"], " ", 
     RowBox[{"(", 
      RowBox[{"17", "-", 
       RowBox[{"8", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 452, 
   "   ", {($CellContext`a - $CellContext`b - $CellContext`c) (
     3 $CellContext`a^3 + 
     3 $CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + 3 $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), (-$CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a^3 + $CellContext`a^2 $CellContext`b + 
     3 $CellContext`a $CellContext`b^2 + 
     3 $CellContext`b^3 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + 
     3 $CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2 + $CellContext`c^3), (-$CellContext`a - \
$CellContext`b + $CellContext`c) ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + 3 $CellContext`a $CellContext`c^2 + 
     3 $CellContext`b $CellContext`c^2 + 3 $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 23] (17 - 8 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948235532*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f9378bfb-84d5-43ee-a8b5-b0fd8bb69c60"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "453"}],
  SequenceForm["n=", 453],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979482391777`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4c0484ad-b346-4f12-84ba-347530251d85"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "454"}],
  SequenceForm["n=", 454],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948241205*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e6eba598-53d2-45a5-9caa-369c98db8686"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "455"}],
  SequenceForm["n=", 455],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794824293*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6907c088-fdf7-4622-831d-f07fc8ce7922"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "456"}],
  SequenceForm["n=", 456],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979482448587`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ca353e45-ad10-4019-b535-9c408931528f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "457"}],
  SequenceForm["n=", 457],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979482471867`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a6588f0f-ffe4-421b-9224-3c944e22d7b1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "458"}],
  SequenceForm["n=", 458],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948249051*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"842fd434-354a-479b-9899-de46747ffa20"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "459"}],
  SequenceForm["n=", 459],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948250925*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c0b12e00-8aac-432a-b89f-2a52adbcecae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "460"}],
  SequenceForm["n=", 460],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948256349*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"76b8023f-6a27-4314-8ed1-d042ed1004cd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "461"}],
  SequenceForm["n=", 461],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948290477*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c240b152-b9ef-4d6f-bf20-1661f258e71b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "462"}],
  SequenceForm["n=", 462],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948293001*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1686a336-44d1-4bf4-80be-2608784beac9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "463"}],
  SequenceForm["n=", 463],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948326981*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"733b51ef-2644-4c05-b709-722361f3e50d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "464"}],
  SequenceForm["n=", 464],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948374339*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b522c68d-8eb1-4733-adef-b3cbde3ca9cd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "465"}],
  SequenceForm["n=", 465],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948381023*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"eec1f171-9a9f-461d-94ed-e237351c554d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "466"}],
  SequenceForm["n=", 466],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979484168*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1c3788db-46bb-4be9-a4ce-7624bdc93899"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "467"}],
  SequenceForm["n=", 467],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948457367*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3b64c30a-bafd-4868-9128-28f794b7b220"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "468"}],
  SequenceForm["n=", 468],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979484597187`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8193c190-b83e-485d-9f9a-69068d3f5119"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "469"}],
  SequenceForm["n=", 469],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979484614563`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dcab09b9-42bd-41d0-b41f-b62435d953e7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "470"}],
  SequenceForm["n=", 470],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979484635*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0726df0c-cfd3-49b4-92fe-f5e71410ee6c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "471"}],
  SequenceForm["n=", 471],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948497826*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d44f2a09-a805-4100-86f7-dcf1af858931"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "472"}],
  SequenceForm["n=", 472],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794853968*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"85c47776-443d-4150-b404-66b03f83cef6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "473"}],
  SequenceForm["n=", 473],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948580941*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"929d06f5-1a5a-43f2-a733-91dcbc626d49"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "474"}],
  SequenceForm["n=", 474],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948621009*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7f3f646f-b591-4dc9-9411-a8927a04b04e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "474", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "14"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 474, 
   "   ", {$CellContext`a ($CellContext`a^3 - $CellContext`a $CellContext`b^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c + 
     2 $CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 + 
     2 $CellContext`b $CellContext`c^2), $CellContext`b (-$CellContext`a^2 \
$CellContext`b + $CellContext`b^3 + 2 $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2), \
$CellContext`c (2 $CellContext`a^2 $CellContext`b + 
     2 $CellContext`a $CellContext`b^2 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 14] (4 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948656692*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5bd8c26c-f833-49c3-b8c6-bc7af3230f75"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "475"}],
  SequenceForm["n=", 475],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979486595993`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7676fc6f-65b0-4574-9e9c-0cc89d0c9cb6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "476"}],
  SequenceForm["n=", 476],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794866145*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"033ba943-92a3-43ef-afbd-f1dd77d7d852"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "477"}],
  SequenceForm["n=", 477],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948663493*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9f228a56-28de-40cb-b1b6-f2551c4d96c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "477", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "6"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "6"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 477, 
   "   ", {($CellContext`a^8 + $CellContext`a^6 $CellContext`b^2 - 
     4 $CellContext`a^4 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^6 + \
$CellContext`b^8 - 3 $CellContext`a^6 $CellContext`c^2 + 
     2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
     3 $CellContext`b^6 $CellContext`c^2 + 
     3 $CellContext`a^4 $CellContext`c^4 - 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     3 $CellContext`b^4 $CellContext`c^4 - $CellContext`a^2 $CellContext`c^6 - \
$CellContext`b^2 $CellContext`c^6) ($CellContext`a^8 - 
     3 $CellContext`a^6 $CellContext`b^2 + 
     3 $CellContext`a^4 $CellContext`b^4 - $CellContext`a^2 $CellContext`b^6 + \
$CellContext`a^6 $CellContext`c^2 + 
     2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - $CellContext`b^6 \
$CellContext`c^2 - 4 $CellContext`a^4 $CellContext`c^4 + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     3 $CellContext`b^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^6 - 
     3 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8), \
($CellContext`a^8 + $CellContext`a^6 $CellContext`b^2 - 
     4 $CellContext`a^4 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^6 + \
$CellContext`b^8 - 3 $CellContext`a^6 $CellContext`c^2 + 
     2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
     3 $CellContext`b^6 $CellContext`c^2 + 
     3 $CellContext`a^4 $CellContext`c^4 - 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     3 $CellContext`b^4 $CellContext`c^4 - $CellContext`a^2 $CellContext`c^6 - \
$CellContext`b^2 $CellContext`c^6) (-$CellContext`a^6 $CellContext`b^2 + 
     3 $CellContext`a^4 $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 - \
$CellContext`a^6 $CellContext`c^2 - 
     2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + $CellContext`b^6 \
$CellContext`c^2 + 3 $CellContext`a^4 $CellContext`c^4 + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     4 $CellContext`b^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`c^6 + $CellContext`b^2 $CellContext`c^6 + \
$CellContext`c^8), ($CellContext`a^8 - 3 $CellContext`a^6 $CellContext`b^2 + 
     3 $CellContext`a^4 $CellContext`b^4 - $CellContext`a^2 $CellContext`b^6 + \
$CellContext`a^6 $CellContext`c^2 + 
     2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - $CellContext`b^6 \
$CellContext`c^2 - 4 $CellContext`a^4 $CellContext`c^4 + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     3 $CellContext`b^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^6 - 
     3 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8) \
(-$CellContext`a^6 $CellContext`b^2 + 3 $CellContext`a^4 $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 - \
$CellContext`a^6 $CellContext`c^2 - 
     2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + $CellContext`b^6 \
$CellContext`c^2 + 3 $CellContext`a^4 $CellContext`c^4 + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     4 $CellContext`b^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`c^6 + $CellContext`b^2 $CellContext`c^6 + \
$CellContext`c^8)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948667388*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d7df4d52-a9ff-4b5b-bcc5-16937e0faa67"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "478"}],
  SequenceForm["n=", 478],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948670805*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5bcaf7c1-ced6-47d3-a867-613cc05ef788"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "478", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"2", "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 478, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a - $CellContext`b + $CellContext`c) \
($CellContext`a^4 - $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), \
$CellContext`b^2 ($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c) (-$CellContext`a^4 + \
$CellContext`b^4 - 2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`c^4), \
$CellContext`c^2 ($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c) (-$CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`c^4)}, 
   "   XM/AM=", 
   Style[2 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948673465*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1955eeae-09c1-4b2d-8876-b3dc56e3333d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "479"}],
  SequenceForm["n=", 479],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948675722*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f4ac3237-971c-4e71-aeba-98454fff0d9c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "479", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}], "3"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], "3"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], "3"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{
      RowBox[{"-", "13"}], "+", 
      RowBox[{"10", " ", 
       SqrtBox["2"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 479, 
   "   ", {($CellContext`a + $CellContext`b - $CellContext`c)^3 \
($CellContext`a - $CellContext`b + $CellContext`c)^3, ($CellContext`a + \
$CellContext`b - $CellContext`c)^3 (-$CellContext`a + $CellContext`b + \
$CellContext`c)^3, ($CellContext`a - $CellContext`b + $CellContext`c)^3 \
(-$CellContext`a + $CellContext`b + $CellContext`c)^3}, "   XM/AM=", 
   Style[(-13 + 10 2^Rational[1, 2])^(-1), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979486776533`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"67a83264-47b2-4b26-8bfa-796bb494ae64"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "480"}],
  SequenceForm["n=", 480],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979486795883`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"af02dabc-1b13-4c35-acfe-22c034481ddb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "480", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "c"}], ")"}], "3"]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], "3"]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], "3"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "14"], " ", 
     RowBox[{"(", 
      RowBox[{"8", "-", 
       RowBox[{"5", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 480, 
   "   ", {$CellContext`a^2 ($CellContext`a - $CellContext`b - \
$CellContext`c)^3, $CellContext`b^2 (-$CellContext`a + $CellContext`b - \
$CellContext`c)^3, $CellContext`c^2 (-$CellContext`a - $CellContext`b + \
$CellContext`c)^3}, "   XM/AM=", 
   Style[Rational[1, 14] (8 - 5 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948681444*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"38b16b0e-d19b-4a9b-be40-8c57b0735888"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "481"}],
  SequenceForm["n=", 481],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979486833067`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"46b42662-e566-4b65-bd69-dec904a20dc8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "482"}],
  SequenceForm["n=", 482],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979487265043`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d1f1f679-86c6-4cee-be45-ee34c3cacb2d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "483"}],
  SequenceForm["n=", 483],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948766398*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"54c9ae5f-c6ff-4500-8cfd-07b34cda8100"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "483", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SqrtBox["a"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"a", " ", "b"}]]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"a", " ", "c"}]]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], ",", 
     RowBox[{
      SqrtBox["b"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"a", " ", "b"}]]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"b", " ", "c"}]]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], ",", 
     RowBox[{
      SqrtBox["c"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"a", " ", "c"}]]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"b", " ", "c"}]]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox[
         RowBox[{"2", "+", 
          SqrtBox["2"]}]]}], ")"}]}], 
     RowBox[{"4", "+", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}], "+", 
      SqrtBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"2", "+", 
          SqrtBox["2"]}], ")"}]}]]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 483, 
   "   ", {$CellContext`a^Rational[1, 2] (
     2 ($CellContext`a $CellContext`b)^
       Rational[
        1, 2] + (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c))^Rational[1, 2]) (
     2 ($CellContext`a $CellContext`c)^
       Rational[
        1, 2] + (($CellContext`a - $CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[1, 2]), $CellContext`b^Rational[1, 2] (
     2 ($CellContext`a $CellContext`b)^
       Rational[
        1, 2] + (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c))^Rational[1, 2]) (
     2 ($CellContext`b $CellContext`c)^
       Rational[1, 2] + ((-$CellContext`a + $CellContext`b + $CellContext`c) (
        $CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[1, 2]), $CellContext`c^Rational[1, 2] (
     2 ($CellContext`a $CellContext`c)^
       Rational[
        1, 2] + (($CellContext`a - $CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c))^Rational[1, 2]) (
     2 ($CellContext`b $CellContext`c)^
       Rational[
        1, 2] + ((-$CellContext`a + $CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c))^Rational[1, 2])}, 
   "   XM/AM=", 
   Style[2^Rational[1, 2] (2 + (2 + 2^Rational[1, 2])^Rational[1, 2])/(4 + 
    4 2^Rational[1, 2] + (2 (2 + 2^Rational[1, 2]))^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948822989*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"06ba4fbf-99d4-4f8c-a3e4-bf03c8da9c89"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "484"}],
  SequenceForm["n=", 484],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948826318*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ab695660-2b9a-4b95-970c-5c62ae5c394a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "484", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"3", "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 484, 
   "   ", {$CellContext`a ($CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c + \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2 - $CellContext`c^3), $CellContext`b \
(-$CellContext`a^3 - $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 $CellContext`c - \
$CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), $CellContext`c (-$CellContext`a^3 + \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 - \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c - $CellContext`b^2 $CellContext`c + \
$CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2 + \
$CellContext`c^3)}, "   XM/AM=", 
   Style[3 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979488320093`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"05ffdcb2-236a-4911-928f-72ce48b3b2cf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "485"}],
  SequenceForm["n=", 485],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948835084*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bcc1a1ee-2dcd-4f1b-9101-4a1f925e7135"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "486"}],
  SequenceForm["n=", 486],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948868372*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ae0226d9-dc14-4dfe-8234-4c92e1da5013"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "487"}],
  SequenceForm["n=", 487],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948870708*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"810453d5-82c9-434f-81ef-005ce952346e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "488"}],
  SequenceForm["n=", 488],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948906041*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"79e8482f-0797-47ce-b229-793348899300"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "489"}],
  SequenceForm["n=", 489],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097948940813*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e8fde400-469b-47c6-a32e-5c2321dc911c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "490"}],
  SequenceForm["n=", 490],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794897724*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8c977514-052a-493b-8d9c-b03920186773"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "491"}],
  SequenceForm["n=", 491],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979490119467`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"88676a9e-5874-4455-b76d-26d805592aa5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "492"}],
  SequenceForm["n=", 492],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979490220337`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8fd824a7-47e7-4926-81ff-80edbd03e757"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "493"}],
  SequenceForm["n=", 493],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949057225*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b9dea47b-ec27-4afa-a684-f3957df68abd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "494"}],
  SequenceForm["n=", 494],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949092358*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e8460b9a-e9fa-4100-90da-3b762dd6d26f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "495"}],
  SequenceForm["n=", 495],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949127392*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dc33e0e0-11e7-497e-bed9-ff2124cbc531"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "495", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", 
     RowBox[{"4", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 495, 
   "   ", {-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    4 $CellContext`a^2 $CellContext`b $CellContext`c - $CellContext`a^2 \
$CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - \
$CellContext`a^2 $CellContext`b^2 - 
    4 $CellContext`a $CellContext`b^2 $CellContext`c - 
    2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4, $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 - 
    4 $CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2}, "   XM/AM=", 
   Style[3/(4 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949130498*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ae485af4-4515-4cf1-9110-12c2226e1b16"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "496"}],
  SequenceForm["n=", 496],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949132971*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2180fd0f-4726-41d2-90fe-a9d8532e29cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "496", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", "2"]}], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 496, 
   "   ", {-$CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
    4 $CellContext`a^2 $CellContext`b $CellContext`c - $CellContext`a^2 \
$CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - \
$CellContext`a^2 $CellContext`b^2 + 
    4 $CellContext`a $CellContext`b^2 $CellContext`c - 
    2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + \
$CellContext`c^4, $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - $CellContext`a^2 \
$CellContext`c^2 + 
    4 $CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2}, "   XM/AM=", 
   Style[Rational[1, 2] 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794913511*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c45b4bdb-7c86-4764-86c9-248fe3d95e74"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "497"}],
  SequenceForm["n=", 497],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979491374474`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d3c91ce7-0fbb-43d2-ae62-4b9c66f39e55"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "497", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 497, 
   "   ", {($CellContext`a - $CellContext`b - $CellContext`c) \
($CellContext`a^2 + $CellContext`b^2 - 
     2 $CellContext`b $CellContext`c + $CellContext`c^2), (-$CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a^2 + $CellContext`b^2 - 
     2 $CellContext`a $CellContext`c + $CellContext`c^2), (-$CellContext`a - \
$CellContext`b + $CellContext`c) ($CellContext`a^2 - 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[Rational[1, 7] (-1 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949143477*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3c3cc762-7f66-4fe9-ba5e-c3a107770372"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "498"}],
  SequenceForm["n=", 498],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949146603*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b783f8f2-8d49-4408-9861-4c4849a14e7f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "498", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 498, 
   "   ", {$CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`b $CellContext`c - 
    2 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    2 $CellContext`a $CellContext`b^2 $CellContext`c - 
    2 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`a $CellContext`b $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4}, "   XM/AM=", 
   Style[Rational[1, 7] (4 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949180204*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2c360002-b2bb-4d4f-9cc8-db90d839f8b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "499"}],
  SequenceForm["n=", 499],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949183099*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"30c4393c-4bfc-4106-ae10-6ef566584c1e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "500"}],
  SequenceForm["n=", 500],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949184732*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"234bdb2f-4453-4d26-9485-d5725919ad13"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "500", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "-", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 500, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`b $CellContext`c - $CellContext`c^2) ($CellContext`a^2 \
$CellContext`b - $CellContext`b^3 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`b $CellContext`c^2 - $CellContext`c^3), \
$CellContext`b^2 (-$CellContext`a^2 + $CellContext`b^2 - $CellContext`a \
$CellContext`c - $CellContext`c^2) (-$CellContext`a^3 + $CellContext`a \
$CellContext`b^2 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`c^3), \
$CellContext`c^2 (-$CellContext`a^2 - $CellContext`a $CellContext`b - \
$CellContext`b^2 + $CellContext`c^2) (-$CellContext`a^3 + $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 - $CellContext`b^3 + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`c^2 + $CellContext`b $CellContext`c^2)}, "   XM/AM=", 
   Style[1 - 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949186962*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2395c984-5005-4476-90ed-5d549761325a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "501"}],
  SequenceForm["n=", 501],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949189362*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f0d587f4-03f0-4432-990e-484b6115a285"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "501", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"3", "-", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 501, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c) ($CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c - \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2 - $CellContext`c^3), $CellContext`b^2 \
($CellContext`a + $CellContext`b) ($CellContext`b + $CellContext`c) \
(-$CellContext`a^3 - $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 $CellContext`c - \
$CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), $CellContext`c^2 ($CellContext`a + \
$CellContext`c) ($CellContext`b + $CellContext`c) (-$CellContext`a^3 - \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 - \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c - $CellContext`b^2 $CellContext`c + \
$CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2 + \
$CellContext`c^3)}, "   XM/AM=", 
   Style[3 - 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949191687*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1309fac4-8ded-44e8-a05c-3cd105f5a34d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "502"}],
  SequenceForm["n=", 502],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949194025*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b02b8981-8a8c-4f5c-88dd-23eb8dcabfaf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "502", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     SqrtBox["2"]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 502, 
   "   ", {($CellContext`b + $CellContext`c) (-$CellContext`a^3 - \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c + $CellContext`b^2 $CellContext`c - \
$CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2 - \
$CellContext`c^3) (-$CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c - \
$CellContext`b^2 $CellContext`c + $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2 + $CellContext`c^3), ($CellContext`a + \
$CellContext`c) ($CellContext`a^3 + $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c - \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2 - $CellContext`c^3) (-$CellContext`a^3 - \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 - \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c - $CellContext`b^2 $CellContext`c + \
$CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2 + \
$CellContext`c^3), ($CellContext`a + $CellContext`b) ($CellContext`a^3 + \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 - \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c - $CellContext`b^2 $CellContext`c - \
$CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2 - \
$CellContext`c^3) (-$CellContext`a^3 - $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c - $CellContext`a $CellContext`b $CellContext`c + \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2 - $CellContext`c^3)}, "   XM/AM=", 
   Style[2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949197008*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9e249b3f-5fa5-4200-85b5-6629c0c8cf91"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "503"}],
  SequenceForm["n=", 503],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979491996403`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dcaa9557-afe2-4cc3-9721-308a37d8abe8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "504"}],
  SequenceForm["n=", 504],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949402047*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ae7fcf9a-f3e0-43a3-95a3-63ff067844ef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "504", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["a", 
         RowBox[{"5", "/", "2"}]]}], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", 
        RowBox[{"3", "/", "2"}]], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", 
        RowBox[{"3", "/", "2"}]], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", 
          RowBox[{"3", "/", "2"}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]]}], "-", 
        RowBox[{
         SuperscriptBox["b", 
          RowBox[{"3", "/", "2"}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], "+", 
        RowBox[{
         SuperscriptBox["c", 
          RowBox[{"3", "/", "2"}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}]}], ")"}]}], 
     ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", 
          RowBox[{"3", "/", "2"}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]]}], "+", 
        RowBox[{
         SuperscriptBox["b", 
          RowBox[{"3", "/", "2"}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], "-", 
        RowBox[{
         SuperscriptBox["c", 
          RowBox[{"3", "/", "2"}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}]}], 
       ")"}]}]}], "}"}], "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", 
   "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SqrtBox[
       RowBox[{"2", "-", 
        SqrtBox["2"]}]]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SqrtBox["2"], "+", 
      SqrtBox[
       RowBox[{"2", "-", 
        SqrtBox["2"]}]]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 504, 
   "   ", {-$CellContext`a^
      Rational[5, 
        2] (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c))^
      Rational[1, 2] + $CellContext`a $CellContext`b^
      Rational[3, 
        2] (($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[1, 2] + $CellContext`a $CellContext`c^
      Rational[3, 
        2] (($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[1, 2], $CellContext`b ($CellContext`a^
       Rational[
        3, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c))^
       Rational[1, 2] - $CellContext`b^
      Rational[3, 
        2] (($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[1, 2] + $CellContext`c^
       Rational[
        3, 2] (($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
       Rational[1, 2]), $CellContext`c ($CellContext`a^
       Rational[
        3, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c))^
       Rational[1, 2] + $CellContext`b^
       Rational[
        3, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
       Rational[1, 2] - $CellContext`c^
      Rational[3, 
        2] (($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^Rational[1, 2])}, 
   "   XM/AM=", 
   Style[(-1 + (2 - 2^Rational[1, 2])^Rational[1, 2])/(-1 + 
    2^Rational[1, 2] + (2 - 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979494604387`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"73449204-3ed8-4d1d-be6e-efce331743c8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "505"}],
  SequenceForm["n=", 505],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949464224*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f8ad3b54-ddc1-49c3-928c-96f5fe375a2e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "506"}],
  SequenceForm["n=", 506],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949642724*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"680878e0-6e99-40ea-946e-3c869bca1b4d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "506", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
       RowBox[{"2", "/", "3"}]]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ")"}], 
       RowBox[{"2", "/", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}], ")"}], 
       RowBox[{"2", "/", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "-", 
         SqrtBox["2"]}], ")"}], 
       RowBox[{"2", "/", "3"}]]}], 
     RowBox[{"4", "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{
       SqrtBox["2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "-", 
          SqrtBox["2"]}], ")"}], 
        RowBox[{"2", "/", "3"}]]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 506, 
   "   ", {($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a - \
$CellContext`b + $CellContext`c) ($CellContext`a (-$CellContext`a + \
$CellContext`b + $CellContext`c))^
     Rational[2, 
       3], ($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`b \
($CellContext`a - $CellContext`b + $CellContext`c))^
     Rational[2, 
       3] (-$CellContext`a + $CellContext`b + $CellContext`c), \
(($CellContext`a + $CellContext`b - $CellContext`c) $CellContext`c)^
     Rational[2, 
       3] ($CellContext`a - $CellContext`b + $CellContext`c) (-$CellContext`a + \
$CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[2^Rational[1, 2] (2 - 2^Rational[1, 2])^Rational[2, 3]/(4 - 2 
    2^Rational[1, 2] + 
    2^Rational[1, 2] (2 - 2^Rational[1, 2])^Rational[2, 3]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979497278748`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"059b0b9f-de48-43eb-b9b3-bbaff3191397"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "507"}],
  SequenceForm["n=", 507],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949731686*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8feac18c-3584-4e7a-b555-367e4fce1b62"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "507", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
       RowBox[{"3", "/", "4"}]]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ")"}], 
       RowBox[{"3", "/", "4"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", "c"}], ")"}], 
       RowBox[{"3", "/", "4"}]], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"2", "-", 
         SqrtBox["2"]}], ")"}], 
       RowBox[{"3", "/", "4"}]]}], 
     RowBox[{"4", "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{
       SqrtBox["2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "-", 
          SqrtBox["2"]}], ")"}], 
        RowBox[{"3", "/", "4"}]]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 507, 
   "   ", {($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a - \
$CellContext`b + $CellContext`c) ($CellContext`a (-$CellContext`a + \
$CellContext`b + $CellContext`c))^
     Rational[3, 
       4], ($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`b \
($CellContext`a - $CellContext`b + $CellContext`c))^
     Rational[3, 
       4] (-$CellContext`a + $CellContext`b + $CellContext`c), \
(($CellContext`a + $CellContext`b - $CellContext`c) $CellContext`c)^
     Rational[3, 
       4] ($CellContext`a - $CellContext`b + $CellContext`c) (-$CellContext`a + \
$CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[2^Rational[1, 2] (2 - 2^Rational[1, 2])^Rational[3, 4]/(4 - 2 
    2^Rational[1, 2] + 
    2^Rational[1, 2] (2 - 2^Rational[1, 2])^Rational[3, 4]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979498054323`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c8b469c8-9905-4c62-9ba7-618a6d759692"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "508"}],
  SequenceForm["n=", 508],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949809237*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4ed26d3e-d895-4861-adb6-47c01648ed09"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "508", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], ",", 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]], ",", 
     SqrtBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SuperscriptBox["2", 
      RowBox[{"1", "/", "4"}]], 
     RowBox[{
      SuperscriptBox["2", 
       RowBox[{"1", "/", "4"}]], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 508, 
   "   ", {(($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c))^
    Rational[1, 
      2], (($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
    Rational[1, 
      2], (($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^Rational[1, 2]}, 
   "   XM/AM=", 
   Style[2^Rational[1, 4]/(2^Rational[1, 4] + 
    2 (2 - 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979498471518`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e5c9e16d-51ee-4b9b-9e97-e3c6c7128b86"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "509"}],
  SequenceForm["n=", 509],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979498503*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5c5dd4eb-15ba-4a2c-bf53-1f48149d5f36"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "509", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]]}], ",", 
     RowBox[{"b", " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}], ",", 
     RowBox[{"c", " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"1", "+", 
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"1", "/", "4"}]], " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 509, 
   "   ", {$CellContext`a (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c))^
     Rational[1, 
       2], $CellContext`b (($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
     Rational[1, 
       2], $CellContext`c (($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^Rational[1, 2]}, 
   "   XM/AM=", 
   Style[(1 + 2^Rational[1, 4] (2 - 2^Rational[1, 2])^Rational[1, 2])^(-1), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979498938303`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0bb10af1-1a15-45c7-9e1e-32690a710399"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "510"}],
  SequenceForm["n=", 510],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949897139*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c1394998-3be6-4b29-acdd-bc4827c3b944"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "510", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", 
         RowBox[{"3", "/", "2"}]], "-", 
        SuperscriptBox["b", 
         RowBox[{"3", "/", "2"}]], "-", 
        SuperscriptBox["c", 
         RowBox[{"3", "/", "2"}]]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", 
          RowBox[{"3", "/", "2"}]]}], "+", 
        SuperscriptBox["b", 
         RowBox[{"3", "/", "2"}]], "-", 
        SuperscriptBox["c", 
         RowBox[{"3", "/", "2"}]]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", 
          RowBox[{"3", "/", "2"}]]}], "-", 
        SuperscriptBox["b", 
         RowBox[{"3", "/", "2"}]], "+", 
        SuperscriptBox["c", 
         RowBox[{"3", "/", "2"}]]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      SuperscriptBox["2", 
       RowBox[{"3", "/", "4"}]]}], 
     RowBox[{
      RowBox[{"-", "2"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["2", 
        RowBox[{"1", "/", "4"}]]}], "+", 
      SuperscriptBox["2", 
       RowBox[{"3", "/", "4"}]]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 510, 
   "   ", {$CellContext`a ($CellContext`a^Rational[3, 2] - $CellContext`b^
     Rational[3, 2] - $CellContext`c^
     Rational[3, 2]), $CellContext`b (-$CellContext`a^
       Rational[3, 2] + $CellContext`b^Rational[3, 2] - $CellContext`c^
     Rational[3, 2]), $CellContext`c (-$CellContext`a^
       Rational[3, 2] - $CellContext`b^
     Rational[3, 2] + $CellContext`c^Rational[3, 2])}, "   XM/AM=", 
   Style[(-2 + 2^Rational[3, 4])/(-2 - 2 2^Rational[1, 4] + 2^Rational[3, 4]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949900725*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5650dd98-9d1c-4aa8-a53f-009af93ad612"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "511"}],
  SequenceForm["n=", 511],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949902964*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f43c1105-c8c3-4f01-8a06-2859a5ce2457"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "512"}],
  SequenceForm["n=", 512],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949904676*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"01b7ab3a-7668-4ff1-a9c8-be33ba60c782"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "513"}],
  SequenceForm["n=", 513],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979499071074`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4b3821eb-426c-4627-ae5a-bb7ed5397c7c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "514"}],
  SequenceForm["n=", 514],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109794990954*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"49a0c798-dfaf-43ca-b5e3-6141151f7d09"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "515"}],
  SequenceForm["n=", 515],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949911374*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8018a9fb-4fd7-4912-86ea-8646be7f0640"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "516"}],
  SequenceForm["n=", 516],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949913501*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3aa82aa1-bd67-4225-b8aa-dfdc4df9fbc9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "517"}],
  SequenceForm["n=", 517],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979499159107`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8e060ee3-bd7e-472e-8741-eea33a851669"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "518"}],
  SequenceForm["n=", 518],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949917684*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9e6733c0-d3e1-40fd-8a6c-85ff7986e6d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "519"}],
  SequenceForm["n=", 519],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949919306*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c0ff9c14-0559-45c3-a8f0-fd3c4321b7fe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "520"}],
  SequenceForm["n=", 520],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949920907*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cdf22e7e-91b8-4d03-8273-9e492054a160"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "521"}],
  SequenceForm["n=", 521],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949923483*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"abc86692-c32e-4d8a-9023-b4ecb48b46f0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "522"}],
  SequenceForm["n=", 522],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979499253893`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f3556d5e-d85a-490a-8ba0-3b4078119f8a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "523"}],
  SequenceForm["n=", 523],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979499274073`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ad9a74cd-9413-404a-91d0-b86d8d31743c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "524"}],
  SequenceForm["n=", 524],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949929138*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e0057991-dd04-4686-a0c9-192c3fd18c56"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "525"}],
  SequenceForm["n=", 525],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949931526*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"67d87134-e78b-4abe-96b8-5cc552b6115a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "526"}],
  SequenceForm["n=", 526],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949933352*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4c8cfdd5-6633-41bf-a1ca-cf9a0d5a29d0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "527"}],
  SequenceForm["n=", 527],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979499351177`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d34ce5c5-4dfc-4e32-b219-eb5a9f80b527"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "528"}],
  SequenceForm["n=", 528],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949936779*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e5873468-2d62-43ba-8fea-a6773b21f058"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "529"}],
  SequenceForm["n=", 529],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949939299*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ef23d81c-252e-447b-879f-cdf2c6f29a78"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "530"}],
  SequenceForm["n=", 530],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979499413357`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1158f6a1-9256-4b95-8ef3-d8093e3c80fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "531"}],
  SequenceForm["n=", 531],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949943083*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d65bc6c9-ef40-4230-aa8d-4c6f6f537a4b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "532"}],
  SequenceForm["n=", 532],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979499447412`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a1a1abb4-c15d-44e7-b0f4-d2f73858568a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "533"}],
  SequenceForm["n=", 533],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949947343*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7c3d131b-be83-4bd9-9f1b-b765334e7a2b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "534"}],
  SequenceForm["n=", 534],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949949402*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b73d46d4-5f0e-4928-a91c-d6f86410c59e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "535"}],
  SequenceForm["n=", 535],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949951354*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"046b9985-aee7-4e53-9ce1-134fd77fc4e9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "536"}],
  SequenceForm["n=", 536],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979499532557`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a0c62d44-6956-4d30-8bcc-a8ab95044c04"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "537"}],
  SequenceForm["n=", 537],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979499565153`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"44ad3aaf-3294-4580-9daf-1d00892af60a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "538"}],
  SequenceForm["n=", 538],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949958474*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f04762f7-87f2-4d65-bb71-2f384836edc1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "539"}],
  SequenceForm["n=", 539],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949960368*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1a0f323a-c54e-4dfb-b741-97459e855223"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "540"}],
  SequenceForm["n=", 540],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979499628572`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"77cf963d-cb8f-4bf0-9528-1ce36f870f8d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "541"}],
  SequenceForm["n=", 541],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949964974*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"325e1e46-83f0-4c96-b9a9-a4c03098db06"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "542"}],
  SequenceForm["n=", 542],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979499669847`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5f5e8b77-a67e-4647-8533-3219339f5019"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "543"}],
  SequenceForm["n=", 543],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949968938*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1db96460-5b55-4d26-953e-711bf37bdc56"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "544"}],
  SequenceForm["n=", 544],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949971859*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"de2ffa55-0826-49dc-8f4f-6428e08f741c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "545"}],
  SequenceForm["n=", 545],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949974141*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2e6dd912-05c3-472c-9f41-46ed84c52e25"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "546"}],
  SequenceForm["n=", 546],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979499759808`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9c1bdfc4-2c3b-49ce-bfc0-988683df1ea8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "546", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "4"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 546, "   ", {
   2 $CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 - 
    3 $CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + 
    6 $CellContext`b^2 $CellContext`c^2 - 
    3 $CellContext`c^4, (-3) $CellContext`a^4 + $CellContext`a^2 \
$CellContext`b^2 + 2 $CellContext`b^4 + 
    6 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - 
    3 $CellContext`c^4, (-3) $CellContext`a^4 + 
    6 $CellContext`a^2 $CellContext`b^2 - 
    3 $CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 + 2 $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[3, 4], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949978527*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"52ca00e0-b840-4d5d-8f88-d0a373030e06"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "547"}],
  SequenceForm["n=", 547],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949981018*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"50a46f1f-7297-4ecb-8df4-5540dfdcc7eb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "547", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"10", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{"5", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"10", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{"5", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"10", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"5", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["5", "12"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 547, "   ", {
   2 $CellContext`a^4 - 7 $CellContext`a^2 $CellContext`b^2 + 
    5 $CellContext`b^4 - 7 $CellContext`a^2 $CellContext`c^2 - 
    10 $CellContext`b^2 $CellContext`c^2 + 5 $CellContext`c^4, 
    5 $CellContext`a^4 - 7 $CellContext`a^2 $CellContext`b^2 + 
    2 $CellContext`b^4 - 10 $CellContext`a^2 $CellContext`c^2 - 
    7 $CellContext`b^2 $CellContext`c^2 + 5 $CellContext`c^4, 
    5 $CellContext`a^4 - 10 $CellContext`a^2 $CellContext`b^2 + 
    5 $CellContext`b^4 - 7 $CellContext`a^2 $CellContext`c^2 - 
    7 $CellContext`b^2 $CellContext`c^2 + 2 $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[5, 12], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949983321*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e7ae1d4b-7920-41a3-8698-ec696a49e37a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "548"}],
  SequenceForm["n=", 548],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949985702*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dcbb421d-6a5d-4843-b9bd-777d30b541d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "548", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"6", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"6", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", "4"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 548, "   ", {
   6 $CellContext`a^4 - 
    5 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
    5 $CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 - 
    5 $CellContext`a^2 $CellContext`b^2 + 6 $CellContext`b^4 + 
    2 $CellContext`a^2 $CellContext`c^2 - 
    5 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
    5 $CellContext`a^2 $CellContext`c^2 - 5 $CellContext`b^2 $CellContext`c^2 + 
    6 $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[-1, 4], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949988694*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1cc1bdd7-ca48-41f5-acb0-e43139271a2d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "549"}],
  SequenceForm["n=", 549],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979499912987`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"98429139-58f2-4b15-8fd7-ddc2acbf4120"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "549", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"5", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "6"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 549, "   ", {
   4 $CellContext`a^4 - 
    5 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    5 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - 
    5 $CellContext`a^2 $CellContext`b^2 + 4 $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`c^2 - 
    5 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    5 $CellContext`a^2 $CellContext`c^2 - 5 $CellContext`b^2 $CellContext`c^2 + 
    4 $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[1, 6], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949993998*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"37817d73-f068-46fd-8ae7-7d2111051fb0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "550"}],
  SequenceForm["n=", 550],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949996799*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cf6eb37e-f4ad-4cbe-b0d4-0259a40eeff6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "550", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", "2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 550, "   ", {
   4 $CellContext`a^4 - 
    3 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
    3 $CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 - 
    3 $CellContext`a^2 $CellContext`b^2 + 4 $CellContext`b^4 + 
    2 $CellContext`a^2 $CellContext`c^2 - 
    3 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4, -$CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
    3 $CellContext`a^2 $CellContext`c^2 - 3 $CellContext`b^2 $CellContext`c^2 + 
    4 $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097949999372*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e1adf657-ef13-4968-9a20-c0da63bdb51f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "551"}],
  SequenceForm["n=", 551],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950002038*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c8f6bfe5-cc09-4794-9bd4-6bb5d80460da"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "551", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"4", " ", "a"}], "+", "b", "+", "c"}], ",", 
     RowBox[{"a", "+", 
      RowBox[{"4", " ", "b"}], "+", "c"}], ",", 
     RowBox[{"a", "+", "b", "+", 
      RowBox[{"4", " ", "c"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "3"]}], "+", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 551, "   ", {
   4 $CellContext`a + $CellContext`b + $CellContext`c, $CellContext`a + 
    4 $CellContext`b + $CellContext`c, $CellContext`a + $CellContext`b + 
    4 $CellContext`c}, "   XM/AM=", 
   Style[Rational[-1, 3] + 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950004642*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7ffce710-1eb2-42e1-ab1d-0b9f819ed7ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "552"}],
  SequenceForm["n=", 552],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950006804*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"56fb6c49-e193-431e-9b18-aee3524202c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "552", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "35"], " ", 
     RowBox[{"(", 
      RowBox[{"11", "+", 
       RowBox[{"8", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 552, 
   "   ", {($CellContext`a + $CellContext`b)^2 ($CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a + $CellContext`c)^2 \
($CellContext`a - $CellContext`b + $CellContext`c), ($CellContext`a + \
$CellContext`b)^2 ($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`b + $CellContext`c)^2 (-$CellContext`a + $CellContext`b + \
$CellContext`c), ($CellContext`a + $CellContext`c)^2 ($CellContext`a - \
$CellContext`b + $CellContext`c) ($CellContext`b + $CellContext`c)^2 \
(-$CellContext`a + $CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 35] (11 + 8 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950008902*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2fb4c2f3-3799-4556-88aa-82e72ac2a6e0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "553"}],
  SequenceForm["n=", 553],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950011755*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a305ae6d-924d-4ece-9ca9-42c4122cac26"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "553", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", 
        RowBox[{"2", " ", "b"}], "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "+", 
        RowBox[{"2", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "6"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 553, 
   "   ", {($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a - \
$CellContext`b + $CellContext`c) (
     2 $CellContext`a + $CellContext`b + $CellContext`c), ($CellContext`a + \
$CellContext`b - $CellContext`c) (-$CellContext`a + $CellContext`b + \
$CellContext`c) ($CellContext`a + 
     2 $CellContext`b + $CellContext`c), ($CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + 2 $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 6] (2 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979500140038`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8c20bdf9-42d0-4fe5-b2bf-475e2c647774"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "554"}],
  SequenceForm["n=", 554],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795001642*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9880a343-c5fe-47ea-97e1-7f1f1eefffca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "555"}],
  SequenceForm["n=", 555],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950018611*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c672f595-c327-4e4c-ac37-2e18b1b6d433"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "555", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{"b", " ", "c"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}], ",", 
     RowBox[{
      SqrtBox[
       RowBox[{"a", " ", "c"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}], ",", 
     RowBox[{
      SqrtBox[
       RowBox[{"a", " ", "b"}]], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
       RowBox[{"3", "/", "2"}]]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SqrtBox["2"], 
     RowBox[{
      SqrtBox["2"], "-", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"4", "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}]}]]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 555, 
   "   ", {($CellContext`b $CellContext`c)^
     Rational[1, 
       2] (($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a - \
$CellContext`b + $CellContext`c))^
     Rational[3, 2], ($CellContext`a $CellContext`c)^
     Rational[1, 
       2] (($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
     Rational[3, 2], ($CellContext`a $CellContext`b)^
     Rational[1, 
       2] (($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^Rational[3, 2]}, 
   "   XM/AM=", 
   Style[2^Rational[1, 2]/(2^Rational[1, 2] - 
    2 (4 - 2 2^Rational[1, 2])^Rational[1, 2] + 
    4 (2 - 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979501579113`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e23d5246-3e60-4792-80f8-a829f57069d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "556"}],
  SequenceForm["n=", 556],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950161137*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"19399d20-e60c-4b56-a595-5c49d2d3239c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "556", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SqrtBox[
      RowBox[{"b", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]], ",", 
     SqrtBox[
      RowBox[{"a", " ", "c", " ", 
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}]}]], ",", 
     SqrtBox[
      RowBox[{"a", " ", "b", " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}]}]]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SqrtBox[
      RowBox[{"2", "-", 
       SqrtBox["2"]}]], 
     RowBox[{
      RowBox[{"2", " ", 
       SqrtBox["2"]}], "+", 
      SqrtBox[
       RowBox[{"2", "-", 
        SqrtBox["2"]}]]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 556, 
   "   ", {($CellContext`b $CellContext`c (-$CellContext`a + $CellContext`b + \
$CellContext`c))^
    Rational[1, 
      2], ($CellContext`a $CellContext`c ($CellContext`a - $CellContext`b + \
$CellContext`c))^
    Rational[1, 
      2], ($CellContext`a $CellContext`b ($CellContext`a + $CellContext`b - \
$CellContext`c))^Rational[1, 2]}, "   XM/AM=", 
   Style[(2 - 2^Rational[1, 2])^Rational[1, 2]/(
    2 2^Rational[1, 2] + (2 - 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979501980753`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"731e195a-622e-4e18-ae8c-54ba1c9a90ba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "557"}],
  SequenceForm["n=", 557],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950201049*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b77064f4-e137-49d6-aee9-3ee55afc4202"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "557", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SqrtBox["a"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"b", " ", "c"}]]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], ",", 
     RowBox[{
      SqrtBox["b"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"a", " ", "c"}]]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], ",", 
     RowBox[{
      SqrtBox["c"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"a", " ", "b"}]]}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"2", "+", 
      SqrtBox["2"]}], 
     RowBox[{"6", "+", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", "+", 
         SqrtBox["2"]}]]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 557, 
   "   ", {$CellContext`a^Rational[1, 2] (
     2 ($CellContext`b $CellContext`c)^
       Rational[
        1, 2] + ((-$CellContext`a + $CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[1, 2]), $CellContext`b^Rational[1, 2] (
     2 ($CellContext`a $CellContext`c)^
       Rational[
        1, 2] + (($CellContext`a - $CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[1, 2]), $CellContext`c^Rational[1, 2] (
     2 ($CellContext`a $CellContext`b)^
       Rational[
        1, 2] + (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c))^Rational[1, 2])}, 
   "   XM/AM=", 
   Style[(2 + 2^Rational[1, 2])/(6 + 2^Rational[1, 2] + 
    2 (2 + 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950240675*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4b02c749-1438-45fd-9810-363a4da01fd1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "558"}],
  SequenceForm["n=", 558],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979502446938`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4d27e27e-8f42-4de8-a875-79abb655083a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "558", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SqrtBox["a"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"b", " ", "c"}]]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], ",", 
     RowBox[{
      SqrtBox["b"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"a", " ", "c"}]]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], ",", 
     RowBox[{
      SqrtBox["c"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"a", " ", "b"}]]}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      SqrtBox["2"]}], 
     RowBox[{
      RowBox[{"-", "6"}], "+", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", "+", 
         SqrtBox["2"]}]]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 558, 
   "   ", {$CellContext`a^Rational[1, 2] (
     2 ($CellContext`b $CellContext`c)^
       Rational[
        1, 2] - ((-$CellContext`a + $CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c))^
     Rational[1, 2]), $CellContext`b^Rational[1, 2] (
     2 ($CellContext`a $CellContext`c)^
       Rational[
        1, 2] - (($CellContext`a - $CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c))^
     Rational[1, 2]), $CellContext`c^Rational[1, 2] (
     2 ($CellContext`a $CellContext`b)^
       Rational[
        1, 2] - (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c))^Rational[1, 2])}, 
   "   XM/AM=", 
   Style[(-2 + 2^Rational[1, 2])/(-6 + 2^Rational[1, 2] + 
    2 (2 + 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950283634*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"13cbd6cd-d10e-4542-a7df-0896e1b158c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "559"}],
  SequenceForm["n=", 559],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950286635*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0a96457c-ff57-4ee3-b77c-fd5dc5e80c65"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "560"}],
  SequenceForm["n=", 560],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950349016*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"01fb63aa-2452-42c4-8e30-eaf18afb6867"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "560", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["a", "5"], ",", 
     SuperscriptBox["b", "5"], ",", 
     SuperscriptBox["c", "5"]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", "7"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "4"}], "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 560, "   ", {$CellContext`a^5, $CellContext`b^5, $CellContext`c^5}, 
   "   XM/AM=", 
   Style[Rational[-2, 7] (-4 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950388701*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4e0d83ef-8231-4b11-a671-bd690476fd33"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "561"}],
  SequenceForm["n=", 561],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950392446*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"36511dff-3a3a-446a-a9c6-18e1baf5472f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "561", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox["c", "3"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["c", "3"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"1", "+", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 561, 
   "   ", {$CellContext`b^3 $CellContext`c^3, $CellContext`a^3 \
$CellContext`c^3, $CellContext`a^3 $CellContext`b^3}, "   XM/AM=", 
   Style[(1 + 4 2^Rational[1, 2])^(-1), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950395475*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"23de744b-752a-4986-bb36-6c5f08a6a1de"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "562"}],
  SequenceForm["n=", 562],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950398712*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"169c77da-1c11-4283-a2fd-fc0c4c4e5ff0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "563"}],
  SequenceForm["n=", 563],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979504016447`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"11106033-4f64-4ec2-942d-1cf211605846"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "563", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "5"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "5"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "5"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"2", "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 563, 
   "   ", {$CellContext`a^5 ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`c^2) ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`b^5 (-$CellContext`a^2 + $CellContext`b^2 - $CellContext`c^2) \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`c^5 (-$CellContext`a^2 - $CellContext`b^2 + $CellContext`c^2) \
($CellContext`a^4 + $CellContext`b^4 - 2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[2 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950405167*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d07ac095-f98e-4768-99b9-eb62bce70c2a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "564"}],
  SequenceForm["n=", 564],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795040844*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0ba03440-abd6-42e3-b6d8-b9e0bd67f34f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "565"}],
  SequenceForm["n=", 565],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950448492*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cca2dc50-e0be-4c42-9438-282fafc931a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "566"}],
  SequenceForm["n=", 566],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950451982*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"63fd6b43-7c9a-40f2-b7d7-995df7f6b5d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "566", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "4"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 566, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 + \
$CellContext`a^4 $CellContext`c^2 - $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^2 - $CellContext`b^4 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^4 - $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6), $CellContext`b^2 ($CellContext`a^6 - 
     2 $CellContext`a^4 $CellContext`b^2 + $CellContext`a^2 $CellContext`b^4 - \
$CellContext`a^4 $CellContext`c^2 - $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^2 + $CellContext`b^4 $CellContext`c^2 - $CellContext`a^2 \
$CellContext`c^4 - 
     2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6), \
$CellContext`c^2 ($CellContext`a^6 - $CellContext`a^4 $CellContext`b^2 - \
$CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 - 
     2 $CellContext`a^4 $CellContext`c^2 - $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^2 - 
     2 $CellContext`b^4 $CellContext`c^2 + $CellContext`a^2 $CellContext`c^4 + \
$CellContext`b^2 $CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[1, 4], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950455604*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"37ee45b6-725b-4707-8823-cb72fe8374dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "567"}],
  SequenceForm["n=", 567],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979504586678`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2e8fc952-0e5d-4fc6-a904-02170c85b666"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "567", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "6"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", "5"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 567, 
   "   ", {$CellContext`a^2 ($CellContext`a^8 - 
     3 $CellContext`a^6 $CellContext`b^2 + 
     3 $CellContext`a^4 $CellContext`b^4 - $CellContext`a^2 $CellContext`b^6 - 
     3 $CellContext`a^6 $CellContext`c^2 + 
     3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
     2 $CellContext`b^6 $CellContext`c^2 + 
     3 $CellContext`a^4 $CellContext`c^4 + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     4 $CellContext`b^4 $CellContext`c^4 - $CellContext`a^2 $CellContext`c^6 - 
     2 $CellContext`b^2 $CellContext`c^6), $CellContext`b^2 \
(-$CellContext`a^6 $CellContext`b^2 + 3 $CellContext`a^4 $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 - 
     2 $CellContext`a^6 $CellContext`c^2 + 
     2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
     3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
     3 $CellContext`b^6 $CellContext`c^2 + 
     4 $CellContext`a^4 $CellContext`c^4 + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     3 $CellContext`b^4 $CellContext`c^4 - 
     2 $CellContext`a^2 $CellContext`c^6 - $CellContext`b^2 \
$CellContext`c^6), $CellContext`c^2 ((-2) $CellContext`a^6 $CellContext`b^2 + 
     4 $CellContext`a^4 $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b^6 - $CellContext`a^6 $CellContext`c^2 + 
     2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - $CellContext`b^6 \
$CellContext`c^2 + 3 $CellContext`a^4 $CellContext`c^4 + 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     3 $CellContext`b^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`c^6 - 
     3 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8)}, "   XM/AM=", 
   Style[
    Rational[2, 5], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950463101*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f7d88fc6-6656-4b44-a690-438770a37372"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "568"}],
  SequenceForm["n=", 568],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950467539*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e46f03eb-c296-48d0-8d10-0fce10e499f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "568", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        SuperscriptBox["b", "8"], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "8"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        SuperscriptBox["c", "8"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "8"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        SuperscriptBox["b", "8"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 568, 
   "   ", {$CellContext`a^2 ($CellContext`a^6 $CellContext`b^2 - 
     3 $CellContext`a^4 $CellContext`b^4 + 
     3 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + \
$CellContext`a^6 $CellContext`c^2 - $CellContext`a^4 $CellContext`b^2 \
$CellContext`c^2 - 2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + 
     2 $CellContext`b^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`c^4 - 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     2 $CellContext`b^4 $CellContext`c^4 + 
     3 $CellContext`a^2 $CellContext`c^6 + 
     2 $CellContext`b^2 $CellContext`c^6 - $CellContext`c^8), \
$CellContext`b^2 (-$CellContext`a^8 + 3 $CellContext`a^6 $CellContext`b^2 - 
     3 $CellContext`a^4 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^6 + 
     2 $CellContext`a^6 $CellContext`c^2 - 
     2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - $CellContext`a^2 \
$CellContext`b^4 $CellContext`c^2 + $CellContext`b^6 $CellContext`c^2 - 
     2 $CellContext`a^4 $CellContext`c^4 - 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     3 $CellContext`b^4 $CellContext`c^4 + 
     2 $CellContext`a^2 $CellContext`c^6 + 
     3 $CellContext`b^2 $CellContext`c^6 - $CellContext`c^8), \
$CellContext`c^2 (-$CellContext`a^8 + 2 $CellContext`a^6 $CellContext`b^2 - 
     2 $CellContext`a^4 $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b^6 - $CellContext`b^8 + 
     3 $CellContext`a^6 $CellContext`c^2 - 
     2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + 
     3 $CellContext`b^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`c^4 - $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^4 - 
     3 $CellContext`b^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^6 + \
$CellContext`b^2 $CellContext`c^6)}, "   XM/AM=", 
   Style[
    Rational[2, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979504720182`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"585c5e7b-371f-4c36-b717-d26a2d7f707e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "569"}],
  SequenceForm["n=", 569],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950476389*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"71a61bbf-af4d-4241-bb34-07a08d825b06"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "569", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "6"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 569, 
   "   ", {$CellContext`a^2 ($CellContext`a^8 - 
     3 $CellContext`a^6 $CellContext`b^2 + 
     3 $CellContext`a^4 $CellContext`b^4 - $CellContext`a^2 $CellContext`b^6 - 
     3 $CellContext`a^6 $CellContext`c^2 + 
     2 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
     3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
     2 $CellContext`b^6 $CellContext`c^2 + 
     3 $CellContext`a^4 $CellContext`c^4 + 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     4 $CellContext`b^4 $CellContext`c^4 - $CellContext`a^2 $CellContext`c^6 - 
     2 $CellContext`b^2 $CellContext`c^6), $CellContext`b^2 \
(-$CellContext`a^6 $CellContext`b^2 + 3 $CellContext`a^4 $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 - 
     2 $CellContext`a^6 $CellContext`c^2 + 
     3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
     3 $CellContext`b^6 $CellContext`c^2 + 
     4 $CellContext`a^4 $CellContext`c^4 + 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     3 $CellContext`b^4 $CellContext`c^4 - 
     2 $CellContext`a^2 $CellContext`c^6 - $CellContext`b^2 \
$CellContext`c^6), $CellContext`c^2 ((-2) $CellContext`a^6 $CellContext`b^2 + 
     4 $CellContext`a^4 $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b^6 - $CellContext`a^6 $CellContext`c^2 + 
     3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + 
     3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - $CellContext`b^6 \
$CellContext`c^2 + 3 $CellContext`a^4 $CellContext`c^4 + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     3 $CellContext`b^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`c^6 - 
     3 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8)}, "   XM/AM=", 
   Style[
    Rational[1, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950480493*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"113f879a-445f-4992-ae15-5c7fe08e290e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "570"}],
  SequenceForm["n=", 570],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979504843893`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c9554ce8-6092-4dd3-b5d7-57cc8431e804"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "570", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 570, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 + \
$CellContext`a^4 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - $CellContext`b^4 \
$CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^4 - $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6), $CellContext`b^2 ($CellContext`a^6 - 
     2 $CellContext`a^4 $CellContext`b^2 + $CellContext`a^2 $CellContext`b^4 - \
$CellContext`a^4 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + $CellContext`b^4 \
$CellContext`c^2 - $CellContext`a^2 $CellContext`c^4 - 
     2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6), \
$CellContext`c^2 ($CellContext`a^6 - $CellContext`a^4 $CellContext`b^2 - \
$CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 - 
     2 $CellContext`a^4 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^4 $CellContext`c^2 + $CellContext`a^2 $CellContext`c^4 + \
$CellContext`b^2 $CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[1, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950488225*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cb925893-cb14-48ab-90db-0c1b053df3d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "571"}],
  SequenceForm["n=", 571],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950492261*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ea70d322-dbe8-4681-9927-ddfed81bfc4b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "572"}],
  SequenceForm["n=", 572],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950495245*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3c34f052-5e75-40a7-ab98-350f8eeed6e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "572", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 572, 
   "   ", {$CellContext`a^2 ($CellContext`a^3 - $CellContext`a \
$CellContext`b^2 + $CellContext`a $CellContext`b $CellContext`c - \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2), $CellContext`b^2 (-$CellContext`a^2 \
$CellContext`b + $CellContext`b^3 - $CellContext`a^2 $CellContext`c + \
$CellContext`a $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2), $CellContext`c^2 \
(-$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 - \
$CellContext`a^2 $CellContext`c + $CellContext`a $CellContext`b \
$CellContext`c - $CellContext`b^2 $CellContext`c + $CellContext`c^3)}, 
   "   XM/AM=", 
   Style[Rational[1, 17] (5 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979504988623`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"71c9f44e-5185-4d8b-827f-4e7cabf11424"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "573"}],
  SequenceForm["n=", 573],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950501873*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ccc3ec3b-8bc7-4690-a84a-afb6b921f032"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "573", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 573, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 $CellContext`b - \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c - $CellContext`c^3), $CellContext`b^2 \
(-$CellContext`a^3 + $CellContext`a $CellContext`b^2 - $CellContext`a \
$CellContext`b $CellContext`c + $CellContext`b^2 $CellContext`c - \
$CellContext`c^3), $CellContext`c^2 (-$CellContext`a^3 - $CellContext`b^3 - \
$CellContext`a $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`c^2 + $CellContext`b $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 7] (1 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979505050287`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a6159824-df2b-401b-95ae-589360da7348"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "574"}],
  SequenceForm["n=", 574],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950508844*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dd0200a6-7f64-47c0-905d-fc998824a892"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "574", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", "7"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 574, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 - 2 $CellContext`b^2 - 
     2 $CellContext`c^2), $CellContext`b^2 ((-2) $CellContext`a^2 + \
$CellContext`b^2 - 
     2 $CellContext`c^2), $CellContext`c^2 ((-2) $CellContext`a^2 - 
     2 $CellContext`b^2 + $CellContext`c^2)}, "   XM/AM=", 
   Style[
    Rational[2, 7], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950511929*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ddf2ec3e-d7f2-4ff2-837f-c590cb040783"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "575"}],
  SequenceForm["n=", 575],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950515409*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b0a7c800-b5ab-4b35-88db-6acb0bfd6543"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "575", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "8"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 575, 
   "   ", {$CellContext`a^2 (2 $CellContext`a^4 - 
     3 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`c^2 - 
     4 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`b^2 ($CellContext`a^4 - 3 $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`b^4 - 4 $CellContext`a^2 $CellContext`c^2 - 
     3 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`c^2 ($CellContext`a^4 - 
     4 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`c^2 - 
     3 $CellContext`b^2 $CellContext`c^2 + 2 $CellContext`c^4)}, "   XM/AM=", 
   
   Style[
    Rational[3, 8], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950520029*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"45e20635-ce8d-4b66-a6fe-db9a2b75d46d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "576"}],
  SequenceForm["n=", 576],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950525384*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1455cf91-bf0a-4954-832c-7623fa89a25b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "576", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "4"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 576, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     3 $CellContext`a^2 $CellContext`b^2 + 2 $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`c^4), $CellContext`b^2 (2 $CellContext`a^4 - 
     3 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - 
     3 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`c^4), $CellContext`c^2 (2 $CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + 2 $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`c^2 - 
     3 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[3, 4], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950528708*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fc1b48ec-a4cf-4fe1-9bc0-294767d06a35"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "577"}],
  SequenceForm["n=", 577],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950532753*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fdacead0-f667-42c3-ad7c-d2155051f34e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "578"}],
  SequenceForm["n=", 578],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950535425*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0a0f0001-51aa-4dd8-9c0a-521a47094863"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "578", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "8"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "6"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        SuperscriptBox["b", "8"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "2"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 578, 
   "   ", {$CellContext`a^2 ($CellContext`a^8 - 
     3 $CellContext`a^6 $CellContext`b^2 + 
     3 $CellContext`a^4 $CellContext`b^4 - $CellContext`a^2 $CellContext`b^6 - 
     3 $CellContext`a^6 $CellContext`c^2 + 
     4 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + $CellContext`a^2 \
$CellContext`b^4 $CellContext`c^2 - 2 $CellContext`b^6 $CellContext`c^2 + 
     3 $CellContext`a^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^4 + 
     4 $CellContext`b^4 $CellContext`c^4 - $CellContext`a^2 $CellContext`c^6 - 
     2 $CellContext`b^2 $CellContext`c^6), $CellContext`b^2 \
(-$CellContext`a^6 $CellContext`b^2 + 3 $CellContext`a^4 $CellContext`b^4 - 
     3 $CellContext`a^2 $CellContext`b^6 + $CellContext`b^8 - 
     2 $CellContext`a^6 $CellContext`c^2 + $CellContext`a^4 $CellContext`b^2 \
$CellContext`c^2 + 4 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 - 
     3 $CellContext`b^6 $CellContext`c^2 + 
     4 $CellContext`a^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^4 + 3 $CellContext`b^4 $CellContext`c^4 - 
     2 $CellContext`a^2 $CellContext`c^6 - $CellContext`b^2 \
$CellContext`c^6), $CellContext`c^2 ((-2) $CellContext`a^6 $CellContext`b^2 + 
     4 $CellContext`a^4 $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b^6 - $CellContext`a^6 $CellContext`c^2 + \
$CellContext`a^4 $CellContext`b^2 $CellContext`c^2 + $CellContext`a^2 \
$CellContext`b^4 $CellContext`c^2 - $CellContext`b^6 $CellContext`c^2 + 
     3 $CellContext`a^4 $CellContext`c^4 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 + 
     3 $CellContext`b^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`c^6 - 
     3 $CellContext`b^2 $CellContext`c^6 + $CellContext`c^8)}, "   XM/AM=", 
   Style[
    Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979505392647`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"69bf2116-9ad4-4f75-93fd-2fc80f65661d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "579"}],
  SequenceForm["n=", 579],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979505445957`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a73bd12a-6f96-4544-b156-beaf9a99345b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "580"}],
  SequenceForm["n=", 580],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950548293*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7ce4fdea-2c14-4691-a467-a1c83b46f142"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "581"}],
  SequenceForm["n=", 581],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979505523157`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"18ae7858-592b-4910-8b15-392927e38f08"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "581", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "5"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 581, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 $CellContext`b - 
     2 $CellContext`a^2 $CellContext`b^3 + $CellContext`b^5 + \
$CellContext`a^4 $CellContext`c + $CellContext`a^3 $CellContext`b \
$CellContext`c - $CellContext`a^2 $CellContext`b^2 $CellContext`c - \
$CellContext`a $CellContext`b^3 $CellContext`c - $CellContext`a^2 \
$CellContext`b $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c^2 - $CellContext`b^3 \
$CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^3 - $CellContext`a $CellContext`b \
$CellContext`c^3 - $CellContext`b^2 $CellContext`c^3 + $CellContext`c^5), \
$CellContext`b^2 ($CellContext`a^5 - 
     2 $CellContext`a^3 $CellContext`b^2 + $CellContext`a $CellContext`b^4 - \
$CellContext`a^3 $CellContext`b $CellContext`c - $CellContext`a^2 \
$CellContext`b^2 $CellContext`c + $CellContext`a $CellContext`b^3 \
$CellContext`c + $CellContext`b^4 $CellContext`c - $CellContext`a^3 \
$CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c^2 - $CellContext`a \
$CellContext`b^2 $CellContext`c^2 - $CellContext`a^2 $CellContext`c^3 - \
$CellContext`a $CellContext`b $CellContext`c^3 - 
     2 $CellContext`b^2 $CellContext`c^3 + $CellContext`c^5), \
$CellContext`c^2 ($CellContext`a^5 - $CellContext`a^3 $CellContext`b^2 - \
$CellContext`a^2 $CellContext`b^3 + $CellContext`b^5 - $CellContext`a^3 \
$CellContext`b $CellContext`c - 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c - $CellContext`a \
$CellContext`b^3 $CellContext`c - 
     2 $CellContext`a^3 $CellContext`c^2 - $CellContext`a^2 $CellContext`b \
$CellContext`c^2 - $CellContext`a $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^3 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^3 + $CellContext`a $CellContext`c^4 + $CellContext`b \
$CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[1, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795055656*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"04e8390f-82ef-414b-9eb5-52b3c8a60022"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "582"}],
  SequenceForm["n=", 582],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950559392*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"195dff7f-f4bb-4f17-b341-2b44cd6ca460"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "582", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "5"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "+", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 582, 
   "   ", {$CellContext`a^2 ($CellContext`a^5 - 
     2 $CellContext`a^3 $CellContext`b^2 + $CellContext`a $CellContext`b^4 - 
     2 $CellContext`a^3 $CellContext`b $CellContext`c - $CellContext`a^2 \
$CellContext`b^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b^3 $CellContext`c + $CellContext`b^4 \
$CellContext`c - 
     2 $CellContext`a^3 $CellContext`c^2 - $CellContext`a^2 $CellContext`b \
$CellContext`c^2 - $CellContext`b^3 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^3 - $CellContext`b^2 \
$CellContext`c^3 + $CellContext`a $CellContext`c^4 + $CellContext`b \
$CellContext`c^4), $CellContext`b^2 ($CellContext`a^4 $CellContext`b - 
     2 $CellContext`a^2 $CellContext`b^3 + $CellContext`b^5 + \
$CellContext`a^4 $CellContext`c + 
     2 $CellContext`a^3 $CellContext`b $CellContext`c - $CellContext`a^2 \
$CellContext`b^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b^3 $CellContext`c - $CellContext`a^3 \
$CellContext`c^2 - $CellContext`a $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^3 $CellContext`c^2 - $CellContext`a^2 $CellContext`c^3 + 
     2 $CellContext`a $CellContext`b $CellContext`c^3 + $CellContext`a \
$CellContext`c^4 + $CellContext`b $CellContext`c^4), $CellContext`c^2 \
($CellContext`a^4 $CellContext`b - $CellContext`a^3 $CellContext`b^2 - \
$CellContext`a^2 $CellContext`b^3 + $CellContext`a $CellContext`b^4 + \
$CellContext`a^4 $CellContext`c + 
     2 $CellContext`a^3 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^3 $CellContext`c + $CellContext`b^4 \
$CellContext`c - $CellContext`a^2 $CellContext`b $CellContext`c^2 - \
$CellContext`a $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^3 - 
     2 $CellContext`a $CellContext`b $CellContext`c^3 - 
     2 $CellContext`b^2 $CellContext`c^3 + $CellContext`c^5)}, "   XM/AM=", 
   Style[1 + 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950562846*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"17cbdbce-6d12-4ee8-a180-627bbbd72aa9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "583"}],
  SequenceForm["n=", 583],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950566041*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"262dfd95-c0eb-47aa-a5a3-74e84289ba78"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "583", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 583, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 $CellContext`b - \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`c^3), \
$CellContext`b^2 (-$CellContext`a^3 + $CellContext`a $CellContext`b^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`c^3), $CellContext`c^2 (-$CellContext`a^3 - \
$CellContext`b^3 + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`c^2 + $CellContext`b $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 7] (4 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950573372*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9371d4a4-40b9-413b-9eb2-ae588463e4f0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "584"}],
  SequenceForm["n=", 584],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979505764*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"53ee3444-759f-4cdd-990b-9f640726d621"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "584", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 584, 
   "   ", {$CellContext`a^2 ($CellContext`a^3 - $CellContext`a \
$CellContext`b^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2), $CellContext`b^2 (-$CellContext`a^2 $CellContext`b + \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2), $CellContext`c^2 \
(-$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 - \
$CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 7] (4 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950611747*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"67ee5130-17b6-4064-8112-9954a0741e6c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "585"}],
  SequenceForm["n=", 585],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950615684*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"85e0cfb4-3d8d-4735-8923-9db8183ba186"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "586"}],
  SequenceForm["n=", 586],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950660553*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"35bf617e-3cdf-461f-9e97-83e4af702c44"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "587"}],
  SequenceForm["n=", 587],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950697502*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"32606ba1-1d3a-4e96-bc4d-a6e989046dc6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "588"}],
  SequenceForm["n=", 588],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795075148*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"075b2f7d-070d-48ec-8aed-92de10a18398"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "589"}],
  SequenceForm["n=", 589],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950787035*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5ec84f45-a4a9-4cc8-bf1a-27fce5f27b03"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "590"}],
  SequenceForm["n=", 590],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950824059*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"deba6317-e38d-493e-a74e-2ab680347c16"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "591"}],
  SequenceForm["n=", 591],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795085964*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5ad8357c-c4f7-4bd4-a981-d738354b5373"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "592"}],
  SequenceForm["n=", 592],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950862364*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a03ef924-42e7-444b-b81e-2edd0554681c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "592", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["11", "29"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 592, 
   "   ", {$CellContext`a^2 ($CellContext`a^6 $CellContext`b^2 - 
     2 $CellContext`a^4 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^6 + 
     2 $CellContext`a^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + 
     2 $CellContext`b^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`c^4 - 
     6 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     3 $CellContext`b^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^6 + \
$CellContext`b^2 $CellContext`c^6) (2 $CellContext`a^6 $CellContext`b^2 - 
     3 $CellContext`a^4 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^6 + \
$CellContext`a^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     6 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + $CellContext`b^6 \
$CellContext`c^2 - 2 $CellContext`a^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     3 $CellContext`b^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^6 + 
     2 $CellContext`b^2 $CellContext`c^6), $CellContext`b^2 ($CellContext`a^6 \
$CellContext`b^2 - 
     2 $CellContext`a^4 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^6 + 
     2 $CellContext`a^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + 
     2 $CellContext`b^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`c^4 - 
     6 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     3 $CellContext`b^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^6 + \
$CellContext`b^2 $CellContext`c^6) ($CellContext`a^6 $CellContext`b^2 - 
     3 $CellContext`a^4 $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b^6 + $CellContext`a^6 $CellContext`c^2 - 
     6 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + $CellContext`b^6 \
$CellContext`c^2 - 3 $CellContext`a^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     2 $CellContext`b^4 $CellContext`c^4 + 
     2 $CellContext`a^2 $CellContext`c^6 + $CellContext`b^2 \
$CellContext`c^6), $CellContext`c^2 ($CellContext`a^6 $CellContext`b^2 - 
     3 $CellContext`a^4 $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b^6 + $CellContext`a^6 $CellContext`c^2 - 
     6 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     3 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + $CellContext`b^6 \
$CellContext`c^2 - 3 $CellContext`a^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     2 $CellContext`b^4 $CellContext`c^4 + 
     2 $CellContext`a^2 $CellContext`c^6 + $CellContext`b^2 $CellContext`c^6) \
(2 $CellContext`a^6 $CellContext`b^2 - 
     3 $CellContext`a^4 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^6 + \
$CellContext`a^6 $CellContext`c^2 - 
     3 $CellContext`a^4 $CellContext`b^2 $CellContext`c^2 - 
     6 $CellContext`a^2 $CellContext`b^4 $CellContext`c^2 + $CellContext`b^6 \
$CellContext`c^2 - 2 $CellContext`a^4 $CellContext`c^4 - 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^4 - 
     3 $CellContext`b^4 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^6 + 
     2 $CellContext`b^2 $CellContext`c^6)}, "   XM/AM=", 
   Style[
    Rational[11, 29], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950866737*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2c36c97c-2c83-4ef9-a2e3-59644288646f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "593"}],
  SequenceForm["n=", 593],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950870536*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8b357926-0dd3-4be5-9db0-15358d0e5dbf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "593", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "41"], " ", 
     RowBox[{"(", 
      RowBox[{"13", "+", 
       RowBox[{"8", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 593, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b)^2 \
($CellContext`a + $CellContext`c)^2, $CellContext`b^2 ($CellContext`a + \
$CellContext`b)^2 ($CellContext`b + $CellContext`c)^2, $CellContext`c^2 \
($CellContext`a + $CellContext`c)^2 ($CellContext`b + $CellContext`c)^2}, 
   "   XM/AM=", 
   Style[Rational[1, 41] (13 + 8 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950904011*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fa23c8ff-21fa-4528-9e5f-f14cc56bd563"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "594"}],
  SequenceForm["n=", 594],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979509083967`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"02df0a24-6de6-44e9-99b5-f93a3461d825"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "594", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], "2"], ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], "2"]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", 
     RowBox[{"5", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 594, 
   "   ", {($CellContext`b + $CellContext`c)^2, ($CellContext`a + \
$CellContext`c)^2, ($CellContext`a + $CellContext`b)^2}, "   XM/AM=", 
   Style[2/(5 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979509113817`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bff45ac8-3a4c-4915-8b0f-1b721caecb4b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "595"}],
  SequenceForm["n=", 595],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950914578*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"270f2dbd-ae36-4071-ae5b-73ebd4752e39"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "595", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "5"}], "+", 
     RowBox[{"4", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 595, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 + $CellContext`a $CellContext`b + \
$CellContext`a $CellContext`c - $CellContext`b $CellContext`c), \
$CellContext`b^2 ($CellContext`a $CellContext`b + $CellContext`b^2 - \
$CellContext`a $CellContext`c + $CellContext`b $CellContext`c), \
$CellContext`c^2 (-$CellContext`a $CellContext`b + $CellContext`a \
$CellContext`c + $CellContext`b $CellContext`c + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[-5 + 4 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950917313*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"653984d0-3c84-4311-980a-96458d209100"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "596"}],
  SequenceForm["n=", 596],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979509201803`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6fb05bce-0399-4083-ab64-a9e8dc0dd34d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "596", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], "+", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 596, 
   "   ", {($CellContext`a $CellContext`b + $CellContext`b^2 - $CellContext`a \
$CellContext`c + $CellContext`b $CellContext`c) (-$CellContext`a \
$CellContext`b + $CellContext`a $CellContext`c + $CellContext`b \
$CellContext`c + $CellContext`c^2), ($CellContext`a^2 + $CellContext`a \
$CellContext`b + $CellContext`a $CellContext`c - $CellContext`b \
$CellContext`c) (-$CellContext`a $CellContext`b + $CellContext`a \
$CellContext`c + $CellContext`b $CellContext`c + $CellContext`c^2), \
($CellContext`a^2 + $CellContext`a $CellContext`b + $CellContext`a \
$CellContext`c - $CellContext`b $CellContext`c) ($CellContext`a \
$CellContext`b + $CellContext`b^2 - $CellContext`a $CellContext`c + \
$CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[Rational[-1, 2] + 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950923209*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d6c6bad9-4d41-4166-a608-6742ee2bc659"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "597"}],
  SequenceForm["n=", 597],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950926311*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0062aea9-6f9b-496e-aac0-4cd1f52d2d4c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "597", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"], "+", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["c", "2"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["5", "12"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 597, "   ", {
   4 $CellContext`a^2 + $CellContext`b^2 + $CellContext`c^2, $CellContext`a^2 + 
    4 $CellContext`b^2 + $CellContext`c^2, $CellContext`a^2 + \
$CellContext`b^2 + 4 $CellContext`c^2}, "   XM/AM=", 
   Style[
    Rational[5, 12], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950929315*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d9bfa8a8-f640-4cf5-99a0-dfdb282cba4c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "598"}],
  SequenceForm["n=", 598],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979509322844`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5ea663d1-e0ed-4343-b513-bc1ec6c00e00"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "598", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["5", "9"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 598, 
   "   ", {(2 $CellContext`a^2 + 2 $CellContext`b^2 - $CellContext`c^2) (
     2 $CellContext`a^2 - $CellContext`b^2 + 2 $CellContext`c^2), (
     2 $CellContext`a^2 + 
     2 $CellContext`b^2 - $CellContext`c^2) (-$CellContext`a^2 + 
     2 $CellContext`b^2 + 2 $CellContext`c^2), (
     2 $CellContext`a^2 - $CellContext`b^2 + 
     2 $CellContext`c^2) (-$CellContext`a^2 + 2 $CellContext`b^2 + 
     2 $CellContext`c^2)}, "   XM/AM=", 
   Style[
    Rational[5, 9], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979509358397`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7b4cdbc0-d50a-4ff5-88c3-c9aed719190e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "599"}],
  SequenceForm["n=", 599],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950939146*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a5ad0307-a822-4d01-86b5-7d17b8bc9c07"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "599", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "2"]}], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["c", "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "6"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 599, 
   "   ", {$CellContext`a^2 - 2 $CellContext`b^2 - 
    2 $CellContext`c^2, (-2) $CellContext`a^2 + $CellContext`b^2 - 
    2 $CellContext`c^2, (-2) $CellContext`a^2 - 
    2 $CellContext`b^2 + $CellContext`c^2}, "   XM/AM=", 
   Style[
    Rational[1, 6], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950942136*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"10283865-afd4-4c86-ae6d-493a7e532d4f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "600"}],
  SequenceForm["n=", 600],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979509449472`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1d14ae28-a424-4056-bbdd-f18aa7279c40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "600", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["3", "103"], " ", 
     RowBox[{"(", 
      RowBox[{"38", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 600, 
   "   ", {$CellContext`a^2 (
     2 $CellContext`a^2 - $CellContext`a $CellContext`b + 2 $CellContext`b^2 - 
     2 $CellContext`c^2) (2 $CellContext`a^2 - 
     2 $CellContext`b^2 - $CellContext`a $CellContext`c + 
     2 $CellContext`c^2) ($CellContext`a^2 $CellContext`b^2 + \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2), \
$CellContext`b^2 (2 $CellContext`a^2 - $CellContext`a $CellContext`b + 
     2 $CellContext`b^2 - 2 $CellContext`c^2) ((-2) $CellContext`a^2 + 
     2 $CellContext`b^2 - $CellContext`b $CellContext`c + 
     2 $CellContext`c^2) ($CellContext`a^2 $CellContext`b^2 - \
$CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2), \
$CellContext`c^2 (2 $CellContext`a^2 - 
     2 $CellContext`b^2 - $CellContext`a $CellContext`c + 
     2 $CellContext`c^2) ((-2) $CellContext`a^2 + 
     2 $CellContext`b^2 - $CellContext`b $CellContext`c + 
     2 $CellContext`c^2) (-$CellContext`a^2 $CellContext`b^2 + \
$CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[Rational[3, 103] (38 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979509490337`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ea91d885-b604-4017-b40f-a94cc2308bbe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "601"}],
  SequenceForm["n=", 601],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979509523487`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"53585159-1191-4d8b-a57b-81782c302718"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "601", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 601, 
   "   ", {$CellContext`a^3 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b $CellContext`c^3 + $CellContext`c^4), $CellContext`b^3 \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^3 $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`c^3 + $CellContext`c^4), $CellContext`c^3 \
($CellContext`a^4 - 2 $CellContext`a^3 $CellContext`b - 
     2 $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[Rational[1, 7] (4 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950956518*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e34d4661-d445-4d80-8e89-aa63da5822e0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "602"}],
  SequenceForm["n=", 602],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950959916*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dff936a7-76db-4df6-afb6-55d236ecc401"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "602", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    SqrtBox["2"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 602, 
   "   ", {$CellContext`a^3 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`b $CellContext`c^3 + $CellContext`c^4), $CellContext`b^3 \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^3 $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`c^3 + $CellContext`c^4), $CellContext`c^3 \
($CellContext`a^4 + 2 $CellContext`a^3 $CellContext`b - 
     2 $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979509631863`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"45dc5d8d-fe0c-4e42-944e-7b820e3619e2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "603"}],
  SequenceForm["n=", 603],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097950966548*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"95b89c47-640d-40e2-b545-002e8b347873"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "604"}],
  SequenceForm["n=", 604],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979509686527`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"692e95ec-583f-4f4f-981f-02afd6fd3069"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "604", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 604, 
   "   ", {$CellContext`a^3 ($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a - $CellContext`b + $CellContext`c), \
$CellContext`b^3 ($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c), $CellContext`c^3 \
($CellContext`a - $CellContext`b + $CellContext`c) (-$CellContext`a + \
$CellContext`b + $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 7] (4 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979510061207`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8263c63c-e8dc-4b16-ac03-28e506c5329a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "605"}],
  SequenceForm["n=", 605],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951010663*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"19e693ea-05ce-4efd-b4b1-85d3751078a0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "606"}],
  SequenceForm["n=", 606],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795104802*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"664b9be9-d4ac-4c80-9b41-7e815f854a2d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "607"}],
  SequenceForm["n=", 607],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951054528*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9c8942d3-a904-46fe-8f7b-cf4062eccee8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "608"}],
  SequenceForm["n=", 608],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951091299*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e33f8b4f-499e-491c-a9bd-76a770a4a5b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "609"}],
  SequenceForm["n=", 609],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979510946283`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2c2d782e-55b9-4081-9511-b2fb1a44b291"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "609", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["5", 
     RowBox[{"7", "+", 
      SqrtBox["2"]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 609, 
   "   ", {$CellContext`a^2 (
     2 $CellContext`a^2 + $CellContext`b $CellContext`c), $CellContext`b^2 (
     2 $CellContext`b^2 + $CellContext`a $CellContext`c), $CellContext`c^2 \
($CellContext`a $CellContext`b + 2 $CellContext`c^2)}, "   XM/AM=", 
   Style[5/(7 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979510971212`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2f3af3cc-e274-448a-b62a-651a68df1583"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "610"}],
  SequenceForm["n=", 610],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951099771*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c0013f58-837f-4b0c-aafe-3657dda5d81a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "610", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 610, 
   "   ", {$CellContext`a (3 $CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), $CellContext`b \
(-$CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + 3 $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4), $CellContext`c \
(-$CellContext`a^4 + 2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + 3 $CellContext`c^4)}, "   XM/AM=", 
   
   Style[-1 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979511022387`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5f457696-fb16-49ce-84fe-e4e4ff2d28b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "611"}],
  SequenceForm["n=", 611],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951104637*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"27fa3268-35e8-43b4-a4b2-ac761fa96b5d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "611", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", 
     RowBox[{"4", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 611, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b $CellContext`c^3 + $CellContext`c^4), $CellContext`b^2 \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^3 $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`c^3 + $CellContext`c^4), $CellContext`c^2 \
($CellContext`a^4 - 2 $CellContext`a^3 $CellContext`b - 
     2 $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[3/(4 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951112906*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ab99b60f-6505-4e3e-9d7a-6ac7c61aac67"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "612"}],
  SequenceForm["n=", 612],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979511170673`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6f5a0016-87af-46cc-9a10-baeaba3add10"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "612", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["3", "17"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "5"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 612, 
   "   ", {$CellContext`a ($CellContext`a^2 + $CellContext`b^2 + 
     2 $CellContext`b $CellContext`c + $CellContext`c^2), $CellContext`b \
($CellContext`a^2 + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + $CellContext`c^2), $CellContext`c \
($CellContext`a^2 + 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[Rational[-3, 17] (-5 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979511529293`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0706b83a-8747-4609-ac67-c71483311e03"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "613"}],
  SequenceForm["n=", 613],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951157064*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b3af236c-84b2-4ced-ae30-001873792a19"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "613", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 613, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`b $CellContext`c^3 + $CellContext`c^4), $CellContext`b^2 \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^3 $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`c^3 + $CellContext`c^4), $CellContext`c^2 \
($CellContext`a^4 + 2 $CellContext`a^3 $CellContext`b - 
     2 $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[Rational[1, 2] 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951159642*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e2d21af4-a8ab-4b4c-bf93-0856552e7bb8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "614"}],
  SequenceForm["n=", 614],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951162808*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ecb18a3d-a266-4275-b454-f77d485a7fb5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "614", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 614, 
   "   ", {$CellContext`a ($CellContext`a^2 + $CellContext`b^2 - 
     2 $CellContext`b $CellContext`c + $CellContext`c^2), $CellContext`b \
($CellContext`a^2 + $CellContext`b^2 - 
     2 $CellContext`a $CellContext`c + $CellContext`c^2), $CellContext`c \
($CellContext`a^2 - 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[Rational[1, 7] (1 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951166206*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fa874115-2345-4dfa-a492-5e1272387a84"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "615"}],
  SequenceForm["n=", 615],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951169232*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f333abef-a91d-4d68-bcea-3c43d01b4c04"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "616"}],
  SequenceForm["n=", 616],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979512084723`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ab960db8-95ef-4e6f-a348-831be22b5b06"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "617"}],
  SequenceForm["n=", 617],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951284005*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"166c052e-07ab-4c3f-9741-c210da538a87"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "618"}],
  SequenceForm["n=", 618],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951338438*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"719656bc-ee6e-45ca-be47-3777ffee2e76"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "619"}],
  SequenceForm["n=", 619],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951383355*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6abe7ef0-6b64-41e2-a1fd-8ba661003fb3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "620"}],
  SequenceForm["n=", 620],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951426445*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dcf245bd-3723-414f-876d-954fd362645a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "620", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "2"],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 620, "   ", {
   2 $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + 2 $CellContext`b^4 - 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 + \
$CellContext`b^4 - 2 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + 2 $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[1, 2], 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951430855*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f468549b-64f5-4f15-a91d-a7d8f0c6d6ba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "621"}],
  SequenceForm["n=", 621],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979514341393`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ce48fb82-178b-4a2f-9d45-205fcba92bf0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "622"}],
  SequenceForm["n=", 622],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951472062*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d549e9a8-b75b-424e-8eb5-8bbb5f3fbe41"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "623"}],
  SequenceForm["n=", 623],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951518873*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"feba8461-f47e-4855-b9ad-ce247a8439f0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "624"}],
  SequenceForm["n=", 624],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951571529*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"204cef78-3d82-4b7f-be72-da13ec022864"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "625"}],
  SequenceForm["n=", 625],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979516163473`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6c789516-1ee9-4c95-9b67-ce58bac524c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "625", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", "2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 625, 
   "   ", {$CellContext`a^2 $CellContext`b^2 - 
    2 $CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 - 
    2 $CellContext`c^4, (-2) $CellContext`a^4 + $CellContext`a^2 \
$CellContext`b^2 + 
    2 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - 
    2 $CellContext`c^4, (-2) $CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 - 
    2 $CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2}, "   XM/AM=", 
   Style[
    Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951624743*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e5cc316c-c6c3-405e-ad2d-0a1d41e996b6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "626"}],
  SequenceForm["n=", 626],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951628253*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"83c1e1d1-9ae2-4737-8e73-e1b39eb11d49"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "626", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "4"], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      SuperscriptBox["b", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "6"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 626, 
   "   ", {$CellContext`b^4 + $CellContext`c^4, $CellContext`a^4 + \
$CellContext`c^4, $CellContext`a^4 + $CellContext`b^4}, "   XM/AM=", 
   Style[
    Rational[1, 6], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951631241*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1ba71fd5-4d6c-4e61-aa1b-90ad9464840c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "627"}],
  SequenceForm["n=", 627],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951634757*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e9c39fe5-9a09-4307-a542-3182e658b67b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "628"}],
  SequenceForm["n=", 628],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951709938*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"02819502-2080-4f10-a477-d446c967ff9c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "629"}],
  SequenceForm["n=", 629],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979517640657`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"27f07491-4a10-48cc-8de0-0686be1ccc4a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "630"}],
  SequenceForm["n=", 630],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951809972*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6cefb0fc-87a0-4e2d-aa7c-ea64b50af384"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "631"}],
  SequenceForm["n=", 631],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979518501472`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"27727e4d-7c0d-49cc-a74d-87f325850775"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "631", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "5"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 631, "   ", {
   3 $CellContext`a^4 - 
    4 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    4 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - 
    4 $CellContext`a^2 $CellContext`b^2 + 3 $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`c^2 - 
    4 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4, $CellContext`a^4 - 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
    4 $CellContext`a^2 $CellContext`c^2 - 4 $CellContext`b^2 $CellContext`c^2 + 
    3 $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[1, 5], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979518531847`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"93127921-3268-4af3-aa1c-f54432be5493"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "632"}],
  SequenceForm["n=", 632],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951855509*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"86b14fc4-d381-4a9b-bb5a-6666ebe71ed2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "632", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "4"]}]}], ",", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"6", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"7", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "10"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 632, "   ", {
   4 $CellContext`a^4 - 7 $CellContext`a^2 $CellContext`b^2 + 
    3 $CellContext`b^4 - 7 $CellContext`a^2 $CellContext`c^2 - 
    6 $CellContext`b^2 $CellContext`c^2 + 3 $CellContext`c^4, 
    3 $CellContext`a^4 - 7 $CellContext`a^2 $CellContext`b^2 + 
    4 $CellContext`b^4 - 6 $CellContext`a^2 $CellContext`c^2 - 
    7 $CellContext`b^2 $CellContext`c^2 + 3 $CellContext`c^4, 
    3 $CellContext`a^4 - 6 $CellContext`a^2 $CellContext`b^2 + 
    3 $CellContext`b^4 - 7 $CellContext`a^2 $CellContext`c^2 - 
    7 $CellContext`b^2 $CellContext`c^2 + 4 $CellContext`c^4}, "   XM/AM=", 
   Style[
    Rational[3, 10], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951857782*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8b1ae753-2f5a-429c-85d9-0c313169aa3c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "633"}],
  SequenceForm["n=", 633],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951860413*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0e054ce8-6e9c-4524-b480-96a246ca787c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "634"}],
  SequenceForm["n=", 634],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951900105*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1e00e9f7-217e-48e9-886c-db0c4c9fb54f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "635"}],
  SequenceForm["n=", 635],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979519444857`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a09a8b0c-ee07-44f9-a679-b8416fa1db4e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "636"}],
  SequenceForm["n=", 636],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097951992551*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"248337c6-b3e5-4d28-a44d-be8403de09f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "637"}],
  SequenceForm["n=", 637],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952029642*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f76cd649-d007-4ee8-88f2-7b4dc66362ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "638"}],
  SequenceForm["n=", 638],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952076241*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b386dddc-cbec-4102-8c59-7d3c12b2fff0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "639"}],
  SequenceForm["n=", 639],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795207967*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"df17f45e-ca97-479a-97ba-24b301f21429"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "640"}],
  SequenceForm["n=", 640],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979521171637`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"16d6f0d8-eac7-4fea-84f6-5eb2b84800f2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "641"}],
  SequenceForm["n=", 641],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979521200457`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7f062c4b-7c52-479a-be55-e7e88b6c18a5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "641", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "4"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      SuperscriptBox["c", "4"], "+", 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["c", "2"], "+", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}]}], ")"}]}]}], ",", 
     
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "4"], "+", 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["b", "2"]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["c", "2"], "+", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
               RowBox[{"(", 
                RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}]}], ")"}]}]}], 
        ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["c", "2"]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}]}]}], "}"}],
    "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "4"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 641, 
   "   ", {(-2) $CellContext`a^4 - $CellContext`b^4 - $CellContext`c^4 + \
$CellContext`c^2 (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c) (-$CellContext`a + \
$CellContext`b + $CellContext`c) ($CellContext`a + $CellContext`b + \
$CellContext`c))^Rational[1, 2] + 
    3 $CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2) + 
    2 $CellContext`b^2 ($CellContext`c^2 + 
      Rational[1, 
         2] (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c) (-$CellContext`a + \
$CellContext`b + $CellContext`c) ($CellContext`a + $CellContext`b + \
$CellContext`c))^Rational[1, 2]), -$CellContext`a^4 - 2 $CellContext`b^4 + 
    3 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4 + $CellContext`c^2 \
(($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a - \
$CellContext`b + $CellContext`c) (-$CellContext`a + $CellContext`b + \
$CellContext`c) ($CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[1, 2] + $CellContext`a^2 (3 $CellContext`b^2 + 
      2 ($CellContext`c^2 + 
        Rational[
          1, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c) (-$CellContext`a + \
$CellContext`b + $CellContext`c) ($CellContext`a + $CellContext`b + \
$CellContext`c))^Rational[1, 2])), -$CellContext`a^4 - $CellContext`b^4 - 
    2 $CellContext`c^4 + $CellContext`b^2 (
      3 $CellContext`c^2 + (($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c) ($CellContext`a + \
$CellContext`b + $CellContext`c))^Rational[1, 2]) + $CellContext`a^2 (
      2 $CellContext`b^2 + 
      3 $CellContext`c^2 + (($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c) ($CellContext`a + \
$CellContext`b + $CellContext`c))^Rational[1, 2])}, "   XM/AM=", 
   Style[
    Rational[1, 4], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952157324*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ad7680f1-9826-4d37-b637-2c56389a3dfb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "642"}],
  SequenceForm["n=", 642],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979521607513`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d3551dcb-048a-467a-aa33-a8a33679050f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "642", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "4"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["b", "2"], "+", 
         SuperscriptBox["c", "2"]}], ")"}]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["c", "2"], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["c", "2"], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["b", "2"]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "2"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], "-", 
      RowBox[{
       SuperscriptBox["c", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["c", "2"], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["c", "2"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["c", "2"]}], "-", 
         SqrtBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}], ")"}]}]}]}], "}"}],
    "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "4"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 642, 
   "   ", {(-2) $CellContext`a^4 - $CellContext`b^4 + 
    3 $CellContext`a^2 ($CellContext`b^2 + $CellContext`c^2) + 
    2 $CellContext`b^2 ($CellContext`c^2 + 
      Rational[-1, 
         2] (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c) (-$CellContext`a + \
$CellContext`b + $CellContext`c) ($CellContext`a + $CellContext`b + \
$CellContext`c))^
        Rational[
         1, 2]) - $CellContext`c^2 ($CellContext`c^2 + (($CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[1, 2]), -$CellContext`a^4 - 2 $CellContext`b^4 + 
    3 $CellContext`b^2 $CellContext`c^2 + $CellContext`a^2 (
      3 $CellContext`b^2 + 
      2 $CellContext`c^2 - (($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c) ($CellContext`a + \
$CellContext`b + $CellContext`c))^
      Rational[1, 
        2]) - $CellContext`c^2 ($CellContext`c^2 + (($CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c) \
($CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[1, 2]), -$CellContext`a^4 - $CellContext`b^4 - 
    2 $CellContext`c^4 + $CellContext`b^2 (
      3 $CellContext`c^2 - (($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c) ($CellContext`a + \
$CellContext`b + $CellContext`c))^Rational[1, 2]) + $CellContext`a^2 (
      2 $CellContext`b^2 + 
      3 $CellContext`c^2 - (($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c) ($CellContext`a + \
$CellContext`b + $CellContext`c))^Rational[1, 2])}, "   XM/AM=", 
   Style[
    Rational[1, 4], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952197043*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"84643ec2-caec-46fd-af18-18a51f19b124"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "643"}],
  SequenceForm["n=", 643],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952200612*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"57c6274c-6148-48d9-9f8c-773ce7b2fd90"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "644"}],
  SequenceForm["n=", 644],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952202729*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"847b0c83-c28c-4dd1-be44-007fe122f2ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "645"}],
  SequenceForm["n=", 645],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952204705*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3cff3202-8072-40be-872d-202f426273bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "646"}],
  SequenceForm["n=", 646],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952206814*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b6ab89f5-3af7-4574-8c0d-18ab166d1afb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "647"}],
  SequenceForm["n=", 647],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952208673*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5e916696-f8cd-458a-9030-d70feac97253"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "648"}],
  SequenceForm["n=", 648],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952210622*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"829411a9-1028-411b-b906-41b63c9378c7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "649"}],
  SequenceForm["n=", 649],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952212935*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"add3abbb-2df6-45e4-a244-636625e444ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "650"}],
  SequenceForm["n=", 650],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979522152*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"81ae5e1d-ff66-44f0-87c6-10f24415bd3e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "651"}],
  SequenceForm["n=", 651],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952217189*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2460bd24-0495-44ac-b6fb-7d8b38022dc1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "652"}],
  SequenceForm["n=", 652],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952219955*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6df215c5-89c4-4e1e-863a-4bed59cbf6bb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "653"}],
  SequenceForm["n=", 653],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979522221212`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bae3db52-bf29-4d46-9535-bf718eb9b138"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "654"}],
  SequenceForm["n=", 654],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979522240543`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8d506efb-9db3-44c8-8133-2c76996b12a6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "655"}],
  SequenceForm["n=", 655],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952226017*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"047dc5e9-bc48-4888-80b3-89160a7764c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "656"}],
  SequenceForm["n=", 656],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979522279*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"10bd169e-3b38-4513-8d2c-ec7f72a6a15d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "657"}],
  SequenceForm["n=", 657],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979522302523`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3ead7f4a-ab5a-460a-b433-5d66e4c620e7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "658"}],
  SequenceForm["n=", 658],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979522323313`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d47030dc-8259-42ea-bfe1-8db7a0233761"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "659"}],
  SequenceForm["n=", 659],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952234529*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8ebc20e5-2b4c-41a6-90af-545034be047b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "660"}],
  SequenceForm["n=", 660],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979522364902`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1b4fdfc4-33bc-4566-b47e-f32de1ac7388"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "661"}],
  SequenceForm["n=", 661],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952238432*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"782e50d9-c21d-455c-a678-2663c9997bb3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "662"}],
  SequenceForm["n=", 662],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952240374*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"51f1b4dc-4505-4119-ac70-28d645a281ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "663"}],
  SequenceForm["n=", 663],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979522424088`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"580dde49-4cf2-4058-9aa5-d614556b04b1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "664"}],
  SequenceForm["n=", 664],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979522443867`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a5eea736-a24c-4ffd-ae61-1923849fd32d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "665"}],
  SequenceForm["n=", 665],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795224634*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"536b90f5-617a-4ac3-91bf-41ab6f4a08ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "666"}],
  SequenceForm["n=", 666],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952248341*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c6bc83d2-e85a-48da-a742-84b9e7829f8f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "667"}],
  SequenceForm["n=", 667],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952251237*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cdb85eae-c000-4877-9be1-e297317ef9cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "668"}],
  SequenceForm["n=", 668],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952253766*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8b09c97a-d076-4191-95f1-79fc756de044"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "669"}],
  SequenceForm["n=", 669],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979522561007`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d4132f77-eaf0-467f-9b56-150b95ab8e40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "670"}],
  SequenceForm["n=", 670],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952258525*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ce2ef112-3734-441a-b07d-567afdd249c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "671"}],
  SequenceForm["n=", 671],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795226103*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"166dc1d2-156e-4cdc-b4ab-46c0481bff73"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "671", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", "3"]}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 671, 
   "   ", {($CellContext`a^2 + $CellContext`b^2 - 
     2 $CellContext`c^2) ($CellContext`a^2 - 
     2 $CellContext`b^2 + $CellContext`c^2), ($CellContext`a^2 + \
$CellContext`b^2 - 
     2 $CellContext`c^2) ((-2) $CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2), ($CellContext`a^2 - 
     2 $CellContext`b^2 + $CellContext`c^2) ((-2) $CellContext`a^2 + \
$CellContext`b^2 + $CellContext`c^2)}, "   XM/AM=", 
   Style[
    Rational[-1, 3], 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952263797*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"983d36c7-8775-42c2-b35a-00faa1fc93bc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "672"}],
  SequenceForm["n=", 672],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979522668457`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"64909839-6424-4197-a259-f2fe980b5dd0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "672", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"2", "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 672, 
   "   ", {$CellContext`a^2 ($CellContext`a $CellContext`b - $CellContext`b^2 + \
$CellContext`a $CellContext`c - $CellContext`c^2), $CellContext`b^2 \
(-$CellContext`a^2 + $CellContext`a $CellContext`b + $CellContext`b \
$CellContext`c - $CellContext`c^2), $CellContext`c^2 (-$CellContext`a^2 - \
$CellContext`b^2 + $CellContext`a $CellContext`c + $CellContext`b \
$CellContext`c)}, "   XM/AM=", 
   Style[2 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795226925*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"46c4bf10-ecc9-4ccf-acce-9a13d1704de2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "673"}],
  SequenceForm["n=", 673],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979522717657`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"31511db9-e98c-4859-a9ea-39961316b412"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "673", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 673, 
   "   ", {($CellContext`a^2 + $CellContext`b^2 - $CellContext`a \
$CellContext`c - $CellContext`b $CellContext`c) ($CellContext`a^2 - \
$CellContext`a $CellContext`b - $CellContext`b $CellContext`c + \
$CellContext`c^2), ($CellContext`a^2 + $CellContext`b^2 - $CellContext`a \
$CellContext`c - $CellContext`b $CellContext`c) (-$CellContext`a \
$CellContext`b + $CellContext`b^2 - $CellContext`a $CellContext`c + \
$CellContext`c^2), (-$CellContext`a $CellContext`b + $CellContext`b^2 - \
$CellContext`a $CellContext`c + $CellContext`c^2) ($CellContext`a^2 - \
$CellContext`a $CellContext`b - $CellContext`b $CellContext`c + \
$CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 7] (-1 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952274712*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"534c3339-7d73-47a2-8863-6575fcff0961"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "674"}],
  SequenceForm["n=", 674],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952277513*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"768e4a7b-6677-4016-adab-6911149b11f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "675"}],
  SequenceForm["n=", 675],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952280155*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"39d7255d-eeae-4e25-b5b6-bd0d4ef00c04"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "675", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 675, 
   "   ", {($CellContext`a^3 + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c - $CellContext`b^2 $CellContext`c) ($CellContext`a^3 - \
$CellContext`a^2 $CellContext`b - $CellContext`b $CellContext`c^2 + \
$CellContext`c^3), ($CellContext`a^3 + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c - $CellContext`b^2 $CellContext`c) (-$CellContext`a \
$CellContext`b^2 + $CellContext`b^3 - $CellContext`a $CellContext`c^2 + \
$CellContext`c^3), (-$CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a $CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 - \
$CellContext`a^2 $CellContext`b - $CellContext`b $CellContext`c^2 + \
$CellContext`c^3)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795228304*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f89b1539-f87e-4f90-967d-4f56c2377754"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "676"}],
  SequenceForm["n=", 676],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952285565*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cb771d62-08c3-40e4-8621-87f1c5896b15"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "677"}],
  SequenceForm["n=", 677],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952288104*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ebc05458-7aa3-4416-80f0-d97d53892012"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "678"}],
  SequenceForm["n=", 678],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952290514*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c1e63660-1724-41f6-84e7-bcb32d0bf085"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "678", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "a"}], "-", "b", "-", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", 
         RowBox[{"2", " ", "b"}], "-", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", 
         RowBox[{"2", " ", "c"}]}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", "7"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "4"}], "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 678, 
   "   ", {$CellContext`a (
      2 $CellContext`a - $CellContext`b - $CellContext`c)^2, $CellContext`b \
(-$CellContext`a + 
      2 $CellContext`b - $CellContext`c)^2, $CellContext`c (-$CellContext`a - \
$CellContext`b + 2 $CellContext`c)^2}, "   XM/AM=", 
   Style[Rational[-2, 7] (-4 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952292777*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e72fabbe-dd47-4d83-99f3-7772121ca4b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "679"}],
  SequenceForm["n=", 679],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979522949944`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d04ff6ca-5aed-4de4-b94d-b1d876861ca2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "679", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", 
         RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", 
         RowBox[{"2", " ", "b"}], "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", 
         RowBox[{"2", " ", "c"}]}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}], "2"]}],
      ",", 
     RowBox[{"c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", 
         RowBox[{"2", " ", "b"}], "+", "c"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}], 
       "2"]}]}], "}"}], "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", 
   "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SqrtBox["2"], 
     RowBox[{"8", "+", 
      SqrtBox["2"]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 679, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b - 
      2 $CellContext`c)^2 ($CellContext`a - 
      2 $CellContext`b + $CellContext`c)^2, $CellContext`b ($CellContext`a + \
$CellContext`b - 
      2 $CellContext`c)^2 ((-2) $CellContext`a + $CellContext`b + \
$CellContext`c)^2, $CellContext`c ($CellContext`a - 
      2 $CellContext`b + $CellContext`c)^2 ((-2) $CellContext`a + \
$CellContext`b + $CellContext`c)^2}, "   XM/AM=", 
   Style[2^Rational[1, 2]/(8 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952297484*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7498c996-8517-4dad-ae8a-5da9bb1e7319"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "680"}],
  SequenceForm["n=", 680],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952300785*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"68aae70d-c9f3-4e6e-8cea-8826c489db24"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "681"}],
  SequenceForm["n=", 681],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795230289*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4bdaa75e-9e98-4c5a-b22e-3e2c9004be6a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "682"}],
  SequenceForm["n=", 682],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979523048763`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"89f18f59-3b3f-4b28-845f-df160c18eed9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "683"}],
  SequenceForm["n=", 683],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952307238*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2af29ba5-f936-494e-828b-e0d604043534"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "684"}],
  SequenceForm["n=", 684],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979523094*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"275076b9-da3c-464d-b41f-a3848a0db89a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "685"}],
  SequenceForm["n=", 685],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979523115797`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8ab1e88f-4d2c-4437-9c08-729e5d8c7a81"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "686"}],
  SequenceForm["n=", 686],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952313696*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c13cd578-c457-43fe-8690-41bdc82069cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "687"}],
  SequenceForm["n=", 687],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952315761*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a962265b-a740-4d3a-8b2d-eeec10a0cb0e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "688"}],
  SequenceForm["n=", 688],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952317679*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f666369d-04e0-472b-ba4b-661eb84e2994"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "689"}],
  SequenceForm["n=", 689],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952319768*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9b064f64-00f5-4a70-9e61-9a5d0a1cca82"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "690"}],
  SequenceForm["n=", 690],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952322056*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b9be1bf4-4b24-4307-a3c7-6f2608a4b58e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "691"}],
  SequenceForm["n=", 691],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952324691*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"069413cd-d28c-45c2-adcf-443602943dec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "692"}],
  SequenceForm["n=", 692],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952326869*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"47be2979-32da-4f45-8c9d-9d6e7adc8ae4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "693"}],
  SequenceForm["n=", 693],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952328989*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"350234d0-9cc5-4501-8f8f-31abcfe5ed49"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "694"}],
  SequenceForm["n=", 694],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952331197*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5ab52653-2121-41d3-9b32-f30d9325ba58"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "694", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", "2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 694, 
   "   ", {$CellContext`a^2 (-$CellContext`b^2 + $CellContext`a \
$CellContext`c) ($CellContext`b^2 + $CellContext`a $CellContext`c) \
($CellContext`a $CellContext`b - $CellContext`c^2) ($CellContext`a \
$CellContext`b + $CellContext`c^2), $CellContext`b^2 (-$CellContext`a^2 + \
$CellContext`b $CellContext`c) ($CellContext`a^2 + $CellContext`b \
$CellContext`c) ($CellContext`a $CellContext`b - $CellContext`c^2) \
($CellContext`a $CellContext`b + $CellContext`c^2), $CellContext`c^2 \
(-$CellContext`b^2 + $CellContext`a $CellContext`c) ($CellContext`b^2 + \
$CellContext`a $CellContext`c) (-$CellContext`a^2 + $CellContext`b \
$CellContext`c) ($CellContext`a^2 + $CellContext`b $CellContext`c)}, 
   "   XM/AM=", 
   Style[
    Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979523336782`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"18b132b8-b3ec-4283-a571-48b85221b2bd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "695"}],
  SequenceForm["n=", 695],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952335916*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c318db44-75a0-48e7-8eca-fc435589e9d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "695", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", "8"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 695, 
   "   ", {$CellContext`a^2 ($CellContext`b^4 + $CellContext`a^2 \
$CellContext`c^2) ($CellContext`a^2 $CellContext`b^2 + $CellContext`c^4), \
$CellContext`b^2 ($CellContext`a^4 + $CellContext`b^2 $CellContext`c^2) \
($CellContext`a^2 $CellContext`b^2 + $CellContext`c^4), $CellContext`c^2 \
($CellContext`b^4 + $CellContext`a^2 $CellContext`c^2) ($CellContext`a^4 + \
$CellContext`b^2 $CellContext`c^2)}, "   XM/AM=", 
   Style[
    Rational[3, 8], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979523380737`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"90369f05-6412-41df-beb5-cbbdeb234338"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "696"}],
  SequenceForm["n=", 696],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952340218*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b6096247-b7a6-44f0-ad2a-8535b575abd2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "697"}],
  SequenceForm["n=", 697],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952342043*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"64735831-56ee-420a-8ddf-112f543d8e34"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "697", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 697, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 $CellContext`b + $CellContext`a \
$CellContext`b^4 - $CellContext`a^4 $CellContext`c - $CellContext`b^4 \
$CellContext`c) (-$CellContext`a^4 $CellContext`b + $CellContext`a^4 \
$CellContext`c + $CellContext`a $CellContext`c^4 - $CellContext`b \
$CellContext`c^4), $CellContext`b^2 ($CellContext`a^4 $CellContext`b + \
$CellContext`a $CellContext`b^4 - $CellContext`a^4 $CellContext`c - \
$CellContext`b^4 $CellContext`c) (-$CellContext`a $CellContext`b^4 + \
$CellContext`b^4 $CellContext`c - $CellContext`a $CellContext`c^4 + \
$CellContext`b $CellContext`c^4), $CellContext`c^2 (-$CellContext`a^4 \
$CellContext`b + $CellContext`a^4 $CellContext`c + $CellContext`a \
$CellContext`c^4 - $CellContext`b $CellContext`c^4) (-$CellContext`a \
$CellContext`b^4 + $CellContext`b^4 $CellContext`c - $CellContext`a \
$CellContext`c^4 + $CellContext`b $CellContext`c^4)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952344404*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6a432f25-56f6-4eec-8a8d-ae13a4fc48a1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "698"}],
  SequenceForm["n=", 698],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952347558*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"272d1fe2-3e70-4f9d-9d6f-74b644586d7a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "699"}],
  SequenceForm["n=", 699],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952349616*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a9b7e6c5-9852-4f25-9c06-11aab8452b0b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "699", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 699, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 $CellContext`b^2 + \
$CellContext`a^2 $CellContext`b^4 - $CellContext`a^4 $CellContext`c^2 - \
$CellContext`b^4 $CellContext`c^2) (-$CellContext`a^4 $CellContext`b^2 + \
$CellContext`a^4 $CellContext`c^2 + $CellContext`a^2 $CellContext`c^4 - \
$CellContext`b^2 $CellContext`c^4), $CellContext`b^2 ($CellContext`a^4 \
$CellContext`b^2 + $CellContext`a^2 $CellContext`b^4 - $CellContext`a^4 \
$CellContext`c^2 - $CellContext`b^4 $CellContext`c^2) (-$CellContext`a^2 \
$CellContext`b^4 + $CellContext`b^4 $CellContext`c^2 - $CellContext`a^2 \
$CellContext`c^4 + $CellContext`b^2 $CellContext`c^4), $CellContext`c^2 \
(-$CellContext`a^4 $CellContext`b^2 + $CellContext`a^4 $CellContext`c^2 + \
$CellContext`a^2 $CellContext`c^4 - $CellContext`b^2 $CellContext`c^4) \
(-$CellContext`a^2 $CellContext`b^4 + $CellContext`b^4 $CellContext`c^2 - \
$CellContext`a^2 $CellContext`c^4 + $CellContext`b^2 $CellContext`c^4)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952352084*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"596ce0af-ac35-4078-84e2-92cd83ca552b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "700"}],
  SequenceForm["n=", 700],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952354515*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f0934802-c8cf-4dd2-bb54-03c7a71d163a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "701"}],
  SequenceForm["n=", 701],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952356297*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c23c32c8-9b96-4121-97d1-39d608d46e67"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "701", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 701, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 $CellContext`b^3 + \
$CellContext`a^3 $CellContext`b^4 - $CellContext`a^4 $CellContext`c^3 - \
$CellContext`b^4 $CellContext`c^3) (-$CellContext`a^4 $CellContext`b^3 + \
$CellContext`a^4 $CellContext`c^3 + $CellContext`a^3 $CellContext`c^4 - \
$CellContext`b^3 $CellContext`c^4), $CellContext`b^2 ($CellContext`a^4 \
$CellContext`b^3 + $CellContext`a^3 $CellContext`b^4 - $CellContext`a^4 \
$CellContext`c^3 - $CellContext`b^4 $CellContext`c^3) (-$CellContext`a^3 \
$CellContext`b^4 + $CellContext`b^4 $CellContext`c^3 - $CellContext`a^3 \
$CellContext`c^4 + $CellContext`b^3 $CellContext`c^4), $CellContext`c^2 \
(-$CellContext`a^4 $CellContext`b^3 + $CellContext`a^4 $CellContext`c^3 + \
$CellContext`a^3 $CellContext`c^4 - $CellContext`b^3 $CellContext`c^4) \
(-$CellContext`a^3 $CellContext`b^4 + $CellContext`b^4 $CellContext`c^3 - \
$CellContext`a^3 $CellContext`c^4 + $CellContext`b^3 $CellContext`c^4)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952358839*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d506c1cd-2d01-4803-865a-81e66157841c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "702"}],
  SequenceForm["n=", 702],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795236131*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2ecd86fc-a3c1-450b-9fca-d8d9de7fa93a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "703"}],
  SequenceForm["n=", 703],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952364069*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b8f5d58a-7e00-4b0f-914d-5ebd3b233e35"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "703", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 703, 
   "   ", {$CellContext`a^2 (
     2 $CellContext`a^4 $CellContext`b^4 - $CellContext`a^4 $CellContext`c^4 - \
$CellContext`b^4 $CellContext`c^4) (-$CellContext`a^4 $CellContext`b^4 + 
     2 $CellContext`a^4 $CellContext`c^4 - $CellContext`b^4 \
$CellContext`c^4), $CellContext`b^2 (
     2 $CellContext`a^4 $CellContext`b^4 - $CellContext`a^4 $CellContext`c^4 - \
$CellContext`b^4 $CellContext`c^4) (-$CellContext`a^4 $CellContext`b^4 - \
$CellContext`a^4 $CellContext`c^4 + 
     2 $CellContext`b^4 $CellContext`c^4), $CellContext`c^2 \
(-$CellContext`a^4 $CellContext`b^4 + 
     2 $CellContext`a^4 $CellContext`c^4 - $CellContext`b^4 $CellContext`c^4) \
(-$CellContext`a^4 $CellContext`b^4 - $CellContext`a^4 $CellContext`c^4 + 
     2 $CellContext`b^4 $CellContext`c^4)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952366794*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"034984d8-adfe-4d27-9591-6ce14cd7f8ea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "704"}],
  SequenceForm["n=", 704],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952369133*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fd535445-b3d8-486c-a7b0-c879f0dca2b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "705"}],
  SequenceForm["n=", 705],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979523720407`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"72c65aeb-b26f-4207-98da-41b6ffd43c91"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "705", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "5"]}], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "5"]}], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 705, 
   "   ", {$CellContext`a^2 (-$CellContext`a^4 $CellContext`b^5 + \
$CellContext`a^5 $CellContext`c^4 - $CellContext`b^5 $CellContext`c^4 + \
$CellContext`a^4 $CellContext`c^5) ($CellContext`a^5 $CellContext`b^4 + \
$CellContext`a^4 $CellContext`b^5 - $CellContext`a^4 $CellContext`c^5 - \
$CellContext`b^4 $CellContext`c^5), $CellContext`b^2 ($CellContext`a^5 \
$CellContext`b^4 + $CellContext`a^4 $CellContext`b^5 - $CellContext`a^4 \
$CellContext`c^5 - $CellContext`b^4 $CellContext`c^5) (-$CellContext`a^5 \
$CellContext`b^4 - $CellContext`a^5 $CellContext`c^4 + $CellContext`b^5 \
$CellContext`c^4 + $CellContext`b^4 $CellContext`c^5), $CellContext`c^2 \
(-$CellContext`a^4 $CellContext`b^5 + $CellContext`a^5 $CellContext`c^4 - \
$CellContext`b^5 $CellContext`c^4 + $CellContext`a^4 $CellContext`c^5) \
(-$CellContext`a^5 $CellContext`b^4 - $CellContext`a^5 $CellContext`c^4 + \
$CellContext`b^5 $CellContext`c^4 + $CellContext`b^4 $CellContext`c^5)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952374793*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f67cc154-ef8f-4632-8798-008006ff2d4e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "706"}],
  SequenceForm["n=", 706],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952377364*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"83ab8a5c-6bd7-44a7-b4cd-b44ca9b013c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "707"}],
  SequenceForm["n=", 707],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952380143*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"839fc24f-a050-4343-8a9c-b0bb227cdd72"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "707", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "6"]}], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "6"]}], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 707, 
   "   ", {$CellContext`a^2 (-$CellContext`a^4 $CellContext`b^6 + \
$CellContext`a^6 $CellContext`c^4 - $CellContext`b^6 $CellContext`c^4 + \
$CellContext`a^4 $CellContext`c^6) ($CellContext`a^6 $CellContext`b^4 + \
$CellContext`a^4 $CellContext`b^6 - $CellContext`a^4 $CellContext`c^6 - \
$CellContext`b^4 $CellContext`c^6), $CellContext`b^2 ($CellContext`a^6 \
$CellContext`b^4 + $CellContext`a^4 $CellContext`b^6 - $CellContext`a^4 \
$CellContext`c^6 - $CellContext`b^4 $CellContext`c^6) (-$CellContext`a^6 \
$CellContext`b^4 - $CellContext`a^6 $CellContext`c^4 + $CellContext`b^6 \
$CellContext`c^4 + $CellContext`b^4 $CellContext`c^6), $CellContext`c^2 \
(-$CellContext`a^4 $CellContext`b^6 + $CellContext`a^6 $CellContext`c^4 - \
$CellContext`b^6 $CellContext`c^4 + $CellContext`a^4 $CellContext`c^6) \
(-$CellContext`a^6 $CellContext`b^4 - $CellContext`a^6 $CellContext`c^4 + \
$CellContext`b^6 $CellContext`c^4 + $CellContext`b^4 $CellContext`c^6)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952382965*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"58c0064f-fee1-4b89-9460-1a73cd123cd1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "708"}],
  SequenceForm["n=", 708],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952385335*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f45675d2-d599-41c9-9c69-4f3e01a76e00"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "709"}],
  SequenceForm["n=", 709],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952387113*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"36935f13-c967-4a8c-bbf0-fa96eda0351d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "709", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "7"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "7"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "7"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "7"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "7"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "7"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "7"]}], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "7"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "7"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "7"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "7"]}], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "7"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 709, 
   "   ", {$CellContext`a^2 (-$CellContext`a^4 $CellContext`b^7 + \
$CellContext`a^7 $CellContext`c^4 - $CellContext`b^7 $CellContext`c^4 + \
$CellContext`a^4 $CellContext`c^7) ($CellContext`a^7 $CellContext`b^4 + \
$CellContext`a^4 $CellContext`b^7 - $CellContext`a^4 $CellContext`c^7 - \
$CellContext`b^4 $CellContext`c^7), $CellContext`b^2 ($CellContext`a^7 \
$CellContext`b^4 + $CellContext`a^4 $CellContext`b^7 - $CellContext`a^4 \
$CellContext`c^7 - $CellContext`b^4 $CellContext`c^7) (-$CellContext`a^7 \
$CellContext`b^4 - $CellContext`a^7 $CellContext`c^4 + $CellContext`b^7 \
$CellContext`c^4 + $CellContext`b^4 $CellContext`c^7), $CellContext`c^2 \
(-$CellContext`a^4 $CellContext`b^7 + $CellContext`a^7 $CellContext`c^4 - \
$CellContext`b^7 $CellContext`c^4 + $CellContext`a^4 $CellContext`c^7) \
(-$CellContext`a^7 $CellContext`b^4 - $CellContext`a^7 $CellContext`c^4 + \
$CellContext`b^7 $CellContext`c^4 + $CellContext`b^4 $CellContext`c^7)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979523895206`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a966e954-5a95-423e-b1cf-407b9fe331b3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "710"}],
  SequenceForm["n=", 710],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952391961*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4f6a82eb-e1ac-4355-9a3b-f75381b5ca32"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "711"}],
  SequenceForm["n=", 711],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952394251*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"42645651-9df7-4ad1-abe2-823ea6a02f85"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "711", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 711, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 + $CellContext`b^4) \
(-$CellContext`b^2 + $CellContext`a $CellContext`c) ($CellContext`b^2 + \
$CellContext`a $CellContext`c) ($CellContext`a $CellContext`b - \
$CellContext`c^2) ($CellContext`a $CellContext`b + $CellContext`c^2) \
($CellContext`b^4 + $CellContext`a^2 $CellContext`c^2) ($CellContext`a^4 + \
$CellContext`c^4) ($CellContext`a^2 $CellContext`b^2 + $CellContext`c^4), \
$CellContext`b^2 ($CellContext`a^4 + $CellContext`b^4) (-$CellContext`a^2 + \
$CellContext`b $CellContext`c) ($CellContext`a^2 + $CellContext`b \
$CellContext`c) ($CellContext`a $CellContext`b - $CellContext`c^2) \
($CellContext`a $CellContext`b + $CellContext`c^2) ($CellContext`a^4 + \
$CellContext`b^2 $CellContext`c^2) ($CellContext`a^2 $CellContext`b^2 + \
$CellContext`c^4) ($CellContext`b^4 + $CellContext`c^4), $CellContext`c^2 \
(-$CellContext`b^2 + $CellContext`a $CellContext`c) ($CellContext`b^2 + \
$CellContext`a $CellContext`c) (-$CellContext`a^2 + $CellContext`b \
$CellContext`c) ($CellContext`a^2 + $CellContext`b $CellContext`c) \
($CellContext`b^4 + $CellContext`a^2 $CellContext`c^2) ($CellContext`a^4 + \
$CellContext`b^2 $CellContext`c^2) ($CellContext`a^4 + $CellContext`c^4) \
($CellContext`b^4 + $CellContext`c^4)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795239753*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"32269d9f-5062-48ea-ae06-3b0d2744f995"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "712"}],
  SequenceForm["n=", 712],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952400116*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a7ab812a-3f03-4564-bdf8-1bf96746e5f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "713"}],
  SequenceForm["n=", 713],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795240196*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6aca29a8-62fe-4a91-bd12-41f7a2a89fd2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "713", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 713, 
   "   ", {$CellContext`a^2 ($CellContext`a^3 $CellContext`b + $CellContext`a \
$CellContext`b^3 - $CellContext`a^3 $CellContext`c - $CellContext`b^3 \
$CellContext`c) (-$CellContext`a^3 $CellContext`b + $CellContext`a^3 \
$CellContext`c + $CellContext`a $CellContext`c^3 - $CellContext`b \
$CellContext`c^3), $CellContext`b^2 ($CellContext`a^3 $CellContext`b + \
$CellContext`a $CellContext`b^3 - $CellContext`a^3 $CellContext`c - \
$CellContext`b^3 $CellContext`c) (-$CellContext`a $CellContext`b^3 + \
$CellContext`b^3 $CellContext`c - $CellContext`a $CellContext`c^3 + \
$CellContext`b $CellContext`c^3), $CellContext`c^2 (-$CellContext`a^3 \
$CellContext`b + $CellContext`a^3 $CellContext`c + $CellContext`a \
$CellContext`c^3 - $CellContext`b $CellContext`c^3) (-$CellContext`a \
$CellContext`b^3 + $CellContext`b^3 $CellContext`c - $CellContext`a \
$CellContext`c^3 + $CellContext`b $CellContext`c^3)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979524045362`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"49c8cc64-ce31-4bb1-b445-aac0a1d19199"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "714"}],
  SequenceForm["n=", 714],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979524073973`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"18d7662f-6b2d-494a-8c30-7e5ba0c7ef8e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "715"}],
  SequenceForm["n=", 715],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979524094353`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"06a1fad5-b89c-45f6-8687-360961660565"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "715", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 715, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c) (-$CellContext`a^2 $CellContext`b^2 + $CellContext`a \
$CellContext`b^2 $CellContext`c + $CellContext`a^2 $CellContext`c^2 - \
$CellContext`b^2 $CellContext`c^2) ($CellContext`a^2 $CellContext`b^2 - \
$CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2), $CellContext`b^2 \
($CellContext`a + $CellContext`b) ($CellContext`b + $CellContext`c) \
($CellContext`a^2 $CellContext`b^2 - $CellContext`a^2 $CellContext`c^2 + \
$CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2) (-$CellContext`a^2 $CellContext`b^2 + $CellContext`a^2 \
$CellContext`b $CellContext`c - $CellContext`a^2 $CellContext`c^2 + \
$CellContext`b^2 $CellContext`c^2), $CellContext`c^2 ($CellContext`a + \
$CellContext`c) ($CellContext`b + $CellContext`c) (-$CellContext`a^2 \
$CellContext`b^2 + $CellContext`a $CellContext`b^2 $CellContext`c + \
$CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) \
(-$CellContext`a^2 $CellContext`b^2 + $CellContext`a^2 $CellContext`b \
$CellContext`c - $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952412137*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"15e4d677-5482-451c-88e1-78908c587aed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "716"}],
  SequenceForm["n=", 716],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979524151487`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e5b49b72-8195-4c30-8f79-b90a89494c43"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "717"}],
  SequenceForm["n=", 717],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979524175177`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3864a5c1-6e8a-42f4-8353-b99b71a2b5c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "717", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 717, 
   "   ", {$CellContext`a^2 (
     2 $CellContext`a^3 $CellContext`b^3 - $CellContext`a^3 $CellContext`c^3 - \
$CellContext`b^3 $CellContext`c^3) (-$CellContext`a^3 $CellContext`b^3 + 
     2 $CellContext`a^3 $CellContext`c^3 - $CellContext`b^3 \
$CellContext`c^3), $CellContext`b^2 (
     2 $CellContext`a^3 $CellContext`b^3 - $CellContext`a^3 $CellContext`c^3 - \
$CellContext`b^3 $CellContext`c^3) (-$CellContext`a^3 $CellContext`b^3 - \
$CellContext`a^3 $CellContext`c^3 + 
     2 $CellContext`b^3 $CellContext`c^3), $CellContext`c^2 \
(-$CellContext`a^3 $CellContext`b^3 + 
     2 $CellContext`a^3 $CellContext`c^3 - $CellContext`b^3 $CellContext`c^3) \
(-$CellContext`a^3 $CellContext`b^3 - $CellContext`a^3 $CellContext`c^3 + 
     2 $CellContext`b^3 $CellContext`c^3)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952420224*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dc049eb4-f8a1-49c8-90b5-fed79a2b4793"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "718"}],
  SequenceForm["n=", 718],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979524228163`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3b6921c5-4862-4d80-8e16-ee1b94861d3f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "719"}],
  SequenceForm["n=", 719],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979524248123`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"98c4b553-22cb-4a79-9bb1-fe25174ad15d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "719", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 719, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c) (-$CellContext`a^2 $CellContext`b^4 + $CellContext`a \
$CellContext`b^4 $CellContext`c - $CellContext`b^4 $CellContext`c^2 + \
$CellContext`a^3 $CellContext`c^3) ($CellContext`a^3 $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c^4 + $CellContext`a $CellContext`b \
$CellContext`c^4 - $CellContext`b^2 $CellContext`c^4), $CellContext`b^2 \
($CellContext`a + $CellContext`b) ($CellContext`b + $CellContext`c) \
(-$CellContext`a^4 $CellContext`b^2 + $CellContext`a^4 $CellContext`b \
$CellContext`c - $CellContext`a^4 $CellContext`c^2 + $CellContext`b^3 \
$CellContext`c^3) ($CellContext`a^3 $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c^4 + $CellContext`a $CellContext`b $CellContext`c^4 - \
$CellContext`b^2 $CellContext`c^4), $CellContext`c^2 ($CellContext`a + \
$CellContext`c) ($CellContext`b + $CellContext`c) (-$CellContext`a^2 \
$CellContext`b^4 + $CellContext`a $CellContext`b^4 $CellContext`c - \
$CellContext`b^4 $CellContext`c^2 + $CellContext`a^3 $CellContext`c^3) \
(-$CellContext`a^4 $CellContext`b^2 + $CellContext`a^4 $CellContext`b \
$CellContext`c - $CellContext`a^4 $CellContext`c^2 + $CellContext`b^3 \
$CellContext`c^3)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952427453*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3b7f95d7-d5ca-47b9-bea9-5f4aa3aaee95"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "720"}],
  SequenceForm["n=", 720],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952430069*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"09a5e1e4-2b2f-45cd-a0df-9c6c73ab3ea8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "721"}],
  SequenceForm["n=", 721],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952432084*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2a7365ee-157d-4116-aee1-afc486fa3139"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "721", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "5"]}], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "5"]}], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 721, 
   "   ", {$CellContext`a^2 (-$CellContext`a^3 $CellContext`b^5 + \
$CellContext`a^5 $CellContext`c^3 - $CellContext`b^5 $CellContext`c^3 + \
$CellContext`a^3 $CellContext`c^5) ($CellContext`a^5 $CellContext`b^3 + \
$CellContext`a^3 $CellContext`b^5 - $CellContext`a^3 $CellContext`c^5 - \
$CellContext`b^3 $CellContext`c^5), $CellContext`b^2 ($CellContext`a^5 \
$CellContext`b^3 + $CellContext`a^3 $CellContext`b^5 - $CellContext`a^3 \
$CellContext`c^5 - $CellContext`b^3 $CellContext`c^5) (-$CellContext`a^5 \
$CellContext`b^3 - $CellContext`a^5 $CellContext`c^3 + $CellContext`b^5 \
$CellContext`c^3 + $CellContext`b^3 $CellContext`c^5), $CellContext`c^2 \
(-$CellContext`a^3 $CellContext`b^5 + $CellContext`a^5 $CellContext`c^3 - \
$CellContext`b^5 $CellContext`c^3 + $CellContext`a^3 $CellContext`c^5) \
(-$CellContext`a^5 $CellContext`b^3 - $CellContext`a^5 $CellContext`c^3 + \
$CellContext`b^5 $CellContext`c^3 + $CellContext`b^3 $CellContext`c^5)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979524350357`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4bc94ec8-a3aa-4312-a24b-28acb60ad05d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "722"}],
  SequenceForm["n=", 722],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952437595*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f9373e86-07f9-4519-a724-c44430455ce7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "723"}],
  SequenceForm["n=", 723],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952439555*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5f1bbefe-ed08-43ee-9320-e89a9ea0d22e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "723", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 723, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b) \
($CellContext`a^2 - $CellContext`a $CellContext`b + $CellContext`b^2) \
($CellContext`a + $CellContext`c) (-$CellContext`b^2 + $CellContext`a \
$CellContext`c) ($CellContext`a $CellContext`b - $CellContext`c^2) \
($CellContext`a^2 - $CellContext`a $CellContext`c + $CellContext`c^2) \
($CellContext`b^4 + $CellContext`a $CellContext`b^2 $CellContext`c + \
$CellContext`a^2 $CellContext`c^2) ($CellContext`a^2 $CellContext`b^2 + \
$CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`c^4), \
$CellContext`b^2 ($CellContext`a + $CellContext`b) ($CellContext`a^2 - \
$CellContext`a $CellContext`b + $CellContext`b^2) ($CellContext`b + \
$CellContext`c) (-$CellContext`a^2 + $CellContext`b $CellContext`c) \
($CellContext`a $CellContext`b - $CellContext`c^2) ($CellContext`b^2 - \
$CellContext`b $CellContext`c + $CellContext`c^2) ($CellContext`a^4 + \
$CellContext`a^2 $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c^2) ($CellContext`a^2 $CellContext`b^2 + $CellContext`a \
$CellContext`b $CellContext`c^2 + $CellContext`c^4), $CellContext`c^2 \
($CellContext`a + $CellContext`c) ($CellContext`b + $CellContext`c) \
(-$CellContext`b^2 + $CellContext`a $CellContext`c) (-$CellContext`a^2 + \
$CellContext`b $CellContext`c) ($CellContext`a^2 - $CellContext`a \
$CellContext`c + $CellContext`c^2) ($CellContext`b^2 - $CellContext`b \
$CellContext`c + $CellContext`c^2) ($CellContext`b^4 + $CellContext`a \
$CellContext`b^2 $CellContext`c + $CellContext`a^2 $CellContext`c^2) \
($CellContext`a^4 + $CellContext`a^2 $CellContext`b $CellContext`c + \
$CellContext`b^2 $CellContext`c^2)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952442494*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bcff5f5c-fd2e-4360-a260-79f4ffa4b41e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "724"}],
  SequenceForm["n=", 724],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795244528*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"73c94d4b-96c3-4aea-b180-842f3619b45b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "725"}],
  SequenceForm["n=", 725],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795244769*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e3b973bd-bd9f-477c-b2c6-b04a2ceba215"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "725", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", 
         SuperscriptBox["b", "7"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "7"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "7"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "7"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "7"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "7"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "7"]}], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "7"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", 
         SuperscriptBox["b", "7"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "7"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "7"]}], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "7"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "7"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "7"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 725, 
   "   ", {$CellContext`a^2 (-$CellContext`a^3 $CellContext`b^7 + \
$CellContext`a^7 $CellContext`c^3 - $CellContext`b^7 $CellContext`c^3 + \
$CellContext`a^3 $CellContext`c^7) ($CellContext`a^7 $CellContext`b^3 + \
$CellContext`a^3 $CellContext`b^7 - $CellContext`a^3 $CellContext`c^7 - \
$CellContext`b^3 $CellContext`c^7), $CellContext`b^2 ($CellContext`a^7 \
$CellContext`b^3 + $CellContext`a^3 $CellContext`b^7 - $CellContext`a^3 \
$CellContext`c^7 - $CellContext`b^3 $CellContext`c^7) (-$CellContext`a^7 \
$CellContext`b^3 - $CellContext`a^7 $CellContext`c^3 + $CellContext`b^7 \
$CellContext`c^3 + $CellContext`b^3 $CellContext`c^7), $CellContext`c^2 \
(-$CellContext`a^3 $CellContext`b^7 + $CellContext`a^7 $CellContext`c^3 - \
$CellContext`b^7 $CellContext`c^3 + $CellContext`a^3 $CellContext`c^7) \
(-$CellContext`a^7 $CellContext`b^3 - $CellContext`a^7 $CellContext`c^3 + \
$CellContext`b^7 $CellContext`c^3 + $CellContext`b^3 $CellContext`c^7)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952450396*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"22983366-a32d-4d26-8d03-ebbcd4ac2a39"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "726"}],
  SequenceForm["n=", 726],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795245296*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"84476d0c-f17a-4e64-9864-427cd51965bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "727"}],
  SequenceForm["n=", 727],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952455028*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e3a91fad-55db-492a-8f72-a1dd2f8864e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "727", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 727, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 - $CellContext`a^2 $CellContext`c - $CellContext`b^2 \
$CellContext`c) (-$CellContext`a^2 $CellContext`b + $CellContext`a^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2), $CellContext`b^2 ($CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`a^2 $CellContext`c - \
$CellContext`b^2 $CellContext`c) (-$CellContext`a $CellContext`b^2 + \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2), $CellContext`c^2 (-$CellContext`a^2 \
$CellContext`b + $CellContext`a^2 $CellContext`c + $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2) (-$CellContext`a \
$CellContext`b^2 + $CellContext`b^2 $CellContext`c - $CellContext`a \
$CellContext`c^2 + $CellContext`b $CellContext`c^2)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952457597*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cd0b5db2-0f50-403c-acde-a9645b5a3b49"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "728"}],
  SequenceForm["n=", 728],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795246034*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6f09560e-1274-44e2-9e65-4a995f32f28f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "728", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "-", "c"}], ")"}], "3"]}], ",", 
     RowBox[{"b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], "3"]}], ",", 
     RowBox[{"c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], "3"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "23"], " ", 
     RowBox[{"(", 
      RowBox[{"11", "-", 
       RowBox[{"7", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 728, 
   "   ", {$CellContext`a ($CellContext`a - $CellContext`b - \
$CellContext`c)^3, $CellContext`b (-$CellContext`a + $CellContext`b - \
$CellContext`c)^3, $CellContext`c (-$CellContext`a - $CellContext`b + \
$CellContext`c)^3}, "   XM/AM=", 
   Style[Rational[1, 23] (11 - 7 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952462901*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6099b4c2-0562-4eca-8a3b-da3fe4f4a030"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "729"}],
  SequenceForm["n=", 729],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795246521*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"35a155d3-598e-401d-abe9-2cb9af3699f1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "729", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 729, 
   "   ", {$CellContext`a^2 (
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`a^2 $CellContext`c^2 - \
$CellContext`b^2 $CellContext`c^2) (-$CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2), $CellContext`b^2 (
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`a^2 $CellContext`c^2 - \
$CellContext`b^2 $CellContext`c^2) (-$CellContext`a^2 $CellContext`b^2 - \
$CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2), $CellContext`c^2 \
(-$CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2) \
(-$CellContext`a^2 $CellContext`b^2 - $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979524679003`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fd73b994-d3e6-455c-83f8-8ca98ca659d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "730"}],
  SequenceForm["n=", 730],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979524703407`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"eebcb52a-c2d7-461e-88f7-5117e9fd4373"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "731"}],
  SequenceForm["n=", 731],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952472514*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f7767737-cadc-4e0e-b73b-3d5dcfc88e4c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "731", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 731, 
   "   ", {$CellContext`a^2 (-$CellContext`a^2 $CellContext`b^3 + \
$CellContext`a^3 $CellContext`c^2 - $CellContext`b^3 $CellContext`c^2 + \
$CellContext`a^2 $CellContext`c^3) ($CellContext`a^3 $CellContext`b^2 + \
$CellContext`a^2 $CellContext`b^3 - $CellContext`a^2 $CellContext`c^3 - \
$CellContext`b^2 $CellContext`c^3), $CellContext`b^2 ($CellContext`a^3 \
$CellContext`b^2 + $CellContext`a^2 $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c^3 - $CellContext`b^2 $CellContext`c^3) (-$CellContext`a^3 \
$CellContext`b^2 - $CellContext`a^3 $CellContext`c^2 + $CellContext`b^3 \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^3), $CellContext`c^2 \
(-$CellContext`a^2 $CellContext`b^3 + $CellContext`a^3 $CellContext`c^2 - \
$CellContext`b^3 $CellContext`c^2 + $CellContext`a^2 $CellContext`c^3) \
(-$CellContext`a^3 $CellContext`b^2 - $CellContext`a^3 $CellContext`c^2 + \
$CellContext`b^3 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^3)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952475408*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"91900c13-972a-44b9-8ab4-4b76191348e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "732"}],
  SequenceForm["n=", 732],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952478507*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0e8120b4-10f5-43b3-b9db-bf626ed44409"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "733"}],
  SequenceForm["n=", 733],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979524809933`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"792948ea-0a0a-4dbb-979f-cc79e3fe29b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "733", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 733, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 + $CellContext`b^2) \
(-$CellContext`b^2 + $CellContext`a $CellContext`c) ($CellContext`b^2 + \
$CellContext`a $CellContext`c) ($CellContext`a $CellContext`b - \
$CellContext`c^2) ($CellContext`a^2 + $CellContext`c^2) ($CellContext`a \
$CellContext`b + $CellContext`c^2), $CellContext`b^2 ($CellContext`a^2 + \
$CellContext`b^2) (-$CellContext`a^2 + $CellContext`b $CellContext`c) \
($CellContext`a^2 + $CellContext`b $CellContext`c) ($CellContext`a \
$CellContext`b - $CellContext`c^2) ($CellContext`a $CellContext`b + \
$CellContext`c^2) ($CellContext`b^2 + $CellContext`c^2), $CellContext`c^2 \
(-$CellContext`b^2 + $CellContext`a $CellContext`c) ($CellContext`b^2 + \
$CellContext`a $CellContext`c) (-$CellContext`a^2 + $CellContext`b \
$CellContext`c) ($CellContext`a^2 + $CellContext`b $CellContext`c) \
($CellContext`a^2 + $CellContext`c^2) ($CellContext`b^2 + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952483581*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ef8899d4-a5a4-4560-9d66-ec7e6685aa87"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "734"}],
  SequenceForm["n=", 734],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795248597*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8aec9a87-3b1b-4196-9a8e-96a946b97e52"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "735"}],
  SequenceForm["n=", 735],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952487926*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"91f6e04d-9029-4a6f-bcc8-46abcad5da30"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "735", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "5"]}], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "5"]}], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 735, 
   "   ", {$CellContext`a^2 (-$CellContext`a^2 $CellContext`b^5 + \
$CellContext`a^5 $CellContext`c^2 - $CellContext`b^5 $CellContext`c^2 + \
$CellContext`a^2 $CellContext`c^5) ($CellContext`a^5 $CellContext`b^2 + \
$CellContext`a^2 $CellContext`b^5 - $CellContext`a^2 $CellContext`c^5 - \
$CellContext`b^2 $CellContext`c^5), $CellContext`b^2 ($CellContext`a^5 \
$CellContext`b^2 + $CellContext`a^2 $CellContext`b^5 - $CellContext`a^2 \
$CellContext`c^5 - $CellContext`b^2 $CellContext`c^5) (-$CellContext`a^5 \
$CellContext`b^2 - $CellContext`a^5 $CellContext`c^2 + $CellContext`b^5 \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^5), $CellContext`c^2 \
(-$CellContext`a^2 $CellContext`b^5 + $CellContext`a^5 $CellContext`c^2 - \
$CellContext`b^5 $CellContext`c^2 + $CellContext`a^2 $CellContext`c^5) \
(-$CellContext`a^5 $CellContext`b^2 - $CellContext`a^5 $CellContext`c^2 + \
$CellContext`b^5 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^5)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979524908953`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"78bde90b-2085-43e8-bf0f-8d045973bb17"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "736"}],
  SequenceForm["n=", 736],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979524938602`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"da70c59c-72f6-42f1-a924-5306577f1b2b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "737"}],
  SequenceForm["n=", 737],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952495902*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0980afe6-c142-4024-a4f9-f91286a790b0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "737", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "6"]}], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "6"]}], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 737, 
   "   ", {$CellContext`a^2 (-$CellContext`a^2 $CellContext`b^6 + \
$CellContext`a^6 $CellContext`c^2 - $CellContext`b^6 $CellContext`c^2 + \
$CellContext`a^2 $CellContext`c^6) ($CellContext`a^6 $CellContext`b^2 + \
$CellContext`a^2 $CellContext`b^6 - $CellContext`a^2 $CellContext`c^6 - \
$CellContext`b^2 $CellContext`c^6), $CellContext`b^2 ($CellContext`a^6 \
$CellContext`b^2 + $CellContext`a^2 $CellContext`b^6 - $CellContext`a^2 \
$CellContext`c^6 - $CellContext`b^2 $CellContext`c^6) (-$CellContext`a^6 \
$CellContext`b^2 - $CellContext`a^6 $CellContext`c^2 + $CellContext`b^6 \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^6), $CellContext`c^2 \
(-$CellContext`a^2 $CellContext`b^6 + $CellContext`a^6 $CellContext`c^2 - \
$CellContext`b^6 $CellContext`c^2 + $CellContext`a^2 $CellContext`c^6) \
(-$CellContext`a^6 $CellContext`b^2 - $CellContext`a^6 $CellContext`c^2 + \
$CellContext`b^6 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^6)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952498584*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"403ffcdb-3f1c-4452-8df1-00c2315bca0a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "738"}],
  SequenceForm["n=", 738],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952501173*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3b05e712-ccf2-4bb9-86b9-22b556f69200"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "738", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}], "3"]}], ",", 
     RowBox[{"b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "-", "c"}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], "3"]}], ",", 
     RowBox[{"c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "-", "b", "+", "c"}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], "3"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "23"], " ", 
     RowBox[{"(", 
      RowBox[{"11", "+", 
       RowBox[{"7", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 738, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b - \
$CellContext`c)^3 ($CellContext`a - $CellContext`b + $CellContext`c)^3, \
$CellContext`b ($CellContext`a + $CellContext`b - $CellContext`c)^3 \
(-$CellContext`a + $CellContext`b + $CellContext`c)^3, $CellContext`c \
($CellContext`a - $CellContext`b + $CellContext`c)^3 (-$CellContext`a + \
$CellContext`b + $CellContext`c)^3}, "   XM/AM=", 
   Style[Rational[1, 23] (11 + 7 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979525035667`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"02d7881b-bd1c-45bd-b3d0-59dd7d11fd3d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "739"}],
  SequenceForm["n=", 739],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979525058928`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"53c8f330-2e48-4332-8dbb-733471aa2aee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "739", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 739, 
   "   ", {$CellContext`a^2 (
     2 $CellContext`a $CellContext`b - $CellContext`a $CellContext`c - \
$CellContext`b $CellContext`c) (-$CellContext`a $CellContext`b + 
     2 $CellContext`a $CellContext`c - $CellContext`b $CellContext`c), \
$CellContext`b^2 (
     2 $CellContext`a $CellContext`b - $CellContext`a $CellContext`c - \
$CellContext`b $CellContext`c) (-$CellContext`a $CellContext`b - \
$CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c), $CellContext`c^2 (-$CellContext`a \
$CellContext`b + 
     2 $CellContext`a $CellContext`c - $CellContext`b $CellContext`c) \
(-$CellContext`a $CellContext`b - $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979525085907`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"04228ee2-ff22-45a3-aa96-f62fe005e66c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "740"}],
  SequenceForm["n=", 740],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979525115433`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7b1450ea-00f4-43d6-aad4-605b8e74e32d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "741"}],
  SequenceForm["n=", 741],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979525141487`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"06be6b28-f745-4056-97e8-bb42a8b63c10"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "741", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 741, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c) ($CellContext`b^2 - $CellContext`a $CellContext`c) \
(-$CellContext`a $CellContext`b + $CellContext`c^2), $CellContext`b^2 \
($CellContext`a + $CellContext`b) ($CellContext`b + $CellContext`c) \
($CellContext`a^2 - $CellContext`b $CellContext`c) (-$CellContext`a \
$CellContext`b + $CellContext`c^2), $CellContext`c^2 ($CellContext`a + \
$CellContext`c) ($CellContext`b + $CellContext`c) ($CellContext`b^2 - \
$CellContext`a $CellContext`c) ($CellContext`a^2 - $CellContext`b \
$CellContext`c)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979525174522`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"72baabfa-437d-44b2-a084-43439042b727"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "742"}],
  SequenceForm["n=", 742],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952520575*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7173441b-8455-4f92-9321-d38aebb72eb8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "743"}],
  SequenceForm["n=", 743],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979525235443`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"853fe7e7-b808-4036-8648-4b7186ba9261"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "743", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 743, 
   "   ", {$CellContext`a^2 (-$CellContext`a $CellContext`b^3 + \
$CellContext`a^3 $CellContext`c - $CellContext`b^3 $CellContext`c + \
$CellContext`a $CellContext`c^3) ($CellContext`a^3 $CellContext`b + \
$CellContext`a $CellContext`b^3 - $CellContext`a $CellContext`c^3 - \
$CellContext`b $CellContext`c^3), $CellContext`b^2 ($CellContext`a^3 \
$CellContext`b + $CellContext`a $CellContext`b^3 - $CellContext`a \
$CellContext`c^3 - $CellContext`b $CellContext`c^3) (-$CellContext`a^3 \
$CellContext`b - $CellContext`a^3 $CellContext`c + $CellContext`b^3 \
$CellContext`c + $CellContext`b $CellContext`c^3), $CellContext`c^2 \
(-$CellContext`a $CellContext`b^3 + $CellContext`a^3 $CellContext`c - \
$CellContext`b^3 $CellContext`c + $CellContext`a $CellContext`c^3) \
(-$CellContext`a^3 $CellContext`b - $CellContext`a^3 $CellContext`c + \
$CellContext`b^3 $CellContext`c + $CellContext`b $CellContext`c^3)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979525271263`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5bdf1b34-b6c0-45eb-b882-55f9260ec795"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "744"}],
  SequenceForm["n=", 744],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952530347*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f64aea1e-b2c7-4eec-bbf9-d1b22e028d3d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "745"}],
  SequenceForm["n=", 745],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952533371*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b2fc1963-2f92-42cc-ae2e-c942bbfd2015"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "745", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 745, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c) (-$CellContext`b^4 + $CellContext`a^3 $CellContext`c - \
$CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`c^3) \
($CellContext`a^3 $CellContext`b - $CellContext`a^2 $CellContext`b^2 + \
$CellContext`a $CellContext`b^3 - $CellContext`c^4), $CellContext`b^2 \
($CellContext`a + $CellContext`b) ($CellContext`b + $CellContext`c) \
(-$CellContext`a^4 + $CellContext`b^3 $CellContext`c - $CellContext`b^2 \
$CellContext`c^2 + $CellContext`b $CellContext`c^3) ($CellContext`a^3 \
$CellContext`b - $CellContext`a^2 $CellContext`b^2 + $CellContext`a \
$CellContext`b^3 - $CellContext`c^4), $CellContext`c^2 ($CellContext`a + \
$CellContext`c) ($CellContext`b + $CellContext`c) (-$CellContext`b^4 + \
$CellContext`a^3 $CellContext`c - $CellContext`a^2 $CellContext`c^2 + \
$CellContext`a $CellContext`c^3) (-$CellContext`a^4 + $CellContext`b^3 \
$CellContext`c - $CellContext`b^2 $CellContext`c^2 + $CellContext`b \
$CellContext`c^3)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952537038*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a56bd30c-1c83-469e-8b1a-5e316eb47976"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "746"}],
  SequenceForm["n=", 746],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952540916*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"412ca65b-b459-4fe7-b3ba-fe8a123b0004"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "747"}],
  SequenceForm["n=", 747],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952544342*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fe84262e-b41d-444f-8fe5-84b983d7de19"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "747", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "5"]}], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "5"]}], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 747, 
   "   ", {$CellContext`a^2 ($CellContext`a $CellContext`b^5 - \
$CellContext`a^5 $CellContext`c + $CellContext`b^5 $CellContext`c - \
$CellContext`a $CellContext`c^5) (-$CellContext`a^5 $CellContext`b - \
$CellContext`a $CellContext`b^5 + $CellContext`a $CellContext`c^5 + \
$CellContext`b $CellContext`c^5), $CellContext`b^2 ($CellContext`a^5 \
$CellContext`b + $CellContext`a^5 $CellContext`c - $CellContext`b^5 \
$CellContext`c - $CellContext`b $CellContext`c^5) (-$CellContext`a^5 \
$CellContext`b - $CellContext`a $CellContext`b^5 + $CellContext`a \
$CellContext`c^5 + $CellContext`b $CellContext`c^5), $CellContext`c^2 \
($CellContext`a $CellContext`b^5 - $CellContext`a^5 $CellContext`c + \
$CellContext`b^5 $CellContext`c - $CellContext`a $CellContext`c^5) \
($CellContext`a^5 $CellContext`b + $CellContext`a^5 $CellContext`c - \
$CellContext`b^5 $CellContext`c - $CellContext`b $CellContext`c^5)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979525477753`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a56a506f-7a5a-4777-bb86-041db50829b1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "748"}],
  SequenceForm["n=", 748],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952551709*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3693d6ef-9181-4882-8bf0-50795f8a219a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "749"}],
  SequenceForm["n=", 749],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795255481*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"47ba4ee8-da91-42e2-b0fc-07bf903c2f3d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "750"}],
  SequenceForm["n=", 750],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952557816*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7640e242-ac55-4387-85ce-109d15733213"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "750", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", "31"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "8"}], "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 750, 
   "   ", {$CellContext`a ($CellContext`a^2 + 
     2 $CellContext`b $CellContext`c), $CellContext`b ($CellContext`b^2 + 
     2 $CellContext`a $CellContext`c), $CellContext`c (
     2 $CellContext`a $CellContext`b + $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[-2, 31] (-8 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952561034*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b0df8b58-dd8b-4cd1-95fc-3b5b4e87cc24"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "751"}],
  SequenceForm["n=", 751],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952569982*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f6a57a14-8d5b-4526-875e-9c5927363434"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "751", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "71"], " ", 
     RowBox[{"(", 
      RowBox[{"23", "+", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 751, 
   "   ", {$CellContext`a ($CellContext`b^2 + 
     2 $CellContext`a $CellContext`c) (
     2 $CellContext`a $CellContext`b + $CellContext`c^2), $CellContext`b \
($CellContext`a^2 + 2 $CellContext`b $CellContext`c) (
     2 $CellContext`a $CellContext`b + $CellContext`c^2), $CellContext`c \
($CellContext`b^2 + 2 $CellContext`a $CellContext`c) ($CellContext`a^2 + 
     2 $CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 71] (23 + 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952574641*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c5c137e2-0b46-4342-99bc-0a47ae00fdc7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "752"}],
  SequenceForm["n=", 752],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979525779133`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"92125144-622b-4f8a-96c1-30e7557c5c5f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "753"}],
  SequenceForm["n=", 753],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952580901*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5dc588b6-4fe8-4f8e-8aa5-001e39048248"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "753", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "3"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "3"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 753, 
   "   ", {$CellContext`a^2 ($CellContext`a^3 + $CellContext`b^3 - 
     2 $CellContext`c^3) ($CellContext`a^3 - 
     2 $CellContext`b^3 + $CellContext`c^3), $CellContext`b^2 \
($CellContext`a^3 + $CellContext`b^3 - 
     2 $CellContext`c^3) ((-2) $CellContext`a^3 + $CellContext`b^3 + \
$CellContext`c^3), $CellContext`c^2 ($CellContext`a^3 - 
     2 $CellContext`b^3 + $CellContext`c^3) ((-2) $CellContext`a^3 + \
$CellContext`b^3 + $CellContext`c^3)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952584334*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7b003024-288e-460e-92ac-87f517f4c7b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "754"}],
  SequenceForm["n=", 754],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952587901*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"679c8933-5d5a-447d-be04-68e0fdd6ba76"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "755"}],
  SequenceForm["n=", 755],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795259125*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"eef8dbed-f99a-4dfb-b46a-7081ce373aea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "755", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 755, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 + $CellContext`b^4 - 
     2 $CellContext`c^4) ($CellContext`a^4 - 
     2 $CellContext`b^4 + $CellContext`c^4), $CellContext`b^2 \
($CellContext`a^4 + $CellContext`b^4 - 
     2 $CellContext`c^4) ((-2) $CellContext`a^4 + $CellContext`b^4 + \
$CellContext`c^4), $CellContext`c^2 ($CellContext`a^4 - 
     2 $CellContext`b^4 + $CellContext`c^4) ((-2) $CellContext`a^4 + \
$CellContext`b^4 + $CellContext`c^4)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952594721*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7b1fe5c0-df76-454e-9257-6ecd77d0b36d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "756"}],
  SequenceForm["n=", 756],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952598358*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3feed5fb-3c15-4f80-8d0e-e9a661e1db29"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "756", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", "c"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["2", "23"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "8"}], "+", 
       RowBox[{"3", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 756, 
   "   ", {$CellContext`a ($CellContext`b + $CellContext`c)^2, $CellContext`b \
($CellContext`a + $CellContext`c)^2, ($CellContext`a + $CellContext`b)^2 \
$CellContext`c}, "   XM/AM=", 
   Style[Rational[-2, 23] (-8 + 3 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952601816*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8251c4db-46dc-43f6-bf80-2c04ab724379"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "757"}],
  SequenceForm["n=", 757],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952604796*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4b061954-66e2-437e-a5b3-529eab49b13f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "757", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "21"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "+", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 757, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b)^2 ($CellContext`a + \
$CellContext`c)^2, $CellContext`b ($CellContext`a + $CellContext`b)^2 \
($CellContext`b + $CellContext`c)^2, $CellContext`c ($CellContext`a + \
$CellContext`c)^2 ($CellContext`b + $CellContext`c)^2}, "   XM/AM=", 
   Style[Rational[1, 21] (5 + 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979526078253`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a85d72ac-ebb0-4c50-8103-b66dae2b5fd1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "758"}],
  SequenceForm["n=", 758],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952611046*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3478695c-bc89-41da-8cf2-1de65137052d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "759"}],
  SequenceForm["n=", 759],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795261414*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"46d2db9d-405e-49ec-8d07-2bb1c945e4b0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "759", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 759, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c) ($CellContext`a^2 - $CellContext`a $CellContext`b + \
$CellContext`b^2 - $CellContext`c^2) ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`a $CellContext`c + $CellContext`c^2), $CellContext`b \
($CellContext`a + $CellContext`b) ($CellContext`b + $CellContext`c) \
($CellContext`a^2 - $CellContext`a $CellContext`b + $CellContext`b^2 - \
$CellContext`c^2) (-$CellContext`a^2 + $CellContext`b^2 - $CellContext`b \
$CellContext`c + $CellContext`c^2), $CellContext`c ($CellContext`a + \
$CellContext`c) ($CellContext`b + $CellContext`c) ($CellContext`a^2 - \
$CellContext`b^2 - $CellContext`a $CellContext`c + $CellContext`c^2) \
(-$CellContext`a^2 + $CellContext`b^2 - $CellContext`b $CellContext`c + \
$CellContext`c^2)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952617403*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5ec3e967-d01e-42de-b69e-0e4a051d2a22"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "760"}],
  SequenceForm["n=", 760],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952620697*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5cd20166-a8ba-4632-869b-6b7e9ce4fa59"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "761"}],
  SequenceForm["n=", 761],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952623785*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8f400b92-e746-4341-9cd2-c07f274eeb32"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "761", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 761, 
   "   ", {$CellContext`a ($CellContext`a^4 + $CellContext`b^4 - \
$CellContext`a $CellContext`c^3 - $CellContext`b $CellContext`c^3) \
($CellContext`a^4 - $CellContext`a $CellContext`b^3 - $CellContext`b^3 \
$CellContext`c + $CellContext`c^4), $CellContext`b ($CellContext`a^4 + \
$CellContext`b^4 - $CellContext`a $CellContext`c^3 - $CellContext`b \
$CellContext`c^3) (-$CellContext`a^3 $CellContext`b + $CellContext`b^4 - \
$CellContext`a^3 $CellContext`c + $CellContext`c^4), $CellContext`c \
(-$CellContext`a^3 $CellContext`b + $CellContext`b^4 - $CellContext`a^3 \
$CellContext`c + $CellContext`c^4) ($CellContext`a^4 - $CellContext`a \
$CellContext`b^3 - $CellContext`b^3 $CellContext`c + $CellContext`c^4)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952627195*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1fa55e13-17f5-4205-a22a-2a3aeff54e8f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "762"}],
  SequenceForm["n=", 762],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952630995*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c2ef6555-5e7e-451c-afd8-4202b58f4620"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "762", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "3"]}], ",", 
     RowBox[{"b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "3"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "3"], " ", "c"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"4", " ", 
      SqrtBox["2"]}], 
     RowBox[{"7", "+", 
      RowBox[{"9", " ", 
       SqrtBox["2"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 762, 
   "   ", {$CellContext`a ($CellContext`b + $CellContext`c)^3, $CellContext`b \
($CellContext`a + $CellContext`c)^3, ($CellContext`a + $CellContext`b)^3 \
$CellContext`c}, "   XM/AM=", 
   Style[4 2^Rational[1, 2]/(7 + 9 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952633987*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"da0d4199-9e5e-4f01-9f11-0224ab9dd85e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "763"}],
  SequenceForm["n=", 763],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952636909*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6b196a20-80cd-4cbc-8e1d-edd2b7cff6b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "763", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "3"]}], ",", 
     RowBox[{"b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "3"]}], ",", 
     RowBox[{"c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "3"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "289"], " ", 
     RowBox[{"(", 
      RowBox[{"81", "+", 
       RowBox[{"56", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 763, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b)^3 ($CellContext`a + \
$CellContext`c)^3, $CellContext`b ($CellContext`a + $CellContext`b)^3 \
($CellContext`b + $CellContext`c)^3, $CellContext`c ($CellContext`a + \
$CellContext`c)^3 ($CellContext`b + $CellContext`c)^3}, "   XM/AM=", 
   Style[Rational[1, 289] (81 + 56 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952640272*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9252adfd-db38-4e90-ba8e-033cdf21a572"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "764"}],
  SequenceForm["n=", 764],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952643681*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c8cda3a8-72b3-4f2a-977d-ed4e87a8d7ce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "765"}],
  SequenceForm["n=", 765],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795264712*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b0b68482-3f69-4909-af55-8fb02f6631d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "766"}],
  SequenceForm["n=", 766],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952650387*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"43abc38c-7b84-4360-a270-51a08875384c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "767"}],
  SequenceForm["n=", 767],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952653122*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"42a24cc7-2563-49c3-b96c-44d621dc2310"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "767", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"a", " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"a", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "a"}], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 767, 
   "   ", {$CellContext`b $CellContext`c ($CellContext`a^4 + $CellContext`b^4 - \
$CellContext`a^3 $CellContext`c - $CellContext`b^3 $CellContext`c) \
($CellContext`a^4 - $CellContext`a^3 $CellContext`b - $CellContext`b \
$CellContext`c^3 + $CellContext`c^4), $CellContext`a $CellContext`c \
($CellContext`a^4 + $CellContext`b^4 - $CellContext`a^3 $CellContext`c - \
$CellContext`b^3 $CellContext`c) (-$CellContext`a $CellContext`b^3 + \
$CellContext`b^4 - $CellContext`a $CellContext`c^3 + $CellContext`c^4), \
$CellContext`a $CellContext`b (-$CellContext`a $CellContext`b^3 + \
$CellContext`b^4 - $CellContext`a $CellContext`c^3 + $CellContext`c^4) \
($CellContext`a^4 - $CellContext`a^3 $CellContext`b - $CellContext`b \
$CellContext`c^3 + $CellContext`c^4)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979526565447`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"14fa8bd9-bee3-4901-a513-812da1d02305"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "768"}],
  SequenceForm["n=", 768],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952660398*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"536172ee-ee8d-4a1d-95d8-9a8fbebed665"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "769"}],
  SequenceForm["n=", 769],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952663776*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cf01bf80-f456-4df0-bcc6-9be9fe16357d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "770"}],
  SequenceForm["n=", 770],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952666684*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ef2bfc5a-8424-41c1-98df-223cae744e15"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "771"}],
  SequenceForm["n=", 771],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952669304*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3ef5a5cf-ee5b-4cb7-af24-2ff0cd3a036b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "772"}],
  SequenceForm["n=", 772],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979526720743`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"60bcb038-b7c7-48f4-abf0-2df9ca3af7c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "773"}],
  SequenceForm["n=", 773],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952675769*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0fc1aa68-a661-45fb-9138-4ff6403ae82e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "774"}],
  SequenceForm["n=", 774],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952679481*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3908a243-c9d7-428d-a576-2aeb612a63e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "774", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"2", "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 774, 
   "   ", {$CellContext`a ($CellContext`a^4 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 + \
$CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - $CellContext`b^4 \
$CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^4 - $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6), $CellContext`b ($CellContext`a^6 - 
     2 $CellContext`a^4 $CellContext`b^2 + $CellContext`a^2 $CellContext`b^4 - \
$CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + $CellContext`b^4 \
$CellContext`c^2 - $CellContext`a^2 $CellContext`c^4 - 
     2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6), $CellContext`c \
($CellContext`a^6 - $CellContext`a^4 $CellContext`b^2 - $CellContext`a^2 \
$CellContext`b^4 + $CellContext`b^6 - 2 $CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^4 $CellContext`c^2 + $CellContext`a^2 $CellContext`c^4 + \
$CellContext`b^2 $CellContext`c^4)}, "   XM/AM=", 
   Style[2 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979526839743`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"58376ce5-d63d-4a42-81e7-3c5875038ddb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "775"}],
  SequenceForm["n=", 775],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952688066*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"54e7add5-4b96-4bd3-8cce-dc4fa3825cf8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "775", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 775, 
   "   ", {$CellContext`a ($CellContext`a^6 - $CellContext`a^4 \
$CellContext`b^2 - $CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 - 
     2 $CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^4 $CellContext`c^2 + $CellContext`a^2 $CellContext`c^4 + \
$CellContext`b^2 $CellContext`c^4) ($CellContext`a^6 - 
     2 $CellContext`a^4 $CellContext`b^2 + $CellContext`a^2 $CellContext`b^4 - \
$CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + $CellContext`b^4 \
$CellContext`c^2 - $CellContext`a^2 $CellContext`c^4 - 
     2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6), $CellContext`b \
($CellContext`a^6 - $CellContext`a^4 $CellContext`b^2 - $CellContext`a^2 \
$CellContext`b^4 + $CellContext`b^6 - 2 $CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^4 $CellContext`c^2 + $CellContext`a^2 $CellContext`c^4 + \
$CellContext`b^2 $CellContext`c^4) ($CellContext`a^4 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 + \
$CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - $CellContext`b^4 \
$CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^4 - $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6), $CellContext`c ($CellContext`a^6 - 
     2 $CellContext`a^4 $CellContext`b^2 + $CellContext`a^2 $CellContext`b^4 - \
$CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + $CellContext`b^4 \
$CellContext`c^2 - $CellContext`a^2 $CellContext`c^4 - 
     2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) \
($CellContext`a^4 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 + \
$CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - $CellContext`b^4 \
$CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^4 - $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6)}, "   XM/AM=", 
   Style[(1 + 2 2^Rational[1, 2])^(-1), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979526923113`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bb359055-c5f6-4847-bedd-af18f342b762"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "776"}],
  SequenceForm["n=", 776],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795269648*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7e3a1ddb-2e71-4c9d-a765-980421cd3cf9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "777"}],
  SequenceForm["n=", 777],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952699841*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5c629cc5-ed8e-476c-895f-aa3562716fa9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "778"}],
  SequenceForm["n=", 778],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952703094*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e15a45b0-3342-469f-8eb8-a6c09e6cde25"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "779"}],
  SequenceForm["n=", 779],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979527063627`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d33750d9-7de6-47a6-81f8-7a23b50e94d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "780"}],
  SequenceForm["n=", 780],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979527095537`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5e0d04aa-479a-46cc-a8f1-d3eb98a3681b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "781"}],
  SequenceForm["n=", 781],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952712494*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9672ac79-bc0a-4bc6-ad56-7b31b3e8aa0a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "782"}],
  SequenceForm["n=", 782],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952715991*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7c6b230f-0b63-4280-b64e-d294ea167a5f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "783"}],
  SequenceForm["n=", 783],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979527189293`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"593f6058-1338-4449-889a-3fdcd181a18e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "784"}],
  SequenceForm["n=", 784],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979527213383`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ead96d22-4a6d-4e2d-8001-a57eb9dda1f3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "785"}],
  SequenceForm["n=", 785],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952723463*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ab5db203-e3d8-4e54-bf73-a6bc130d369a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "786"}],
  SequenceForm["n=", 786],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952725952*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f7d2d39d-a584-483a-9a68-236bde62d4b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "787"}],
  SequenceForm["n=", 787],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952728397*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3c5ec2b5-d4a5-4aad-841e-ccc152362421"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "788"}],
  SequenceForm["n=", 788],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952730874*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"581cf19d-94d6-492b-babd-9744a710fe85"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "789"}],
  SequenceForm["n=", 789],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952732936*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5d622b53-6fb9-4997-9e58-83ed5d1e718e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "790"}],
  SequenceForm["n=", 790],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952734964*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7815e1fd-c3c7-4df0-95c8-48cad22cb089"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "791"}],
  SequenceForm["n=", 791],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952736964*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5b64e602-5043-4942-b940-8bf388cad611"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "792"}],
  SequenceForm["n=", 792],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952738977*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e35547ab-de37-467b-811f-5e4504e0f3ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "793"}],
  SequenceForm["n=", 793],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979527409887`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fc6f680e-3812-485d-9fc2-3c988aeb6974"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "794"}],
  SequenceForm["n=", 794],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979527430887`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9b15f7b8-babd-4b8b-b04f-9a7ae9510d56"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "795"}],
  SequenceForm["n=", 795],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952745541*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8bb1c9be-eb30-46be-b8a0-ccd4817cfdcd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "796"}],
  SequenceForm["n=", 796],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952747897*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6d791ecc-ad04-41c9-ae0e-9e453a029a8b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "797"}],
  SequenceForm["n=", 797],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952750057*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"019ff082-b109-45d2-a538-24b57f6813ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "798"}],
  SequenceForm["n=", 798],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952752133*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"840cfeb3-2d02-4f20-b0ad-97abb3fbfea8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "799"}],
  SequenceForm["n=", 799],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979527542257`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9b6137a2-13cc-4241-afdf-7e39d84a16a7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "800"}],
  SequenceForm["n=", 800],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979527563066`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a88beb57-fbf0-4b1d-86c4-40ebbe2dcfed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "800", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 800, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 + \
$CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - $CellContext`b^4 \
$CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^4 - $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6), $CellContext`b^2 ($CellContext`a^6 - 
     2 $CellContext`a^4 $CellContext`b^2 + $CellContext`a^2 $CellContext`b^4 - \
$CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + $CellContext`b^4 \
$CellContext`c^2 - $CellContext`a^2 $CellContext`c^4 - 
     2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6), \
$CellContext`c^2 ($CellContext`a^6 - $CellContext`a^4 $CellContext`b^2 - \
$CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 - 
     2 $CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^4 $CellContext`c^2 + $CellContext`a^2 $CellContext`c^4 + \
$CellContext`b^2 $CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[2, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952759047*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9dde0893-ff42-4929-aff5-03cd75670601"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "801"}],
  SequenceForm["n=", 801],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979527618313`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d1e6683d-7d12-44e2-a8eb-e4b11ce92d0f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "801", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "5"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 801, 
   "   ", {($CellContext`a^6 - $CellContext`a^4 $CellContext`b^2 - \
$CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 - 
     2 $CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^4 $CellContext`c^2 + $CellContext`a^2 $CellContext`c^4 + \
$CellContext`b^2 $CellContext`c^4) ($CellContext`a^6 - 
     2 $CellContext`a^4 $CellContext`b^2 + $CellContext`a^2 $CellContext`b^4 - \
$CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + $CellContext`b^4 \
$CellContext`c^2 - $CellContext`a^2 $CellContext`c^4 - 
     2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6), \
($CellContext`a^6 - $CellContext`a^4 $CellContext`b^2 - $CellContext`a^2 \
$CellContext`b^4 + $CellContext`b^6 - 2 $CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^4 $CellContext`c^2 + $CellContext`a^2 $CellContext`c^4 + \
$CellContext`b^2 $CellContext`c^4) ($CellContext`a^4 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 + \
$CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - $CellContext`b^4 \
$CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^4 - $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6), ($CellContext`a^6 - 
     2 $CellContext`a^4 $CellContext`b^2 + $CellContext`a^2 $CellContext`b^4 - \
$CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + $CellContext`b^4 \
$CellContext`c^2 - $CellContext`a^2 $CellContext`c^4 - 
     2 $CellContext`b^2 $CellContext`c^4 + $CellContext`c^6) \
($CellContext`a^4 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 + \
$CellContext`a^4 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 - $CellContext`b^4 \
$CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^4 - $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6)}, "   XM/AM=", 
   Style[
    Rational[1, 5], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952765264*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6548ef06-4791-44b6-af20-feef8a3679ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "802"}],
  SequenceForm["n=", 802],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952768606*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2d9dee77-70d2-48e7-aa1d-b47056f75900"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "803"}],
  SequenceForm["n=", 803],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952770907*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"df3378be-3254-4415-801a-27328de4fec3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "804"}],
  SequenceForm["n=", 804],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952772997*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5ffd1f1a-9f22-4430-90b1-978d45b5f4d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "805"}],
  SequenceForm["n=", 805],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952775082*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d2edc2de-780e-44c1-aafb-051101c03061"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "806"}],
  SequenceForm["n=", 806],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979527773533`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"32a959e6-08ab-463a-adfb-1a5dfe3ab86b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "807"}],
  SequenceForm["n=", 807],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952779449*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"98feaa01-0d57-4575-80ed-3447dcddf390"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "808"}],
  SequenceForm["n=", 808],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952781549*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"19dcaabd-4a93-490a-b498-7332f93c4ee1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "809"}],
  SequenceForm["n=", 809],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952783737*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0ce4d6e0-3dd4-4d2a-9d6e-15b58df6ab21"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "810"}],
  SequenceForm["n=", 810],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952785817*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1ab7ed62-e8d9-4644-ba90-10d26bda07f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "811"}],
  SequenceForm["n=", 811],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952787874*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d4b482e2-9578-4fc2-ad2b-a63668015b4d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "812"}],
  SequenceForm["n=", 812],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795278994*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3a7d535d-046a-46bf-895b-652f1122ed5f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "813"}],
  SequenceForm["n=", 813],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952791947*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"83f1b173-ff4b-415f-aff6-a2b6e262f1a0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "814"}],
  SequenceForm["n=", 814],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952793983*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a0d4d7df-8534-4f00-92e3-9114a2adf6a0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "815"}],
  SequenceForm["n=", 815],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979527961683`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"afa1c406-c8d5-487d-b045-cb72f2ea1d5b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "816"}],
  SequenceForm["n=", 816],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952798483*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b5306fe6-64a7-4024-a139-de1439eda36f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "817"}],
  SequenceForm["n=", 817],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952800729*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9ddeb378-75a6-4cfe-a625-6a0926398907"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "818"}],
  SequenceForm["n=", 818],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952803265*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b14439a8-f5c2-4337-b741-317c499224ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "819"}],
  SequenceForm["n=", 819],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979528054943`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"55986510-c87d-4660-afa1-93b5d7d0d3bc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "820"}],
  SequenceForm["n=", 820],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979528075857`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d0b2e957-f1c6-4c15-bfba-b805cb18e3ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "821"}],
  SequenceForm["n=", 821],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979528096933`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5d711980-07e3-45de-b095-a4bf44adb96e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "822"}],
  SequenceForm["n=", 822],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979528118267`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e5856c2a-56c2-44b1-9573-163340eb727f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "823"}],
  SequenceForm["n=", 823],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952813981*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8c60d04a-a45c-4eb7-937c-8db2a3073db4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "824"}],
  SequenceForm["n=", 824],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952816102*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"79505f91-2df4-4cdd-84be-22befe3bc747"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "825"}],
  SequenceForm["n=", 825],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979528182087`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b30f0195-7092-4353-961c-edbb7e1f1fb4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "826"}],
  SequenceForm["n=", 826],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952820506*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0adf8f73-213b-4dc1-ae52-d1cf94294a15"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "827"}],
  SequenceForm["n=", 827],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952822866*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d6361451-952c-4126-8484-cea8a0ed5cd3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "828"}],
  SequenceForm["n=", 828],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979528251333`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a6ff87e5-6b53-4080-9236-2b62d7095d54"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "829"}],
  SequenceForm["n=", 829],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952827611*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"358c6fc3-e2de-4f64-8b92-bc5fa61b7510"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "830"}],
  SequenceForm["n=", 830],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952830162*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1775ccc9-4f97-4580-a731-68f91a982dec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "831"}],
  SequenceForm["n=", 831],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952832415*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3b3aeb95-a7df-4d88-b69e-7de9fae698b3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "832"}],
  SequenceForm["n=", 832],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952835236*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"07c24eb6-8a62-483a-b39a-e4fe90e95408"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "833"}],
  SequenceForm["n=", 833],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952838438*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"89e2f39e-937d-471a-8c88-10f1f5c7b322"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "834"}],
  SequenceForm["n=", 834],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952841455*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"83e25644-22fd-4b24-a26a-3b3b49723808"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "835"}],
  SequenceForm["n=", 835],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979528438883`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"22198181-75f7-4ca7-9863-34655e95b44e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "836"}],
  SequenceForm["n=", 836],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979528465767`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"04f37746-a93b-4e28-a955-75a99c8d13d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "837"}],
  SequenceForm["n=", 837],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952849227*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"93013369-de48-4cc9-ab85-c5403d2ca44a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "838"}],
  SequenceForm["n=", 838],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952851427*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6d1a379d-a6d2-4c47-9c50-e6cd21fee9bc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "839"}],
  SequenceForm["n=", 839],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952853589*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ce5fe48f-e95a-4a08-a140-bd4eb353f176"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "840"}],
  SequenceForm["n=", 840],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795285639*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e19380dd-8400-4964-a741-3a27a62bcaf7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "840", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 840, 
   "   ", {$CellContext`a^2 ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c - $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a $CellContext`c^2 + 2 $CellContext`b $CellContext`c^2 - 
     2 $CellContext`c^3) ($CellContext`a^3 - $CellContext`a^2 $CellContext`b + 
     2 $CellContext`a $CellContext`b^2 - 
     2 $CellContext`b^3 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2 + $CellContext`c^3), $CellContext`b^2 \
($CellContext`a^3 - $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 $CellContext`c - \
$CellContext`b^2 $CellContext`c + 2 $CellContext`a $CellContext`c^2 + 
     2 $CellContext`b $CellContext`c^2 - 
     2 $CellContext`c^3) ((-2) $CellContext`a^3 + 
     2 $CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + 
     2 $CellContext`a^2 $CellContext`c - $CellContext`b^2 $CellContext`c - \
$CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2 + \
$CellContext`c^3), $CellContext`c^2 ((-2) $CellContext`a^3 + 
     2 $CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + 
     2 $CellContext`a^2 $CellContext`c - $CellContext`b^2 $CellContext`c - \
$CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2 + \
$CellContext`c^3) ($CellContext`a^3 - $CellContext`a^2 $CellContext`b + 
     2 $CellContext`a $CellContext`b^2 - 
     2 $CellContext`b^3 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979528598347`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"34f9e0a2-31f7-4fb5-b21a-66fa42a64982"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "841"}],
  SequenceForm["n=", 841],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952862891*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fc2359e3-1651-4fb0-96be-6975ccbce5df"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "841", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "10"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "8"]}], "+", 
        SuperscriptBox["b", "10"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"22", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "8"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "10"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "10"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "10"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"22", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "8"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "8"]}], "+", 
        SuperscriptBox["c", "10"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "10"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "8"]}], "+", 
        SuperscriptBox["b", "10"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"22", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "8"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "10"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "10"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "8"]}], "+", 
        SuperscriptBox["b", "10"], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"22", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "8"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "8"]}], "+", 
        SuperscriptBox["c", "10"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "10"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "8"]}], "+", 
        SuperscriptBox["b", "10"], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"22", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "8"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "8"]}], "+", 
        SuperscriptBox["c", "10"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "10"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "10"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"16", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"22", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"11", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"8", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"13", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "8"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "8"]}], "+", 
        SuperscriptBox["c", "10"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 841, 
   "   ", {$CellContext`a^2 ($CellContext`a^10 - 
     3 $CellContext`a^8 $CellContext`b^2 + 
     2 $CellContext`a^6 $CellContext`b^4 + 
     2 $CellContext`a^4 $CellContext`b^6 - 
     3 $CellContext`a^2 $CellContext`b^8 + $CellContext`b^10 + 
     3 $CellContext`a^8 $CellContext`c^2 + 
     8 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 - 
     22 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 + 
     8 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 + 
     3 $CellContext`b^8 $CellContext`c^2 - 
     13 $CellContext`a^6 $CellContext`c^4 + 
     11 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 + 
     11 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 - 
     13 $CellContext`b^6 $CellContext`c^4 + 
     11 $CellContext`a^4 $CellContext`c^6 - 
     16 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 + 
     11 $CellContext`b^4 $CellContext`c^6 - 
     2 $CellContext`c^10) ($CellContext`a^10 + 
     3 $CellContext`a^8 $CellContext`b^2 - 
     13 $CellContext`a^6 $CellContext`b^4 + 
     11 $CellContext`a^4 $CellContext`b^6 - 2 $CellContext`b^10 - 
     3 $CellContext`a^8 $CellContext`c^2 + 
     8 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 + 
     11 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 - 
     16 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 + 
     2 $CellContext`a^6 $CellContext`c^4 - 
     22 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 + 
     11 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 + 
     11 $CellContext`b^6 $CellContext`c^4 + 
     2 $CellContext`a^4 $CellContext`c^6 + 
     8 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 - 
     13 $CellContext`b^4 $CellContext`c^6 - 
     3 $CellContext`a^2 $CellContext`c^8 + 
     3 $CellContext`b^2 $CellContext`c^8 + $CellContext`c^10), \
$CellContext`b^2 ($CellContext`a^10 - 3 $CellContext`a^8 $CellContext`b^2 + 
     2 $CellContext`a^6 $CellContext`b^4 + 
     2 $CellContext`a^4 $CellContext`b^6 - 
     3 $CellContext`a^2 $CellContext`b^8 + $CellContext`b^10 + 
     3 $CellContext`a^8 $CellContext`c^2 + 
     8 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 - 
     22 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 + 
     8 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 + 
     3 $CellContext`b^8 $CellContext`c^2 - 
     13 $CellContext`a^6 $CellContext`c^4 + 
     11 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 + 
     11 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 - 
     13 $CellContext`b^6 $CellContext`c^4 + 
     11 $CellContext`a^4 $CellContext`c^6 - 
     16 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 + 
     11 $CellContext`b^4 $CellContext`c^6 - 
     2 $CellContext`c^10) ((-2) $CellContext`a^10 + 
     11 $CellContext`a^6 $CellContext`b^4 - 
     13 $CellContext`a^4 $CellContext`b^6 + 
     3 $CellContext`a^2 $CellContext`b^8 + $CellContext`b^10 - 
     16 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 + 
     11 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 + 
     8 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 - 
     3 $CellContext`b^8 $CellContext`c^2 + 
     11 $CellContext`a^6 $CellContext`c^4 + 
     11 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 - 
     22 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 + 
     2 $CellContext`b^6 $CellContext`c^4 - 
     13 $CellContext`a^4 $CellContext`c^6 + 
     8 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 + 
     2 $CellContext`b^4 $CellContext`c^6 + 
     3 $CellContext`a^2 $CellContext`c^8 - 
     3 $CellContext`b^2 $CellContext`c^8 + $CellContext`c^10), \
$CellContext`c^2 ((-2) $CellContext`a^10 + 
     11 $CellContext`a^6 $CellContext`b^4 - 
     13 $CellContext`a^4 $CellContext`b^6 + 
     3 $CellContext`a^2 $CellContext`b^8 + $CellContext`b^10 - 
     16 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 + 
     11 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 + 
     8 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 - 
     3 $CellContext`b^8 $CellContext`c^2 + 
     11 $CellContext`a^6 $CellContext`c^4 + 
     11 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 - 
     22 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 + 
     2 $CellContext`b^6 $CellContext`c^4 - 
     13 $CellContext`a^4 $CellContext`c^6 + 
     8 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 + 
     2 $CellContext`b^4 $CellContext`c^6 + 
     3 $CellContext`a^2 $CellContext`c^8 - 
     3 $CellContext`b^2 $CellContext`c^8 + $CellContext`c^10) \
($CellContext`a^10 + 3 $CellContext`a^8 $CellContext`b^2 - 
     13 $CellContext`a^6 $CellContext`b^4 + 
     11 $CellContext`a^4 $CellContext`b^6 - 2 $CellContext`b^10 - 
     3 $CellContext`a^8 $CellContext`c^2 + 
     8 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 + 
     11 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 - 
     16 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 + 
     2 $CellContext`a^6 $CellContext`c^4 - 
     22 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 + 
     11 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 + 
     11 $CellContext`b^6 $CellContext`c^4 + 
     2 $CellContext`a^4 $CellContext`c^6 + 
     8 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 - 
     13 $CellContext`b^4 $CellContext`c^6 - 
     3 $CellContext`a^2 $CellContext`c^8 + 
     3 $CellContext`b^2 $CellContext`c^8 + $CellContext`c^10)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952868574*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f0162ccd-7c70-4b89-ba7c-510051aa61b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "842"}],
  SequenceForm["n=", 842],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952873321*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b20fde6c-7f01-4128-aac0-bdccc1171c5e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "842", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "6"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "6"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "6"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "6"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "6"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 842, 
   "   ", {$CellContext`a^2 ($CellContext`a^6 - $CellContext`a^4 \
$CellContext`b^2 - $CellContext`a^2 $CellContext`b^4 + $CellContext`b^6 - \
$CellContext`a^4 $CellContext`c^2 - $CellContext`b^4 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`c^4 + 
     2 $CellContext`b^2 $CellContext`c^4 - 
     2 $CellContext`c^6) ($CellContext`a^6 - $CellContext`a^4 \
$CellContext`b^2 + 2 $CellContext`a^2 $CellContext`b^4 - 
     2 $CellContext`b^6 - $CellContext`a^4 $CellContext`c^2 + 
     2 $CellContext`b^4 $CellContext`c^2 - $CellContext`a^2 $CellContext`c^4 - \
$CellContext`b^2 $CellContext`c^4 + $CellContext`c^6), $CellContext`b^2 \
($CellContext`a^6 - $CellContext`a^4 $CellContext`b^2 - $CellContext`a^2 \
$CellContext`b^4 + $CellContext`b^6 - $CellContext`a^4 $CellContext`c^2 - \
$CellContext`b^4 $CellContext`c^2 + 2 $CellContext`a^2 $CellContext`c^4 + 
     2 $CellContext`b^2 $CellContext`c^4 - 
     2 $CellContext`c^6) ((-2) $CellContext`a^6 + 
     2 $CellContext`a^4 $CellContext`b^2 - $CellContext`a^2 $CellContext`b^4 + \
$CellContext`b^6 + 
     2 $CellContext`a^4 $CellContext`c^2 - $CellContext`b^4 $CellContext`c^2 - \
$CellContext`a^2 $CellContext`c^4 - $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6), $CellContext`c^2 ((-2) $CellContext`a^6 + 
     2 $CellContext`a^4 $CellContext`b^2 - $CellContext`a^2 $CellContext`b^4 + \
$CellContext`b^6 + 
     2 $CellContext`a^4 $CellContext`c^2 - $CellContext`b^4 $CellContext`c^2 - \
$CellContext`a^2 $CellContext`c^4 - $CellContext`b^2 $CellContext`c^4 + \
$CellContext`c^6) ($CellContext`a^6 - $CellContext`a^4 $CellContext`b^2 + 
     2 $CellContext`a^2 $CellContext`b^4 - 
     2 $CellContext`b^6 - $CellContext`a^4 $CellContext`c^2 + 
     2 $CellContext`b^4 $CellContext`c^2 - $CellContext`a^2 $CellContext`c^4 - \
$CellContext`b^2 $CellContext`c^4 + $CellContext`c^6)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952876583*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e896d20c-98ac-4a52-b768-e61a9663d043"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "843"}],
  SequenceForm["n=", 843],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979528799057`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"09e8f136-4754-47ec-9577-01ebb22c9da1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "843", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 843, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     4 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`c^4) ($CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - 2 $CellContext`b^4 - 
     4 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`b^2 ($CellContext`a^4 - 
     4 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`c^4) ((-2) $CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 - 
     4 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`c^2 ((-2) $CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`c^2 - 
     4 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 + 2 $CellContext`a^2 $CellContext`b^2 - 2 $CellContext`b^4 - 
     4 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952883174*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ac70d84f-55ae-46f6-9f61-45a413d15301"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "844"}],
  SequenceForm["n=", 844],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952886087*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8b7e0e9a-1a17-492d-a4dd-1694716b3594"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "844", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "a"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SqrtBox[
           RowBox[{"b", " ", "c"}]]}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{"a", " ", "c"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{"a", " ", "b"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "b"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{"b", " ", "c"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}], "-", 
        RowBox[{
         SqrtBox[
          RowBox[{"a", " ", "c"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{"a", " ", "b"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"-", "c"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SqrtBox[
          RowBox[{"b", " ", "c"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}], "+", 
        RowBox[{
         SqrtBox[
          RowBox[{"a", " ", "c"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}], "-", 
        RowBox[{
         SqrtBox[
          RowBox[{"a", " ", "b"}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"4", "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}]}]]}], "-", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"2", "-", 
           SqrtBox["2"]}]]}]}], ")"}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 844, 
   "   ", {-$CellContext`a (-($CellContext`b $CellContext`c)^
       Rational[
        1, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c))^
       Rational[3, 2] + ($CellContext`a $CellContext`c)^
       Rational[
        1, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
       Rational[3, 2] + ($CellContext`a $CellContext`b)^
       Rational[
        1, 2] (($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
       Rational[3, 2]), -$CellContext`b (($CellContext`b $CellContext`c)^
       Rational[
        1, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c))^
       Rational[3, 2] - ($CellContext`a $CellContext`c)^
      Rational[
       1, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[3, 2] + ($CellContext`a $CellContext`b)^
       Rational[
        1, 2] (($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
       Rational[3, 2]), -$CellContext`c (($CellContext`b $CellContext`c)^
       Rational[
        1, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c))^
       Rational[3, 2] + ($CellContext`a $CellContext`c)^
       Rational[
        1, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
       Rational[3, 2] - ($CellContext`a $CellContext`b)^
      Rational[1, 
        2] (($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^Rational[3, 2])}, 
   "   XM/AM=", 
   Style[(-2 + 2^Rational[1, 2])^(-1) (2^Rational[1, 2] + 
     2 (4 - 2 2^Rational[1, 2])^Rational[1, 2] - 
     4 (2 - 2^Rational[1, 2])^Rational[1, 2])/(1 + 
    2 (2 - 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979528894653`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"88891cef-e05d-4399-abb0-4725bc4a4066"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "845"}],
  SequenceForm["n=", 845],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952892981*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0c0f5d36-b60b-4100-87a7-84636568f025"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "845", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SqrtBox["a"]}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}], "+", 
        RowBox[{
         SqrtBox["b"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}], "+", 
        RowBox[{
         SqrtBox["c"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SqrtBox["a"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}], "-", 
        RowBox[{
         SqrtBox["b"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}], "+", 
        RowBox[{
         SqrtBox["c"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SqrtBox["a"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}], "+", 
        RowBox[{
         SqrtBox["b"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}], "-", 
        RowBox[{
         SqrtBox["c"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ")"}], 
          RowBox[{"3", "/", "2"}]]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SqrtBox[
         RowBox[{"4", "-", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}]], "-", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"2", "-", 
           SqrtBox["2"]}]]}]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SqrtBox["2"], "+", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"2", "-", 
           SqrtBox["2"]}]]}]}], ")"}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 845, 
   "   ", {$CellContext`a (-$CellContext`a^
       Rational[
        1, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c))^
       Rational[3, 2] + $CellContext`b^
       Rational[
        1, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
       Rational[3, 2] + $CellContext`c^
       Rational[
        1, 2] (($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
       Rational[3, 2]), $CellContext`b ($CellContext`a^
       Rational[
        1, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c))^
       Rational[3, 2] - $CellContext`b^
      Rational[1, 
        2] (($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
      Rational[3, 2] + $CellContext`c^
       Rational[
        1, 2] (($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
       Rational[3, 2]), $CellContext`c ($CellContext`a^
       Rational[
        1, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c))^
       Rational[3, 2] + $CellContext`b^
       Rational[
        1, 2] (($CellContext`a + $CellContext`b - $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^
       Rational[3, 2] - $CellContext`c^
      Rational[1, 
        2] (($CellContext`a - $CellContext`b + $CellContext`c) \
(-$CellContext`a + $CellContext`b + $CellContext`c))^Rational[3, 2])}, 
   "   XM/AM=", 
   Style[2 (-2 + 2^Rational[1, 2])^(-1) (
     1 + (4 - 2 2^Rational[1, 2])^Rational[1, 2] - 
     2 (2 - 2^Rational[1, 2])^Rational[1, 2])/(2^Rational[1, 2] + 
    2 (2 - 2^Rational[1, 2])^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952946649*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"db0b5449-69f3-45d5-a693-7d22cb99422c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "846"}],
  SequenceForm["n=", 846],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952952342*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2a9c990b-cf07-45dc-8c32-9925ada28d41"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "846", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "5"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 846, 
   "   ", {$CellContext`a ($CellContext`a^2 - $CellContext`a $CellContext`b - \
$CellContext`b^2 - $CellContext`a $CellContext`c - $CellContext`b \
$CellContext`c - $CellContext`c^2), $CellContext`b (-$CellContext`a^2 - \
$CellContext`a $CellContext`b + $CellContext`b^2 - $CellContext`a \
$CellContext`c - $CellContext`b $CellContext`c - $CellContext`c^2), \
$CellContext`c (-$CellContext`a^2 - $CellContext`a $CellContext`b - \
$CellContext`b^2 - $CellContext`a $CellContext`c - $CellContext`b \
$CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 5] (3 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952959724*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d277071b-80e2-46b3-9eb2-e8bca3b5f693"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "847"}],
  SequenceForm["n=", 847],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952964498*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"587be98d-56c5-4311-873a-2ff266be7c69"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "847", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 847, 
   "   ", {$CellContext`b^2 $CellContext`c^2 (-$CellContext`a^2 + \
$CellContext`b^2 - $CellContext`c^2) (-$CellContext`a^2 - $CellContext`b^2 + \
$CellContext`c^2) ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 + $CellContext`b^4 - 2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`a^2 $CellContext`c^2 ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`c^2) (-$CellContext`a^2 - $CellContext`b^2 + $CellContext`c^2) \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 + $CellContext`b^4 - 2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4), \
$CellContext`a^2 $CellContext`b^2 ($CellContext`a^2 - $CellContext`b^2 - \
$CellContext`c^2) (-$CellContext`a^2 + $CellContext`b^2 - $CellContext`c^2) \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`c^4) \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, "   XM/AM=", 
   Style[
    Rational[1, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952968573*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ba353b31-1c63-4d29-ba17-29121289a4ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "848"}],
  SequenceForm["n=", 848],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979529726152`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"70cfd6db-e370-429f-b3fd-79c957fa5dc2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "849"}],
  SequenceForm["n=", 849],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097952975243*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0c9bf53a-307a-4ccc-8b3f-25837aa7e793"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "849", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox["c", "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "23"], " ", 
     RowBox[{"(", 
      RowBox[{"7", "+", 
       RowBox[{"6", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 849, 
   "   ", {$CellContext`a^3 ($CellContext`a + $CellContext`b)^2 \
($CellContext`a + $CellContext`c)^2, $CellContext`b^3 ($CellContext`a + \
$CellContext`b)^2 ($CellContext`b + $CellContext`c)^2, $CellContext`c^3 \
($CellContext`a + $CellContext`c)^2 ($CellContext`b + $CellContext`c)^2}, 
   "   XM/AM=", 
   Style[Rational[1, 23] (7 + 6 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953018093*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dbd370be-5794-40b4-b421-f3f70f049573"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "850"}],
  SequenceForm["n=", 850],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795302245*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1a18ef15-7488-4320-9232-74bdec211a12"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "851"}],
  SequenceForm["n=", 851],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979530256433`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1b929672-0009-46ad-a130-f7c9d26f5b5b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "851", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"2", "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 851, 
   "   ", {$CellContext`a ($CellContext`b + $CellContext`c) ($CellContext`a^4 - \
$CellContext`a^2 $CellContext`b^2 + $CellContext`a^2 $CellContext`b \
$CellContext`c - $CellContext`b^3 $CellContext`c - $CellContext`a^2 \
$CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`b $CellContext`c^3), \
$CellContext`b ($CellContext`a + $CellContext`c) (-$CellContext`a^2 \
$CellContext`b^2 + $CellContext`b^4 - $CellContext`a^3 $CellContext`c + \
$CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 - \
$CellContext`a $CellContext`c^3), ($CellContext`a + $CellContext`b) \
$CellContext`c (-$CellContext`a^3 $CellContext`b + 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`a $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + $CellContext`c^4)}, 
   "   XM/AM=", 
   Style[2 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953029764*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7158d20e-c9b9-4c20-be3f-05aaef076109"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "852"}],
  SequenceForm["n=", 852],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953034604*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ab509e3d-5292-4fb1-b14a-18d70b134cdd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "853"}],
  SequenceForm["n=", 853],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979530379677`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f0f888ab-8c01-4879-9863-168923d815de"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "853", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 853, 
   "   ", {$CellContext`a^2 ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`a^5 $CellContext`b^2 - $CellContext`a^4 \
$CellContext`b^3 - $CellContext`a^3 $CellContext`b^4 + $CellContext`a^2 \
$CellContext`b^5 + $CellContext`a^4 $CellContext`b^2 $CellContext`c - \
$CellContext`a^2 $CellContext`b^4 $CellContext`c + $CellContext`a^5 \
$CellContext`c^2 + $CellContext`a^4 $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^5 $CellContext`c^2 - $CellContext`a^4 $CellContext`c^3 + 
     2 $CellContext`b^4 $CellContext`c^3 - $CellContext`a^3 $CellContext`c^4 - \
$CellContext`a^2 $CellContext`b $CellContext`c^4 + 
     2 $CellContext`b^3 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^5 - 
     2 $CellContext`b^2 $CellContext`c^5), $CellContext`b^2 (-$CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a^5 $CellContext`b^2 - \
$CellContext`a^4 $CellContext`b^3 - $CellContext`a^3 $CellContext`b^4 + \
$CellContext`a^2 $CellContext`b^5 - $CellContext`a^4 $CellContext`b^2 \
$CellContext`c + $CellContext`a^2 $CellContext`b^4 $CellContext`c - 
     2 $CellContext`a^5 $CellContext`c^2 + $CellContext`a $CellContext`b^4 \
$CellContext`c^2 + $CellContext`b^5 $CellContext`c^2 + 
     2 $CellContext`a^4 $CellContext`c^3 - $CellContext`b^4 $CellContext`c^3 + 
     2 $CellContext`a^3 $CellContext`c^4 - $CellContext`a $CellContext`b^2 \
$CellContext`c^4 - $CellContext`b^3 $CellContext`c^4 - 
     2 $CellContext`a^2 $CellContext`c^5 + $CellContext`b^2 \
$CellContext`c^5), $CellContext`c^2 (-$CellContext`a - $CellContext`b + \
$CellContext`c) ((-2) $CellContext`a^5 $CellContext`b^2 + 
     2 $CellContext`a^4 $CellContext`b^3 + 
     2 $CellContext`a^3 $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b^5 + $CellContext`a^5 $CellContext`c^2 - \
$CellContext`a^4 $CellContext`b $CellContext`c^2 - $CellContext`a \
$CellContext`b^4 $CellContext`c^2 + $CellContext`b^5 $CellContext`c^2 - \
$CellContext`a^4 $CellContext`c^3 - $CellContext`b^4 $CellContext`c^3 - \
$CellContext`a^3 $CellContext`c^4 + $CellContext`a^2 $CellContext`b \
$CellContext`c^4 + $CellContext`a $CellContext`b^2 $CellContext`c^4 - \
$CellContext`b^3 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^5 + \
$CellContext`b^2 $CellContext`c^5)}, "   XM/AM=", 
   Style[(-2) (1 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979530428257`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"63e3e4f9-2037-4350-8e82-7d084b9bd81a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "854"}],
  SequenceForm["n=", 854],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953049101*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"18dbaeae-4d91-43bf-8414-36c480fc29c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "854", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "5"]}], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["2", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"3", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 854, 
   "   ", {$CellContext`a^2 ($CellContext`a^5 $CellContext`b^2 + \
$CellContext`a^4 $CellContext`b^3 - $CellContext`a^3 $CellContext`b^4 - \
$CellContext`a^2 $CellContext`b^5 - $CellContext`a^4 $CellContext`b^2 \
$CellContext`c + $CellContext`a^2 $CellContext`b^4 $CellContext`c + \
$CellContext`a^5 $CellContext`c^2 - $CellContext`a^4 $CellContext`b \
$CellContext`c^2 + 
     2 $CellContext`b^5 $CellContext`c^2 + $CellContext`a^4 $CellContext`c^3 - 
     2 $CellContext`b^4 $CellContext`c^3 - $CellContext`a^3 $CellContext`c^4 + \
$CellContext`a^2 $CellContext`b $CellContext`c^4 - 
     2 $CellContext`b^3 $CellContext`c^4 - $CellContext`a^2 $CellContext`c^5 + 
     2 $CellContext`b^2 $CellContext`c^5), $CellContext`b^2 \
(-$CellContext`a^5 $CellContext`b^2 - $CellContext`a^4 $CellContext`b^3 + \
$CellContext`a^3 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^5 + \
$CellContext`a^4 $CellContext`b^2 $CellContext`c - $CellContext`a^2 \
$CellContext`b^4 $CellContext`c + 
     2 $CellContext`a^5 $CellContext`c^2 - $CellContext`a $CellContext`b^4 \
$CellContext`c^2 + $CellContext`b^5 $CellContext`c^2 - 
     2 $CellContext`a^4 $CellContext`c^3 + $CellContext`b^4 $CellContext`c^3 - 
     2 $CellContext`a^3 $CellContext`c^4 + $CellContext`a $CellContext`b^2 \
$CellContext`c^4 - $CellContext`b^3 $CellContext`c^4 + 
     2 $CellContext`a^2 $CellContext`c^5 - $CellContext`b^2 \
$CellContext`c^5), $CellContext`c^2 (2 $CellContext`a^5 $CellContext`b^2 - 
     2 $CellContext`a^4 $CellContext`b^3 - 
     2 $CellContext`a^3 $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b^5 - $CellContext`a^5 $CellContext`c^2 + \
$CellContext`a^4 $CellContext`b $CellContext`c^2 + $CellContext`a \
$CellContext`b^4 $CellContext`c^2 - $CellContext`b^5 $CellContext`c^2 - \
$CellContext`a^4 $CellContext`c^3 - $CellContext`b^4 $CellContext`c^3 + \
$CellContext`a^3 $CellContext`c^4 - $CellContext`a^2 $CellContext`b \
$CellContext`c^4 - $CellContext`a $CellContext`b^2 $CellContext`c^4 + \
$CellContext`b^3 $CellContext`c^4 + $CellContext`a^2 $CellContext`c^5 + \
$CellContext`b^2 $CellContext`c^5)}, "   XM/AM=", 
   Style[Rational[2, 7] (3 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979530539513`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e622b667-7ba6-4c54-b814-2b95e9fc2db5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "855"}],
  SequenceForm["n=", 855],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979530586643`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"452d66a6-ff0e-42ec-ad22-7aa051fbf7c7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "855", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    SqrtBox["2"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 855, 
   "   ", {$CellContext`a ($CellContext`a^5 $CellContext`b + $CellContext`a^4 \
$CellContext`b^2 - $CellContext`a^3 $CellContext`b^3 - $CellContext`a^2 \
$CellContext`b^4 + $CellContext`a^5 $CellContext`c - 
     2 $CellContext`a^4 $CellContext`b $CellContext`c + $CellContext`a^2 \
$CellContext`b^3 $CellContext`c - $CellContext`a $CellContext`b^4 \
$CellContext`c + $CellContext`b^5 $CellContext`c + $CellContext`a^4 \
$CellContext`c^2 + $CellContext`a $CellContext`b^3 $CellContext`c^2 - \
$CellContext`a^3 $CellContext`c^3 + $CellContext`a^2 $CellContext`b \
$CellContext`c^3 + $CellContext`a $CellContext`b^2 $CellContext`c^3 - 
     2 $CellContext`b^3 $CellContext`c^3 - $CellContext`a^2 $CellContext`c^4 - \
$CellContext`a $CellContext`b $CellContext`c^4 + $CellContext`b \
$CellContext`c^5), $CellContext`b (-$CellContext`a^4 $CellContext`b^2 - \
$CellContext`a^3 $CellContext`b^3 + $CellContext`a^2 $CellContext`b^4 + \
$CellContext`a $CellContext`b^5 + $CellContext`a^5 $CellContext`c - \
$CellContext`a^4 $CellContext`b $CellContext`c + $CellContext`a^3 \
$CellContext`b^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b^4 $CellContext`c + $CellContext`b^5 \
$CellContext`c + $CellContext`a^3 $CellContext`b $CellContext`c^2 + \
$CellContext`b^4 $CellContext`c^2 - 
     2 $CellContext`a^3 $CellContext`c^3 + $CellContext`a^2 $CellContext`b \
$CellContext`c^3 + $CellContext`a $CellContext`b^2 $CellContext`c^3 - \
$CellContext`b^3 $CellContext`c^3 - $CellContext`a $CellContext`b \
$CellContext`c^4 - $CellContext`b^2 $CellContext`c^4 + $CellContext`a \
$CellContext`c^5), $CellContext`c ($CellContext`a^5 $CellContext`b - 
     2 $CellContext`a^3 $CellContext`b^3 + $CellContext`a $CellContext`b^5 - \
$CellContext`a^4 $CellContext`b $CellContext`c + $CellContext`a^3 \
$CellContext`b^2 $CellContext`c + $CellContext`a^2 $CellContext`b^3 \
$CellContext`c - $CellContext`a $CellContext`b^4 $CellContext`c - \
$CellContext`a^4 $CellContext`c^2 + $CellContext`a^3 $CellContext`b \
$CellContext`c^2 + $CellContext`a $CellContext`b^3 $CellContext`c^2 - \
$CellContext`b^4 $CellContext`c^2 - $CellContext`a^3 $CellContext`c^3 - \
$CellContext`b^3 $CellContext`c^3 + $CellContext`a^2 $CellContext`c^4 - 
     2 $CellContext`a $CellContext`b $CellContext`c^4 + $CellContext`b^2 \
$CellContext`c^4 + $CellContext`a $CellContext`c^5 + $CellContext`b \
$CellContext`c^5)}, "   XM/AM=", 
   Style[2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953063315*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"27d25f24-74d4-40ac-989c-4df1ff9fcb67"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "856"}],
  SequenceForm["n=", 856],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979530678787`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7b35ba7e-e5c5-49ac-8246-7ca4cae5a15b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "857"}],
  SequenceForm["n=", 857],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953071176*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f1c8f5f7-944b-4c80-ad8c-4c621db59084"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "857", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 857, 
   "   ", {($CellContext`b + $CellContext`c) (-$CellContext`a^4 + \
$CellContext`b^4 + $CellContext`a^2 $CellContext`b $CellContext`c - \
$CellContext`b^3 $CellContext`c - $CellContext`b $CellContext`c^3 + \
$CellContext`c^4), ($CellContext`a + $CellContext`c) ($CellContext`a^4 - \
$CellContext`b^4 - $CellContext`a^3 $CellContext`c + $CellContext`a \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^3 + \
$CellContext`c^4), ($CellContext`a + $CellContext`b) ($CellContext`a^4 - \
$CellContext`a^3 $CellContext`b - $CellContext`a $CellContext`b^3 + \
$CellContext`b^4 + $CellContext`a $CellContext`b $CellContext`c^2 - \
$CellContext`c^4)}, "   XM/AM=", 
   Style[-1 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795307493*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bda3573c-cb22-45b2-b838-76e1791abbe4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "858"}],
  SequenceForm["n=", 858],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953078746*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4ff58052-4bc7-428a-9772-c6bcd1911bc4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "858", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "6"], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      SuperscriptBox["c", "6"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "6"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "4"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "4"]}], "-", 
      SuperscriptBox["c", "6"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "6"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "4"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "4"]}], "-", 
      SuperscriptBox["b", "6"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 858, 
   "   ", {$CellContext`a^4 $CellContext`b^2 - $CellContext`b^6 + \
$CellContext`a^4 $CellContext`c^2 - 
    2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + $CellContext`b^4 \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^4 - $CellContext`c^6, \
-$CellContext`a^6 + $CellContext`a^2 $CellContext`b^4 + $CellContext`a^4 \
$CellContext`c^2 - 
    2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + $CellContext`b^4 \
$CellContext`c^2 + $CellContext`a^2 $CellContext`c^4 - $CellContext`c^6, \
-$CellContext`a^6 + $CellContext`a^4 $CellContext`b^2 + $CellContext`a^2 \
$CellContext`b^4 - $CellContext`b^6 - 
    2 $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + $CellContext`a^2 \
$CellContext`c^4 + $CellContext`b^2 $CellContext`c^4}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953082967*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fd33c150-cd5b-447e-a9a3-62167f2393b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "859"}],
  SequenceForm["n=", 859],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953087256*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"435d7e82-2b78-49fc-a003-5938d343ac45"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "859", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 859, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b) ($CellContext`a + \
$CellContext`c) ($CellContext`a^2 $CellContext`b - $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`b $CellContext`c^2 - $CellContext`c^3), \
$CellContext`b^2 ($CellContext`a + $CellContext`b) ($CellContext`b + \
$CellContext`c) (-$CellContext`a^3 + $CellContext`a $CellContext`b^2 + \
$CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`c^3), \
$CellContext`c^2 ($CellContext`a + $CellContext`c) ($CellContext`b + \
$CellContext`c) (-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`c^2 + $CellContext`b $CellContext`c^2)}, "   XM/AM=", 
   Style[1 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953091133*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"29e17946-7016-4e82-b820-92ca8fa3fba1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "860"}],
  SequenceForm["n=", 860],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953094674*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"97ccc61d-444f-41f3-925f-969d477282fc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "861"}],
  SequenceForm["n=", 861],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795309829*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"74c48b28-b6ea-4dd9-8cb9-0cbfc9d6f8dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "861", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "5"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "5"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "5"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "5"]}], " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "5"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "5"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 861, 
   "   ", {$CellContext`a ($CellContext`a - $CellContext`b - $CellContext`c) \
($CellContext`a^5 $CellContext`b - $CellContext`a^4 $CellContext`b^2 - \
$CellContext`a^3 $CellContext`b^3 + $CellContext`a^2 $CellContext`b^4 + \
$CellContext`a^5 $CellContext`c + 
     2 $CellContext`a^4 $CellContext`b $CellContext`c - $CellContext`a^2 \
$CellContext`b^3 $CellContext`c - $CellContext`a $CellContext`b^4 \
$CellContext`c - $CellContext`b^5 $CellContext`c - $CellContext`a^4 \
$CellContext`c^2 + $CellContext`a $CellContext`b^3 $CellContext`c^2 - \
$CellContext`a^3 $CellContext`c^3 - $CellContext`a^2 $CellContext`b \
$CellContext`c^3 + $CellContext`a $CellContext`b^2 $CellContext`c^3 + 
     2 $CellContext`b^3 $CellContext`c^3 + $CellContext`a^2 $CellContext`c^4 - \
$CellContext`a $CellContext`b $CellContext`c^4 - $CellContext`b \
$CellContext`c^5), $CellContext`b (-$CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a^4 $CellContext`b^2 - $CellContext`a^3 \
$CellContext`b^3 - $CellContext`a^2 $CellContext`b^4 + $CellContext`a \
$CellContext`b^5 - $CellContext`a^5 $CellContext`c - $CellContext`a^4 \
$CellContext`b $CellContext`c - $CellContext`a^3 $CellContext`b^2 \
$CellContext`c + 
     2 $CellContext`a $CellContext`b^4 $CellContext`c + $CellContext`b^5 \
$CellContext`c + $CellContext`a^3 $CellContext`b $CellContext`c^2 - \
$CellContext`b^4 $CellContext`c^2 + 
     2 $CellContext`a^3 $CellContext`c^3 + $CellContext`a^2 $CellContext`b \
$CellContext`c^3 - $CellContext`a $CellContext`b^2 $CellContext`c^3 - \
$CellContext`b^3 $CellContext`c^3 - $CellContext`a $CellContext`b \
$CellContext`c^4 + $CellContext`b^2 $CellContext`c^4 - $CellContext`a \
$CellContext`c^5), $CellContext`c (-$CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a^5 $CellContext`b + 
     2 $CellContext`a^3 $CellContext`b^3 - $CellContext`a $CellContext`b^5 - \
$CellContext`a^4 $CellContext`b $CellContext`c + $CellContext`a^3 \
$CellContext`b^2 $CellContext`c + $CellContext`a^2 $CellContext`b^3 \
$CellContext`c - $CellContext`a $CellContext`b^4 $CellContext`c + \
$CellContext`a^4 $CellContext`c^2 - $CellContext`a^3 $CellContext`b \
$CellContext`c^2 - $CellContext`a $CellContext`b^3 $CellContext`c^2 + \
$CellContext`b^4 $CellContext`c^2 - $CellContext`a^3 $CellContext`c^3 - \
$CellContext`b^3 $CellContext`c^3 - $CellContext`a^2 $CellContext`c^4 + 
     2 $CellContext`a $CellContext`b $CellContext`c^4 - $CellContext`b^2 \
$CellContext`c^4 + $CellContext`a $CellContext`c^5 + $CellContext`b \
$CellContext`c^5)}, "   XM/AM=", 
   Style[-2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953103389*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6e998cc5-bd49-46bd-ab75-1248a1d3fac3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "862"}],
  SequenceForm["n=", 862],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795310781*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"473d7af6-3f0d-4c8e-a48d-afa4e2cf3800"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "863"}],
  SequenceForm["n=", 863],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953110982*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f8315810-07f3-4dff-86a1-16540fe18a07"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "863", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b"}], ")"}], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["2", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 863, 
   "   ", {$CellContext`a^3 ($CellContext`b + $CellContext`c) \
($CellContext`a^4 $CellContext`b^2 - $CellContext`a^2 $CellContext`b^4 - \
$CellContext`a^4 $CellContext`b $CellContext`c + $CellContext`a^2 \
$CellContext`b^3 $CellContext`c + $CellContext`a^4 $CellContext`c^2 - \
$CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + $CellContext`b^4 \
$CellContext`c^2 + $CellContext`a^2 $CellContext`b $CellContext`c^3 - 
     2 $CellContext`b^3 $CellContext`c^3 - $CellContext`a^2 $CellContext`c^4 + \
$CellContext`b^2 $CellContext`c^4), $CellContext`b^3 ($CellContext`a + \
$CellContext`c) (-$CellContext`a^4 $CellContext`b^2 + $CellContext`a^2 \
$CellContext`b^4 + $CellContext`a^3 $CellContext`b^2 $CellContext`c - \
$CellContext`a $CellContext`b^4 $CellContext`c + $CellContext`a^4 \
$CellContext`c^2 - $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + \
$CellContext`b^4 $CellContext`c^2 - 
     2 $CellContext`a^3 $CellContext`c^3 + $CellContext`a $CellContext`b^2 \
$CellContext`c^3 + $CellContext`a^2 $CellContext`c^4 - $CellContext`b^2 \
$CellContext`c^4), ($CellContext`a + $CellContext`b) $CellContext`c^3 \
($CellContext`a^4 $CellContext`b^2 - 
     2 $CellContext`a^3 $CellContext`b^3 + $CellContext`a^2 $CellContext`b^4 - \
$CellContext`a^4 $CellContext`c^2 + $CellContext`a^3 $CellContext`b \
$CellContext`c^2 - $CellContext`a^2 $CellContext`b^2 $CellContext`c^2 + \
$CellContext`a $CellContext`b^3 $CellContext`c^2 - $CellContext`b^4 \
$CellContext`c^2 + $CellContext`a^2 $CellContext`c^4 - $CellContext`a \
$CellContext`b $CellContext`c^4 + $CellContext`b^2 $CellContext`c^4)}, 
   "   XM/AM=", 
   Style[Rational[2, 7] (4 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953115699*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cc344f33-9222-4334-aa6a-31f57ceab195"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "864"}],
  SequenceForm["n=", 864],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795312018*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"85b68a81-04e9-4a15-975d-208b85a4bde5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "864", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "6"]}], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "4"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["4", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 864, 
   "   ", {$CellContext`a^4 ($CellContext`a^4 $CellContext`b^4 - \
$CellContext`a^2 $CellContext`b^6 + $CellContext`b^6 $CellContext`c^2 + \
$CellContext`a^4 $CellContext`c^4 - 
     2 $CellContext`b^4 $CellContext`c^4 - $CellContext`a^2 $CellContext`c^6 + \
$CellContext`b^2 $CellContext`c^6), $CellContext`b^4 (-$CellContext`a^6 \
$CellContext`b^2 + $CellContext`a^4 $CellContext`b^4 + $CellContext`a^6 \
$CellContext`c^2 - 
     2 $CellContext`a^4 $CellContext`c^4 + $CellContext`b^4 $CellContext`c^4 + \
$CellContext`a^2 $CellContext`c^6 - $CellContext`b^2 $CellContext`c^6), \
$CellContext`c^4 ($CellContext`a^6 $CellContext`b^2 - 
     2 $CellContext`a^4 $CellContext`b^4 + $CellContext`a^2 $CellContext`b^6 - \
$CellContext`a^6 $CellContext`c^2 - $CellContext`b^6 $CellContext`c^2 + \
$CellContext`a^4 $CellContext`c^4 + $CellContext`b^4 $CellContext`c^4)}, 
   "   XM/AM=", 
   Style[
    Rational[4, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979531241713`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b77127ce-cbec-4c4f-93c1-aa47ab11cc0c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "865"}],
  SequenceForm["n=", 865],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795312847*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4a8da548-cf1d-4d7c-93a9-b209cae9a744"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "866"}],
  SequenceForm["n=", 866],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979531319027`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0f5444dd-2e5c-4d18-943e-7feb7b7d8b25"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "867"}],
  SequenceForm["n=", 867],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795313489*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7f022c1f-ce63-4128-9d64-89da9183cbdf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "868"}],
  SequenceForm["n=", 868],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953138152*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"279356ad-9ee1-407c-9a89-e4fff5ab72e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "869"}],
  SequenceForm["n=", 869],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979531418877`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c241fb0e-0112-4ece-84cf-8fa7c8610dc5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "869", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      SuperscriptBox["c", "3"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["3", "23"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "8"}], "+", 
       RowBox[{"3", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 869, 
   "   ", {$CellContext`a^3 ($CellContext`b^2 + $CellContext`b $CellContext`c + \
$CellContext`c^2), $CellContext`b^3 ($CellContext`a^2 + $CellContext`a \
$CellContext`c + $CellContext`c^2), ($CellContext`a^2 + $CellContext`a \
$CellContext`b + $CellContext`b^2) $CellContext`c^3}, "   XM/AM=", 
   Style[Rational[-3, 23] (-8 + 3 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953145814*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b371092f-45b2-4282-984a-db2958ac5a47"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "870"}],
  SequenceForm["n=", 870],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953149618*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ce549080-13a4-4410-970e-a32f30146f0a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "870", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", "c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"a", " ", "b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "89"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "+", 
       RowBox[{"18", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 870, 
   "   ", {$CellContext`b ($CellContext`a^2 + $CellContext`a $CellContext`b + \
$CellContext`b^2) $CellContext`c ($CellContext`a^2 + $CellContext`a \
$CellContext`c + $CellContext`c^2), $CellContext`a ($CellContext`a^2 + \
$CellContext`a $CellContext`b + $CellContext`b^2) $CellContext`c \
($CellContext`b^2 + $CellContext`b $CellContext`c + $CellContext`c^2), \
$CellContext`a $CellContext`b ($CellContext`a^2 + $CellContext`a \
$CellContext`c + $CellContext`c^2) ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 89] (5 + 18 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953153453*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5520dad1-ce43-4eda-a719-c523ee2cd041"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "871"}],
  SequenceForm["n=", 871],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979531570787`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fb87dbb6-6487-4439-b0a9-54fd4fae8ddd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "871", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "329"], " ", 
     RowBox[{"(", 
      RowBox[{"17", "+", 
       RowBox[{"36", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 871, 
   "   ", {$CellContext`b^3 ($CellContext`a^2 + $CellContext`a $CellContext`b + \
$CellContext`b^2) $CellContext`c^3 ($CellContext`a^2 + $CellContext`a \
$CellContext`c + $CellContext`c^2), $CellContext`a^3 ($CellContext`a^2 + \
$CellContext`a $CellContext`b + $CellContext`b^2) $CellContext`c^3 \
($CellContext`b^2 + $CellContext`b $CellContext`c + $CellContext`c^2), \
$CellContext`a^3 $CellContext`b^3 ($CellContext`a^2 + $CellContext`a \
$CellContext`c + $CellContext`c^2) ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 329] (17 + 36 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953160843*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1feb81d8-932e-4454-ac76-e7eea07c8683"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "872"}],
  SequenceForm["n=", 872],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979531647253`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dc213849-27d4-468a-81b3-00d03facc4d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "872", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
      SuperscriptBox["c", "3"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["4", "21"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "4"}], "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 872, 
   "   ", {$CellContext`a^3 ($CellContext`b + $CellContext`c)^2, \
$CellContext`b^3 ($CellContext`a + $CellContext`c)^2, ($CellContext`a + \
$CellContext`b)^2 $CellContext`c^3}, "   XM/AM=", 
   Style[Rational[-4, 21] (-4 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979531687107`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"00eb5f5e-848e-4825-ae81-e6abe3457c85"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "873"}],
  SequenceForm["n=", 873],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953172481*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"74df74db-af4b-43b4-ba88-0cf618ab6599"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "873", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", "c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"a", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "b"}], ")"}], "2"], " ", "c", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
     RowBox[{"a", " ", "b", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"b", "+", "c"}], ")"}], "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "191"], " ", 
     RowBox[{"(", 
      RowBox[{"31", "+", 
       RowBox[{"24", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 873, 
   "   ", {$CellContext`b ($CellContext`a + $CellContext`b)^2 $CellContext`c \
($CellContext`a + $CellContext`c)^2, $CellContext`a ($CellContext`a + \
$CellContext`b)^2 $CellContext`c ($CellContext`b + $CellContext`c)^2, \
$CellContext`a $CellContext`b ($CellContext`a + $CellContext`c)^2 \
($CellContext`b + $CellContext`c)^2}, "   XM/AM=", 
   Style[Rational[1, 191] (31 + 24 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953176036*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0a3f00bf-c614-4543-aed3-7dce70e7a043"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "874"}],
  SequenceForm["n=", 874],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979531799917`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0fc64b1d-0fc3-477d-8842-1d885063815e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "875"}],
  SequenceForm["n=", 875],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979531832027`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b2baef97-bad4-4b5f-92cf-49334115182a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "876"}],
  SequenceForm["n=", 876],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979531864443`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8b8cbff3-c286-4e06-a2f6-d0fe4ab75f16"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "877"}],
  SequenceForm["n=", 877],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953189856*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b1244b46-a987-4611-a32b-ac9f8f15e191"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "878"}],
  SequenceForm["n=", 878],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953193301*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1910cf00-9879-4183-9fa1-51af58ba044f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "879"}],
  SequenceForm["n=", 879],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953196748*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6109c70c-effc-427c-806e-e5d7e2c4477c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "880"}],
  SequenceForm["n=", 880],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953199671*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"70b1f551-d4e2-44ee-8141-e1549b78add3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "881"}],
  SequenceForm["n=", 881],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953202362*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"07bea58e-48ce-4ca6-b4f7-65b70b13bfd3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "882"}],
  SequenceForm["n=", 882],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795320505*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ceec645a-3e6c-490d-ac0b-4547e792618c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "883"}],
  SequenceForm["n=", 883],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953208126*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9a274137-536f-4c3d-a044-b25b3dabbea7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "884"}],
  SequenceForm["n=", 884],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953211565*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f0bb4956-446e-4cbd-b257-9fdef566caba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "885"}],
  SequenceForm["n=", 885],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953214733*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"70cce601-dcb4-40a5-9426-018054ec7bea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "886"}],
  SequenceForm["n=", 886],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795321799*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"52bc3da8-1b0f-44c9-bef8-b74379762e44"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "887"}],
  SequenceForm["n=", 887],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979532212887`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"10a7c122-761e-4fa3-93ab-7086b8204988"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "888"}],
  SequenceForm["n=", 888],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979532241163`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"86efab23-5f6c-40ac-ab87-4f2f030937df"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "889"}],
  SequenceForm["n=", 889],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953227971*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ec37c6df-be70-4c35-b563-894111bd2d50"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "890"}],
  SequenceForm["n=", 890],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979532319736`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"eb651212-0eed-4f88-8694-7fbf2e5bf8bb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "891"}],
  SequenceForm["n=", 891],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953235816*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7b7bd710-2f66-408e-84ec-e917dfb63d3b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "892"}],
  SequenceForm["n=", 892],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979532392807`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e56ad9e7-fb00-45ff-9778-d3a135608513"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "893"}],
  SequenceForm["n=", 893],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979532434797`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"04c1d008-1afb-448f-9ec8-6247760dd884"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "893", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "14"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", 
       RowBox[{"3", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 893, 
   "   ", {$CellContext`a^2 ($CellContext`b^2 + $CellContext`a \
$CellContext`c) ($CellContext`a $CellContext`b + $CellContext`c^2), \
$CellContext`b^2 ($CellContext`a^2 + $CellContext`b $CellContext`c) \
($CellContext`a $CellContext`b + $CellContext`c^2), $CellContext`c^2 \
($CellContext`b^2 + $CellContext`a $CellContext`c) ($CellContext`a^2 + \
$CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 14] (2 + 3 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953247456*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"91ba32bd-2100-49ea-bf56-6a4f4ff71b2f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "894"}],
  SequenceForm["n=", 894],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953250442*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e54f516d-9a95-4402-93c5-a534aa145cd0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "894", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      RowBox[{"b", " ", "c"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], "+", 
      RowBox[{"a", " ", "c"}]}], ",", 
     RowBox[{
      RowBox[{"a", " ", "b"}], "+", 
      SuperscriptBox["c", "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["3", 
     RowBox[{"5", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 894, 
   "   ", {$CellContext`a^2 + $CellContext`b $CellContext`c, $CellContext`b^2 + \
$CellContext`a $CellContext`c, $CellContext`a $CellContext`b + \
$CellContext`c^2}, "   XM/AM=", 
   Style[3/(5 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953253574*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"19d6dd0b-d0df-4750-8e9b-cc3e4de26387"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "895"}],
  SequenceForm["n=", 895],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979532566967`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5013dc96-0584-412a-937b-02a75ce53cc8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "896"}],
  SequenceForm["n=", 896],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953259523*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"cbe6aee2-9719-4ddb-83ae-f9774d0398c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "896", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"2", "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 896, 
   "   ", {$CellContext`a (
     2 $CellContext`a^2 - $CellContext`b^2 - $CellContext`c^2), \
$CellContext`b (-$CellContext`a^2 + 
     2 $CellContext`b^2 - $CellContext`c^2), $CellContext`c \
(-$CellContext`a^2 - $CellContext`b^2 + 2 $CellContext`c^2)}, "   XM/AM=", 
   Style[2 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953263136*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"38d89ffd-7807-4c2c-97cf-d9cfc433ac2b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "897"}],
  SequenceForm["n=", 897],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979532661743`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"96376876-14de-4695-bde7-0cfc90a2c186"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "897", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 897, 
   "   ", {$CellContext`a ($CellContext`a^2 + $CellContext`b^2 - 
     2 $CellContext`c^2) ($CellContext`a^2 - 
     2 $CellContext`b^2 + $CellContext`c^2), $CellContext`b ($CellContext`a^2 + \
$CellContext`b^2 - 
     2 $CellContext`c^2) ((-2) $CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2), $CellContext`c ($CellContext`a^2 - 
     2 $CellContext`b^2 + $CellContext`c^2) ((-2) $CellContext`a^2 + \
$CellContext`b^2 + $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 7] (-1 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953269231*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4cb38975-55c9-4b4e-9717-0365b7e94d14"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "898"}],
  SequenceForm["n=", 898],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953272846*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"52f9397f-2864-4045-b8c8-12c2a272abea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "899"}],
  SequenceForm["n=", 899],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953275523*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3d009f1c-82b3-4c10-b993-67d047bb199a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "899", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"2", " ", "b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"2", "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 899, 
   "   ", {$CellContext`a ($CellContext`a $CellContext`b + $CellContext`a \
$CellContext`c - 
     2 $CellContext`b $CellContext`c), $CellContext`b ($CellContext`a \
$CellContext`b - 
     2 $CellContext`a $CellContext`c + $CellContext`b $CellContext`c), \
$CellContext`c ((-2) $CellContext`a $CellContext`b + $CellContext`a \
$CellContext`c + $CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[2 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953278068*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9e1d4b7a-bdd9-4186-8201-c22ba74e6441"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "900"}],
  SequenceForm["n=", 900],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953281823*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"eaae0210-9d3a-4394-8a5e-3ec3aefb0024"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "901"}],
  SequenceForm["n=", 901],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953285263*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3e4ce93d-e10c-4b08-8c78-a5810d90517e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "902"}],
  SequenceForm["n=", 902],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979532884617`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a83dc640-5cb0-483f-a970-5fee499ff4aa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "902", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a"}], "-", "b", "-", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", 
        RowBox[{"2", " ", "b"}], "-", "c"}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", 
        RowBox[{"2", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox["2",
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 902, 
   "   ", {$CellContext`a^2 (
     2 $CellContext`a - $CellContext`b - $CellContext`c), $CellContext`b^2 \
(-$CellContext`a + 
     2 $CellContext`b - $CellContext`c), $CellContext`c^2 (-$CellContext`a - \
$CellContext`b + 2 $CellContext`c)}, "   XM/AM=", 
   Style[2, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953292151*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d9bd17e4-1066-42f6-a0ee-3b41bbba547d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "903"}],
  SequenceForm["n=", 903],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953295106*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2d7191d6-32f5-4596-8118-1b99c80e06f8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "903", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", 
        RowBox[{"2", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", 
        RowBox[{"2", " ", "b"}], "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", 
        RowBox[{"2", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", 
        RowBox[{"2", " ", "b"}], "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}]}], 
    "}"}], "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox["1", "3"]}],
    StripOnInput->False,
    LineColor->RGBColor[1, 0, 0],
    FrontFaceColor->RGBColor[1, 0, 0],
    BackFaceColor->RGBColor[1, 0, 0],
    GraphicsColor->RGBColor[1, 0, 0],
    FontColor->RGBColor[1, 0, 0]]}],
  SequenceForm[
  "n=", 903, 
   "   ", {($CellContext`a + $CellContext`b - 
     2 $CellContext`c) ($CellContext`a - 
     2 $CellContext`b + $CellContext`c), ($CellContext`a + $CellContext`b - 
     2 $CellContext`c) ((-2) $CellContext`a + $CellContext`b + \
$CellContext`c), ($CellContext`a - 
     2 $CellContext`b + $CellContext`c) ((-2) $CellContext`a + $CellContext`b + \
$CellContext`c)}, "   XM/AM=", 
   Style[
    Rational[-1, 3], 
    RGBColor[1, 0, 0]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953298283*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"156f005a-937a-47bf-a233-7f05c507f1d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "904"}],
  SequenceForm["n=", 904],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953300844*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4a90604a-536d-4ec9-b9a3-c4d05fc8f804"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "904", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "23"], " ", 
     RowBox[{"(", 
      RowBox[{"8", "+", 
       RowBox[{"3", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 904, 
   "   ", {$CellContext`a^3 ($CellContext`b^2 + $CellContext`a \
$CellContext`c) ($CellContext`a $CellContext`b + $CellContext`c^2), \
$CellContext`b^3 ($CellContext`a^2 + $CellContext`b $CellContext`c) \
($CellContext`a $CellContext`b + $CellContext`c^2), $CellContext`c^3 \
($CellContext`b^2 + $CellContext`a $CellContext`c) ($CellContext`a^2 + \
$CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 23] (8 + 3 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795330341*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fc203c2a-979e-4466-8267-451fb5ee1232"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "905"}],
  SequenceForm["n=", 905],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953306365*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bc41932c-0074-4d06-a559-1e2e4fbc2672"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "906"}],
  SequenceForm["n=", 906],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979533087053`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6d3e4184-9520-4765-adef-2a2c3838c035"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "907"}],
  SequenceForm["n=", 907],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953310967*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"09b3d36e-c759-4cdd-910a-64601082561f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "908"}],
  SequenceForm["n=", 908],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795331391*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"52f65aa5-7a0e-4d07-bc6a-4b9f9b1601df"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "908", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "-", 
      SuperscriptBox["b", "3"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "3"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "3"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      SuperscriptBox["c", "3"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "3"], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "2"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 908, 
   "   ", {$CellContext`a^2 $CellContext`b - $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c - 
    2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`b $CellContext`c^2 - $CellContext`c^3, \
-$CellContext`a^3 + $CellContext`a $CellContext`b^2 + $CellContext`a^2 \
$CellContext`c - 
    2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`c^3, \
-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 - 
    2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`c^2 + $CellContext`b $CellContext`c^2}, "   XM/AM=", 
   Style[-1 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953316873*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"784a9440-9b0b-4a46-824f-40ce88f46ae2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "909"}],
  SequenceForm["n=", 909],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953319951*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9921c525-4406-415a-be4a-e42250c22e96"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "909", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 909, 
   "   ", {$CellContext`a^2 ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2) ($CellContext`a^3 - \
$CellContext`a $CellContext`b^2 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3), \
$CellContext`b^2 ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2) (-$CellContext`a^2 \
$CellContext`b + $CellContext`b^3 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`b $CellContext`c^2 + $CellContext`c^3), \
$CellContext`c^2 ($CellContext`a^3 - $CellContext`a $CellContext`b^2 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3) \
(-$CellContext`a^2 $CellContext`b + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`b $CellContext`c^2 + $CellContext`c^3)}, 
   "   XM/AM=", 
   Style[-1 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979533237133`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d8407544-3bfc-45c5-ae6b-2ca110edaf54"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "910"}],
  SequenceForm["n=", 910],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953327684*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8f83cd75-e983-4237-940b-acc5e860b54e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "910", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"2", "+", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 910, 
   "   ", {$CellContext`a (
     2 $CellContext`a^3 - $CellContext`a^2 $CellContext`b - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + $CellContext`b^2 $CellContext`c + \
$CellContext`b $CellContext`c^2 - $CellContext`c^3), $CellContext`b \
(-$CellContext`a^3 - $CellContext`a $CellContext`b^2 + 
     2 $CellContext`b^3 + $CellContext`a^2 $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`c^3), \
$CellContext`c (-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 - $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2 + 2 $CellContext`c^3)}, 
   "   XM/AM=", 
   Style[2 + 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979533318644`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4a87d6f5-21fa-44d6-b7f2-b4533c62898e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "911"}],
  SequenceForm["n=", 911],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953335063*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ebece836-b386-497b-b54d-d8cb08255ba9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "911", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 911, 
   "   ", {$CellContext`a^3 ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2 - 
     2 $CellContext`c^3) ($CellContext`a^3 + $CellContext`a $CellContext`b^2 - 
     2 $CellContext`b^3 - $CellContext`a^2 $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3), \
$CellContext`b^3 ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`a \
$CellContext`c^2 + $CellContext`b $CellContext`c^2 - 
     2 $CellContext`c^3) ((-2) $CellContext`a^3 + $CellContext`a^2 \
$CellContext`b + $CellContext`b^3 + $CellContext`a^2 $CellContext`c - \
$CellContext`b^2 $CellContext`c - $CellContext`b $CellContext`c^2 + \
$CellContext`c^3), $CellContext`c^3 ($CellContext`a^3 + $CellContext`a \
$CellContext`b^2 - 
     2 $CellContext`b^3 - $CellContext`a^2 $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3) ((-2) \
$CellContext`a^3 + $CellContext`a^2 $CellContext`b + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c - $CellContext`b^2 $CellContext`c - \
$CellContext`b $CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[-1 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953338307*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0fb8133c-07ec-46b6-94d5-a8498757da3f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "912"}],
  SequenceForm["n=", 912],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953341872*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a31d123a-31dc-48f2-bcd8-4fc356180249"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "913"}],
  SequenceForm["n=", 913],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795334447*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ce413e90-0a82-436f-8eea-21a34694481b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "913", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 913, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 + $CellContext`b^2 - \
$CellContext`c^2) ($CellContext`a^2 - $CellContext`b^2 + $CellContext`c^2) \
($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^3 $CellContext`c + $CellContext`a^2 $CellContext`b \
$CellContext`c + $CellContext`a $CellContext`b^2 $CellContext`c - \
$CellContext`b^3 $CellContext`c - $CellContext`a^2 $CellContext`c^2 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`a $CellContext`c^3 + \
$CellContext`b $CellContext`c^3) ($CellContext`a^4 - $CellContext`a^3 \
$CellContext`b - $CellContext`a^2 $CellContext`b^2 + $CellContext`a \
$CellContext`b^3 + $CellContext`a^2 $CellContext`b $CellContext`c + \
$CellContext`b^3 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 - $CellContext`b \
$CellContext`c^3 + $CellContext`c^4), $CellContext`b^2 ($CellContext`a^2 + \
$CellContext`b^2 - $CellContext`c^2) (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2) ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^3 $CellContext`c + $CellContext`a^2 $CellContext`b \
$CellContext`c + $CellContext`a $CellContext`b^2 $CellContext`c - \
$CellContext`b^3 $CellContext`c - $CellContext`a^2 $CellContext`c^2 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`a $CellContext`c^3 + \
$CellContext`b $CellContext`c^3) ($CellContext`a^3 $CellContext`b - \
$CellContext`a^2 $CellContext`b^2 - $CellContext`a $CellContext`b^3 + \
$CellContext`b^4 + $CellContext`a^3 $CellContext`c + $CellContext`a \
$CellContext`b^2 $CellContext`c - $CellContext`a^2 $CellContext`c^2 + \
$CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`a $CellContext`c^3 + \
$CellContext`c^4), $CellContext`c^2 ($CellContext`a^2 - $CellContext`b^2 + \
$CellContext`c^2) (-$CellContext`a^2 + $CellContext`b^2 + $CellContext`c^2) \
($CellContext`a^3 $CellContext`b - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`a $CellContext`b^3 + $CellContext`b^4 + $CellContext`a^3 \
$CellContext`c + $CellContext`a $CellContext`b^2 $CellContext`c - \
$CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`a $CellContext`c^3 + \
$CellContext`c^4) ($CellContext`a^4 - $CellContext`a^3 $CellContext`b - \
$CellContext`a^2 $CellContext`b^2 + $CellContext`a $CellContext`b^3 + \
$CellContext`a^2 $CellContext`b $CellContext`c + $CellContext`b^3 \
$CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 - $CellContext`b \
$CellContext`c^3 + $CellContext`c^4)}, "   XM/AM=", 
   Style[-1 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979533489847`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c300efcb-9d28-421b-82e9-d4542775c898"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "914"}],
  SequenceForm["n=", 914],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953352614*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ee948d36-49f6-40ef-8dc7-72b1cc3058b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "914", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 914, 
   "   ", {($CellContext`a^2 - $CellContext`b^2 - $CellContext`c^2) \
($CellContext`a^3 $CellContext`b - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`a $CellContext`b^3 + $CellContext`b^4 + $CellContext`a^3 \
$CellContext`c + $CellContext`a $CellContext`b^2 $CellContext`c - \
$CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`a $CellContext`c^3 + \
$CellContext`c^4), (-$CellContext`a^2 + $CellContext`b^2 - $CellContext`c^2) \
($CellContext`a^4 - $CellContext`a^3 $CellContext`b - $CellContext`a^2 \
$CellContext`b^2 + $CellContext`a $CellContext`b^3 + $CellContext`a^2 \
$CellContext`b $CellContext`c + $CellContext`b^3 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 - $CellContext`b \
$CellContext`c^3 + $CellContext`c^4), (-$CellContext`a^2 - $CellContext`b^2 + \
$CellContext`c^2) ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^3 $CellContext`c + $CellContext`a^2 $CellContext`b \
$CellContext`c + $CellContext`a $CellContext`b^2 $CellContext`c - \
$CellContext`b^3 $CellContext`c - $CellContext`a^2 $CellContext`c^2 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`a $CellContext`c^3 + \
$CellContext`b $CellContext`c^3)}, "   XM/AM=", 
   Style[-1 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979533565493`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f6e25dd3-9764-4ed4-acca-09cd3d321848"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "915"}],
  SequenceForm["n=", 915],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953360723*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"71206405-21cf-4eb5-bc87-d034ec017afa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "915", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 915, 
   "   ", {$CellContext`a ($CellContext`a^2 + $CellContext`b^2 - \
$CellContext`c^2) ($CellContext`a^2 - $CellContext`b^2 + $CellContext`c^2) \
($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^3 $CellContext`c + $CellContext`a^2 $CellContext`b \
$CellContext`c + $CellContext`a $CellContext`b^2 $CellContext`c - \
$CellContext`b^3 $CellContext`c - $CellContext`a^2 $CellContext`c^2 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`a $CellContext`c^3 + \
$CellContext`b $CellContext`c^3) ($CellContext`a^4 - $CellContext`a^3 \
$CellContext`b - $CellContext`a^2 $CellContext`b^2 + $CellContext`a \
$CellContext`b^3 + $CellContext`a^2 $CellContext`b $CellContext`c + \
$CellContext`b^3 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 - $CellContext`b \
$CellContext`c^3 + $CellContext`c^4), $CellContext`b ($CellContext`a^2 + \
$CellContext`b^2 - $CellContext`c^2) (-$CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2) ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - \
$CellContext`a^3 $CellContext`c + $CellContext`a^2 $CellContext`b \
$CellContext`c + $CellContext`a $CellContext`b^2 $CellContext`c - \
$CellContext`b^3 $CellContext`c - $CellContext`a^2 $CellContext`c^2 - \
$CellContext`b^2 $CellContext`c^2 + $CellContext`a $CellContext`c^3 + \
$CellContext`b $CellContext`c^3) ($CellContext`a^3 $CellContext`b - \
$CellContext`a^2 $CellContext`b^2 - $CellContext`a $CellContext`b^3 + \
$CellContext`b^4 + $CellContext`a^3 $CellContext`c + $CellContext`a \
$CellContext`b^2 $CellContext`c - $CellContext`a^2 $CellContext`c^2 + \
$CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`a $CellContext`c^3 + \
$CellContext`c^4), $CellContext`c ($CellContext`a^2 - $CellContext`b^2 + \
$CellContext`c^2) (-$CellContext`a^2 + $CellContext`b^2 + $CellContext`c^2) \
($CellContext`a^3 $CellContext`b - $CellContext`a^2 $CellContext`b^2 - \
$CellContext`a $CellContext`b^3 + $CellContext`b^4 + $CellContext`a^3 \
$CellContext`c + $CellContext`a $CellContext`b^2 $CellContext`c - \
$CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`a $CellContext`c^3 + \
$CellContext`c^4) ($CellContext`a^4 - $CellContext`a^3 $CellContext`b - \
$CellContext`a^2 $CellContext`b^2 + $CellContext`a $CellContext`b^3 + \
$CellContext`a^2 $CellContext`b $CellContext`c + $CellContext`b^3 \
$CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 - $CellContext`b \
$CellContext`c^3 + $CellContext`c^4)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953365478*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7926a166-f995-4ed8-8ed3-2c68b9353e77"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "916"}],
  SequenceForm["n=", 916],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953369084*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7da50bab-3652-4b69-bfbc-fdb51ee5c704"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "917"}],
  SequenceForm["n=", 917],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953371703*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4019f2df-27ba-4f8d-8f07-e4a04f1805ce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "917", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "5"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "5"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 917, 
   "   ", {($CellContext`a^2 + $CellContext`b^2 - $CellContext`c^2) \
($CellContext`a^2 - $CellContext`b^2 + $CellContext`c^2) ($CellContext`a^5 - \
$CellContext`a^3 $CellContext`b^2 - $CellContext`a^2 $CellContext`b^3 + \
$CellContext`b^5 - $CellContext`a^4 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c - $CellContext`b^4 \
$CellContext`c - $CellContext`a^3 $CellContext`c^2 - $CellContext`b^3 \
$CellContext`c^2 + $CellContext`a^2 $CellContext`c^3 + $CellContext`b^2 \
$CellContext`c^3) ($CellContext`a^5 - $CellContext`a^4 $CellContext`b - \
$CellContext`a^3 $CellContext`b^2 + $CellContext`a^2 $CellContext`b^3 - \
$CellContext`a^3 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c^2 + $CellContext`b^3 \
$CellContext`c^2 - $CellContext`a^2 $CellContext`c^3 - $CellContext`b^2 \
$CellContext`c^3 - $CellContext`b $CellContext`c^4 + $CellContext`c^5), \
($CellContext`a^2 + $CellContext`b^2 - $CellContext`c^2) (-$CellContext`a^2 + \
$CellContext`b^2 + $CellContext`c^2) ($CellContext`a^5 - $CellContext`a^3 \
$CellContext`b^2 - $CellContext`a^2 $CellContext`b^3 + $CellContext`b^5 - \
$CellContext`a^4 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c - $CellContext`b^4 \
$CellContext`c - $CellContext`a^3 $CellContext`c^2 - $CellContext`b^3 \
$CellContext`c^2 + $CellContext`a^2 $CellContext`c^3 + $CellContext`b^2 \
$CellContext`c^3) ($CellContext`a^3 $CellContext`b^2 - $CellContext`a^2 \
$CellContext`b^3 - $CellContext`a $CellContext`b^4 + $CellContext`b^5 + \
$CellContext`a^3 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c^2 - $CellContext`b^3 \
$CellContext`c^2 - $CellContext`a^2 $CellContext`c^3 - $CellContext`b^2 \
$CellContext`c^3 - $CellContext`a $CellContext`c^4 + $CellContext`c^5), \
($CellContext`a^2 - $CellContext`b^2 + $CellContext`c^2) (-$CellContext`a^2 + \
$CellContext`b^2 + $CellContext`c^2) ($CellContext`a^3 $CellContext`b^2 - \
$CellContext`a^2 $CellContext`b^3 - $CellContext`a $CellContext`b^4 + \
$CellContext`b^5 + $CellContext`a^3 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c^2 - $CellContext`b^3 \
$CellContext`c^2 - $CellContext`a^2 $CellContext`c^3 - $CellContext`b^2 \
$CellContext`c^3 - $CellContext`a $CellContext`c^4 + $CellContext`c^5) \
($CellContext`a^5 - $CellContext`a^4 $CellContext`b - $CellContext`a^3 \
$CellContext`b^2 + $CellContext`a^2 $CellContext`b^3 - $CellContext`a^3 \
$CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c^2 + $CellContext`b^3 \
$CellContext`c^2 - $CellContext`a^2 $CellContext`c^3 - $CellContext`b^2 \
$CellContext`c^3 - $CellContext`b $CellContext`c^4 + $CellContext`c^5)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795337574*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"5df49939-96cb-4a72-af9f-7495fc79e105"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "918"}],
  SequenceForm["n=", 918],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953379586*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"36408421-8096-4c1d-8d2b-4c38469582c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "919"}],
  SequenceForm["n=", 919],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979533866*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3e71ef95-9206-439a-8112-04eed47e8299"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "920"}],
  SequenceForm["n=", 920],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953389909*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"67e87938-9357-46c3-8cc4-89d885dcefa7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "921"}],
  SequenceForm["n=", 921],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979533922033`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d38a76e2-57e3-492a-a66c-f265eccd9d6c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "922"}],
  SequenceForm["n=", 922],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953395369*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8d4ca027-a8f9-427c-b0de-190a8b506c48"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "922", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["2", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 922, 
   "   ", {$CellContext`a^3 (
     2 $CellContext`a^2 - $CellContext`b^2 - $CellContext`c^2), \
$CellContext`b^3 (-$CellContext`a^2 + 
     2 $CellContext`b^2 - $CellContext`c^2), $CellContext`c^3 \
(-$CellContext`a^2 - $CellContext`b^2 + 2 $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[2, 7] (4 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953398156*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2e81d637-a5a8-4901-987d-0ebf21ae5429"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "923"}],
  SequenceForm["n=", 923],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979534008427`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2f234596-116d-4f27-a1b6-13062065f77e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "923", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 923, 
   "   ", {$CellContext`a^3 ($CellContext`a^2 + $CellContext`b^2 - 
     2 $CellContext`c^2) ($CellContext`a^2 - 
     2 $CellContext`b^2 + $CellContext`c^2), $CellContext`b^3 \
($CellContext`a^2 + $CellContext`b^2 - 
     2 $CellContext`c^2) ((-2) $CellContext`a^2 + $CellContext`b^2 + \
$CellContext`c^2), $CellContext`c^3 ($CellContext`a^2 - 
     2 $CellContext`b^2 + $CellContext`c^2) ((-2) $CellContext`a^2 + \
$CellContext`b^2 + $CellContext`c^2)}, "   XM/AM=", 
   Style[-1 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953403634*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"62044103-1f40-4bb4-9523-b2c19c321bc1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "924"}],
  SequenceForm["n=", 924],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953406364*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"129edd70-cf79-494b-8b4e-6b8c00cd0b72"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "925"}],
  SequenceForm["n=", 925],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979534088306`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2592ab20-c79e-4942-90e0-241a3dd7ba4b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "926"}],
  SequenceForm["n=", 926],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979534111137`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6f76bb00-4899-4f65-9c8b-3d57a9a3c5a0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "927"}],
  SequenceForm["n=", 927],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979534133883`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"abf906e0-4e0c-49bf-9879-0d8431973c25"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "928"}],
  SequenceForm["n=", 928],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953415827*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8186b2ec-b975-40de-85ae-8bb0fd28bffb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "929"}],
  SequenceForm["n=", 929],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953418318*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e5f8bba2-2b85-40ed-8e23-656990bd3050"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "930"}],
  SequenceForm["n=", 930],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979534211493`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"aa269226-7b97-4572-8f48-f839095ab4df"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "931"}],
  SequenceForm["n=", 931],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953424273*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"209683d2-21b8-45da-bb4c-8837a8c0418d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "932"}],
  SequenceForm["n=", 932],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953427232*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e8792aee-3108-4c66-b0b6-8cb7c15e2981"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "933"}],
  SequenceForm["n=", 933],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953430489*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"d3f91d8a-67ad-4203-bfe2-340561c1bcfe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "934"}],
  SequenceForm["n=", 934],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953434585*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"651a180f-6320-455d-bfa6-77d2e165eff1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "935"}],
  SequenceForm["n=", 935],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953438794*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2485d3de-2cba-4174-870a-8691f1565ca7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "936"}],
  SequenceForm["n=", 936],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795344248*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ec7c7cbc-c4e4-4d84-a3fe-821dde5a6a73"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "936", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "23"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 936, 
   "   ", {$CellContext`a ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c + 2 $CellContext`a $CellContext`b $CellContext`c + 
     3 $CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 + 
     3 $CellContext`b $CellContext`c^2 + $CellContext`c^3), $CellContext`b \
($CellContext`a^3 - $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + 3 $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + 
     3 $CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2 + \
$CellContext`c^3), $CellContext`c ($CellContext`a^3 + 
     3 $CellContext`a^2 $CellContext`b + 
     3 $CellContext`a $CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 23] (5 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953445814*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"40980070-2c89-4192-9a98-ace59a9acfa8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "937"}],
  SequenceForm["n=", 937],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953449092*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"23b59401-3acd-4150-9e64-a96443e1db11"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "937", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"11", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 937, 
   "   ", {$CellContext`a ($CellContext`a^3 + 
     3 $CellContext`a^2 $CellContext`b + 
     3 $CellContext`a $CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 + 
     3 $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + 
     3 $CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2 + \
$CellContext`c^3), $CellContext`b ($CellContext`a^3 + 
     3 $CellContext`a^2 $CellContext`b + 
     3 $CellContext`a $CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + 
     3 $CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 + 
     3 $CellContext`b $CellContext`c^2 + $CellContext`c^3), $CellContext`c \
($CellContext`a^3 - $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + 3 $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + 
     3 $CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2 + \
$CellContext`c^3) ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c + 2 $CellContext`a $CellContext`b $CellContext`c + 
     3 $CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 + 
     3 $CellContext`b $CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 17] (11 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953452849*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ce5f5bf3-26f0-4336-aae5-e3aef95ac2b0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "938"}],
  SequenceForm["n=", 938],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953456036*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"755cc50c-aa13-4126-90e2-db0f5d9725fa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "938", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "c"}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b"}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "23"], " ", 
     RowBox[{"(", 
      RowBox[{"13", "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 938, 
   "   ", {$CellContext`a^4 - 2 $CellContext`a^3 $CellContext`b + 
    2 $CellContext`a $CellContext`b^3 - $CellContext`b^4 - 
    2 $CellContext`a^3 $CellContext`c - 
    4 $CellContext`a^2 $CellContext`b $CellContext`c - 
    2 $CellContext`a $CellContext`b^2 $CellContext`c - 
    2 $CellContext`a $CellContext`b $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 + 
    2 $CellContext`a $CellContext`c^3 - $CellContext`c^4, -$CellContext`a^4 + 
    2 $CellContext`a^3 $CellContext`b - 
    2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`b $CellContext`c - 
    4 $CellContext`a $CellContext`b^2 $CellContext`c - 
    2 $CellContext`b^3 $CellContext`c + 2 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`a $CellContext`b $CellContext`c^2 + 
    2 $CellContext`b $CellContext`c^3 - $CellContext`c^4, -$CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + 
    2 $CellContext`a^3 $CellContext`c - 
    2 $CellContext`a^2 $CellContext`b $CellContext`c - 
    2 $CellContext`a $CellContext`b^2 $CellContext`c + 
    2 $CellContext`b^3 $CellContext`c - 
    4 $CellContext`a $CellContext`b $CellContext`c^2 - 
    2 $CellContext`a $CellContext`c^3 - 
    2 $CellContext`b $CellContext`c^3 + $CellContext`c^4}, "   XM/AM=", 
   Style[Rational[1, 23] (13 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953459134*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4ed2d8f5-a084-4cc8-a46f-37a15ab6aaf7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "939"}],
  SequenceForm["n=", 939],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953462182*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8ecf5505-afea-402f-afa7-c9c2b27e1d97"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "939", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"4", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"4", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "14"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 939, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^3 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`b^3 $CellContext`c + 
     4 $CellContext`a $CellContext`b $CellContext`c^2 + 
     2 $CellContext`a $CellContext`c^3 + 
     2 $CellContext`b $CellContext`c^3 - $CellContext`c^4) ($CellContext`a^4 - 
     2 $CellContext`a^3 $CellContext`b + 
     2 $CellContext`a $CellContext`b^3 - $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     4 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b $CellContext`c^3 + $CellContext`c^4), $CellContext`b^2 \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^3 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`b^3 $CellContext`c + 
     4 $CellContext`a $CellContext`b $CellContext`c^2 + 
     2 $CellContext`a $CellContext`c^3 + 
     2 $CellContext`b $CellContext`c^3 - $CellContext`c^4) (-$CellContext`a^4 + 
     2 $CellContext`a^3 $CellContext`b - 
     2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 + 
     2 $CellContext`a^3 $CellContext`c + 
     4 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`c^3 + $CellContext`c^4), $CellContext`c^2 \
(-$CellContext`a^4 + 2 $CellContext`a^3 $CellContext`b - 
     2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 + 
     2 $CellContext`a^3 $CellContext`c + 
     4 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`c^3 + $CellContext`c^4) ($CellContext`a^4 - 
     2 $CellContext`a^3 $CellContext`b + 
     2 $CellContext`a $CellContext`b^3 - $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     4 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b $CellContext`c^3 + $CellContext`c^4)}, "   XM/AM=", 
   Style[Rational[1, 14] (4 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979534663897`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c3c13155-e355-4625-ba2f-3742bc297277"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "940"}],
  SequenceForm["n=", 940],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979534703197`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"638e09f7-ad82-45da-8c1f-959a77a9fae1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "940", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"6", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 940, 
   "   ", {$CellContext`a ($CellContext`a^2 + $CellContext`a $CellContext`b + \
$CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c), $CellContext`b ($CellContext`a \
$CellContext`b + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + $CellContext`b $CellContext`c), \
$CellContext`c (
     2 $CellContext`a $CellContext`b + $CellContext`a $CellContext`c + \
$CellContext`b $CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 17] (6 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953473077*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"dccef913-1dac-4269-ae7a-a239624e97be"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "941"}],
  SequenceForm["n=", 941],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953476283*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b40b6f87-b769-4506-a046-79953e9429d0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "941", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "31"], " ", 
     RowBox[{"(", 
      RowBox[{"15", "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 941, 
   "   ", {$CellContext`a ($CellContext`a $CellContext`b + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + $CellContext`b $CellContext`c) (
     2 $CellContext`a $CellContext`b + $CellContext`a $CellContext`c + \
$CellContext`b $CellContext`c + $CellContext`c^2), $CellContext`b \
($CellContext`a^2 + $CellContext`a $CellContext`b + $CellContext`a \
$CellContext`c + 2 $CellContext`b $CellContext`c) (
     2 $CellContext`a $CellContext`b + $CellContext`a $CellContext`c + \
$CellContext`b $CellContext`c + $CellContext`c^2), $CellContext`c \
($CellContext`a $CellContext`b + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + $CellContext`b $CellContext`c) \
($CellContext`a^2 + $CellContext`a $CellContext`b + $CellContext`a \
$CellContext`c + 2 $CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 31] (15 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953480475*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8ddd97ec-0ffc-445a-8f0e-2f2974403b85"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "942"}],
  SequenceForm["n=", 942],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953484626*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9e5f1b47-90cf-4711-acab-3d5675659923"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "942", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "2"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 942, 
   "   ", {$CellContext`a ($CellContext`a^2 $CellContext`b - $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`b $CellContext`c^2 - $CellContext`c^3), \
$CellContext`b (-$CellContext`a^3 + $CellContext`a $CellContext`b^2 + \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`c^3), \
$CellContext`c (-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 - $CellContext`b^3 + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`c^2 + $CellContext`b $CellContext`c^2)}, "   XM/AM=", 
   Style[
    Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953488674*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"77613275-76fb-44d2-84e9-f70186cd902c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "943"}],
  SequenceForm["n=", 943],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953492701*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7013c5ed-e557-47a3-aabf-c00249f07609"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "943", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 943, 
   "   ", {$CellContext`a ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2) ($CellContext`a^3 - \
$CellContext`a $CellContext`b^2 - $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3), \
$CellContext`b ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2) (-$CellContext`a^2 \
$CellContext`b + $CellContext`b^3 - $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`b $CellContext`c^2 + $CellContext`c^3), \
$CellContext`c ($CellContext`a^3 - $CellContext`a $CellContext`b^2 - \
$CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3) \
(-$CellContext`a^2 $CellContext`b + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`b $CellContext`c^2 + $CellContext`c^3)}, 
   "   XM/AM=", 
   Style[
    Rational[1, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953497244*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b1d3f940-ebdf-4802-9371-4617d687147a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "944"}],
  SequenceForm["n=", 944],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953501604*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8e9104f0-397e-454c-8aa6-9edd6040d2d2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "944", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "c"}], "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      RowBox[{"2", " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["c", "4"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "3"}], "+", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 944, "   ", {
   3 $CellContext`a^4 - 2 $CellContext`a^3 $CellContext`b - 
    2 $CellContext`a^2 $CellContext`b^2 + 
    2 $CellContext`a $CellContext`b^3 - $CellContext`b^4 - 
    2 $CellContext`a^3 $CellContext`c + 
    4 $CellContext`a^2 $CellContext`b $CellContext`c - 
    2 $CellContext`a $CellContext`b^2 $CellContext`c - 
    2 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`a $CellContext`b $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 + 
    2 $CellContext`a $CellContext`c^3 - $CellContext`c^4, -$CellContext`a^4 + 
    2 $CellContext`a^3 $CellContext`b - 2 $CellContext`a^2 $CellContext`b^2 - 
    2 $CellContext`a $CellContext`b^3 + 3 $CellContext`b^4 - 
    2 $CellContext`a^2 $CellContext`b $CellContext`c + 
    4 $CellContext`a $CellContext`b^2 $CellContext`c - 
    2 $CellContext`b^3 $CellContext`c + 2 $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`a $CellContext`b $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 + 
    2 $CellContext`b $CellContext`c^3 - $CellContext`c^4, -$CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + 
    2 $CellContext`a^3 $CellContext`c - 
    2 $CellContext`a^2 $CellContext`b $CellContext`c - 
    2 $CellContext`a $CellContext`b^2 $CellContext`c + 
    2 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 + 
    4 $CellContext`a $CellContext`b $CellContext`c^2 - 
    2 $CellContext`b^2 $CellContext`c^2 - 2 $CellContext`a $CellContext`c^3 - 
    2 $CellContext`b $CellContext`c^3 + 3 $CellContext`c^4}, "   XM/AM=", 
   Style[-3 + 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979535068827`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ba23ba1a-f999-4ad6-b036-403410b05017"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "945"}],
  SequenceForm["n=", 945],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979535116367`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bf36c594-de50-4d47-9a76-cd834682de88"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "945", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    SqrtBox["2"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 945, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^3 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`b^3 $CellContext`c + 2 $CellContext`a^2 $CellContext`c^2 - 
     4 $CellContext`a $CellContext`b $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 + 2 $CellContext`a $CellContext`c^3 + 
     2 $CellContext`b $CellContext`c^3 - 
     3 $CellContext`c^4) ($CellContext`a^4 - 
     2 $CellContext`a^3 $CellContext`b + 2 $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`a $CellContext`b^3 - 3 $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     4 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b $CellContext`c^3 + $CellContext`c^4), $CellContext`b^2 \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^3 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`b^3 $CellContext`c + 2 $CellContext`a^2 $CellContext`c^2 - 
     4 $CellContext`a $CellContext`b $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 + 2 $CellContext`a $CellContext`c^3 + 
     2 $CellContext`b $CellContext`c^3 - 
     3 $CellContext`c^4) ((-3) $CellContext`a^4 + 
     2 $CellContext`a^3 $CellContext`b + 2 $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 + 
     2 $CellContext`a^3 $CellContext`c - 
     4 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`c^3 + $CellContext`c^4), $CellContext`c^2 \
((-3) $CellContext`a^4 + 2 $CellContext`a^3 $CellContext`b + 
     2 $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 + 
     2 $CellContext`a^3 $CellContext`c - 
     4 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`c^3 + $CellContext`c^4) ($CellContext`a^4 - 
     2 $CellContext`a^3 $CellContext`b + 2 $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`a $CellContext`b^3 - 3 $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     4 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b $CellContext`c^3 + $CellContext`c^4)}, "   XM/AM=", 
   Style[2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979535172453`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8f85bedb-4b83-441a-b2fd-66491c3f2128"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "946"}],
  SequenceForm["n=", 946],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953521584*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9fb813ae-0d5c-4c67-b2bc-93d8d977145f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "946", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     SqrtBox["2"]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 946, 
   "   ", {$CellContext`a^3 $CellContext`b + $CellContext`a^2 \
$CellContext`b^2 - $CellContext`a $CellContext`b^3 - $CellContext`b^4 + \
$CellContext`a^3 $CellContext`c - 
    2 $CellContext`a^2 $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`b^2 $CellContext`c + $CellContext`a^2 $CellContext`c^2 + \
$CellContext`a $CellContext`b $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 - $CellContext`a $CellContext`c^3 - \
$CellContext`c^4, -$CellContext`a^4 - $CellContext`a^3 $CellContext`b + \
$CellContext`a^2 $CellContext`b^2 + $CellContext`a $CellContext`b^3 + \
$CellContext`a^2 $CellContext`b $CellContext`c - 
    2 $CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c + 
    2 $CellContext`a^2 $CellContext`c^2 + $CellContext`a $CellContext`b \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - $CellContext`b \
$CellContext`c^3 - $CellContext`c^4, -$CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - $CellContext`a^3 \
$CellContext`c + $CellContext`a^2 $CellContext`b $CellContext`c + \
$CellContext`a $CellContext`b^2 $CellContext`c - $CellContext`b^3 \
$CellContext`c + $CellContext`a^2 $CellContext`c^2 - 
    2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`a $CellContext`c^3 + $CellContext`b \
$CellContext`c^3}, "   XM/AM=", 
   Style[2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795352501*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"74843884-7e31-462c-9d15-d459743e787d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "947"}],
  SequenceForm["n=", 947],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979535280437`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9592087a-f411-4bb2-a9f3-30222c4ccbba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "947", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"3", "-", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 947, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
$CellContext`a^3 $CellContext`c - $CellContext`a^2 $CellContext`b \
$CellContext`c - $CellContext`a $CellContext`b^2 $CellContext`c + \
$CellContext`b^3 $CellContext`c - $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2 - $CellContext`a $CellContext`c^3 - $CellContext`b \
$CellContext`c^3) ($CellContext`a^4 + $CellContext`a^3 $CellContext`b - \
$CellContext`a^2 $CellContext`b^2 - $CellContext`a $CellContext`b^3 - \
$CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - $CellContext`b^3 \
$CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`a $CellContext`b \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + $CellContext`b \
$CellContext`c^3 + $CellContext`c^4), $CellContext`b^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + \
$CellContext`a^3 $CellContext`c - $CellContext`a^2 $CellContext`b \
$CellContext`c - $CellContext`a $CellContext`b^2 $CellContext`c + \
$CellContext`b^3 $CellContext`c - $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2 - $CellContext`a $CellContext`c^3 - $CellContext`b \
$CellContext`c^3) (-$CellContext`a^3 $CellContext`b - $CellContext`a^2 \
$CellContext`b^2 + $CellContext`a $CellContext`b^3 + $CellContext`b^4 - \
$CellContext`a^3 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`b^2 $CellContext`c - $CellContext`a^2 $CellContext`c^2 - \
$CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`a $CellContext`c^3 + \
$CellContext`c^4), $CellContext`c^2 (-$CellContext`a^3 $CellContext`b - \
$CellContext`a^2 $CellContext`b^2 + $CellContext`a $CellContext`b^3 + \
$CellContext`b^4 - $CellContext`a^3 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`b^2 $CellContext`c - $CellContext`a^2 $CellContext`c^2 - \
$CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + $CellContext`a $CellContext`c^3 + \
$CellContext`c^4) ($CellContext`a^4 + $CellContext`a^3 $CellContext`b - \
$CellContext`a^2 $CellContext`b^2 - $CellContext`a $CellContext`b^3 - \
$CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - $CellContext`b^3 \
$CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`a $CellContext`b \
$CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 + $CellContext`b \
$CellContext`c^3 + $CellContext`c^4)}, "   XM/AM=", 
   Style[3 - 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953531755*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1afb14e9-b9a7-49cd-9006-f29d55a9cd5c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "948"}],
  SequenceForm["n=", 948],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953535564*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f7b89d0f-695e-4078-acaa-68923f5932dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "948", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "31"], " ", 
     RowBox[{"(", 
      RowBox[{"15", "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 948, 
   "   ", {($CellContext`a + $CellContext`b - $CellContext`c) ($CellContext`a - \
$CellContext`b + $CellContext`c) ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), ($CellContext`a + $CellContext`b - \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c) \
(-$CellContext`a^3 + $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 - $CellContext`c^3), ($CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c) \
(-$CellContext`a^3 + $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 31] (15 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979535387077`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8a7274d7-b80c-41fe-a2aa-5430d3a46226"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "949"}],
  SequenceForm["n=", 949],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979535419083`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4994d32d-b72c-4cb5-98b3-aed13f28f7fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "949", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"6", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 949, 
   "   ", {$CellContext`a^2 ($CellContext`a - $CellContext`b - \
$CellContext`c) ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`b^2 (-$CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 - $CellContext`c^3) (-$CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`c^2 (-$CellContext`a - \
$CellContext`b + $CellContext`c) (-$CellContext`a^3 + $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 - $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 17] (6 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953545478*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"54136938-d3f7-4957-9089-1f3338728bc6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "950"}],
  SequenceForm["n=", 950],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979535493603`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"790b0683-390b-4811-b995-48eb06c83d86"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "950", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "-", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 950, 
   "   ", {($CellContext`a - $CellContext`b - $CellContext`c) (
     2 $CellContext`a^3 + $CellContext`a^2 $CellContext`b + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c - $CellContext`b^2 $CellContext`c - \
$CellContext`b $CellContext`c^2 + $CellContext`c^3), (-$CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a^3 + $CellContext`a \
$CellContext`b^2 + 
     2 $CellContext`b^3 - $CellContext`a^2 $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3), \
(-$CellContext`a - $CellContext`b + $CellContext`c) ($CellContext`a^3 - \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + 2 $CellContext`c^3)}, "   XM/AM=", 
   Style[1 - 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795355287*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1783ad97-d920-43af-a2e8-d0be9ee8de24"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "951"}],
  SequenceForm["n=", 951],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953555975*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1999d64d-7df0-47b7-9532-2135c90d4ca4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "951", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 951, 
   "   ", {$CellContext`a^2 ($CellContext`a + $CellContext`b - \
$CellContext`c) ($CellContext`a - $CellContext`b + $CellContext`c) \
($CellContext`a^3 + $CellContext`a $CellContext`b^2 + 
     2 $CellContext`b^3 - $CellContext`a^2 $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3) \
($CellContext`a^3 - $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2 + 
     2 $CellContext`c^3), $CellContext`b^2 ($CellContext`a + $CellContext`b - \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c) (
     2 $CellContext`a^3 + $CellContext`a^2 $CellContext`b + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c - $CellContext`b^2 $CellContext`c - \
$CellContext`b $CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 - \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + 
     2 $CellContext`c^3), $CellContext`c^2 ($CellContext`a - $CellContext`b + \
$CellContext`c) (-$CellContext`a + $CellContext`b + $CellContext`c) \
($CellContext`a^3 + $CellContext`a $CellContext`b^2 + 
     2 $CellContext`b^3 - $CellContext`a^2 $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`c^3) (
     2 $CellContext`a^3 + $CellContext`a^2 $CellContext`b + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c - $CellContext`b^2 $CellContext`c - \
$CellContext`b $CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 7] (1 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979535592527`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9104714d-5423-4dc2-ae14-358143452a10"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "952"}],
  SequenceForm["n=", 952],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953562595*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"58563898-07d4-4061-b38b-6c45d3d29ded"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "953"}],
  SequenceForm["n=", 953],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795356507*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"42ac4302-2560-48e3-bab2-f53cc377e848"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "953", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 953, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^3 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`b^3 $CellContext`c + $CellContext`a^2 $CellContext`c^2 - 
     4 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 + 2 $CellContext`a $CellContext`c^3 + 
     2 $CellContext`b $CellContext`c^3 - 
     2 $CellContext`c^4) ($CellContext`a^4 - 
     2 $CellContext`a^3 $CellContext`b + $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`a $CellContext`b^3 - 2 $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     4 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 - 
     2 $CellContext`b $CellContext`c^3 + $CellContext`c^4), $CellContext`b^2 \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 - 
     2 $CellContext`a^3 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`b^3 $CellContext`c + $CellContext`a^2 $CellContext`c^2 - 
     4 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 + 2 $CellContext`a $CellContext`c^3 + 
     2 $CellContext`b $CellContext`c^3 - 
     2 $CellContext`c^4) ((-2) $CellContext`a^4 + 
     2 $CellContext`a^3 $CellContext`b + $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 + 
     2 $CellContext`a^3 $CellContext`c - 
     4 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`a^2 \
$CellContext`c^2 + 2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`c^3 + $CellContext`c^4), $CellContext`c^2 \
((-2) $CellContext`a^4 + 
     2 $CellContext`a^3 $CellContext`b + $CellContext`a^2 $CellContext`b^2 - 
     2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 + 
     2 $CellContext`a^3 $CellContext`c - 
     4 $CellContext`a^2 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`a^2 \
$CellContext`c^2 + 2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`c^3 + $CellContext`c^4) ($CellContext`a^4 - 
     2 $CellContext`a^3 $CellContext`b + $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`a $CellContext`b^3 - 2 $CellContext`b^4 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     4 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 - 2 $CellContext`b $CellContext`c^3 + $CellContext`c^4)}, 
   "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953568969*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b6a2fd66-be16-4ad1-9016-fa7d2f365b74"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "954"}],
  SequenceForm["n=", 954],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979535729322`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f17e08fa-85e0-4346-bf83-e104784a32c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "954", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "5"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "4"], " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "14"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 954, 
   "   ", {$CellContext`a ($CellContext`a^5 - 
     2 $CellContext`a^4 $CellContext`b + 
     2 $CellContext`a^2 $CellContext`b^3 - $CellContext`a $CellContext`b^4 - 
     2 $CellContext`a^4 $CellContext`c + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c - 
     2 $CellContext`b^4 $CellContext`c + 
     4 $CellContext`a^2 $CellContext`b $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`b^3 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`c^3 + 
     2 $CellContext`b^2 $CellContext`c^3 - $CellContext`a $CellContext`c^4 - 
     2 $CellContext`b $CellContext`c^4), $CellContext`b (-$CellContext`a^4 \
$CellContext`b + 2 $CellContext`a^3 $CellContext`b^2 - 
     2 $CellContext`a $CellContext`b^4 + $CellContext`b^5 - 
     2 $CellContext`a^4 $CellContext`c + 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c - 
     2 $CellContext`b^4 $CellContext`c + 2 $CellContext`a^3 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`b $CellContext`c^2 + 
     4 $CellContext`a $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a^2 $CellContext`c^3 + 
     2 $CellContext`b^2 $CellContext`c^3 - 
     2 $CellContext`a $CellContext`c^4 - $CellContext`b $CellContext`c^4), \
$CellContext`c ((-2) $CellContext`a^4 $CellContext`b + 
     2 $CellContext`a^3 $CellContext`b^2 + 
     2 $CellContext`a^2 $CellContext`b^3 - 
     2 $CellContext`a $CellContext`b^4 - $CellContext`a^4 $CellContext`c + 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c - $CellContext`b^4 \
$CellContext`c + 2 $CellContext`a^3 $CellContext`c^2 + 
     4 $CellContext`a^2 $CellContext`b $CellContext`c^2 + 
     4 $CellContext`a $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`b^3 $CellContext`c^2 - 2 $CellContext`a $CellContext`c^4 - 
     2 $CellContext`b $CellContext`c^4 + $CellContext`c^5)}, "   XM/AM=", 
   Style[Rational[1, 14] (4 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979535765877`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"28b40769-abae-4ff5-a3ed-3ae5307a7452"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "955"}],
  SequenceForm["n=", 955],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979535802383`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"974565cc-df3d-47a4-ba93-8773880711bd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "955", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        SuperscriptBox["b", "5"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "c"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        SuperscriptBox["c", "5"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "5"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "c"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        SuperscriptBox["c", "5"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        SuperscriptBox["b", "5"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "c"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "5"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "c"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "23"], " ", 
     RowBox[{"(", 
      RowBox[{"13", "-", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 955, 
   "   ", {$CellContext`a ($CellContext`a^4 $CellContext`b - 
     2 $CellContext`a^3 $CellContext`b^2 + 
     2 $CellContext`a $CellContext`b^4 - $CellContext`b^5 + 
     2 $CellContext`a^4 $CellContext`c - 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b^4 $CellContext`c - 2 $CellContext`a^3 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c^2 - 
     4 $CellContext`a $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^3 - 
     2 $CellContext`b^2 $CellContext`c^3 + 
     2 $CellContext`a $CellContext`c^4 + $CellContext`b $CellContext`c^4) (
     2 $CellContext`a^4 $CellContext`b - 2 $CellContext`a^3 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^3 + 
     2 $CellContext`a $CellContext`b^4 + $CellContext`a^4 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c + $CellContext`b^4 \
$CellContext`c - 2 $CellContext`a^3 $CellContext`c^2 - 
     4 $CellContext`a^2 $CellContext`b $CellContext`c^2 - 
     4 $CellContext`a $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^3 $CellContext`c^2 + 2 $CellContext`a $CellContext`c^4 + 
     2 $CellContext`b $CellContext`c^4 - $CellContext`c^5), $CellContext`b \
(-$CellContext`a^5 + 2 $CellContext`a^4 $CellContext`b - 
     2 $CellContext`a^2 $CellContext`b^3 + $CellContext`a $CellContext`b^4 + 
     2 $CellContext`a^4 $CellContext`c - 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b^4 $CellContext`c - 
     4 $CellContext`a^2 $CellContext`b $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^3 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^3 - 
     2 $CellContext`b^2 $CellContext`c^3 + $CellContext`a $CellContext`c^4 + 
     2 $CellContext`b $CellContext`c^4) (2 $CellContext`a^4 $CellContext`b - 
     2 $CellContext`a^3 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^3 + 
     2 $CellContext`a $CellContext`b^4 + $CellContext`a^4 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c + $CellContext`b^4 \
$CellContext`c - 2 $CellContext`a^3 $CellContext`c^2 - 
     4 $CellContext`a^2 $CellContext`b $CellContext`c^2 - 
     4 $CellContext`a $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^3 $CellContext`c^2 + 2 $CellContext`a $CellContext`c^4 + 
     2 $CellContext`b $CellContext`c^4 - $CellContext`c^5), $CellContext`c \
($CellContext`a^4 $CellContext`b - 2 $CellContext`a^3 $CellContext`b^2 + 
     2 $CellContext`a $CellContext`b^4 - $CellContext`b^5 + 
     2 $CellContext`a^4 $CellContext`c - 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b^4 $CellContext`c - 2 $CellContext`a^3 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c^2 - 
     4 $CellContext`a $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^3 - 
     2 $CellContext`b^2 $CellContext`c^3 + 
     2 $CellContext`a $CellContext`c^4 + $CellContext`b $CellContext`c^4) \
(-$CellContext`a^5 + 2 $CellContext`a^4 $CellContext`b - 
     2 $CellContext`a^2 $CellContext`b^3 + $CellContext`a $CellContext`b^4 + 
     2 $CellContext`a^4 $CellContext`c - 
     4 $CellContext`a^2 $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b^4 $CellContext`c - 
     4 $CellContext`a^2 $CellContext`b $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^3 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^3 - 
     2 $CellContext`b^2 $CellContext`c^3 + $CellContext`a $CellContext`c^4 + 
     2 $CellContext`b $CellContext`c^4)}, "   XM/AM=", 
   Style[Rational[1, 23] (13 - 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953584661*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"59d913e1-4610-4f46-85fd-e3641e3a933e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "956"}],
  SequenceForm["n=", 956],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953588985*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2ef17a87-7ae6-4b3f-b2d0-b5ebc17ac195"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "956", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     FractionBox["3", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 956, 
   "   ", {$CellContext`a ($CellContext`a^3 - $CellContext`a $CellContext`b^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c - 
     2 $CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - 
     2 $CellContext`b $CellContext`c^2), $CellContext`b (-$CellContext`a^2 \
$CellContext`b + $CellContext`b^3 - 2 $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2), \
$CellContext`c ((-2) $CellContext`a^2 $CellContext`b - 
     2 $CellContext`a $CellContext`b^2 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`c^3)}, "   XM/AM=", 
   Style[-2 + 3 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953591844*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ce6b6cd6-adee-4e6d-85b3-5a5e142c61c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "957"}],
  SequenceForm["n=", 957],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953594586*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9fb775ae-3431-4aac-bced-74dd8f9b911d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "957", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["3", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 957, 
   "   ", {$CellContext`a ($CellContext`a^2 $CellContext`b - $CellContext`b^3 + 
     2 $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2) (
     2 $CellContext`a^2 $CellContext`b + 
     2 $CellContext`a $CellContext`b^2 + $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`c^3), $CellContext`b (-$CellContext`a^3 + \
$CellContext`a $CellContext`b^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c + 
     2 $CellContext`b^2 $CellContext`c + $CellContext`a $CellContext`c^2 + 
     2 $CellContext`b $CellContext`c^2) (2 $CellContext`a^2 $CellContext`b + 
     2 $CellContext`a $CellContext`b^2 + $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`c^3), $CellContext`c ($CellContext`a^2 \
$CellContext`b - $CellContext`b^3 + 2 $CellContext`a^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2) \
(-$CellContext`a^3 + $CellContext`a $CellContext`b^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c + 
     2 $CellContext`b^2 $CellContext`c + $CellContext`a $CellContext`c^2 + 
     2 $CellContext`b $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[3, 7] (-1 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953598247*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"6d4023ad-74ad-49fd-97cb-60bdf0bc06c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "958"}],
  SequenceForm["n=", 958],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953601407*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"584b99e0-cfa7-460e-9c9b-33beb6748ccb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "958", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "4"}], "+", 
     RowBox[{"3", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 958, 
   "   ", {$CellContext`a ($CellContext`a - $CellContext`b - $CellContext`c) \
($CellContext`a^2 + $CellContext`a $CellContext`b + $CellContext`a \
$CellContext`c + 
     2 $CellContext`b $CellContext`c), $CellContext`b (-$CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a $CellContext`b + \
$CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + $CellContext`b $CellContext`c), \
$CellContext`c (-$CellContext`a - $CellContext`b + $CellContext`c) (
     2 $CellContext`a $CellContext`b + $CellContext`a $CellContext`c + \
$CellContext`b $CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[-4 + 3 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979536041737`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ba30fccc-c595-40dd-8bef-daf3faf32d16"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "959"}],
  SequenceForm["n=", 959],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979536068087`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"470f74ac-d335-4d62-a4dd-f0f7be5ff3a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "959", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 959, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c) ($CellContext`a \
$CellContext`b + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + $CellContext`b $CellContext`c) (
     2 $CellContext`a $CellContext`b + $CellContext`a $CellContext`c + \
$CellContext`b $CellContext`c + $CellContext`c^2), $CellContext`b \
($CellContext`a + $CellContext`b - $CellContext`c) (-$CellContext`a + \
$CellContext`b + $CellContext`c) ($CellContext`a^2 + $CellContext`a \
$CellContext`b + $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c) (
     2 $CellContext`a $CellContext`b + $CellContext`a $CellContext`c + \
$CellContext`b $CellContext`c + $CellContext`c^2), $CellContext`c \
($CellContext`a - $CellContext`b + $CellContext`c) (-$CellContext`a + \
$CellContext`b + $CellContext`c) ($CellContext`a $CellContext`b + \
$CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + $CellContext`b $CellContext`c) \
($CellContext`a^2 + $CellContext`a $CellContext`b + $CellContext`a \
$CellContext`c + 2 $CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 3] (-1 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979536097937`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"586ac716-eb72-4322-9a78-9c11e2a815f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "960"}],
  SequenceForm["n=", 960],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953613092*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f937a62d-8633-4c82-895e-a72571ce034e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "960", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], "+", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 960, 
   "   ", {$CellContext`a ($CellContext`a - $CellContext`b - $CellContext`c) \
($CellContext`a $CellContext`b + $CellContext`b^2 + $CellContext`a \
$CellContext`c + $CellContext`c^2), $CellContext`b (-$CellContext`a + \
$CellContext`b - $CellContext`c) ($CellContext`a^2 + $CellContext`a \
$CellContext`b + $CellContext`b $CellContext`c + $CellContext`c^2), \
$CellContext`c (-$CellContext`a - $CellContext`b + $CellContext`c) \
($CellContext`a^2 + $CellContext`b^2 + $CellContext`a $CellContext`c + \
$CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[Rational[-1, 2] + 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953615933*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fdc6bead-9756-4b8b-9290-a484570f3493"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "961"}],
  SequenceForm["n=", 961],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953618675*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"03a0fb97-b5dd-474d-9c0c-acc0e0a76356"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "961", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "5"}], "+", 
     RowBox[{"4", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 961, 
   "   ", {$CellContext`a ($CellContext`a + $CellContext`b - $CellContext`c) \
($CellContext`a - $CellContext`b + $CellContext`c) ($CellContext`a^2 + \
$CellContext`b^2 + $CellContext`a $CellContext`c + $CellContext`b \
$CellContext`c) ($CellContext`a^2 + $CellContext`a $CellContext`b + \
$CellContext`b $CellContext`c + $CellContext`c^2), $CellContext`b \
($CellContext`a + $CellContext`b - $CellContext`c) (-$CellContext`a + \
$CellContext`b + $CellContext`c) ($CellContext`a^2 + $CellContext`b^2 + \
$CellContext`a $CellContext`c + $CellContext`b $CellContext`c) \
($CellContext`a $CellContext`b + $CellContext`b^2 + $CellContext`a \
$CellContext`c + $CellContext`c^2), $CellContext`c ($CellContext`a - \
$CellContext`b + $CellContext`c) (-$CellContext`a + $CellContext`b + \
$CellContext`c) ($CellContext`a $CellContext`b + $CellContext`b^2 + \
$CellContext`a $CellContext`c + $CellContext`c^2) ($CellContext`a^2 + \
$CellContext`a $CellContext`b + $CellContext`b $CellContext`c + \
$CellContext`c^2)}, "   XM/AM=", 
   Style[-5 + 4 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953621703*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"294e8564-b013-4039-9903-39595404f6a6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "962"}],
  SequenceForm["n=", 962],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979536245413`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"03d08861-c331-40c8-a8fd-cec9c0471955"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "962", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b"}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "3"]}], "-", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "c"}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
      RowBox[{"4", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "-", 
      SuperscriptBox["c", "4"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["b", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "3"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "3"], " ", "c"}], "-", 
      RowBox[{"4", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"2", " ", "b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 962, 
   "   ", {$CellContext`a^4 + 2 $CellContext`a^3 $CellContext`b - 
    2 $CellContext`a $CellContext`b^3 - $CellContext`b^4 + 
    2 $CellContext`a^3 $CellContext`c - 
    4 $CellContext`a^2 $CellContext`b $CellContext`c + 
    2 $CellContext`a $CellContext`b^2 $CellContext`c + 
    2 $CellContext`a $CellContext`b $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 - 
    2 $CellContext`a $CellContext`c^3 - $CellContext`c^4, -$CellContext`a^4 - 
    2 $CellContext`a^3 $CellContext`b + 
    2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 + 
    2 $CellContext`a^2 $CellContext`b $CellContext`c - 
    4 $CellContext`a $CellContext`b^2 $CellContext`c + 
    2 $CellContext`b^3 $CellContext`c + 2 $CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`a $CellContext`b $CellContext`c^2 - 
    2 $CellContext`b $CellContext`c^3 - $CellContext`c^4, -$CellContext`a^4 + 
    2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 - 
    2 $CellContext`a^3 $CellContext`c + 
    2 $CellContext`a^2 $CellContext`b $CellContext`c + 
    2 $CellContext`a $CellContext`b^2 $CellContext`c - 
    2 $CellContext`b^3 $CellContext`c - 
    4 $CellContext`a $CellContext`b $CellContext`c^2 + 
    2 $CellContext`a $CellContext`c^3 + 
    2 $CellContext`b $CellContext`c^3 + $CellContext`c^4}, "   XM/AM=", 
   Style[-1 + 2 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953627925*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"03dc4f10-663f-4648-8296-dd066d917267"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "963"}],
  SequenceForm["n=", 963],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953630907*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"49c99a6e-3641-4b72-936b-4a1558eea61a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "963", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"4", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"4", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"4", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 963, 
   "   ", {$CellContext`a^2 ($CellContext`a^4 - 
     2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^3 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b^3 $CellContext`c + 
     4 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`a $CellContext`c^3 - 
     2 $CellContext`b $CellContext`c^3 - $CellContext`c^4) ($CellContext`a^4 + 
     2 $CellContext`a^3 $CellContext`b - 
     2 $CellContext`a $CellContext`b^3 - $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     4 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + 
     2 $CellContext`b $CellContext`c^3 + $CellContext`c^4), $CellContext`b^2 \
($CellContext`a^4 - 2 $CellContext`a^2 $CellContext`b^2 + $CellContext`b^4 + 
     2 $CellContext`a^3 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b^3 $CellContext`c + 
     4 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`a $CellContext`c^3 - 
     2 $CellContext`b $CellContext`c^3 - $CellContext`c^4) (-$CellContext`a^4 - 
     2 $CellContext`a^3 $CellContext`b + 
     2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 - 
     2 $CellContext`a^3 $CellContext`c + 
     4 $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`c^3 + $CellContext`c^4), $CellContext`c^2 \
(-$CellContext`a^4 - 2 $CellContext`a^3 $CellContext`b + 
     2 $CellContext`a $CellContext`b^3 + $CellContext`b^4 - 
     2 $CellContext`a^3 $CellContext`c + 
     4 $CellContext`a^2 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`c^3 + $CellContext`c^4) ($CellContext`a^4 + 
     2 $CellContext`a^3 $CellContext`b - 
     2 $CellContext`a $CellContext`b^3 - $CellContext`b^4 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c + 
     4 $CellContext`a $CellContext`b^2 $CellContext`c - 
     2 $CellContext`b^3 $CellContext`c - 2 $CellContext`a^2 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c^2 + 
     2 $CellContext`b $CellContext`c^3 + $CellContext`c^4)}, "   XM/AM=", 
   Style[-1 + 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953634685*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ac17bae1-6ca6-4da1-a04d-48de34ed1240"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "964"}],
  SequenceForm["n=", 964],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953638475*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e2038724-4358-43c7-a53d-55e92425c11a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "964", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["a", "3"], " ", "b"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["b", "3"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", "c"}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
      RowBox[{"2", " ", "a", " ", 
       SuperscriptBox["b", "2"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["b", "3"], " ", "c"}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"2", " ", "a", " ", "b", " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{"a", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      RowBox[{"b", " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "4"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"13", "-", 
       RowBox[{"5", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 964, 
   "   ", {$CellContext`a^4 + $CellContext`a^3 $CellContext`b + \
$CellContext`a^2 $CellContext`b^2 + $CellContext`a $CellContext`b^3 + \
$CellContext`a^3 $CellContext`c + 
    2 $CellContext`a^2 $CellContext`b $CellContext`c + 
    2 $CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c + $CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`a $CellContext`b $CellContext`c^2 + 
    2 $CellContext`b^2 $CellContext`c^2 + $CellContext`a $CellContext`c^3 + \
$CellContext`b $CellContext`c^3, $CellContext`a^3 $CellContext`b + \
$CellContext`a^2 $CellContext`b^2 + $CellContext`a $CellContext`b^3 + \
$CellContext`b^4 + $CellContext`a^3 $CellContext`c + 
    2 $CellContext`a^2 $CellContext`b $CellContext`c + 
    2 $CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c + 2 $CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`a $CellContext`c^3 + $CellContext`b \
$CellContext`c^3, $CellContext`a^3 $CellContext`b + 
    2 $CellContext`a^2 $CellContext`b^2 + $CellContext`a $CellContext`b^3 + \
$CellContext`a^3 $CellContext`c + 
    2 $CellContext`a^2 $CellContext`b $CellContext`c + 
    2 $CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c + $CellContext`a^2 $CellContext`c^2 + 
    2 $CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`a $CellContext`c^3 + $CellContext`b \
$CellContext`c^3 + $CellContext`c^4}, "   XM/AM=", 
   Style[Rational[1, 17] (13 - 5 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953641753*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"4c9444c5-1873-4182-bfdd-c8ac6fa201bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "965"}],
  SequenceForm["n=", 965],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953644912*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c3de4311-80b5-4283-bf3c-848fc76f46a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "965", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"6", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 965, 
   "   ", {$CellContext`a ($CellContext`a^4 - $CellContext`a^3 $CellContext`b - \
$CellContext`a^2 $CellContext`b^2 + $CellContext`a $CellContext`b^3 - \
$CellContext`a^3 $CellContext`c + 
     3 $CellContext`a $CellContext`b^2 $CellContext`c + 
     2 $CellContext`b^3 $CellContext`c - $CellContext`a^2 $CellContext`c^2 + 
     3 $CellContext`a $CellContext`b $CellContext`c^2 + 
     4 $CellContext`b^2 $CellContext`c^2 + $CellContext`a $CellContext`c^3 + 
     2 $CellContext`b $CellContext`c^3), $CellContext`b ($CellContext`a^3 \
$CellContext`b - $CellContext`a^2 $CellContext`b^2 - $CellContext`a \
$CellContext`b^3 + $CellContext`b^4 + 2 $CellContext`a^3 $CellContext`c + 
     3 $CellContext`a^2 $CellContext`b $CellContext`c - $CellContext`b^3 \
$CellContext`c + 4 $CellContext`a^2 $CellContext`c^2 + 
     3 $CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2 + 
     2 $CellContext`a $CellContext`c^3 + $CellContext`b $CellContext`c^3), \
$CellContext`c (2 $CellContext`a^3 $CellContext`b + 
     4 $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`a $CellContext`b^3 + $CellContext`a^3 $CellContext`c + 
     3 $CellContext`a^2 $CellContext`b $CellContext`c + 
     3 $CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c - $CellContext`a^2 $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2 - $CellContext`a $CellContext`c^3 - $CellContext`b \
$CellContext`c^3 + $CellContext`c^4)}, "   XM/AM=", 
   Style[Rational[1, 17] (6 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795364865*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1f6efffa-baae-455c-b773-f8b3a92c9e53"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "966"}],
  SequenceForm["n=", 966],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979536520147`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a78823f9-b2ad-4121-8411-c09e4b707584"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "966", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "b"}], "-", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "c"}], "-", 
      RowBox[{"2", " ", "b", " ", "c"}], "-", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", "b"}], "+", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "c"}], "-", 
      RowBox[{"2", " ", "b", " ", "c"}], "-", 
      SuperscriptBox["c", "2"]}], ",", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["a", "2"]}], "-", 
      RowBox[{"2", " ", "a", " ", "b"}], "-", 
      SuperscriptBox["b", "2"], "-", 
      RowBox[{"2", " ", "a", " ", "c"}], "-", 
      RowBox[{"2", " ", "b", " ", "c"}], "+", 
      SuperscriptBox["c", "2"]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "47"], " ", 
     RowBox[{"(", 
      RowBox[{"19", "-", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 966, 
   "   ", {$CellContext`a^2 - 
    2 $CellContext`a $CellContext`b - $CellContext`b^2 - 
    2 $CellContext`a $CellContext`c - 
    2 $CellContext`b $CellContext`c - $CellContext`c^2, -$CellContext`a^2 - 
    2 $CellContext`a $CellContext`b + $CellContext`b^2 - 
    2 $CellContext`a $CellContext`c - 
    2 $CellContext`b $CellContext`c - $CellContext`c^2, -$CellContext`a^2 - 
    2 $CellContext`a $CellContext`b - $CellContext`b^2 - 
    2 $CellContext`a $CellContext`c - 
    2 $CellContext`b $CellContext`c + $CellContext`c^2}, "   XM/AM=", 
   Style[Rational[1, 47] (19 - 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953655002*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"adf1bc2d-9d5b-450d-9158-aac7a7240fe8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "967"}],
  SequenceForm["n=", 967],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953658379*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"65963baa-c145-4f39-83fb-0502b101d07a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "967", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["2", "23"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 967, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 + 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c - $CellContext`c^2) ($CellContext`a^2 + 
     2 $CellContext`a $CellContext`b - $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c + $CellContext`c^2), $CellContext`b^2 \
($CellContext`a^2 + 2 $CellContext`a $CellContext`b + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c - $CellContext`c^2) (-$CellContext`a^2 + 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c + $CellContext`c^2), $CellContext`c^2 \
($CellContext`a^2 + 2 $CellContext`a $CellContext`b - $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c + $CellContext`c^2) (-$CellContext`a^2 + 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[2, 23] (5 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979536618967`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0352ad51-6a64-4870-ae22-df220898c80e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "968"}],
  SequenceForm["n=", 968],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953665566*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"26c23bd1-86f2-47e6-9202-ac877bc8c621"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "968", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"2", " ", "a", " ", "c"}], "-", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"11", "-", 
       RowBox[{"6", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 968, 
   "   ", {$CellContext`a ($CellContext`a^2 - 
     2 $CellContext`a $CellContext`b - $CellContext`b^2 - 
     2 $CellContext`a $CellContext`c - 
     2 $CellContext`b $CellContext`c - $CellContext`c^2), $CellContext`b \
(-$CellContext`a^2 - 2 $CellContext`a $CellContext`b + $CellContext`b^2 - 
     2 $CellContext`a $CellContext`c - 
     2 $CellContext`b $CellContext`c - $CellContext`c^2), $CellContext`c \
(-$CellContext`a^2 - 2 $CellContext`a $CellContext`b - $CellContext`b^2 - 
     2 $CellContext`a $CellContext`c - 
     2 $CellContext`b $CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 7] (11 - 6 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979536685266`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"90d0bb30-9ace-4a71-8b87-ec34b3a2162b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "969"}],
  SequenceForm["n=", 969],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953671392*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"47c0b7bf-df87-4642-a1d1-350ee02a74fe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "969", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"2", " ", "a", " ", "c"}], "+", 
        RowBox[{"2", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox[
     SqrtBox["2"], "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 969, 
   "   ", {$CellContext`a ($CellContext`a^2 + 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c - $CellContext`c^2) ($CellContext`a^2 + 
     2 $CellContext`a $CellContext`b - $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c + $CellContext`c^2), $CellContext`b \
($CellContext`a^2 + 2 $CellContext`a $CellContext`b + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c - $CellContext`c^2) (-$CellContext`a^2 + 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c + $CellContext`c^2), $CellContext`c \
($CellContext`a^2 + 2 $CellContext`a $CellContext`b - $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c + $CellContext`c^2) (-$CellContext`a^2 + 
     2 $CellContext`a $CellContext`b + $CellContext`b^2 + 
     2 $CellContext`a $CellContext`c + 
     2 $CellContext`b $CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 3] 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953674698*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"585a395b-b569-41ff-bb27-5bb0c1b287ea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "970"}],
  SequenceForm["n=", 970],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953677928*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"a75b95c1-649b-412c-b1bc-e3560dc99750"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "970", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        SuperscriptBox["b", "5"], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        SuperscriptBox["c", "5"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        SuperscriptBox["c", "5"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "5"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "-", 
        SuperscriptBox["b", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], "-", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 970, 
   "   ", {$CellContext`a^2 ($CellContext`a^3 $CellContext`b^2 + \
$CellContext`a^2 $CellContext`b^3 - $CellContext`a $CellContext`b^4 - \
$CellContext`b^5 + 
     2 $CellContext`a^3 $CellContext`b $CellContext`c + $CellContext`a^2 \
$CellContext`b^2 $CellContext`c - 
     2 $CellContext`a $CellContext`b^3 $CellContext`c - $CellContext`b^4 \
$CellContext`c + $CellContext`a^3 $CellContext`c^2 + $CellContext`a^2 \
$CellContext`b $CellContext`c^2 + $CellContext`a^2 $CellContext`c^3 - 
     2 $CellContext`a $CellContext`b $CellContext`c^3 - $CellContext`a \
$CellContext`c^4 - $CellContext`b $CellContext`c^4 - $CellContext`c^5), \
$CellContext`b^2 (-$CellContext`a^5 - $CellContext`a^4 $CellContext`b + \
$CellContext`a^3 $CellContext`b^2 + $CellContext`a^2 $CellContext`b^3 - \
$CellContext`a^4 $CellContext`c - 
     2 $CellContext`a^3 $CellContext`b $CellContext`c + $CellContext`a^2 \
$CellContext`b^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b^3 $CellContext`c + $CellContext`a \
$CellContext`b^2 $CellContext`c^2 + $CellContext`b^3 $CellContext`c^2 - 
     2 $CellContext`a $CellContext`b $CellContext`c^3 + $CellContext`b^2 \
$CellContext`c^3 - $CellContext`a $CellContext`c^4 - $CellContext`b \
$CellContext`c^4 - $CellContext`c^5), $CellContext`c^2 (-$CellContext`a^5 - \
$CellContext`a^4 $CellContext`b - $CellContext`a $CellContext`b^4 - \
$CellContext`b^5 - $CellContext`a^4 $CellContext`c - 
     2 $CellContext`a^3 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^3 $CellContext`c - $CellContext`b^4 \
$CellContext`c + $CellContext`a^3 $CellContext`c^2 + $CellContext`a^2 \
$CellContext`b $CellContext`c^2 + $CellContext`a $CellContext`b^2 \
$CellContext`c^2 + $CellContext`b^3 $CellContext`c^2 + $CellContext`a^2 \
$CellContext`c^3 + 
     2 $CellContext`a $CellContext`b $CellContext`c^3 + $CellContext`b^2 \
$CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[-1, 2] - 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953682035*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3b8854e9-0d41-4c97-87e9-e6b411ed214d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "971"}],
  SequenceForm["n=", 971],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953685533*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"754a15b1-4fbe-4a8d-8cec-08bf6205b5dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "972"}],
  SequenceForm["n=", 972],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979536881437`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"81cbdd54-1dcb-4e83-a5a1-062aaa086c8d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "972", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "5"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "5"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"2", " ", "b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "4"]}], " ", "b"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", "1"}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 972, 
   "   ", {$CellContext`a ($CellContext`a^5 + $CellContext`a^4 $CellContext`b - 
     2 $CellContext`a^3 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^3 + $CellContext`a $CellContext`b^4 + \
$CellContext`b^5 - 2 $CellContext`a^4 $CellContext`c + 
     2 $CellContext`a^3 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^3 $CellContext`c - 
     2 $CellContext`b^4 $CellContext`c + 2 $CellContext`a^2 $CellContext`c^3 - 
     2 $CellContext`a $CellContext`b $CellContext`c^3 + 
     2 $CellContext`b^2 $CellContext`c^3 - $CellContext`a $CellContext`c^4 - \
$CellContext`b $CellContext`c^4) ($CellContext`a^5 - 
     2 $CellContext`a^4 $CellContext`b + 
     2 $CellContext`a^2 $CellContext`b^3 - $CellContext`a $CellContext`b^4 + \
$CellContext`a^4 $CellContext`c + 
     2 $CellContext`a^3 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^3 $CellContext`c - $CellContext`b^4 \
$CellContext`c - 2 $CellContext`a^3 $CellContext`c^2 + 
     2 $CellContext`b^3 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^3 + 
     2 $CellContext`a $CellContext`b $CellContext`c^3 + $CellContext`a \
$CellContext`c^4 - 
     2 $CellContext`b $CellContext`c^4 + $CellContext`c^5), $CellContext`b \
($CellContext`a^5 + $CellContext`a^4 $CellContext`b - 
     2 $CellContext`a^3 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^3 + $CellContext`a $CellContext`b^4 + \
$CellContext`b^5 - 2 $CellContext`a^4 $CellContext`c + 
     2 $CellContext`a^3 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^3 $CellContext`c - 
     2 $CellContext`b^4 $CellContext`c + 2 $CellContext`a^2 $CellContext`c^3 - 
     2 $CellContext`a $CellContext`b $CellContext`c^3 + 
     2 $CellContext`b^2 $CellContext`c^3 - $CellContext`a $CellContext`c^4 - \
$CellContext`b $CellContext`c^4) (-$CellContext`a^4 $CellContext`b + 
     2 $CellContext`a^3 $CellContext`b^2 - 
     2 $CellContext`a $CellContext`b^4 + $CellContext`b^5 - $CellContext`a^4 \
$CellContext`c - 2 $CellContext`a^3 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^3 $CellContext`c + $CellContext`b^4 \
$CellContext`c + 2 $CellContext`a^3 $CellContext`c^2 - 
     2 $CellContext`b^3 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^3 - 
     2 $CellContext`b^2 $CellContext`c^3 - 
     2 $CellContext`a $CellContext`c^4 + $CellContext`b $CellContext`c^4 + \
$CellContext`c^5), $CellContext`c ($CellContext`a^5 - 
     2 $CellContext`a^4 $CellContext`b + 
     2 $CellContext`a^2 $CellContext`b^3 - $CellContext`a $CellContext`b^4 + \
$CellContext`a^4 $CellContext`c + 
     2 $CellContext`a^3 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^3 $CellContext`c - $CellContext`b^4 \
$CellContext`c - 2 $CellContext`a^3 $CellContext`c^2 + 
     2 $CellContext`b^3 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^3 + 
     2 $CellContext`a $CellContext`b $CellContext`c^3 + $CellContext`a \
$CellContext`c^4 - 
     2 $CellContext`b $CellContext`c^4 + $CellContext`c^5) (-$CellContext`a^4 \
$CellContext`b + 2 $CellContext`a^3 $CellContext`b^2 - 
     2 $CellContext`a $CellContext`b^4 + $CellContext`b^5 - $CellContext`a^4 \
$CellContext`c - 2 $CellContext`a^3 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^3 $CellContext`c + $CellContext`b^4 \
$CellContext`c + 2 $CellContext`a^3 $CellContext`c^2 - 
     2 $CellContext`b^3 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^3 - 
     2 $CellContext`b^2 $CellContext`c^3 - 
     2 $CellContext`a $CellContext`c^4 + $CellContext`b $CellContext`c^4 + \
$CellContext`c^5)}, "   XM/AM=", 
   Style[-1, 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953692527*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bbdbe50f-f3d3-4c15-b3de-c88c21f4872f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "973"}],
  SequenceForm["n=", 973],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953696638*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"00c440c1-29ba-42c4-bb2f-8e4b30e7dd82"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "973", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "10"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "8"]}], "+", 
        SuperscriptBox["b", "10"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "8"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "8"]}], "+", 
        SuperscriptBox["c", "10"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "4"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "10"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "8"]}], "+", 
        SuperscriptBox["b", "10"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "8"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "8"]}], "+", 
        SuperscriptBox["c", "10"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "10"], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "6"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "8"]}], "+", 
        SuperscriptBox["b", "10"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "8"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "6"], " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "4"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "6"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "4"], " ", 
         SuperscriptBox["c", "6"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "8"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "8"]}], "+", 
        SuperscriptBox["c", "10"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["2", "3"],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 973, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 $CellContext`b^2 - \
$CellContext`b^4 + $CellContext`a^2 $CellContext`c^2 + 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`c^4) \
($CellContext`a^10 - 3 $CellContext`a^8 $CellContext`b^2 + 
     2 $CellContext`a^6 $CellContext`b^4 + 
     2 $CellContext`a^4 $CellContext`b^6 - 
     3 $CellContext`a^2 $CellContext`b^8 + $CellContext`b^10 - 
     3 $CellContext`a^8 $CellContext`c^2 + 
     3 $CellContext`a^6 $CellContext`b^2 $CellContext`c^2 + $CellContext`a^4 \
$CellContext`b^4 $CellContext`c^2 + $CellContext`a^2 $CellContext`b^6 \
$CellContext`c^2 - 2 $CellContext`b^8 $CellContext`c^2 + 
     2 $CellContext`a^6 $CellContext`c^4 + $CellContext`a^4 $CellContext`b^2 \
$CellContext`c^4 + 
     4 $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 + $CellContext`b^6 \
$CellContext`c^4 + 
     2 $CellContext`a^4 $CellContext`c^6 + $CellContext`a^2 $CellContext`b^2 \
$CellContext`c^6 + $CellContext`b^4 $CellContext`c^6 - 
     3 $CellContext`a^2 $CellContext`c^8 - 
     2 $CellContext`b^2 $CellContext`c^8 + $CellContext`c^10), \
$CellContext`b^2 (-$CellContext`a^4 + $CellContext`a^2 $CellContext`b^2 + 
     2 $CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - \
$CellContext`c^4) ($CellContext`a^10 - 3 $CellContext`a^8 $CellContext`b^2 + 
     2 $CellContext`a^6 $CellContext`b^4 + 
     2 $CellContext`a^4 $CellContext`b^6 - 
     3 $CellContext`a^2 $CellContext`b^8 + $CellContext`b^10 - 
     2 $CellContext`a^8 $CellContext`c^2 + $CellContext`a^6 $CellContext`b^2 \
$CellContext`c^2 + $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 + 
     3 $CellContext`a^2 $CellContext`b^6 $CellContext`c^2 - 
     3 $CellContext`b^8 $CellContext`c^2 + $CellContext`a^6 $CellContext`c^4 + 
     4 $CellContext`a^4 $CellContext`b^2 $CellContext`c^4 + $CellContext`a^2 \
$CellContext`b^4 $CellContext`c^4 + 
     2 $CellContext`b^6 $CellContext`c^4 + $CellContext`a^4 $CellContext`c^6 + \
$CellContext`a^2 $CellContext`b^2 $CellContext`c^6 + 
     2 $CellContext`b^4 $CellContext`c^6 - 
     2 $CellContext`a^2 $CellContext`c^8 - 
     3 $CellContext`b^2 $CellContext`c^8 + $CellContext`c^10), \
$CellContext`c^2 (-$CellContext`a^4 + 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`b^4 + \
$CellContext`a^2 $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2) \
($CellContext`a^10 - 
     2 $CellContext`a^8 $CellContext`b^2 + $CellContext`a^6 $CellContext`b^4 + \
$CellContext`a^4 $CellContext`b^6 - 
     2 $CellContext`a^2 $CellContext`b^8 + $CellContext`b^10 - 
     3 $CellContext`a^8 $CellContext`c^2 + $CellContext`a^6 $CellContext`b^2 \
$CellContext`c^2 + 
     4 $CellContext`a^4 $CellContext`b^4 $CellContext`c^2 + $CellContext`a^2 \
$CellContext`b^6 $CellContext`c^2 - 3 $CellContext`b^8 $CellContext`c^2 + 
     2 $CellContext`a^6 $CellContext`c^4 + $CellContext`a^4 $CellContext`b^2 \
$CellContext`c^4 + $CellContext`a^2 $CellContext`b^4 $CellContext`c^4 + 
     2 $CellContext`b^6 $CellContext`c^4 + 
     2 $CellContext`a^4 $CellContext`c^6 + 
     3 $CellContext`a^2 $CellContext`b^2 $CellContext`c^6 + 
     2 $CellContext`b^4 $CellContext`c^6 - 
     3 $CellContext`a^2 $CellContext`c^8 - 
     3 $CellContext`b^2 $CellContext`c^8 + $CellContext`c^10)}, "   XM/AM=", 
   Style[
    Rational[2, 3], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953700989*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"81aa6c6b-83aa-4910-a19d-b362f4457d54"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "974"}],
  SequenceForm["n=", 974],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953705213*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f03f1e2a-1daa-47de-ba61-395923d1c814"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "975"}],
  SequenceForm["n=", 975],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953707749*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"97fad206-3d67-4a01-b652-e12b628e8177"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "975", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"4", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"4", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"4", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "14"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 975, 
   "   ", {$CellContext`a ($CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c + 4 $CellContext`a $CellContext`b $CellContext`c + 
     3 $CellContext`b^2 $CellContext`c + $CellContext`a $CellContext`c^2 + 
     3 $CellContext`b $CellContext`c^2 + $CellContext`c^3), $CellContext`b \
($CellContext`a^3 + $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + 3 $CellContext`a^2 $CellContext`c + 
     4 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + 
     3 $CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2 + \
$CellContext`c^3), $CellContext`c ($CellContext`a^3 + 
     3 $CellContext`a^2 $CellContext`b + 
     3 $CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c + 
     4 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 14] (4 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953744635*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"35dc837d-4673-4646-8efd-b145fa30846a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "976"}],
  SequenceForm["n=", 976],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979537492867`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"09fa59cf-1182-4711-976f-827738435bd5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "976", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"4", "-", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 976, 
   "   ", {$CellContext`a ($CellContext`a^3 + $CellContext`b^3 + \
$CellContext`b^2 $CellContext`c + $CellContext`b $CellContext`c^2 + \
$CellContext`c^3), $CellContext`b ($CellContext`a^3 + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c + $CellContext`a $CellContext`c^2 + \
$CellContext`c^3), $CellContext`c ($CellContext`a^3 + $CellContext`a^2 \
$CellContext`b + $CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 7] (4 - 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953752811*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0594e026-91ec-44c1-98d2-f9972174ed54"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "977"}],
  SequenceForm["n=", 977],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953756303*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3af82e7d-a832-4c6e-8442-6b80f209b317"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "977", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 977, 
   "   ", {$CellContext`a ($CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`c^3) \
($CellContext`a^3 + $CellContext`b^3 + $CellContext`a^2 $CellContext`c + \
$CellContext`a $CellContext`c^2 + $CellContext`c^3), $CellContext`b \
($CellContext`a^3 + $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + $CellContext`c^3) ($CellContext`a^3 + \
$CellContext`b^3 + $CellContext`b^2 $CellContext`c + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`c ($CellContext`a^3 + \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c + $CellContext`a \
$CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 + $CellContext`b^3 + \
$CellContext`b^2 $CellContext`c + $CellContext`b $CellContext`c^2 + \
$CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 17] (5 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795375953*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e6aa5a21-44ee-4f83-8d6a-7ecb94365ea3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "978"}],
  SequenceForm["n=", 978],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953763155*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"1779fa16-ee00-4066-9e88-f7368382eaad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "978", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "3"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 978, 
   "   ", {$CellContext`a ($CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 + $CellContext`a^2 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c - $CellContext`b^2 $CellContext`c + \
$CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2), \
$CellContext`b ($CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 - $CellContext`a^2 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c + $CellContext`b^2 $CellContext`c - \
$CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2), \
$CellContext`c (-$CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 + $CellContext`a^2 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c + $CellContext`b^2 $CellContext`c + \
$CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[Rational[1, 3] (1 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795376648*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"49103765-46fa-4ad4-8316-487361c28f3d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "979"}],
  SequenceForm["n=", 979],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953769457*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"500cd37c-2315-4d65-9425-54f330655d3a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "979", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "-", 
       RowBox[{"3", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 979, 
   "   ", {$CellContext`a ($CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 - $CellContext`a^2 $CellContext`c + $CellContext`a \
$CellContext`b $CellContext`c - $CellContext`b^2 $CellContext`c - \
$CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2) \
(-$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 + \
$CellContext`a^2 $CellContext`c + $CellContext`a $CellContext`b \
$CellContext`c - $CellContext`b^2 $CellContext`c + $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2), $CellContext`b \
($CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 - \
$CellContext`a^2 $CellContext`c + $CellContext`a $CellContext`b \
$CellContext`c - $CellContext`b^2 $CellContext`c - $CellContext`a \
$CellContext`c^2 - $CellContext`b $CellContext`c^2) (-$CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 - $CellContext`a^2 \
$CellContext`c + $CellContext`a $CellContext`b $CellContext`c + \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2), $CellContext`c (-$CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`a^2 \
$CellContext`c + $CellContext`a $CellContext`b $CellContext`c - \
$CellContext`b^2 $CellContext`c + $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2) (-$CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 - $CellContext`a^2 $CellContext`c + \
$CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 7] (5 - 3 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953805469*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7922dce8-1e65-4cd6-b77c-06ddd9b99b37"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "980"}],
  SequenceForm["n=", 980],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953809567*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"57b3a7ef-5d6d-4fe1-9f8c-1cb4e77d64ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "980", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["2", "71"], " ", 
     RowBox[{"(", 
      RowBox[{"12", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 980, 
   "   ", {$CellContext`a ($CellContext`a^2 $CellContext`b^2 + $CellContext`a \
$CellContext`b^3 + $CellContext`a^2 $CellContext`b $CellContext`c + \
$CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c + $CellContext`a^2 $CellContext`c^2 + $CellContext`a \
$CellContext`b $CellContext`c^2 + $CellContext`a $CellContext`c^3 + \
$CellContext`b $CellContext`c^3), $CellContext`b ($CellContext`a^3 \
$CellContext`b + $CellContext`a^2 $CellContext`b^2 + $CellContext`a^3 \
$CellContext`c + $CellContext`a^2 $CellContext`b $CellContext`c + \
$CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`a \
$CellContext`b $CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 + \
$CellContext`a $CellContext`c^3 + $CellContext`b $CellContext`c^3), \
$CellContext`c ($CellContext`a^3 $CellContext`b + $CellContext`a \
$CellContext`b^3 + $CellContext`a^3 $CellContext`c + $CellContext`a^2 \
$CellContext`b $CellContext`c + $CellContext`a $CellContext`b^2 \
$CellContext`c + $CellContext`b^3 $CellContext`c + $CellContext`a^2 \
$CellContext`c^2 + $CellContext`a $CellContext`b $CellContext`c^2 + \
$CellContext`b^2 $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[2, 71] (12 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953812612*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"75510c0d-2d31-48ba-933d-de3409b67c4c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "981"}],
  SequenceForm["n=", 981],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.86109795381616*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"337294a1-0bb0-4644-ae86-04f96e380087"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "981", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "127"], " ", 
     RowBox[{"(", 
      RowBox[{"63", "-", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 981, 
   "   ", {$CellContext`a ($CellContext`a^3 $CellContext`b + $CellContext`a \
$CellContext`b^3 + $CellContext`a^3 $CellContext`c + $CellContext`a^2 \
$CellContext`b $CellContext`c + $CellContext`a $CellContext`b^2 \
$CellContext`c + $CellContext`b^3 $CellContext`c + $CellContext`a^2 \
$CellContext`c^2 + $CellContext`a $CellContext`b $CellContext`c^2 + \
$CellContext`b^2 $CellContext`c^2) ($CellContext`a^3 $CellContext`b + \
$CellContext`a^2 $CellContext`b^2 + $CellContext`a^3 $CellContext`c + \
$CellContext`a^2 $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`b^2 $CellContext`c + $CellContext`a $CellContext`b \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 + $CellContext`a \
$CellContext`c^3 + $CellContext`b $CellContext`c^3), $CellContext`b \
($CellContext`a^3 $CellContext`b + $CellContext`a $CellContext`b^3 + \
$CellContext`a^3 $CellContext`c + $CellContext`a^2 $CellContext`b \
$CellContext`c + $CellContext`a $CellContext`b^2 $CellContext`c + \
$CellContext`b^3 $CellContext`c + $CellContext`a^2 $CellContext`c^2 + \
$CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2) ($CellContext`a^2 $CellContext`b^2 + $CellContext`a \
$CellContext`b^3 + $CellContext`a^2 $CellContext`b $CellContext`c + \
$CellContext`a $CellContext`b^2 $CellContext`c + $CellContext`b^3 \
$CellContext`c + $CellContext`a^2 $CellContext`c^2 + $CellContext`a \
$CellContext`b $CellContext`c^2 + $CellContext`a $CellContext`c^3 + \
$CellContext`b $CellContext`c^3), $CellContext`c ($CellContext`a^2 \
$CellContext`b^2 + $CellContext`a $CellContext`b^3 + $CellContext`a^2 \
$CellContext`b $CellContext`c + $CellContext`a $CellContext`b^2 \
$CellContext`c + $CellContext`b^3 $CellContext`c + $CellContext`a^2 \
$CellContext`c^2 + $CellContext`a $CellContext`b $CellContext`c^2 + \
$CellContext`a $CellContext`c^3 + $CellContext`b $CellContext`c^3) \
($CellContext`a^3 $CellContext`b + $CellContext`a^2 $CellContext`b^2 + \
$CellContext`a^3 $CellContext`c + $CellContext`a^2 $CellContext`b \
$CellContext`c + $CellContext`a $CellContext`b^2 $CellContext`c + \
$CellContext`a $CellContext`b $CellContext`c^2 + $CellContext`b^2 \
$CellContext`c^2 + $CellContext`a $CellContext`c^3 + $CellContext`b \
$CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 127] (63 - 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953819981*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3300b872-911d-4ae3-b588-6c41754a275b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "982"}],
  SequenceForm["n=", 982],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979538233347`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"179be93c-173e-4cb1-8209-7f13a0d4b7a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "982", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", "c"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"3", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 982, 
   "   ", {$CellContext`a ($CellContext`b^2 - $CellContext`b $CellContext`c + \
$CellContext`c^2), $CellContext`b ($CellContext`a^2 - $CellContext`a \
$CellContext`c + $CellContext`c^2), ($CellContext`a^2 - $CellContext`a \
$CellContext`b + $CellContext`b^2) $CellContext`c}, "   XM/AM=", 
   Style[Rational[1, 17] (1 + 3 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953826064*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"26ee6c01-e2ac-4803-b3b6-7e890a6d7c83"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "983"}],
  SequenceForm["n=", 983],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953828971*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"76ca1f37-a310-405b-b504-1bb95fcbe07a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "983", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"1", "-", 
     FractionBox[
      SqrtBox["2"], "3"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 983, 
   "   ", {$CellContext`a ($CellContext`a^2 - $CellContext`a $CellContext`b + \
$CellContext`b^2) ($CellContext`a^2 - $CellContext`a $CellContext`c + \
$CellContext`c^2), $CellContext`b ($CellContext`a^2 - $CellContext`a \
$CellContext`b + $CellContext`b^2) ($CellContext`b^2 - $CellContext`b \
$CellContext`c + $CellContext`c^2), $CellContext`c ($CellContext`a^2 - \
$CellContext`a $CellContext`c + $CellContext`c^2) ($CellContext`b^2 - \
$CellContext`b $CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[1 + Rational[-1, 3] 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953835973*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"9b8450da-398b-4ee7-b0cc-76a8497007f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "984"}],
  SequenceForm["n=", 984],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953839775*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ee282a88-ef4e-44fb-a60a-f50218a6c69d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "984", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", "c"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["3", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"5", "-", 
       RowBox[{"3", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 984, 
   "   ", {$CellContext`a ($CellContext`b^2 + $CellContext`b $CellContext`c + \
$CellContext`c^2), $CellContext`b ($CellContext`a^2 + $CellContext`a \
$CellContext`c + $CellContext`c^2), ($CellContext`a^2 + $CellContext`a \
$CellContext`b + $CellContext`b^2) $CellContext`c}, "   XM/AM=", 
   Style[Rational[3, 7] (5 - 3 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953874989*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7a519422-bdc9-4c76-a319-b8195ff0a53e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "985"}],
  SequenceForm["n=", 985],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953878701*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"95463b26-2f4f-479e-9cec-de107dde025e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "985", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "23"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"9", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 985, 
   "   ", {$CellContext`a ($CellContext`a^2 + $CellContext`a $CellContext`b + \
$CellContext`b^2) ($CellContext`a^2 + $CellContext`a $CellContext`c + \
$CellContext`c^2), $CellContext`b ($CellContext`a^2 + $CellContext`a \
$CellContext`b + $CellContext`b^2) ($CellContext`b^2 + $CellContext`b \
$CellContext`c + $CellContext`c^2), $CellContext`c ($CellContext`a^2 + \
$CellContext`a $CellContext`c + $CellContext`c^2) ($CellContext`b^2 + \
$CellContext`b $CellContext`c + $CellContext`c^2)}, "   XM/AM=", 
   Style[Rational[1, 23] (-1 + 9 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979538818407`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"0250b964-4b8e-4717-b4c9-eb798ac5160e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "986"}],
  SequenceForm["n=", 986],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953884935*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"802e415d-80a2-4a93-8f33-bb58c18b9387"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "986", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{"13", "-", 
       RowBox[{"5", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 986, 
   "   ", {$CellContext`a ($CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a $CellContext`b $CellContext`c + $CellContext`a \
$CellContext`c^2 + $CellContext`c^3), $CellContext`b ($CellContext`a^3 + \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b \
$CellContext`c + $CellContext`b $CellContext`c^2 + $CellContext`c^3), \
$CellContext`c ($CellContext`a^3 + $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c + $CellContext`a $CellContext`b $CellContext`c + \
$CellContext`b^2 $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 17] (13 - 5 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979538877983`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2000ff3e-761f-49b8-b2d7-126b5e0f463f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "987"}],
  SequenceForm["n=", 987],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979538906593`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f7b9185e-83b7-45a0-b43e-80bee770b541"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "987", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", "b", " ", "c"}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "5"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SqrtBox["2"]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 987, 
   "   ", {$CellContext`a ($CellContext`a^3 + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c + $CellContext`a $CellContext`b \
$CellContext`c + $CellContext`b^2 $CellContext`c) ($CellContext`a^3 + \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b \
$CellContext`c + $CellContext`b $CellContext`c^2 + $CellContext`c^3), \
$CellContext`b ($CellContext`a^3 + $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c + $CellContext`a $CellContext`b $CellContext`c + \
$CellContext`b^2 $CellContext`c) ($CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + $CellContext`a $CellContext`b $CellContext`c + \
$CellContext`a $CellContext`c^2 + $CellContext`c^3), $CellContext`c \
($CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`a \
$CellContext`b $CellContext`c + $CellContext`a $CellContext`c^2 + \
$CellContext`c^3) ($CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b $CellContext`c + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 5] (1 + 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979539265833`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e6b0a1cf-0b41-4bed-b671-3c74239075a4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "988"}],
  SequenceForm["n=", 988],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953931266*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"e93bc124-7e20-477f-8c4d-be15952750ef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "988", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"3", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"2", " ", 
      SqrtBox["2"]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 988, 
   "   ", {$CellContext`a ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - 
     3 $CellContext`a $CellContext`b^2 - $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c - $CellContext`b^2 $CellContext`c - 
     3 $CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2 - \
$CellContext`c^3), $CellContext`b (-$CellContext`a^3 - 
     3 $CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - 
     3 $CellContext`b $CellContext`c^2 - $CellContext`c^3), $CellContext`c \
(-$CellContext`a^3 - $CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 - $CellContext`b^3 - 3 $CellContext`a^2 $CellContext`c - 
     3 $CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 2] 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953934758*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ff9f79f9-9726-4401-b96e-25333f290dfb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "989"}],
  SequenceForm["n=", 989],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979539378557`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"20a62979-e11d-4beb-ac27-b09fdb7922f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "989", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"3", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"3", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{"9", "-", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 989, 
   "   ", {$CellContext`a ($CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 + 
     3 $CellContext`a^2 $CellContext`c + 
     3 $CellContext`b^2 $CellContext`c + $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2 - $CellContext`c^3) ($CellContext`a^3 + 
     3 $CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 - \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + 
     3 $CellContext`b $CellContext`c^2 + $CellContext`c^3), $CellContext`b \
($CellContext`a^3 + $CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 + $CellContext`b^3 + 3 $CellContext`a^2 $CellContext`c + 
     3 $CellContext`b^2 $CellContext`c + $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2 - $CellContext`c^3) (-$CellContext`a^3 + \
$CellContext`a^2 $CellContext`b + 
     3 $CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c + $CellContext`b^2 $CellContext`c + 
     3 $CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2 + \
$CellContext`c^3), $CellContext`c (-$CellContext`a^3 + $CellContext`a^2 \
$CellContext`b + 
     3 $CellContext`a $CellContext`b^2 + $CellContext`b^3 + $CellContext`a^2 \
$CellContext`c + $CellContext`b^2 $CellContext`c + 
     3 $CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2 + \
$CellContext`c^3) ($CellContext`a^3 + 
     3 $CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 - \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + 
     3 $CellContext`b $CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 7] (9 - 4 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979539415216`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"7838c14d-5ef7-4484-811a-85be4f0c4bbd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "990"}],
  SequenceForm["n=", 990],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953945004*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ba9194bd-3185-453a-9d44-4b6bc28f2d34"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "990", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "3"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "5"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "5"], "+", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "4"]}], "+", 
        SuperscriptBox["b", "5"], "-", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "c"}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "3"], " ", "b", " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", 
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "4"], " ", "c"}], "-", 
        RowBox[{"2", " ", "a", " ", "b", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "4"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "4"]}], "+", 
        SuperscriptBox["c", "5"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     SqrtBox["2"]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 990, 
   "   ", {$CellContext`a ($CellContext`a^5 - $CellContext`a^4 $CellContext`b - \
$CellContext`a $CellContext`b^4 + $CellContext`b^5 - $CellContext`a^4 \
$CellContext`c - 2 $CellContext`a^3 $CellContext`b $CellContext`c + 
     2 $CellContext`a $CellContext`b^3 $CellContext`c + $CellContext`b^4 \
$CellContext`c - 2 $CellContext`a $CellContext`b^2 $CellContext`c^2 - 
     2 $CellContext`b^3 $CellContext`c^2 + 
     2 $CellContext`a $CellContext`b $CellContext`c^3 - 
     2 $CellContext`b^2 $CellContext`c^3 - $CellContext`a $CellContext`c^4 + \
$CellContext`b $CellContext`c^4 + $CellContext`c^5), $CellContext`b \
($CellContext`a^5 - $CellContext`a^4 $CellContext`b - $CellContext`a \
$CellContext`b^4 + $CellContext`b^5 + $CellContext`a^4 $CellContext`c + 
     2 $CellContext`a^3 $CellContext`b $CellContext`c - 
     2 $CellContext`a $CellContext`b^3 $CellContext`c - $CellContext`b^4 \
$CellContext`c - 2 $CellContext`a^3 $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`b $CellContext`c^2 - 
     2 $CellContext`a^2 $CellContext`c^3 + 
     2 $CellContext`a $CellContext`b $CellContext`c^3 + $CellContext`a \
$CellContext`c^4 - $CellContext`b $CellContext`c^4 + $CellContext`c^5), \
$CellContext`c ($CellContext`a^5 + $CellContext`a^4 $CellContext`b - 
     2 $CellContext`a^3 $CellContext`b^2 - 
     2 $CellContext`a^2 $CellContext`b^3 + $CellContext`a $CellContext`b^4 + \
$CellContext`b^5 - $CellContext`a^4 $CellContext`c + 
     2 $CellContext`a^3 $CellContext`b $CellContext`c - 
     2 $CellContext`a^2 $CellContext`b^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b^3 $CellContext`c - $CellContext`b^4 \
$CellContext`c - 
     2 $CellContext`a $CellContext`b $CellContext`c^3 - $CellContext`a \
$CellContext`c^4 - $CellContext`b $CellContext`c^4 + $CellContext`c^5)}, 
   "   XM/AM=", 
   Style[2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953948731*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"f9a94817-14b6-4b80-bdc3-53de145d7989"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "991"}],
  SequenceForm["n=", 991],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953951961*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"862b6eee-97c4-48fc-8fd6-6d55d8816595"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "991", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        SuperscriptBox["c", "4"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "+", 
        SuperscriptBox["b", "4"], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    FractionBox["1", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}]],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 991, 
   "   ", {$CellContext`a^2 ($CellContext`a^3 $CellContext`b - \
$CellContext`a^2 $CellContext`b^2 - $CellContext`a $CellContext`b^3 + \
$CellContext`b^4 + $CellContext`a^3 $CellContext`c + $CellContext`a^2 \
$CellContext`b $CellContext`c - $CellContext`a $CellContext`b^2 \
$CellContext`c - $CellContext`b^3 $CellContext`c - $CellContext`a^2 \
$CellContext`c^2 - $CellContext`a $CellContext`b $CellContext`c^2 - \
$CellContext`a $CellContext`c^3 - $CellContext`b $CellContext`c^3 + \
$CellContext`c^4), $CellContext`b^2 ($CellContext`a^4 - $CellContext`a^3 \
$CellContext`b - $CellContext`a^2 $CellContext`b^2 + $CellContext`a \
$CellContext`b^3 - $CellContext`a^3 $CellContext`c - $CellContext`a^2 \
$CellContext`b $CellContext`c + $CellContext`a $CellContext`b^2 \
$CellContext`c + $CellContext`b^3 $CellContext`c - $CellContext`a \
$CellContext`b $CellContext`c^2 - $CellContext`b^2 $CellContext`c^2 - \
$CellContext`a $CellContext`c^3 - $CellContext`b $CellContext`c^3 + \
$CellContext`c^4), $CellContext`c^2 ($CellContext`a^4 - $CellContext`a^3 \
$CellContext`b - $CellContext`a $CellContext`b^3 + $CellContext`b^4 - \
$CellContext`a^3 $CellContext`c - $CellContext`a^2 $CellContext`b \
$CellContext`c - $CellContext`a $CellContext`b^2 $CellContext`c - \
$CellContext`b^3 $CellContext`c - $CellContext`a^2 $CellContext`c^2 + \
$CellContext`a $CellContext`b $CellContext`c^2 - $CellContext`b^2 \
$CellContext`c^2 + $CellContext`a $CellContext`c^3 + $CellContext`b \
$CellContext`c^3)}, "   XM/AM=", 
   Style[(1 + 2 2^Rational[1, 2])^(-1), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979539551373`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3809aaa2-9408-417d-b21a-25416d58c911"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "992"}],
  SequenceForm["n=", 992],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979539584084`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3da50bb0-d037-4851-9ab6-1848d7a5bee5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "992", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "3"], " ", "b"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "3"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "3"], " ", "c"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "3"]}], " ", "b"}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "3"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b", " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "3"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "3"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"-", 
     FractionBox[
      SqrtBox["2"], "3"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 992, 
   "   ", {$CellContext`a ($CellContext`a^3 $CellContext`b + $CellContext`a^2 \
$CellContext`b^2 + $CellContext`a^3 $CellContext`c - $CellContext`a \
$CellContext`b^2 $CellContext`c - $CellContext`b^3 $CellContext`c + \
$CellContext`a^2 $CellContext`c^2 - $CellContext`a $CellContext`b \
$CellContext`c^2 - 
     2 $CellContext`b^2 $CellContext`c^2 - $CellContext`b $CellContext`c^3), \
$CellContext`b ($CellContext`a^2 $CellContext`b^2 + $CellContext`a \
$CellContext`b^3 - $CellContext`a^3 $CellContext`c - $CellContext`a^2 \
$CellContext`b $CellContext`c + $CellContext`b^3 $CellContext`c - 
     2 $CellContext`a^2 $CellContext`c^2 - $CellContext`a $CellContext`b \
$CellContext`c^2 + $CellContext`b^2 $CellContext`c^2 - $CellContext`a \
$CellContext`c^3), $CellContext`c (-$CellContext`a^3 $CellContext`b - 
     2 $CellContext`a^2 $CellContext`b^2 - $CellContext`a $CellContext`b^3 - \
$CellContext`a^2 $CellContext`b $CellContext`c - $CellContext`a \
$CellContext`b^2 $CellContext`c + $CellContext`a^2 $CellContext`c^2 + \
$CellContext`b^2 $CellContext`c^2 + $CellContext`a $CellContext`c^3 + \
$CellContext`b $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[-1, 3] 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979539615192`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8acb7a55-b360-4c38-9cb7-036a9a5bfe0b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "993"}],
  SequenceForm["n=", 993],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953964513*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"aa13fe25-9af5-4f0b-93e2-f54c6c89b4c1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "993", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], "+", 
     FractionBox["1", 
      SqrtBox["2"]]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 993, 
   "   ", {$CellContext`a ($CellContext`a^3 - $CellContext`a $CellContext`b^2 - \
$CellContext`b^2 $CellContext`c - $CellContext`a $CellContext`c^2 - \
$CellContext`b $CellContext`c^2), $CellContext`b (-$CellContext`a^2 \
$CellContext`b + $CellContext`b^3 - $CellContext`a^2 $CellContext`c - \
$CellContext`a $CellContext`c^2 - $CellContext`b $CellContext`c^2), \
$CellContext`c (-$CellContext`a^2 $CellContext`b - $CellContext`a \
$CellContext`b^2 - $CellContext`a^2 $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[-1, 2] + 2^Rational[-1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953967516*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"fd62e93a-8104-4a4e-8055-b4b6c87f7ae1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "994"}],
  SequenceForm["n=", 994],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953970417*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"3617d050-a952-45d6-93d0-048fe5f6d4e4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "994", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "3"]}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "5"}], "+", 
     RowBox[{"4", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 994, 
   "   ", {$CellContext`a ($CellContext`a^2 $CellContext`b - $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c + $CellContext`a $CellContext`c^2 + \
$CellContext`b $CellContext`c^2) ($CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 + $CellContext`a^2 $CellContext`c + \
$CellContext`b^2 $CellContext`c - $CellContext`c^3), $CellContext`b \
(-$CellContext`a^3 + $CellContext`a $CellContext`b^2 + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2) ($CellContext`a^2 $CellContext`b + $CellContext`a \
$CellContext`b^2 + $CellContext`a^2 $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`c^3), $CellContext`c ($CellContext`a^2 \
$CellContext`b - $CellContext`b^3 + $CellContext`a^2 $CellContext`c + \
$CellContext`a $CellContext`c^2 + $CellContext`b $CellContext`c^2) \
(-$CellContext`a^3 + $CellContext`a $CellContext`b^2 + $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2)}, "   XM/AM=", 
   Style[-5 + 4 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953973695*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"58195856-f27d-4624-ab07-a46584320d33"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "995"}],
  SequenceForm["n=", 995],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953976878*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"8f0329ff-ab21-413b-8dd6-d98285a7a738"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "995", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "17"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "3"}], "+", 
       RowBox[{"8", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 995, 
   "   ", {$CellContext`a^2 ($CellContext`a $CellContext`b + $CellContext`b^2 + \
$CellContext`a $CellContext`c - $CellContext`b $CellContext`c + \
$CellContext`c^2), $CellContext`b^2 ($CellContext`a^2 + $CellContext`a \
$CellContext`b - $CellContext`a $CellContext`c + $CellContext`b \
$CellContext`c + $CellContext`c^2), $CellContext`c^2 ($CellContext`a^2 - \
$CellContext`a $CellContext`b + $CellContext`b^2 + $CellContext`a \
$CellContext`c + $CellContext`b $CellContext`c)}, "   XM/AM=", 
   Style[Rational[1, 17] (-3 + 8 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953979907*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"2102bb34-f5a9-4d3d-8468-db5277dd487f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "996"}],
  SequenceForm["n=", 996],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953982769*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c321fee6-fa83-4ef6-b69c-f793a5cf717e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "996", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"a", " ", "c"}], "-", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "+", 
        RowBox[{"a", " ", "b"}], "-", 
        RowBox[{"a", " ", "c"}], "+", 
        RowBox[{"b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"6", "-", 
     RowBox[{"4", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 996, 
   "   ", {($CellContext`a^2 - $CellContext`a $CellContext`b + \
$CellContext`b^2 + $CellContext`a $CellContext`c + $CellContext`b \
$CellContext`c) ($CellContext`a^2 + $CellContext`a $CellContext`b - \
$CellContext`a $CellContext`c + $CellContext`b $CellContext`c + \
$CellContext`c^2), ($CellContext`a^2 - $CellContext`a $CellContext`b + \
$CellContext`b^2 + $CellContext`a $CellContext`c + $CellContext`b \
$CellContext`c) ($CellContext`a $CellContext`b + $CellContext`b^2 + \
$CellContext`a $CellContext`c - $CellContext`b $CellContext`c + \
$CellContext`c^2), ($CellContext`a $CellContext`b + $CellContext`b^2 + \
$CellContext`a $CellContext`c - $CellContext`b $CellContext`c + \
$CellContext`c^2) ($CellContext`a^2 + $CellContext`a $CellContext`b - \
$CellContext`a $CellContext`c + $CellContext`b $CellContext`c + \
$CellContext`c^2)}, "   XM/AM=", 
   Style[6 - 4 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953985915*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"da87dae4-4861-492e-97be-83465709645f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "997"}],
  SequenceForm["n=", 997],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953988789*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"ce6b8395-0b17-4cd1-8b72-82b3f292243d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "997", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["1", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 997, 
   "   ", {$CellContext`a ($CellContext`a^3 - $CellContext`a^2 $CellContext`b - \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`b ($CellContext`a^3 - \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`c ($CellContext`a^3 + \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[Rational[1, 7] (-1 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.8610979539917517`*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"63b16f98-0fda-4deb-8402-edd1b57daa16"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "998"}],
  SequenceForm["n=", 998],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953995015*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"76568dfc-4c0d-442a-8027-0a4edbaf8f61"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "998", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"b", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}], ",", 
     RowBox[{"c", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "+", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "+", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "-", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "b"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        SuperscriptBox["b", "3"], "-", 
        RowBox[{
         SuperscriptBox["a", "2"], " ", "c"}], "+", 
        RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{"2", "-", 
     SqrtBox["2"]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 998, 
   "   ", {$CellContext`a ($CellContext`a^3 + $CellContext`a^2 $CellContext`b + \
$CellContext`a $CellContext`b^2 + $CellContext`b^3 - $CellContext`a^2 \
$CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 + \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`b ($CellContext`a^3 + \
$CellContext`a^2 $CellContext`b + $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 - $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3), $CellContext`c ($CellContext`a^3 - \
$CellContext`a^2 $CellContext`b - $CellContext`a $CellContext`b^2 + \
$CellContext`b^3 + $CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c - $CellContext`b^2 \
$CellContext`c + $CellContext`a $CellContext`c^2 - $CellContext`b \
$CellContext`c^2 + $CellContext`c^3) ($CellContext`a^3 - $CellContext`a^2 \
$CellContext`b - $CellContext`a $CellContext`b^2 + $CellContext`b^3 - \
$CellContext`a^2 $CellContext`c + 
     2 $CellContext`a $CellContext`b $CellContext`c + $CellContext`b^2 \
$CellContext`c - $CellContext`a $CellContext`c^2 + $CellContext`b \
$CellContext`c^2 + $CellContext`c^3)}, "   XM/AM=", 
   Style[2 - 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097953998865*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"bbec66ea-b346-4a33-8cb6-1316dd5a0759"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "999"}],
  SequenceForm["n=", 999],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097954002253*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"b7f54f88-fcb4-469f-a027-fc3afccd7470"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "999", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"4", " ", "b", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["b", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "+", 
        RowBox[{"4", " ", "a", " ", "c"}], "-", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      SuperscriptBox["c", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        RowBox[{"4", " ", "a", " ", "b"}], "-", 
        SuperscriptBox["b", "2"], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     FractionBox["2", "7"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}]}], ")"}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 999, 
   "   ", {$CellContext`a^2 ($CellContext`a^2 - $CellContext`b^2 + 
     4 $CellContext`b $CellContext`c - $CellContext`c^2), $CellContext`b^2 \
(-$CellContext`a^2 + $CellContext`b^2 + 
     4 $CellContext`a $CellContext`c - $CellContext`c^2), $CellContext`c^2 \
(-$CellContext`a^2 + 
     4 $CellContext`a $CellContext`b - $CellContext`b^2 + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[Rational[2, 7] (-1 + 2 2^Rational[1, 2]), 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097954005417*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c7df5033-ff4a-4788-ad35-aa33fbd24743"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "1000"}],
  SequenceForm["n=", 1000],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097954008587*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"c0c384b2-c41b-4613-9cd9-fb387bbb969c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"n=\"\>", "\[InvisibleSpace]", "1000", 
   "\[InvisibleSpace]", "\<\"   \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"4", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"4", " ", "a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        RowBox[{"4", " ", "a", " ", "b"}], "+", 
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"4", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["a", "2"], "-", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"4", " ", "a", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["a", "2"]}], "+", 
        SuperscriptBox["b", "2"], "-", 
        RowBox[{"4", " ", "b", " ", "c"}], "+", 
        SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}], 
   "\[InvisibleSpace]", "\<\"   XM/AM=\"\>", "\[InvisibleSpace]", 
   StyleBox[
    RowBox[{
     RowBox[{"-", "11"}], "+", 
     RowBox[{"8", " ", 
      SqrtBox["2"]}]}],
    StripOnInput->False,
    LineColor->RGBColor[0, 0, 1],
    FrontFaceColor->RGBColor[0, 0, 1],
    BackFaceColor->RGBColor[0, 0, 1],
    GraphicsColor->RGBColor[0, 0, 1],
    FontColor->RGBColor[0, 0, 1]]}],
  SequenceForm[
  "n=", 1000, 
   "   ", {($CellContext`a^2 - 
     4 $CellContext`a $CellContext`b + $CellContext`b^2 - $CellContext`c^2) \
($CellContext`a^2 - $CellContext`b^2 - 
     4 $CellContext`a $CellContext`c + $CellContext`c^2), ($CellContext`a^2 - 
     4 $CellContext`a $CellContext`b + $CellContext`b^2 - $CellContext`c^2) \
(-$CellContext`a^2 + $CellContext`b^2 - 
     4 $CellContext`b $CellContext`c + $CellContext`c^2), ($CellContext`a^2 - \
$CellContext`b^2 - 
     4 $CellContext`a $CellContext`c + $CellContext`c^2) (-$CellContext`a^2 + \
$CellContext`b^2 - 4 $CellContext`b $CellContext`c + $CellContext`c^2)}, 
   "   XM/AM=", 
   Style[-11 + 8 2^Rational[1, 2], 
    RGBColor[0, 0, 1]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.859110299359682*^9, 3.8599094333407373`*^9, 
  3.861097954011797*^9},
 CellLabel->
  "During evaluation of \
In[161]:=",ExpressionUUID->"106dffe7-b632-4144-b291-2491ca2f2a66"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["coincidesWithAsq"], "Input",
 CellLabel->
  "In[174]:=",ExpressionUUID->"7ff707fe-fb7e-4fb4-a5a8-1d1f07da1fcf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "4", ",", "19", ",", "24", ",", "25", ",", "27", ",", "28", ",", "29", ",", 
   "33", ",", "34", ",", "46", ",", "47", ",", "52", ",", "53", ",", "92", 
   ",", "93", ",", "113", ",", "114", ",", "117", ",", "118", ",", "119", ",",
    "120", ",", "121", ",", "126", ",", "128", ",", "129", ",", "131", ",", 
   "132", ",", "133", ",", "138", ",", "155", ",", "157", ",", "158", ",", 
   "186", ",", "193", ",", "196", ",", "204", ",", "207", ",", "208", ",", 
   "209", ",", "211", ",", "225", ",", "230", ",", "231", ",", "232", ",", 
   "235", ",", "240", ",", "242", ",", "243", ",", "264", ",", "270", ",", 
   "273", ",", "275", ",", "276", ",", "278", ",", "281", ",", "286", ",", 
   "297", ",", "317", ",", "318", ",", "324", ",", "331", ",", "340", ",", 
   "342", ",", "378", ",", "393", ",", "403", ",", "406", ",", "407", ",", 
   "410", ",", "412", ",", "414", ",", "415", ",", "419", ",", "420", ",", 
   "421", ",", "422", ",", "423", ",", "424", ",", "425", ",", "427", ",", 
   "428", ",", "429", ",", "430", ",", "431", ",", "433", ",", "434", ",", 
   "435", ",", "436", ",", "437", ",", "438", ",", "439", ",", "444", ",", 
   "445", ",", "447", ",", "450", ",", "451", ",", "453", ",", "454", ",", 
   "455", ",", "456", ",", "457", ",", "458", ",", "459", ",", "460", ",", 
   "461", ",", "462", ",", "463", ",", "467", ",", "468", ",", "469", ",", 
   "470", ",", "471", ",", "472", ",", "473", ",", "475", ",", "562", ",", 
   "564", ",", "571", ",", "579", ",", "580", ",", "587", ",", "607", ",", 
   "608", ",", "683", ",", "749", ",", "821", ",", "829", ",", "837", ",", 
   "860", ",", "862", ",", "920"}], "}"}]], "Output",
 CellChangeTimes->{3.8591103736542397`*^9, 3.859909447456253*^9, 
  3.86109795406271*^9},
 CellLabel->
  "Out[174]=",ExpressionUUID->"532c2965-c49d-47e1-90c5-86467118b034"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["coincidesWithMsq"], "Input",
 CellChangeTimes->{3.8591103794048443`*^9},
 CellLabel->
  "In[175]:=",ExpressionUUID->"258af001-00c3-48c9-ac4e-b559909e0542"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "3", ",", "48", ",", "49", ",", "63", ",", "68", ",", "69", ",", "71", ",", 
   "72", ",", "73", ",", "77", ",", "78", ",", "90", ",", "91", ",", "96", 
   ",", "97", ",", "184", ",", "185", ",", "201", ",", "212", ",", "216", ",",
    "217", ",", "219", ",", "222", ",", "228", ",", "248", ",", "254", ",", 
   "255", ",", "265", ",", "268", ",", "271", ",", "272", ",", "283", ",", 
   "287", ",", "293", ",", "295", ",", "296", ",", "304", ",", "305", ",", 
   "306", ",", "307", ",", "326", ",", "328", ",", "332", ",", "336", ",", 
   "337", ",", "343", ",", "345", ",", "348", ",", "394", ",", "408", ",", 
   "417", ",", "418", ",", "426", ",", "432", ",", "440", ",", "441", ",", 
   "464", ",", "465", ",", "466", ",", "487", ",", "488", ",", "499", ",", 
   "577", ",", "603", ",", "682", ",", "748", ",", "820", ",", "828", ",", 
   "836", ",", "852", ",", "856", ",", "895", ",", "921", ",", "974"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.859110380421358*^9, 3.85990944750334*^9, 
  3.861097954104002*^9},
 CellLabel->
  "Out[175]=",ExpressionUUID->"bf6882ff-1781-4189-bfd7-52ec84587310"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Square Tables, parts 1-4", "Subsubsection",
 CellChangeTimes->{{3.859406121202154*^9, 3.8594061332914877`*^9}, {
   3.859408406471219*^9, 3.85940843731094*^9}, {3.861090782028387*^9, 
   3.861090802604138*^9}, 
   3.8610908463082647`*^9},ExpressionUUID->"2b8637f3-d4d5-4f42-a9c1-\
c41976364171"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pairs", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptA", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptM", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"n", "=", "1"}], ",", 
    RowBox[{"n", "\[LessEqual]", "1000"}], ",", 
    RowBox[{"n", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"coords", "=", 
      RowBox[{"ETC1", "[", 
       RowBox[{"[", 
        RowBox[{"n", ",", "2"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"ignore", " ", "transcendental", " ", "centers"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"coords", "\[Equal]", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
       RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
      RowBox[{"ptX", "=", 
       RowBox[{"coords", "/.", 
        RowBox[{"S", "->", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]]}]}]}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"ignore", " ", "points", " ", "at", " ", "infinity"}], " ", 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{"u", "+", "v", "+", "w"}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Expand", "[", 
         RowBox[{
          RowBox[{"u", "+", "v", "+", "w"}], "/.", 
          RowBox[{"c", "\[Rule]", "b"}]}], "]"}], "\[Equal]", "0"}], ",", 
       RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"ratio", " ", "=", " ", 
       RowBox[{"XM", "/", "AM"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"ratio", "=", 
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{
         RowBox[{"u", "/", 
          RowBox[{"(", 
           RowBox[{"u", "+", 
            RowBox[{"2", "v"}]}], ")"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"a", "\[Rule]", 
            RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
           RowBox[{"b", "\[Rule]", "1"}], ",", 
           RowBox[{"c", "\[Rule]", "1"}]}], "}"}]}], "]"}], "//", "Quiet"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "ignore", " ", "points", " ", "that", " ", "coincide", " ", "with", " ",
        "A"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ratio", "\[Equal]", "1"}], ",", 
       RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ratio", "===", "ComplexInfinity"}], ",", 
       RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"ratio", "===", "Indeterminate"}], ",", 
       RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"areaRatio", " ", "=", " ", 
       RowBox[{"ABCD", "/", "FGHI"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"aRatio", "=", 
      RowBox[{"2", "/", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", "ratio"}], ")"}], "^", "2"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"areaRatio", " ", "=", 
      RowBox[{"Together", "[", 
       RowBox[{"ToRadicals", "[", 
        RowBox[{"RootReduce", "[", "aRatio", "]"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "areaRatio", "]"}], "===", "Root"}], ",", 
       RowBox[{"areaRatio", "=", 
        RowBox[{"Together", "[", 
         RowBox[{"ToRadicals", "[", "aRatio", "]"}], "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"areaRatio", "=", 
        RowBox[{"Together", "[", 
         RowBox[{"ToRadicals", "[", 
          RowBox[{"RootReduce", "[", "areaRatio", "]"}], "]"}], "]"}]}], 
       ";"}], "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"!", 
        RowBox[{"NumericQ", "[", "areaRatio", "]"}]}], ",", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<Bug for n=\>\"", ",", "n", ",", "\"\<  areaRatio=\>\"", ",", 
          "areaRatio"}], "]"}], ";", 
        RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"NumericQ", "[", "areaRatio", "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"AppendTo", "[", 
         RowBox[{"pairs", ",", 
          RowBox[{"{", 
           RowBox[{"areaRatio", ",", "n"}], "}"}]}], "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.85823859791429*^9, 3.85823861081002*^9}, {
   3.858238666170635*^9, 3.858238671842203*^9}, {3.8582387034349937`*^9, 
   3.858238879946652*^9}, {3.8582389657328787`*^9, 3.8582389797310667`*^9}, {
   3.8582392486772118`*^9, 3.8582392767083197`*^9}, {3.858239316526222*^9, 
   3.858239316940321*^9}, {3.8582393919104853`*^9, 3.858239410404519*^9}, {
   3.858331060436795*^9, 3.8583310835636053`*^9}, {3.8583311335560627`*^9, 
   3.8583312056613417`*^9}, {3.858331353269075*^9, 3.858331361757183*^9}, {
   3.85833142168615*^9, 3.858331476637041*^9}, {3.8583315261749496`*^9, 
   3.858331647885808*^9}, 3.858331679870125*^9, {3.858331841511511*^9, 
   3.858331889799799*^9}, {3.858331948776697*^9, 3.858331950886672*^9}, {
   3.858332138091186*^9, 3.858332168351516*^9}, {3.8583598800744762`*^9, 
   3.858359881256414*^9}, {3.8590572502474737`*^9, 3.859057297806314*^9}, {
   3.859057346582951*^9, 3.859057445855009*^9}, {3.859057654764593*^9, 
   3.859057672008007*^9}, {3.859057728585338*^9, 3.8590577494402647`*^9}, {
   3.8590578014496107`*^9, 3.859057898193756*^9}, {3.859057958193616*^9, 
   3.8590579702170258`*^9}, {3.8590580079943*^9, 3.859058022673209*^9}, {
   3.8590581266503973`*^9, 3.8590581393538837`*^9}, {3.8591099751016607`*^9, 
   3.859110043172707*^9}, {3.859110184262834*^9, 3.8591102137013683`*^9}, {
   3.859110250494644*^9, 3.8591102538301773`*^9}, {3.859110286463319*^9, 
   3.859110291237661*^9}, {3.859192895412109*^9, 3.859193265339439*^9}, {
   3.859193335904272*^9, 3.859193346988246*^9}, 3.8591933953582973`*^9, {
   3.8591934296889687`*^9, 3.8591934353439837`*^9}, {3.85919357794179*^9, 
   3.859193644900833*^9}, {3.859193960278303*^9, 3.8591940017500057`*^9}, {
   3.859194085014502*^9, 3.859194094278327*^9}, {3.859194441897365*^9, 
   3.859194456007503*^9}, 3.8591945245713787`*^9, {3.859194641801712*^9, 
   3.859194670936103*^9}, {3.859194730049881*^9, 3.859194742520611*^9}, {
   3.8591947860599546`*^9, 3.859194842936734*^9}, {3.8591950251152554`*^9, 
   3.859195035194462*^9}, {3.859195098154798*^9, 3.85919510403347*^9}, {
   3.859195187883399*^9, 3.859195190961973*^9}, {3.8591953075311832`*^9, 
   3.859195332322146*^9}, {3.859195455268127*^9, 3.859195461058927*^9}, {
   3.859195622396669*^9, 3.859195638451591*^9}, {3.859195806029646*^9, 
   3.859195808660171*^9}, {3.8591959775818233`*^9, 3.8591959841725388`*^9}, {
   3.859196103070344*^9, 3.8591961075167427`*^9}, {3.85920809541967*^9, 
   3.859208230443451*^9}, {3.859208743566683*^9, 3.8592087559571123`*^9}, 
   3.8592088172503242`*^9, {3.859208976063848*^9, 3.859208978814032*^9}, 
   3.859209019951803*^9, {3.859209079615933*^9, 3.859209081006212*^9}, {
   3.859209321616637*^9, 3.859209326126926*^9}, {3.859209715377391*^9, 
   3.85920981306577*^9}, {3.859209856784973*^9, 3.8592100083293867`*^9}, {
   3.859210059290832*^9, 3.859210064137679*^9}, {3.8592101249549093`*^9, 
   3.859210157829227*^9}, {3.859210223762401*^9, 3.859210258170362*^9}, {
   3.8592102987077208`*^9, 3.85921030849011*^9}, {3.8592103727718782`*^9, 
   3.859210378266246*^9}, {3.859210414899645*^9, 3.859210535842691*^9}, {
   3.859210632213037*^9, 3.859210636203147*^9}, {3.859211023206346*^9, 
   3.859211027268468*^9}},
 CellLabel->
  "In[176]:=",ExpressionUUID->"770858ec-8802-48fb-954d-e60af9d525c5"],

Cell[CellGroupData[{

Cell[BoxData["pairs"], "Input",
 CellChangeTimes->{{3.859196111278577*^9, 3.8591961123876657`*^9}},
 CellLabel->
  "In[180]:=",ExpressionUUID->"bd3fbdcf-db05-4c15-87d3-44a58ca8fcc2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}]}], ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox["3"]}], ")"}]}], ",", "13"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["3"]}], ")"}]}], ",", "14"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "+", 
      SqrtBox["3"]}], ",", "15"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "-", 
      SqrtBox["3"]}], ",", "16"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "+", 
        RowBox[{"3", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "17"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "-", 
        RowBox[{"3", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "18"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "20"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "21"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "22"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "23"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "31"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", "32"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}]}], ",", "35"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "36"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "37"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "38"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["50", "9"], ",", "39"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "40"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "41"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "42"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"19", "-", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}]}], ",", "43"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "44"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["64", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "45"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "48"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "49"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", "51"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", "54"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "55"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "56"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", "+", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}]}], ",", "57"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "58"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"27", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "60"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"14", "-", 
      RowBox[{"5", " ", 
       SqrtBox["3"]}]}], ",", "61"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"14", "+", 
      RowBox[{"5", " ", 
       SqrtBox["3"]}]}], ",", "62"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "63"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "65"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["8", "9"], ",", "67"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "69"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "70"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "71"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "72"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "73"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "74"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "75"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "8"], ",", "76"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "77"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "78"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", "+", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}]}], ",", "79"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "80"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "81"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"17", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "82"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["49", "8"], ",", "83"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "84"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "85"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"27", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "86"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"163", "+", 
        RowBox[{"18", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "87"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "-", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "88"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "98"], " ", 
      RowBox[{"(", 
       RowBox[{"561", "+", 
        RowBox[{"184", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "89"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "94"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "8"], ",", "95"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "97"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "98"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "102"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "103"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "104"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "105"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "106"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "111"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "115"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "116"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "122"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "123"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "124"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "125"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "127"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "130"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "137"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["32", "9"], ",", "140"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["32", "9"], ",", "141"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "142"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"32", ",", "143"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "-", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "144"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"17", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "145"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "146"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "147"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "148"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "149"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "150"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "151"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "152"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "153"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "160"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"7", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"10", "-", 
           RowBox[{"7", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "164"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "9"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "165"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"19", "-", 
      RowBox[{"10", " ", 
       SqrtBox["2"]}], "-", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"10", "-", 
           RowBox[{"7", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "166"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"931", "-", 
      RowBox[{"658", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"54146", "-", 
           RowBox[{"38287", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "167"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"295", "-", 
      RowBox[{"208", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"20714", "-", 
           RowBox[{"14647", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "168"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "169"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"179", "-", 
      RowBox[{"126", " ", 
       SqrtBox["2"]}]}], ",", "170"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"41", "-", 
      RowBox[{"24", " ", 
       SqrtBox["2"]}]}], ",", "171"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "172"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"7", "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"2", "-", 
           SqrtBox["2"]}], ")"}]}]]}]}], ",", "173"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"6", "+", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", "+", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", "174"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "175"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "176"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"13", "+", 
        RowBox[{"9", " ", 
         SqrtBox["2"]}], "-", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"58", "+", 
           RowBox[{"41", " ", 
            SqrtBox["2"]}]}]]}]}], ")"}]}], ",", "177"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "8"}], "-", 
        RowBox[{"5", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"10", "+", 
             RowBox[{"7", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "178"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"227", "-", 
        RowBox[{"154", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"28", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"58", "-", 
             RowBox[{"41", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "179"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"1169", "-", 
        RowBox[{"672", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"33178", "-", 
           RowBox[{"23201", " ", 
            SqrtBox["2"]}]}]]}]}], ")"}]}], ",", "180"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "41"}], "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "181"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["32", "9"], ",", "182"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["49", "18"], ",", "183"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "184"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "185"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "187"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"6", "-", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", "-", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", "188"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "189"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"11", "-", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}]}], ",", "191"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "192"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "2"], ",", "194"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", "195"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "197"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "198"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "199"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"11", "-", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}]}], ",", "200"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "201"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"10", "+", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}], "-", 
      SqrtBox[
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"17", "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}]]}], ",", "202"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"10", "+", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}], "+", 
      SqrtBox[
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"17", "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}]]}], ",", "203"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "17"}], "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "205"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "18"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "210"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "212"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "33"}], "+", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "213"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "214"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "215"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "216"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "217"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", "218"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "219"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "220"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "222"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", "223"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "226"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "227"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "228"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["9", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "229"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["50", "9"], ",", "233"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "34"}], "-", 
        RowBox[{"23", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"58", "+", 
             RowBox[{"41", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "234"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"18", "-", 
        SqrtBox["2"], "-", 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"2", "-", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", "236"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "237"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "238"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "239"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "241"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "244"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "245"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "246"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "248"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "2"], ",", "251"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["49", "18"], ",", "252"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "253"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "255"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "256"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "18"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        RowBox[{"14", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "257"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"31", "-", 
      RowBox[{"20", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"194", "-", 
           RowBox[{"137", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "258"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", "-", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"2", "-", 
           SqrtBox["2"]}], ")"}]}]]}]}], ",", "259"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"8", "+", 
        RowBox[{"3", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             SqrtBox["2"]}], ")"}]}]]}]}], ")"}]}], ",", "260"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "32"], " ", 
      RowBox[{"(", 
       RowBox[{"83", "+", 
        RowBox[{"18", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "261"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "2"], ",", "262"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"32", ",", "263"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "265"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", "+", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", 
           SqrtBox["2"]}], ")"}]}]]}]}], ",", "266"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "267"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "268"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "269"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "271"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "274"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "8"], ",", "277"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "279"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "280"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", "282"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "283"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", "284"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "285"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "287"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["49", "8"], ",", "288"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"32", "-", 
      RowBox[{"19", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"194", "-", 
           RowBox[{"137", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "289"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "8"], ",", "290"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "291"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "292"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "293"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "294"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "295"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "296"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["3", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox["3"]}], ")"}]}], ",", "298"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["3", "4"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["3"]}], ")"}]}], ",", "299"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "+", 
        RowBox[{"5", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "300"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "-", 
        RowBox[{"5", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "301"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"26", "-", 
        RowBox[{"7", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "302"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"26", "+", 
        RowBox[{"7", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "303"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "304"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "305"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "306"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "307"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["121", "32"], ",", "308"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "309"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "32"], " ", 
      RowBox[{"(", 
       RowBox[{"83", "+", 
        RowBox[{"18", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "310"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", "311"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "312"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "313"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "314"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "8"], ",", "315"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "8"], ",", "316"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "319"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "320"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}]}], ",", "321"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "322"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "323"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "325"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "326"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["49", "8"], ",", "327"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "328"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "329"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "98"], " ", 
      RowBox[{"(", 
       RowBox[{"233", "+", 
        RowBox[{"60", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "330"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "332"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "8"], ",", "333"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "334"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "335"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "336"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "337"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "338"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "339"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "4"], ",", "341"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "343"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "344"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "345"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "-", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "346"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "347"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "348"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", "349"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "350"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "8"], ",", "352"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "8"], ",", "353"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["18", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "354"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "355"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"11", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}], ",", "361"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"5", "-", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}], ",", "362"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"23", "-", 
      RowBox[{"8", " ", 
       SqrtBox["2"]}], "-", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"50", "-", 
           RowBox[{"31", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "363"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", 
           RowBox[{"3", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "364"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "+", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["2", 
        RowBox[{"3", "/", "4"}]]}]}], ",", "365"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"4", "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["2", 
          RowBox[{"1", "/", "4"}]]}], "+", 
        SqrtBox["2"]}], ")"}]}], ",", "366"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "-", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"24", "+", 
             RowBox[{"17", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "367"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "371"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["162", "25"], ",", "373"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["18", "289"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "123"}], "+", 
        RowBox[{"22", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "374"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "36"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "375"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "8"], ",", "376"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", "377"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", "+", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}]}], ",", "379"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "25"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "380"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", "381"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "382"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["3", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "7"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "383"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["121", "18"], ",", "384"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "385"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "386"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "387"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"17", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "388"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "389"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "98"], " ", 
      RowBox[{"(", 
       RowBox[{"193", "+", 
        RowBox[{"132", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "390"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "98"], " ", 
      RowBox[{"(", 
       RowBox[{"561", "-", 
        RowBox[{"184", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "391"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["18", "289"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "392"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "394"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "395"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "396"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"13", "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "397"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "13"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "398"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "399"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"995", "+", 
        RowBox[{"702", " ", 
         SqrtBox["2"]}], "-", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"61466", "+", 
             RowBox[{"43463", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "400"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "401"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "402"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "404"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "405"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "408"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "36"], " ", 
      RowBox[{"(", 
       RowBox[{"97", "+", 
        RowBox[{"60", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "409"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "-", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "411"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "36"], " ", 
      RowBox[{"(", 
       RowBox[{"73", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "413"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "-", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "416"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "417"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "418"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "426"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "440"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "441"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "442"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"27", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "443"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["2", "9"], ",", "446"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "448"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "17"}], "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "449"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "-", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "452"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "464"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "465"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "466"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "474"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "477"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "478"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"131", "+", 
        RowBox[{"90", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "479"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "43"}], "+", 
        RowBox[{"30", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "480"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "481"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "482"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"10", "-", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", 
             SqrtBox["2"]}], ")"}]}]]}]}], ")"}]}], ",", "483"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", "484"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "485"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["32", "25"], ",", "486"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "488"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "8"], ",", "490"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "8"], ",", "492"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["50", "9"], ",", "493"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "494"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["16", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "495"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["16", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "496"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "497"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "498"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "499"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "500"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "501"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "502"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"11", "-", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"10", "-", 
         RowBox[{"7", " ", 
          SqrtBox["2"]}]}]]}]}], ",", "503"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"5", "-", 
      RowBox[{"3", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"10", "-", 
         RowBox[{"7", " ", 
          SqrtBox["2"]}]}]]}]}], ",", "504"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"47", "+", 
      RowBox[{"32", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"6", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"58", "+", 
           RowBox[{"41", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "505"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"2", "/", "3"}]], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SqrtBox["2"]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}]}], ")"}], "2"], 
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SqrtBox["2"]}], ")"}], 
        RowBox[{"2", "/", "3"}]]}]], ",", "506"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", "-", 
            SqrtBox["2"]}], ")"}], 
          RowBox[{"3", "/", "4"}]]}], ")"}], "2"], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SqrtBox["2"]}], ")"}], "2"]}]], ",", "507"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"5", "+", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"1", "+", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", "508"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "+", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SqrtBox["2"]}], ")"}]}]]}]}], ",", "509"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         RowBox[{"3", " ", 
          SqrtBox["2"]}]}]]}]}], ",", "510"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"32", ",", "546"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["288", "49"], ",", "547"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["32", "25"], ",", "548"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["72", "25"], ",", "549"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["8", "9"], ",", "550"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["36", "529"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "551"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["25", "32"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "552"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["36", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "553"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["3", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"5", "+", 
        RowBox[{"3", " ", 
         SqrtBox["2"]}], "-", 
        SqrtBox[
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"2", " ", 
             SqrtBox["2"]}]}], ")"}]}]]}], ")"}]}], ",", "554"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"18", "+", 
        RowBox[{"7", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"10", "+", 
             RowBox[{"7", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "555"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"10", "-", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", 
             SqrtBox["2"]}], ")"}]}]]}]}], ")"}]}], ",", "556"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"154", "+", 
        RowBox[{"105", " ", 
         SqrtBox["2"]}], "-", 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"338", "+", 
             RowBox[{"239", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "557"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"18", "+", 
        SqrtBox["2"], "+", 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"2", "+", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", "558"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"21", "+", 
        RowBox[{"9", " ", 
         SqrtBox["3"]}], "-", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"62", "+", 
           RowBox[{"35", " ", 
            SqrtBox["3"]}]}]]}]}], ")"}]}], ",", "559"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "560"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "561"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["32", "9"], ",", "566"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["50", "9"], ",", "567"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", "568"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", "569"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", "570"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "572"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "573"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["98", "25"], ",", "574"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["128", "25"], ",", "575"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"32", ",", "576"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "577"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "578"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", "581"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "582"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "583"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "584"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "18"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "585"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "586"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["49", "8"], ",", "588"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["50", "9"], ",", "590"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "591"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["841", "162"], ",", "592"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"57", "+", 
        RowBox[{"28", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "593"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "81"}], "+", 
        RowBox[{"56", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "594"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"17", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "595"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["8", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "596"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["288", "49"], ",", "597"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["81", "8"], ",", "598"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["72", "25"], ",", "599"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "139"}], "+", 
        RowBox[{"66", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "600"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "601"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "602"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "603"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "604"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "33"}], "+", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "605"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "606"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"97", "-", 
      RowBox[{"60", " ", 
       SqrtBox["2"]}]}], ",", "609"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", "610"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["16", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "611"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "612"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["16", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "613"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "614"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "615"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["3", "2"], ",", "616"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["3", "2"], ",", "617"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "12"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["3"]}], ")"}]}], ",", "618"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"12", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox["3"]}], ")"}]}], ",", "619"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "620"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"7", "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "621"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"7", "-", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "622"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox["3"]}], ")"}]}], ",", "623"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["4", "3"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["3"]}], ")"}]}], ",", "624"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["8", "9"], ",", "625"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["72", "25"], ",", "626"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "-", 
        RowBox[{"8", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "627"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "+", 
        RowBox[{"8", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "628"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["4", "121"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "146"}], "+", 
        RowBox[{"17", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "629"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "121"], " ", 
      RowBox[{"(", 
       RowBox[{"146", "+", 
        RowBox[{"17", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "630"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "8"], ",", "631"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["200", "49"], ",", "632"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"13", "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "633"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"13", "-", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "634"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "169"], " ", 
      RowBox[{"(", 
       RowBox[{"146", "+", 
        RowBox[{"17", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "635"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["4", "169"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "146"}], "+", 
        RowBox[{"17", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "636"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", "637"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "638"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", "639"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "640"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["32", "9"], ",", "641"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "642"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "8"], ",", "671"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "672"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "-", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "673"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "675"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "678"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "679"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "682"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["8", "9"], ",", "694"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["128", "25"], ",", "695"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "697"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "699"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "701"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "703"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "705"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "707"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "709"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "711"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "713"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "715"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "717"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "719"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "721"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "723"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "725"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "727"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"121", "-", 
      RowBox[{"84", " ", 
       SqrtBox["2"]}]}], ",", "728"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "729"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "731"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "733"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "735"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "737"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"121", "+", 
      RowBox[{"84", " ", 
       SqrtBox["2"]}]}], ",", "738"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "739"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "741"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "743"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "745"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "747"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "748"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "233"}], "+", 
        RowBox[{"60", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "750"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"73", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "751"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "753"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "755"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "121"}], "+", 
        RowBox[{"84", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "756"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["9", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "757"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "759"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "761"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3249"}], "+", 
        RowBox[{"2296", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "762"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "64"], " ", 
      RowBox[{"(", 
       RowBox[{"387", "+", 
        RowBox[{"182", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "763"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "767"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "774"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "775"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", "800"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "8"], ",", "801"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "820"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "828"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "836"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "840"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "841"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "842"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "843"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"43", "-", 
      RowBox[{"30", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"58", "-", 
         RowBox[{"41", " ", 
          SqrtBox["2"]}]}]]}]}], ",", "844"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"23", "-", 
      RowBox[{"16", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"58", "-", 
           RowBox[{"41", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "845"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "25"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "846"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "849"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "851"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "852"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "17"}], "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "853"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "854"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "855"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "856"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", "857"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "858"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "859"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "861"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "863"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", "864"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "865"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "866"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "867"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "868"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"163", "+", 
        RowBox[{"18", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "869"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "36"], " ", 
      RowBox[{"(", 
       RowBox[{"107", "+", 
        RowBox[{"42", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "870"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "144"], " ", 
      RowBox[{"(", 
       RowBox[{"347", "+", 
        RowBox[{"78", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "871"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "18"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "57"}], "+", 
        RowBox[{"40", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "872"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "64"], " ", 
      RowBox[{"(", 
       RowBox[{"209", "+", 
        RowBox[{"60", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "873"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "893"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "894"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "895"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "896"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "-", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "897"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "899"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "902"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "8"], ",", "903"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"27", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "904"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", "908"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", "909"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "910"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", "911"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "922"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", "923"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"163", "+", 
        RowBox[{"18", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "936"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"19", "-", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}]}], ",", "937"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"27", "-", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "938"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "939"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"123", "+", 
        RowBox[{"22", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "940"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "-", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "941"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "942"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", "943"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "944"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "945"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "946"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "947"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "948"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "123"}], "+", 
        RowBox[{"22", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "949"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "950"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "951"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "953"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "954"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"27", "-", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "955"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "956"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"43", "+", 
        RowBox[{"30", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "957"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"43", "+", 
        RowBox[{"30", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "958"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["9", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "959"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["8", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "960"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"17", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "961"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "962"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "963"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"33", "-", 
      RowBox[{"20", " ", 
       SqrtBox["2"]}]}], ",", "964"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "123"}], "+", 
        RowBox[{"22", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "965"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "-", 
        RowBox[{"14", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "966"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"177", "+", 
        RowBox[{"52", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "967"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "968"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["18", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "969"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["8", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "970"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", "972"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", "973"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "974"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "975"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "976"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "977"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "978"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"11", "-", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}]}], ",", "979"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "961"], " ", 
      RowBox[{"(", 
       RowBox[{"2217", "+", 
        RowBox[{"188", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "980"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"129", "-", 
        RowBox[{"16", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "981"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"137", "+", 
        RowBox[{"48", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "982"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "983"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"113", "+", 
        RowBox[{"72", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "984"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "985"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"33", "-", 
      RowBox[{"20", " ", 
       SqrtBox["2"]}]}], ",", "986"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["25", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "987"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["16", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "988"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "989"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "990"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "991"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["18", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "992"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["8", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "993"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"17", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "994"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "995"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"57", "+", 
        RowBox[{"40", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "996"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "997"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "998"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"113", "+", 
        RowBox[{"72", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "999"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"17", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", "1000"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8591961129864388`*^9, 3.859208237962557*^9, {3.8592087727735*^9, 
   3.859208824305455*^9}, 3.8592089834888906`*^9, 3.859209025448769*^9, 
   3.859209112196504*^9, 3.859209332798243*^9, {3.859209749662231*^9, 
   3.8592098170120296`*^9}, {3.859209885949573*^9, 3.8592099187363253`*^9}, 
   3.859209951180669*^9, 3.85920998352744*^9, 3.8592100165584097`*^9, 
   3.859210068948765*^9, 3.859210130382897*^9, {3.859210162575156*^9, 
   3.8592101731674957`*^9}, 3.859210231857257*^9, 3.859210262912274*^9, 
   3.859210313055344*^9, 3.859210384839203*^9, 3.859210435207982*^9, {
   3.859210515784499*^9, 3.8592105423524847`*^9}, 3.859210655415382*^9, 
   3.8592108572353077`*^9, 3.859211051009965*^9, 3.859909461473579*^9, 
   3.861097968636037*^9},
 CellLabel->
  "Out[180]=",ExpressionUUID->"29f7a319-432c-43f5-8f53-f123da82ed25"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gathered", "=", 
  RowBox[{"GatherBy", "[", 
   RowBox[{"pairs", ",", "First"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8592133437587223`*^9, 3.8592133474912767`*^9}, {
  3.85921349419559*^9, 3.859213528747282*^9}},
 CellLabel->
  "In[181]:=",ExpressionUUID->"b24625dd-6efc-4381-86e8-8289a4f3151d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ",", "377"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "2"], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "2"], ",", "54"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "2"], ",", "284"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "2"], ",", "311"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "2"], ",", "349"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "2"], ",", "569"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "2"], ",", "570"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "2"], ",", "581"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "2"], ",", "637"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "2"], ",", "639"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "2"], ",", "943"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "48"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "49"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "63"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "69"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "71"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "72"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "73"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "77"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "78"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "97"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "115"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "116"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "122"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "123"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "124"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "125"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "127"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "130"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "137"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "184"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "185"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "187"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "201"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "212"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "216"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "217"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "219"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "222"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "228"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "237"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "244"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "245"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "246"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "248"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "255"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "265"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "268"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "271"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "283"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "287"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "293"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "295"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "296"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "304"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "305"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "306"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "307"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "326"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "328"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "332"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "336"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "337"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "338"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "339"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "343"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "345"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "348"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "382"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "394"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "399"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "408"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "417"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "418"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "426"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "440"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "441"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "464"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "465"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "466"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "488"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "499"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "577"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "591"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "603"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "606"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "615"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "640"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "682"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "748"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "820"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "828"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "836"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "852"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "856"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "865"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "866"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "867"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "868"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "895"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "902"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "974"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"8", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "169"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "226"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "344"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "389"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "402"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "482"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "485"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "494"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "578"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "620"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "642"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "942"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "58"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "614"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "951"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "313"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "501"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "947"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "962"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"9", "-", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"9", "-", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ",", "35"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"9", "-", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ",", "321"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"4", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "55"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "241"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "405"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "500"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "582"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "950"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "42"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "863"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "9"}], "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "922"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         SqrtBox["3"]}], ")"}]}], ",", "13"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         SqrtBox["3"]}], ")"}]}], ",", "14"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", "+", 
       SqrtBox["3"]}], ",", "15"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", "-", 
       SqrtBox["3"]}], ",", "16"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"14", "+", 
         RowBox[{"3", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "17"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"14", "-", 
         RowBox[{"3", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "18"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "22"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "23"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "70"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "74"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "94"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "98"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "102"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "103"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "104"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "105"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "106"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "111"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "146"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "147"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "148"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "149"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "150"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "151"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "152"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "153"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "160"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "175"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "253"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "280"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "323"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "325"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "347"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "385"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "401"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "477"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "586"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "638"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "675"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "697"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "699"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "701"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "703"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "705"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "707"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "709"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "711"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "713"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "715"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "717"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "719"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "721"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "723"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "725"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "727"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "729"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "731"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "733"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "735"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "737"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "739"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "741"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "743"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "745"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "747"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "753"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "755"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "759"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "761"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "767"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "840"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "841"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "842"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "843"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "858"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "953"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "2"], ",", "972"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "21"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "75"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "371"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "497"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "775"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "991"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "997"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "31"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "65"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "355"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "602"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "774"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "855"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "945"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "998"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"18", ",", "32"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "51"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "195"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "218"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "381"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "568"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "800"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "864"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"18", ",", "973"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "36"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "40"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "80"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "84"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "238"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "291"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "859"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "37"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "41"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "442"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "498"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "584"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "601"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "11"}], "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "976"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["2", "9"], " ", 
       RowBox[{"(", 
        RowBox[{"11", "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "38"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["50", "9"], ",", "39"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["50", "9"], ",", "233"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["50", "9"], ",", "493"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["50", "9"], ",", "567"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["50", "9"], ",", "590"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"19", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ",", "43"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"19", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ",", "937"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "44"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "197"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "227"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "478"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "672"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "851"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "861"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "896"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "899"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "910"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["64", "49"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "9"}], "+", 
         RowBox[{"4", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "45"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "56"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "214"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "215"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "481"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "502"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "946"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"4", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "990"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ",", "57"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ",", "79"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ",", "379"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "8"], " ", 
        RowBox[{"(", 
         RowBox[{"27", "+", 
          RowBox[{"10", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "60"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "8"], " ", 
        RowBox[{"(", 
         RowBox[{"27", "+", 
          RowBox[{"10", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "86"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "8"], " ", 
        RowBox[{"(", 
         RowBox[{"27", "+", 
          RowBox[{"10", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "443"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"14", "-", 
       RowBox[{"5", " ", 
        SqrtBox["3"]}]}], ",", "61"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"14", "+", 
       RowBox[{"5", " ", 
        SqrtBox["3"]}]}], ",", "62"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["8", "9"], ",", "67"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["8", "9"], ",", "550"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["8", "9"], ",", "625"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["8", "9"], ",", "694"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["25", "8"], ",", "76"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["25", "8"], ",", "95"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["25", "8"], ",", "277"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["25", "8"], ",", "333"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["25", "8"], ",", "353"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["25", "8"], ",", "492"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["25", "8"], ",", "631"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["25", "8"], ",", "801"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"19", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "81"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"19", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "85"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"19", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "386"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"19", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "404"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"19", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "977"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"17", "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "82"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"17", "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "388"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["49", "8"], ",", "83"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["49", "8"], ",", "288"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["49", "8"], ",", "327"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["49", "8"], ",", "588"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"163", "+", 
          RowBox[{"18", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "87"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"163", "+", 
          RowBox[{"18", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "936"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "-", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "88"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "-", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "411"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "-", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "416"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "-", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "673"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "-", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "897"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "98"], " ", 
       RowBox[{"(", 
        RowBox[{"561", "+", 
         RowBox[{"184", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "89"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["32", "9"], ",", "140"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["32", "9"], ",", "141"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["32", "9"], ",", "182"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["32", "9"], ",", "566"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["32", "9"], ",", "641"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["4", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"51", "+", 
          RowBox[{"10", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "142"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["4", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"51", "+", 
          RowBox[{"10", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "474"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["4", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"51", "+", 
          RowBox[{"10", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "939"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["4", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"51", "+", 
          RowBox[{"10", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "954"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["4", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"51", "+", 
          RowBox[{"10", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "975"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"32", ",", "143"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"32", ",", "263"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"32", ",", "546"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"32", ",", "576"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"9", "-", 
         RowBox[{"4", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "144"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"17", "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "145"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"17", "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "595"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"17", "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "961"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"17", "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "994"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"7", "-", 
       RowBox[{"4", " ", 
        SqrtBox["2"]}], "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"10", "-", 
            RowBox[{"7", " ", 
             SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "164"}], "}"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "9"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "165"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"19", "-", 
       RowBox[{"10", " ", 
        SqrtBox["2"]}], "-", 
       RowBox[{"4", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"10", "-", 
            RowBox[{"7", " ", 
             SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "166"}], "}"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"931", "-", 
       RowBox[{"658", " ", 
        SqrtBox["2"]}], "+", 
       RowBox[{"4", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"54146", "-", 
            RowBox[{"38287", " ", 
             SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "167"}], "}"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"295", "-", 
       RowBox[{"208", " ", 
        SqrtBox["2"]}], "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"20714", "-", 
            RowBox[{"14647", " ", 
             SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "168"}], "}"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"179", "-", 
       RowBox[{"126", " ", 
        SqrtBox["2"]}]}], ",", "170"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"41", "-", 
       RowBox[{"24", " ", 
        SqrtBox["2"]}]}], ",", "171"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "11"}], "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "172"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"7", "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"2", "-", 
            SqrtBox["2"]}], ")"}]}]]}]}], ",", "173"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"6", "+", 
         SqrtBox["2"], "+", 
         RowBox[{"4", " ", 
          SqrtBox[
           RowBox[{"2", "+", 
            SqrtBox["2"]}]]}]}], ")"}]}], ",", "174"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "176"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "192"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "387"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "989"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"13", "+", 
         RowBox[{"9", " ", 
          SqrtBox["2"]}], "-", 
         RowBox[{"2", " ", 
          SqrtBox[
           RowBox[{"58", "+", 
            RowBox[{"41", " ", 
             SqrtBox["2"]}]}]]}]}], ")"}]}], ",", "177"}], "}"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "8"}], "-", 
         RowBox[{"5", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"10", "+", 
              RowBox[{"7", " ", 
               SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "178"}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"227", "-", 
         RowBox[{"154", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{"28", " ", 
          SqrtBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"58", "-", 
              RowBox[{"41", " ", 
               SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "179"}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "49"], " ", 
       RowBox[{"(", 
        RowBox[{"1169", "-", 
         RowBox[{"672", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{"8", " ", 
          SqrtBox[
           RowBox[{"33178", "-", 
            RowBox[{"23201", " ", 
             SqrtBox["2"]}]}]]}]}], ")"}]}], ",", "180"}], "}"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "41"}], "+", 
         RowBox[{"24", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "181"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["49", "18"], ",", "183"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["49", "18"], ",", "252"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"6", "-", 
         SqrtBox["2"], "+", 
         RowBox[{"4", " ", 
          SqrtBox[
           RowBox[{"2", "-", 
            SqrtBox["2"]}]]}]}], ")"}]}], ",", "188"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "-", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "189"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "-", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "239"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"11", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ",", "191"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"11", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ",", "200"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"11", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ",", "979"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["25", "2"], ",", "194"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["25", "2"], ",", "251"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["25", "2"], ",", "262"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "198"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "4"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "292"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "8"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "199"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"10", "+", 
       RowBox[{"6", " ", 
        SqrtBox["2"]}], "-", 
       SqrtBox[
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{"17", "+", 
           RowBox[{"12", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}], ",", "202"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"10", "+", 
       RowBox[{"6", " ", 
        SqrtBox["2"]}], "+", 
       SqrtBox[
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{"17", "+", 
           RowBox[{"12", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}], ",", "203"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "17"}], "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "205"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "17"}], "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "449"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "17"}], "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "853"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "18"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "210"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "33"}], "+", 
          RowBox[{"20", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "213"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "33"}], "+", 
          RowBox[{"20", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "605"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "16"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "220"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ",", "223"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ",", "282"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ",", "484"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ",", "610"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ",", "857"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ",", "908"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ",", "909"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ",", "911"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ",", "923"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["9", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "229"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["9", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "959"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "34"}], "-", 
         RowBox[{"23", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{"4", " ", 
          SqrtBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"58", "+", 
              RowBox[{"41", " ", 
               SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "234"}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"18", "-", 
         SqrtBox["2"], "-", 
         RowBox[{"8", " ", 
          SqrtBox[
           RowBox[{"2", "-", 
            SqrtBox["2"]}]]}]}], ")"}]}], ",", "236"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "9"], " ", 
       RowBox[{"(", 
        RowBox[{"33", "+", 
         RowBox[{"8", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "256"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "18"], " ", 
       RowBox[{"(", 
        RowBox[{"51", "+", 
         RowBox[{"14", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "257"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"31", "-", 
       RowBox[{"20", " ", 
        SqrtBox["2"]}], "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"194", "-", 
            RowBox[{"137", " ", 
             SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "258"}], "}"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"4", "-", 
       SqrtBox["2"], "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"2", "-", 
            SqrtBox["2"]}], ")"}]}]]}]}], ",", "259"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"8", "+", 
         RowBox[{"3", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"2", "+", 
              SqrtBox["2"]}], ")"}]}]]}]}], ")"}]}], ",", "260"}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "32"], " ", 
        RowBox[{"(", 
         RowBox[{"83", "+", 
          RowBox[{"18", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "261"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "32"], " ", 
        RowBox[{"(", 
         RowBox[{"83", "+", 
          RowBox[{"18", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "310"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"4", "+", 
       SqrtBox["2"], "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"2", "+", 
            SqrtBox["2"]}], ")"}]}]]}]}], ",", "266"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"9", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "267"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"9", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "269"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"9", " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "978"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "16"], " ", 
       RowBox[{"(", 
        RowBox[{"51", "+", 
         RowBox[{"10", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "274"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"33", "+", 
         RowBox[{"20", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "279"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "-", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "285"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "-", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "309"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "-", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "320"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "-", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "350"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "-", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "448"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"32", "-", 
       RowBox[{"19", " ", 
        SqrtBox["2"]}], "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"194", "-", 
            RowBox[{"137", " ", 
             SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "289"}], "}"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "8"], ",", "290"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "8"], ",", "315"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "8"], ",", "376"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "8"], ",", "490"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "8"], ",", "671"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["9", "8"], ",", "903"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "-", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "294"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "-", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "329"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "-", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "335"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "-", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "573"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["3", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         SqrtBox["3"]}], ")"}]}], ",", "298"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["3", "4"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         SqrtBox["3"]}], ")"}]}], ",", "299"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"14", "+", 
         RowBox[{"5", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "300"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"14", "-", 
         RowBox[{"5", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "301"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"26", "-", 
         RowBox[{"7", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "302"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"26", "+", 
         RowBox[{"7", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "303"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["121", "32"], ",", "308"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"19", "-", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "312"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"19", "-", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "319"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"19", "-", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "572"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "16"], " ", 
        RowBox[{"(", 
         RowBox[{"33", "+", 
          RowBox[{"8", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "314"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "16"], " ", 
        RowBox[{"(", 
         RowBox[{"33", "+", 
          RowBox[{"8", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "561"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "16"], " ", 
        RowBox[{"(", 
         RowBox[{"33", "+", 
          RowBox[{"8", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "679"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "8"], ",", "316"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "8"], ",", "352"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "322"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "334"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "4"], " ", 
        RowBox[{"(", 
         RowBox[{"3", "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "944"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "98"], " ", 
       RowBox[{"(", 
        RowBox[{"233", "+", 
         RowBox[{"60", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "330"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["9", "4"], ",", "341"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"33", "-", 
         RowBox[{"20", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "346"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["18", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "354"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["18", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "969"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"11", "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"]}], "+", 
       RowBox[{"4", " ", 
        SqrtBox[
         RowBox[{"2", "-", 
          SqrtBox["2"]}]]}]}], ",", "361"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"5", "-", 
       SqrtBox["2"], "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"2", "-", 
          SqrtBox["2"]}]]}]}], ",", "362"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"23", "-", 
       RowBox[{"8", " ", 
        SqrtBox["2"]}], "-", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"50", "-", 
            RowBox[{"31", " ", 
             SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "363"}], "}"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"3", "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", 
            RowBox[{"3", " ", 
             SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "364"}], "}"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", "+", 
       SqrtBox["2"], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["2", 
         RowBox[{"3", "/", "4"}]]}]}], ",", "365"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"4", "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["2", 
           RowBox[{"1", "/", "4"}]]}], "+", 
         SqrtBox["2"]}], ")"}]}], ",", "366"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "11"}], "-", 
         RowBox[{"8", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"24", "+", 
              RowBox[{"17", " ", 
               SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "367"}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["162", "25"], ",", "373"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["18", "289"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "123"}], "+", 
         RowBox[{"22", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "374"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "36"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "375"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "25"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "380"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "25"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "846"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["3", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "7"}], "+", 
         RowBox[{"4", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "383"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["121", "18"], ",", "384"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "98"], " ", 
       RowBox[{"(", 
        RowBox[{"193", "+", 
         RowBox[{"132", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "390"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "98"], " ", 
       RowBox[{"(", 
        RowBox[{"561", "-", 
         RowBox[{"184", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "391"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["18", "289"], " ", 
       RowBox[{"(", 
        RowBox[{"33", "+", 
         RowBox[{"20", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "392"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"6", ",", "395"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "396"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["2", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"13", "+", 
         RowBox[{"4", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "397"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["2", "3"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "13"}], "+", 
         RowBox[{"4", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "398"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"995", "+", 
         RowBox[{"702", " ", 
          SqrtBox["2"]}], "-", 
         RowBox[{"4", " ", 
          SqrtBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"61466", "+", 
              RowBox[{"43463", " ", 
               SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "400"}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "36"], " ", 
       RowBox[{"(", 
        RowBox[{"97", "+", 
         RowBox[{"60", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "409"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "36"], " ", 
       RowBox[{"(", 
        RowBox[{"73", "+", 
         RowBox[{"12", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "413"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["2", "9"], ",", "446"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"41", "-", 
         RowBox[{"24", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "452"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"131", "+", 
         RowBox[{"90", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "479"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "43"}], "+", 
         RowBox[{"30", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "480"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"10", "-", 
         SqrtBox["2"], "+", 
         RowBox[{"4", " ", 
          SqrtBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"2", "-", 
              SqrtBox["2"]}], ")"}]}]]}]}], ")"}]}], ",", "483"}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["32", "25"], ",", "486"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["32", "25"], ",", "548"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["16", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "495"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["16", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "611"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["16", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "496"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["16", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "613"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["16", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "988"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"11", "-", 
       RowBox[{"6", " ", 
        SqrtBox["2"]}], "+", 
       RowBox[{"4", " ", 
        SqrtBox[
         RowBox[{"10", "-", 
          RowBox[{"7", " ", 
           SqrtBox["2"]}]}]]}]}], ",", "503"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"5", "-", 
       RowBox[{"3", " ", 
        SqrtBox["2"]}], "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"10", "-", 
          RowBox[{"7", " ", 
           SqrtBox["2"]}]}]]}]}], ",", "504"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"47", "+", 
       RowBox[{"32", " ", 
        SqrtBox["2"]}], "+", 
       RowBox[{"6", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"58", "+", 
            RowBox[{"41", " ", 
             SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "505"}], "}"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{
           SuperscriptBox["2", 
            RowBox[{"2", "/", "3"}]], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              SqrtBox["2"]}], ")"}], 
            RowBox[{"1", "/", "3"}]]}]}], ")"}], "2"], 
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"1", "/", "3"}]], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SqrtBox["2"]}], ")"}], 
         RowBox[{"2", "/", "3"}]]}]], ",", "506"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["2"]}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"2", "-", 
             SqrtBox["2"]}], ")"}], 
           RowBox[{"3", "/", "4"}]]}], ")"}], "2"], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SqrtBox["2"]}], ")"}], "2"]}]], ",", "507"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         SqrtBox["2"], "+", 
         RowBox[{"4", " ", 
          SqrtBox[
           RowBox[{"1", "+", 
            SqrtBox["2"]}]]}]}], ")"}]}], ",", "508"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"3", "+", 
       SqrtBox["2"], "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SqrtBox["2"]}], ")"}]}]]}]}], ",", "509"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"3", "-", 
       SqrtBox["2"], "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "4"}], "+", 
          RowBox[{"3", " ", 
           SqrtBox["2"]}]}]]}]}], ",", "510"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["288", "49"], ",", "547"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["288", "49"], ",", "597"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["72", "25"], ",", "549"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["72", "25"], ",", "599"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["72", "25"], ",", "626"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["36", "529"], " ", 
       RowBox[{"(", 
        RowBox[{"41", "+", 
         RowBox[{"24", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "551"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["25", "32"], " ", 
       RowBox[{"(", 
        RowBox[{"11", "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "552"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["36", "49"], " ", 
       RowBox[{"(", 
        RowBox[{"9", "+", 
         RowBox[{"4", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "553"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["3", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         RowBox[{"3", " ", 
          SqrtBox["2"]}], "-", 
         SqrtBox[
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}], ")"}]}], ",", "554"}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"18", "+", 
         RowBox[{"7", " ", 
          SqrtBox["2"]}], "+", 
         RowBox[{"4", " ", 
          SqrtBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"10", "+", 
              RowBox[{"7", " ", 
               SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "555"}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"10", "-", 
         SqrtBox["2"], "+", 
         RowBox[{"4", " ", 
          SqrtBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"2", "-", 
              SqrtBox["2"]}], ")"}]}]]}]}], ")"}]}], ",", "556"}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"154", "+", 
         RowBox[{"105", " ", 
          SqrtBox["2"]}], "-", 
         RowBox[{"8", " ", 
          SqrtBox[
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"338", "+", 
              RowBox[{"239", " ", 
               SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", "557"}], "}"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"18", "+", 
         SqrtBox["2"], "+", 
         RowBox[{"8", " ", 
          SqrtBox[
           RowBox[{"2", "+", 
            SqrtBox["2"]}]]}]}], ")"}]}], ",", "558"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"21", "+", 
         RowBox[{"9", " ", 
          SqrtBox["3"]}], "-", 
         RowBox[{"2", " ", 
          SqrtBox[
           RowBox[{"62", "+", 
            RowBox[{"35", " ", 
             SqrtBox["3"]}]}]]}]}], ")"}]}], ",", "559"}], "}"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "560"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "678"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"9", "+", 
          RowBox[{"4", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "854"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["98", "25"], ",", "574"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["128", "25"], ",", "575"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["128", "25"], ",", "695"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "583"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "604"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "18"], " ", 
       RowBox[{"(", 
        RowBox[{"41", "+", 
         RowBox[{"24", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "585"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["841", "162"], ",", "592"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "8"], " ", 
       RowBox[{"(", 
        RowBox[{"57", "+", 
         RowBox[{"28", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "593"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "81"}], "+", 
         RowBox[{"56", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "594"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["8", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "596"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["8", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "960"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["8", "49"], " ", 
        RowBox[{"(", 
         RowBox[{"11", "+", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "993"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["81", "8"], ",", "598"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "139"}], "+", 
         RowBox[{"66", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "600"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"97", "-", 
       RowBox[{"60", " ", 
        SqrtBox["2"]}]}], ",", "609"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"19", "-", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "612"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"19", "-", 
          RowBox[{"6", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "894"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["3", "2"], ",", "616"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["3", "2"], ",", "617"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         SqrtBox["3"]}], ")"}]}], ",", "618"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"12", " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         SqrtBox["3"]}], ")"}]}], ",", "619"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"7", "+", 
         RowBox[{"4", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "621"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"7", "-", 
         RowBox[{"4", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "622"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["4", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"2", "+", 
         SqrtBox["3"]}], ")"}]}], ",", "623"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["4", "3"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         SqrtBox["3"]}], ")"}]}], ",", "624"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"19", "-", 
         RowBox[{"8", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "627"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"19", "+", 
         RowBox[{"8", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "628"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["4", "121"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "146"}], "+", 
         RowBox[{"17", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "629"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["4", "121"], " ", 
       RowBox[{"(", 
        RowBox[{"146", "+", 
         RowBox[{"17", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "630"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      FractionBox["200", "49"], ",", "632"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "6"], " ", 
       RowBox[{"(", 
        RowBox[{"13", "+", 
         RowBox[{"4", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "633"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "6"], " ", 
       RowBox[{"(", 
        RowBox[{"13", "-", 
         RowBox[{"4", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "634"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["4", "169"], " ", 
       RowBox[{"(", 
        RowBox[{"146", "+", 
         RowBox[{"17", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "635"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["4", "169"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "146"}], "+", 
         RowBox[{"17", " ", 
          SqrtBox["3"]}]}], ")"}]}], ",", "636"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"121", "-", 
       RowBox[{"84", " ", 
        SqrtBox["2"]}]}], ",", "728"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"121", "+", 
       RowBox[{"84", " ", 
        SqrtBox["2"]}]}], ",", "738"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["2", "49"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "233"}], "+", 
         RowBox[{"60", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "750"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "16"], " ", 
       RowBox[{"(", 
        RowBox[{"73", "+", 
         RowBox[{"12", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "751"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "121"}], "+", 
         RowBox[{"84", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "756"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["9", "16"], " ", 
       RowBox[{"(", 
        RowBox[{"9", "+", 
         RowBox[{"4", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "757"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3249"}], "+", 
         RowBox[{"2296", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "762"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "64"], " ", 
       RowBox[{"(", 
        RowBox[{"387", "+", 
         RowBox[{"182", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "763"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"43", "-", 
       RowBox[{"30", " ", 
        SqrtBox["2"]}], "+", 
       RowBox[{"4", " ", 
        SqrtBox[
         RowBox[{"58", "-", 
          RowBox[{"41", " ", 
           SqrtBox["2"]}]}]]}]}], ",", "844"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"23", "-", 
       RowBox[{"16", " ", 
        SqrtBox["2"]}], "+", 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"58", "-", 
            RowBox[{"41", " ", 
             SqrtBox["2"]}]}], ")"}]}]]}]}], ",", "845"}], "}"}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"41", "+", 
         RowBox[{"24", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "849"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["2", "49"], " ", 
       RowBox[{"(", 
        RowBox[{"163", "+", 
         RowBox[{"18", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "869"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "36"], " ", 
       RowBox[{"(", 
        RowBox[{"107", "+", 
         RowBox[{"42", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "870"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "144"], " ", 
       RowBox[{"(", 
        RowBox[{"347", "+", 
         RowBox[{"78", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "871"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "18"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "57"}], "+", 
         RowBox[{"40", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "872"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "64"], " ", 
       RowBox[{"(", 
        RowBox[{"209", "+", 
         RowBox[{"60", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "873"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["4", "9"], " ", 
       RowBox[{"(", 
        RowBox[{"9", "+", 
         RowBox[{"4", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "893"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["2", "9"], " ", 
       RowBox[{"(", 
        RowBox[{"27", "+", 
         RowBox[{"10", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "904"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"27", "-", 
          RowBox[{"10", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "938"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"27", "-", 
          RowBox[{"10", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "955"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["2", "49"], " ", 
       RowBox[{"(", 
        RowBox[{"123", "+", 
         RowBox[{"22", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "940"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"33", "-", 
         RowBox[{"8", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "941"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"33", "+", 
         RowBox[{"8", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "948"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["2", "49"]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "123"}], "+", 
          RowBox[{"22", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "949"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["2", "49"]}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "123"}], "+", 
          RowBox[{"22", " ", 
           SqrtBox["2"]}]}], ")"}]}], ",", "965"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["4", "9"], " ", 
       RowBox[{"(", 
        RowBox[{"3", "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "956"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"43", "+", 
         RowBox[{"30", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "957"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["2", "49"], " ", 
       RowBox[{"(", 
        RowBox[{"43", "+", 
         RowBox[{"30", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "958"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["4", "49"], " ", 
       RowBox[{"(", 
        RowBox[{"9", "+", 
         RowBox[{"4", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "963"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"33", "-", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ",", "964"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"33", "-", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ",", "986"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "8"], " ", 
       RowBox[{"(", 
        RowBox[{"51", "-", 
         RowBox[{"14", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "966"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["2", "49"], " ", 
       RowBox[{"(", 
        RowBox[{"177", "+", 
         RowBox[{"52", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "967"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{"11", "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "968"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["8", "49"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "11"}], "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "970"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["2", "961"], " ", 
       RowBox[{"(", 
        RowBox[{"2217", "+", 
         RowBox[{"188", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "980"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "16"], " ", 
       RowBox[{"(", 
        RowBox[{"129", "-", 
         RowBox[{"16", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "981"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "49"], " ", 
       RowBox[{"(", 
        RowBox[{"137", "+", 
         RowBox[{"48", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "982"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"9", ",", "983"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "49"], " ", 
       RowBox[{"(", 
        RowBox[{"113", "+", 
         RowBox[{"72", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "984"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "9"], " ", 
       RowBox[{"(", 
        RowBox[{"41", "+", 
         RowBox[{"24", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "985"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["25", "49"], " ", 
       RowBox[{"(", 
        RowBox[{"9", "+", 
         RowBox[{"4", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "987"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["18", "49"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "11"}], "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "992"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "8"], " ", 
       RowBox[{"(", 
        RowBox[{"33", "+", 
         RowBox[{"20", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "995"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["2", "49"], " ", 
       RowBox[{"(", 
        RowBox[{"57", "+", 
         RowBox[{"40", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "996"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["2", "49"], " ", 
       RowBox[{"(", 
        RowBox[{"113", "+", 
         RowBox[{"72", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "999"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       FractionBox["1", "8"], " ", 
       RowBox[{"(", 
        RowBox[{"17", "+", 
         RowBox[{"12", " ", 
          SqrtBox["2"]}]}], ")"}]}], ",", "1000"}], "}"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.8592135120610332`*^9, 3.8592135299654217`*^9}, 
   3.859909461608657*^9, 3.861097968712734*^9},
 CellLabel->
  "Out[181]=",ExpressionUUID->"2a759879-93a8-43b9-abf2-1fe72d147ea9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"grouped", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{"Map", "[", 
        RowBox[{"Last", ",", "#"}], "]"}]}], "}"}], "&"}], ",", "gathered"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.859213666751851*^9, 3.8592137126360683`*^9}, {
  3.859213772494132*^9, 3.859213774268517*^9}},
 CellLabel->
  "In[182]:=",ExpressionUUID->"2496f4ba-0a8b-475e-b634-963c1ddd21bf"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "377"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "54", ",", "284", ",", "311", ",", "349", ",", "569", ",", 
       "570", ",", "581", ",", "637", ",", "639", ",", "943"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "11", ",", "48", ",", "49", ",", "63", ",", "69", ",", "71", 
       ",", "72", ",", "73", ",", "77", ",", "78", ",", "97", ",", "115", ",",
        "116", ",", "122", ",", "123", ",", "124", ",", "125", ",", "127", 
       ",", "130", ",", "137", ",", "184", ",", "185", ",", "187", ",", "201",
        ",", "212", ",", "216", ",", "217", ",", "219", ",", "222", ",", 
       "228", ",", "237", ",", "244", ",", "245", ",", "246", ",", "248", ",",
        "255", ",", "265", ",", "268", ",", "271", ",", "283", ",", "287", 
       ",", "293", ",", "295", ",", "296", ",", "304", ",", "305", ",", "306",
        ",", "307", ",", "326", ",", "328", ",", "332", ",", "336", ",", 
       "337", ",", "338", ",", "339", ",", "343", ",", "345", ",", "348", ",",
        "382", ",", "394", ",", "399", ",", "408", ",", "417", ",", "418", 
       ",", "426", ",", "440", ",", "441", ",", "464", ",", "465", ",", "466",
        ",", "488", ",", "499", ",", "577", ",", "591", ",", "603", ",", 
       "606", ",", "615", ",", "640", ",", "682", ",", "748", ",", "820", ",",
        "828", ",", "836", ",", "852", ",", "856", ",", "865", ",", "866", 
       ",", "867", ",", "868", ",", "895", ",", "902", ",", "974"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "6", ",", "169", ",", "226", ",", "344", ",", "389", ",", 
       "402", ",", "482", ",", "485", ",", "494", ",", "578", ",", "620", ",",
        "642", ",", "942"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "58", ",", "614", ",", "951"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "313", ",", "501", ",", "947", ",", "962"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "35", ",", "321"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"{", 
      RowBox[{
      "10", ",", "55", ",", "241", ",", "405", ",", "500", ",", "582", ",", 
       "950"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "42", ",", "863", ",", "922"}], "}"}]}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "13", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "14", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "+", 
      SqrtBox["3"]}], ",", 
     RowBox[{"{", "15", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "-", 
      SqrtBox["3"]}], ",", 
     RowBox[{"{", "16", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "+", 
        RowBox[{"3", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "17", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "-", 
        RowBox[{"3", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "18", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", 
     RowBox[{"{", 
      RowBox[{
      "20", ",", "22", ",", "23", ",", "70", ",", "74", ",", "94", ",", "98", 
       ",", "102", ",", "103", ",", "104", ",", "105", ",", "106", ",", "111",
        ",", "146", ",", "147", ",", "148", ",", "149", ",", "150", ",", 
       "151", ",", "152", ",", "153", ",", "160", ",", "175", ",", "253", ",",
        "280", ",", "323", ",", "325", ",", "347", ",", "385", ",", "401", 
       ",", "477", ",", "586", ",", "638", ",", "675", ",", "697", ",", "699",
        ",", "701", ",", "703", ",", "705", ",", "707", ",", "709", ",", 
       "711", ",", "713", ",", "715", ",", "717", ",", "719", ",", "721", ",",
        "723", ",", "725", ",", "727", ",", "729", ",", "731", ",", "733", 
       ",", "735", ",", "737", ",", "739", ",", "741", ",", "743", ",", "745",
        ",", "747", ",", "753", ",", "755", ",", "759", ",", "761", ",", 
       "767", ",", "840", ",", "841", ",", "842", ",", "843", ",", "858", ",",
        "953", ",", "972"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "21", ",", "75", ",", "371", ",", "497", ",", "775", ",", "991", ",", 
       "997"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "31", ",", "65", ",", "355", ",", "602", ",", "774", ",", "855", ",", 
       "945", ",", "998"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"{", 
      RowBox[{
      "32", ",", "51", ",", "195", ",", "218", ",", "381", ",", "568", ",", 
       "800", ",", "864", ",", "973"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{
      "36", ",", "40", ",", "80", ",", "84", ",", "238", ",", "291", ",", 
       "859"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "37", ",", "41", ",", "442", ",", "498", ",", "584", ",", "601", ",", 
       "976"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "38", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["50", "9"], ",", 
     RowBox[{"{", 
      RowBox[{"39", ",", "233", ",", "493", ",", "567", ",", "590"}], "}"}]}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"19", "-", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"43", ",", "937"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "44", ",", "197", ",", "227", ",", "478", ",", "672", ",", "851", ",", 
       "861", ",", "896", ",", "899", ",", "910"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["64", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "45", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "56", ",", "214", ",", "215", ",", "481", ",", "502", ",", "946", ",", 
       "990"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", "+", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"57", ",", "79", ",", "379"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"27", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"60", ",", "86", ",", "443"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"14", "-", 
      RowBox[{"5", " ", 
       SqrtBox["3"]}]}], ",", 
     RowBox[{"{", "61", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"14", "+", 
      RowBox[{"5", " ", 
       SqrtBox["3"]}]}], ",", 
     RowBox[{"{", "62", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["8", "9"], ",", 
     RowBox[{"{", 
      RowBox[{"67", ",", "550", ",", "625", ",", "694"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "8"], ",", 
     RowBox[{"{", 
      RowBox[{
      "76", ",", "95", ",", "277", ",", "333", ",", "353", ",", "492", ",", 
       "631", ",", "801"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"81", ",", "85", ",", "386", ",", "404", ",", "977"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"17", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"82", ",", "388"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["49", "8"], ",", 
     RowBox[{"{", 
      RowBox[{"83", ",", "288", ",", "327", ",", "588"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"163", "+", 
        RowBox[{"18", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"87", ",", "936"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "-", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"88", ",", "411", ",", "416", ",", "673", ",", "897"}], "}"}]}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "98"], " ", 
      RowBox[{"(", 
       RowBox[{"561", "+", 
        RowBox[{"184", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "89", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["32", "9"], ",", 
     RowBox[{"{", 
      RowBox[{"140", ",", "141", ",", "182", ",", "566", ",", "641"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"142", ",", "474", ",", "939", ",", "954", ",", "975"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"32", ",", 
     RowBox[{"{", 
      RowBox[{"143", ",", "263", ",", "546", ",", "576"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "-", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "144", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"17", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"145", ",", "595", ",", "961", ",", "994"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"7", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"10", "-", 
           RowBox[{"7", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "164", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "9"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "165", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"19", "-", 
      RowBox[{"10", " ", 
       SqrtBox["2"]}], "-", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"10", "-", 
           RowBox[{"7", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "166", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"931", "-", 
      RowBox[{"658", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"54146", "-", 
           RowBox[{"38287", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "167", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"295", "-", 
      RowBox[{"208", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"20714", "-", 
           RowBox[{"14647", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "168", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"179", "-", 
      RowBox[{"126", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", "170", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"41", "-", 
      RowBox[{"24", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", "171", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "172", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"7", "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"2", "-", 
           SqrtBox["2"]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "173", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"6", "+", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", "+", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "174", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"176", ",", "192", ",", "387", ",", "989"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"13", "+", 
        RowBox[{"9", " ", 
         SqrtBox["2"]}], "-", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"58", "+", 
           RowBox[{"41", " ", 
            SqrtBox["2"]}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "177", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "8"}], "-", 
        RowBox[{"5", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"10", "+", 
             RowBox[{"7", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "178", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"227", "-", 
        RowBox[{"154", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"28", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"58", "-", 
             RowBox[{"41", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "179", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"1169", "-", 
        RowBox[{"672", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"33178", "-", 
           RowBox[{"23201", " ", 
            SqrtBox["2"]}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "180", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "41"}], "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "181", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["49", "18"], ",", 
     RowBox[{"{", 
      RowBox[{"183", ",", "252"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"6", "-", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", "-", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "188", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"189", ",", "239"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"11", "-", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"191", ",", "200", ",", "979"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "2"], ",", 
     RowBox[{"{", 
      RowBox[{"194", ",", "251", ",", "262"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"198", ",", "292"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "199", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"10", "+", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}], "-", 
      SqrtBox[
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"17", "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}]]}], ",", 
     RowBox[{"{", "202", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"10", "+", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}], "+", 
      SqrtBox[
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"17", "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}]]}], ",", 
     RowBox[{"{", "203", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "17"}], "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"205", ",", "449", ",", "853"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "18"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "210", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "33"}], "+", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"213", ",", "605"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "220", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "223", ",", "282", ",", "484", ",", "610", ",", "857", ",", "908", ",", 
       "909", ",", "911", ",", "923"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["9", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"229", ",", "959"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "34"}], "-", 
        RowBox[{"23", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"58", "+", 
             RowBox[{"41", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "234", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"18", "-", 
        SqrtBox["2"], "-", 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"2", "-", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "236", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "256", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "18"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        RowBox[{"14", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "257", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"31", "-", 
      RowBox[{"20", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"194", "-", 
           RowBox[{"137", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "258", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", "-", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"2", "-", 
           SqrtBox["2"]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "259", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"8", "+", 
        RowBox[{"3", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             SqrtBox["2"]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "260", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "32"], " ", 
      RowBox[{"(", 
       RowBox[{"83", "+", 
        RowBox[{"18", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"261", ",", "310"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", "+", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", 
           SqrtBox["2"]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "266", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"267", ",", "269", ",", "978"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "274", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "279", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"285", ",", "309", ",", "320", ",", "350", ",", "448"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"32", "-", 
      RowBox[{"19", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"194", "-", 
           RowBox[{"137", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "289", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "8"], ",", 
     RowBox[{"{", 
      RowBox[{
      "290", ",", "315", ",", "376", ",", "490", ",", "671", ",", "903"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"294", ",", "329", ",", "335", ",", "573"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["3", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "298", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["3", "4"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "299", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "+", 
        RowBox[{"5", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "300", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "-", 
        RowBox[{"5", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "301", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"26", "-", 
        RowBox[{"7", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "302", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"26", "+", 
        RowBox[{"7", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "303", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["121", "32"], ",", 
     RowBox[{"{", "308", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"312", ",", "319", ",", "572"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"314", ",", "561", ",", "679"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "8"], ",", 
     RowBox[{"{", 
      RowBox[{"316", ",", "352"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"322", ",", "334", ",", "944"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "98"], " ", 
      RowBox[{"(", 
       RowBox[{"233", "+", 
        RowBox[{"60", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "330", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "4"], ",", 
     RowBox[{"{", "341", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "-", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "346", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["18", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"354", ",", "969"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"11", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}], ",", 
     RowBox[{"{", "361", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"5", "-", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}], ",", 
     RowBox[{"{", "362", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"23", "-", 
      RowBox[{"8", " ", 
       SqrtBox["2"]}], "-", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"50", "-", 
           RowBox[{"31", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "363", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", 
           RowBox[{"3", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "364", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "+", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["2", 
        RowBox[{"3", "/", "4"}]]}]}], ",", 
     RowBox[{"{", "365", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"4", "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["2", 
          RowBox[{"1", "/", "4"}]]}], "+", 
        SqrtBox["2"]}], ")"}]}], ",", 
     RowBox[{"{", "366", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "-", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"24", "+", 
             RowBox[{"17", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "367", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["162", "25"], ",", 
     RowBox[{"{", "373", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["18", "289"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "123"}], "+", 
        RowBox[{"22", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "374", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "36"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "375", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "25"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "846"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["3", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "7"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "383", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["121", "18"], ",", 
     RowBox[{"{", "384", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "98"], " ", 
      RowBox[{"(", 
       RowBox[{"193", "+", 
        RowBox[{"132", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "390", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "98"], " ", 
      RowBox[{"(", 
       RowBox[{"561", "-", 
        RowBox[{"184", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "391", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["18", "289"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "392", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", 
     RowBox[{"{", 
      RowBox[{"395", ",", "396"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"13", "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "397", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "13"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "398", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"995", "+", 
        RowBox[{"702", " ", 
         SqrtBox["2"]}], "-", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"61466", "+", 
             RowBox[{"43463", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "400", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "36"], " ", 
      RowBox[{"(", 
       RowBox[{"97", "+", 
        RowBox[{"60", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "409", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "36"], " ", 
      RowBox[{"(", 
       RowBox[{"73", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "413", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["2", "9"], ",", 
     RowBox[{"{", "446", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "-", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "452", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"131", "+", 
        RowBox[{"90", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "479", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "43"}], "+", 
        RowBox[{"30", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "480", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"10", "-", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", 
             SqrtBox["2"]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "483", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["32", "25"], ",", 
     RowBox[{"{", 
      RowBox[{"486", ",", "548"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["16", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"495", ",", "611"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["16", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"496", ",", "613", ",", "988"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"11", "-", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"10", "-", 
         RowBox[{"7", " ", 
          SqrtBox["2"]}]}]]}]}], ",", 
     RowBox[{"{", "503", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"5", "-", 
      RowBox[{"3", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"10", "-", 
         RowBox[{"7", " ", 
          SqrtBox["2"]}]}]]}]}], ",", 
     RowBox[{"{", "504", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"47", "+", 
      RowBox[{"32", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"6", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"58", "+", 
           RowBox[{"41", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "505", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"2", "/", "3"}]], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SqrtBox["2"]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}]}], ")"}], "2"], 
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SqrtBox["2"]}], ")"}], 
        RowBox[{"2", "/", "3"}]]}]], ",", 
     RowBox[{"{", "506", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", "-", 
            SqrtBox["2"]}], ")"}], 
          RowBox[{"3", "/", "4"}]]}], ")"}], "2"], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SqrtBox["2"]}], ")"}], "2"]}]], ",", 
     RowBox[{"{", "507", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"5", "+", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"1", "+", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "508", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "+", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SqrtBox["2"]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "509", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         RowBox[{"3", " ", 
          SqrtBox["2"]}]}]]}]}], ",", 
     RowBox[{"{", "510", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["288", "49"], ",", 
     RowBox[{"{", 
      RowBox[{"547", ",", "597"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["72", "25"], ",", 
     RowBox[{"{", 
      RowBox[{"549", ",", "599", ",", "626"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["36", "529"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "551", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["25", "32"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "552", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["36", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "553", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["3", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"5", "+", 
        RowBox[{"3", " ", 
         SqrtBox["2"]}], "-", 
        SqrtBox[
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"2", " ", 
             SqrtBox["2"]}]}], ")"}]}]]}], ")"}]}], ",", 
     RowBox[{"{", "554", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"18", "+", 
        RowBox[{"7", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"10", "+", 
             RowBox[{"7", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "555", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"10", "-", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", 
             SqrtBox["2"]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "556", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"154", "+", 
        RowBox[{"105", " ", 
         SqrtBox["2"]}], "-", 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"338", "+", 
             RowBox[{"239", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "557", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"18", "+", 
        SqrtBox["2"], "+", 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"2", "+", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "558", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"21", "+", 
        RowBox[{"9", " ", 
         SqrtBox["3"]}], "-", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"62", "+", 
           RowBox[{"35", " ", 
            SqrtBox["3"]}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "559", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "678", ",", "854"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["98", "25"], ",", 
     RowBox[{"{", "574", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["128", "25"], ",", 
     RowBox[{"{", 
      RowBox[{"575", ",", "695"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"583", ",", "604"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "18"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "585", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["841", "162"], ",", 
     RowBox[{"{", "592", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"57", "+", 
        RowBox[{"28", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "593", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "81"}], "+", 
        RowBox[{"56", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "594", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["8", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"596", ",", "960", ",", "993"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["81", "8"], ",", 
     RowBox[{"{", "598", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "139"}], "+", 
        RowBox[{"66", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "600", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"97", "-", 
      RowBox[{"60", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", "609", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"612", ",", "894"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["3", "2"], ",", 
     RowBox[{"{", 
      RowBox[{"616", ",", "617"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "12"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "618", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"12", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "619", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"7", "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "621", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"7", "-", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "622", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "623", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["4", "3"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "624", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "-", 
        RowBox[{"8", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "627", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "+", 
        RowBox[{"8", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "628", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["4", "121"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "146"}], "+", 
        RowBox[{"17", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "629", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "121"], " ", 
      RowBox[{"(", 
       RowBox[{"146", "+", 
        RowBox[{"17", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "630", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["200", "49"], ",", 
     RowBox[{"{", "632", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"13", "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "633", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"13", "-", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "634", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "169"], " ", 
      RowBox[{"(", 
       RowBox[{"146", "+", 
        RowBox[{"17", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "635", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["4", "169"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "146"}], "+", 
        RowBox[{"17", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "636", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"121", "-", 
      RowBox[{"84", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", "728", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"121", "+", 
      RowBox[{"84", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", "738", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "233"}], "+", 
        RowBox[{"60", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "750", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"73", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "751", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "121"}], "+", 
        RowBox[{"84", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "756", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["9", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "757", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3249"}], "+", 
        RowBox[{"2296", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "762", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "64"], " ", 
      RowBox[{"(", 
       RowBox[{"387", "+", 
        RowBox[{"182", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "763", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"43", "-", 
      RowBox[{"30", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"58", "-", 
         RowBox[{"41", " ", 
          SqrtBox["2"]}]}]]}]}], ",", 
     RowBox[{"{", "844", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"23", "-", 
      RowBox[{"16", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"58", "-", 
           RowBox[{"41", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "845", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "849", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"163", "+", 
        RowBox[{"18", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "869", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "36"], " ", 
      RowBox[{"(", 
       RowBox[{"107", "+", 
        RowBox[{"42", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "870", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "144"], " ", 
      RowBox[{"(", 
       RowBox[{"347", "+", 
        RowBox[{"78", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "871", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "18"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "57"}], "+", 
        RowBox[{"40", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "872", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "64"], " ", 
      RowBox[{"(", 
       RowBox[{"209", "+", 
        RowBox[{"60", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "873", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "893", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"27", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "904", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"27", "-", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"938", ",", "955"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"123", "+", 
        RowBox[{"22", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "940", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "-", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "941", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "948", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "123"}], "+", 
        RowBox[{"22", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"949", ",", "965"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "956", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"43", "+", 
        RowBox[{"30", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "957", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"43", "+", 
        RowBox[{"30", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "958", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "963", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"33", "-", 
      RowBox[{"20", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"964", ",", "986"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "-", 
        RowBox[{"14", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "966", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"177", "+", 
        RowBox[{"52", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "967", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "968", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["8", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "970", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "961"], " ", 
      RowBox[{"(", 
       RowBox[{"2217", "+", 
        RowBox[{"188", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "980", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"129", "-", 
        RowBox[{"16", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "981", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"137", "+", 
        RowBox[{"48", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "982", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     RowBox[{"{", "983", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"113", "+", 
        RowBox[{"72", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "984", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "985", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["25", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "987", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["18", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "992", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "995", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"57", "+", 
        RowBox[{"40", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "996", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"113", "+", 
        RowBox[{"72", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "999", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"17", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "1000", "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.859213714242857*^9, 3.85921377539301*^9, 
  3.8599094617290583`*^9, 3.861097968774529*^9},
 CellLabel->
  "Out[182]=",ExpressionUUID->"e90b08c6-b038-4e45-a245-c4d069e1edb0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sorted", "=", 
  RowBox[{"Sort", "[", 
   RowBox[{"grouped", ",", "NumericalOrder"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.859213786631111*^9, 3.859213790252185*^9}, {
  3.859213885766192*^9, 3.859213901140476*^9}, {3.859213941670411*^9, 
  3.859213944356699*^9}},
 CellLabel->
  "In[183]:=",ExpressionUUID->"79fc2e96-9af2-470b-942e-a45dddcfe5aa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"7", "-", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "622", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"285", ",", "309", ",", "320", ",", "350", ",", "448"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "17"}], "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"205", ",", "449", ",", "853"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "-", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"189", ",", "239"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["3", "2"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "7"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "383", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "8"], ",", 
     RowBox[{"{", 
      RowBox[{"316", ",", "352"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "223", ",", "282", ",", "484", ",", "610", ",", "857", ",", "908", ",", 
       "909", ",", "911", ",", "923"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["3", "4"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "299", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["2", "9"], ",", 
     RowBox[{"{", "446", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "-", 
      SqrtBox["3"]}], ",", 
     RowBox[{"{", "16", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "44", ",", "197", ",", "227", ",", "478", ",", "672", ",", "851", ",", 
       "861", ",", "896", ",", "899", ",", "910"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["4", "3"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "624", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["8", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "970", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", 
     RowBox[{"{", 
      RowBox[{
      "20", ",", "22", ",", "23", ",", "70", ",", "74", ",", "94", ",", "98", 
       ",", "102", ",", "103", ",", "104", ",", "105", ",", "106", ",", "111",
        ",", "146", ",", "147", ",", "148", ",", "149", ",", "150", ",", 
       "151", ",", "152", ",", "153", ",", "160", ",", "175", ",", "253", ",",
        "280", ",", "323", ",", "325", ",", "347", ",", "385", ",", "401", 
       ",", "477", ",", "586", ",", "638", ",", "675", ",", "697", ",", "699",
        ",", "701", ",", "703", ",", "705", ",", "707", ",", "709", ",", 
       "711", ",", "713", ",", "715", ",", "717", ",", "719", ",", "721", ",",
        "723", ",", "725", ",", "727", ",", "729", ",", "731", ",", "733", 
       ",", "735", ",", "737", ",", "739", ",", "741", ",", "743", ",", "745",
        ",", "747", ",", "753", ",", "755", ",", "759", ",", "761", ",", 
       "767", ",", "840", ",", "841", ",", "842", ",", "843", ",", "858", ",",
        "953", ",", "972"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"198", ",", "292"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"23", "-", 
      RowBox[{"16", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"58", "-", 
           RowBox[{"41", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "845", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "14", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"179", "-", 
      RowBox[{"126", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", "170", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "-", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"88", ",", "411", ",", "416", ",", "673", ",", "897"}], "}"}]}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"931", "-", 
      RowBox[{"658", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"54146", "-", 
           RowBox[{"38287", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "167", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["8", "9"], ",", 
     RowBox[{"{", 
      RowBox[{"67", ",", "550", ",", "625", ",", "694"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["18", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "992", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{
      "36", ",", "40", ",", "80", ",", "84", ",", "238", ",", "291", ",", 
       "859"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"13", "-", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "634", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"43", "-", 
      RowBox[{"30", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"58", "-", 
         RowBox[{"41", " ", 
          SqrtBox["2"]}]}]]}]}], ",", 
     RowBox[{"{", "844", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "8"], ",", 
     RowBox[{"{", 
      RowBox[{
      "290", ",", "315", ",", "376", ",", "490", ",", "671", ",", "903"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"295", "-", 
      RowBox[{"208", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"20714", "-", 
           RowBox[{"14647", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "168", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "963", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"294", ",", "329", ",", "335", ",", "573"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["32", "25"], ",", 
     RowBox[{"{", 
      RowBox[{"486", ",", "548"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "-", 
        RowBox[{"5", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "301", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "8"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "199", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"5", "-", 
      RowBox[{"3", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"10", "-", 
         RowBox[{"7", " ", 
          SqrtBox["2"]}]}]]}]}], ",", 
     RowBox[{"{", "504", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"322", ",", "334", ",", "944"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["3", "2"], ",", 
     RowBox[{"{", 
      RowBox[{"616", ",", "617"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "9"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "165", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "-", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "144", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"{", 
      RowBox[{
      "3", ",", "11", ",", "48", ",", "49", ",", "63", ",", "69", ",", "71", 
       ",", "72", ",", "73", ",", "77", ",", "78", ",", "97", ",", "115", ",",
        "116", ",", "122", ",", "123", ",", "124", ",", "125", ",", "127", 
       ",", "130", ",", "137", ",", "184", ",", "185", ",", "187", ",", "201",
        ",", "212", ",", "216", ",", "217", ",", "219", ",", "222", ",", 
       "228", ",", "237", ",", "244", ",", "245", ",", "246", ",", "248", ",",
        "255", ",", "265", ",", "268", ",", "271", ",", "283", ",", "287", 
       ",", "293", ",", "295", ",", "296", ",", "304", ",", "305", ",", "306",
        ",", "307", ",", "326", ",", "328", ",", "332", ",", "336", ",", 
       "337", ",", "338", ",", "339", ",", "343", ",", "345", ",", "348", ",",
        "382", ",", "394", ",", "399", ",", "408", ",", "417", ",", "418", 
       ",", "426", ",", "440", ",", "441", ",", "464", ",", "465", ",", "466",
        ",", "488", ",", "499", ",", "577", ",", "591", ",", "603", ",", 
       "606", ",", "615", ",", "640", ",", "682", ",", "748", ",", "820", ",",
        "828", ",", "836", ",", "852", ",", "856", ",", "865", ",", "866", 
       ",", "867", ",", "868", ",", "895", ",", "902", ",", "974"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"995", "+", 
        RowBox[{"702", " ", 
         SqrtBox["2"]}], "-", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"61466", "+", 
             RowBox[{"43463", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "400", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"121", "-", 
      RowBox[{"84", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", "728", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"7", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"10", "-", 
           RowBox[{"7", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "164", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "4"], ",", 
     RowBox[{"{", "341", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "43"}], "+", 
        RowBox[{"30", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "480", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "-", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "346", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "36"], " ", 
      RowBox[{"(", 
       RowBox[{"73", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "413", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"11", "-", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"191", ",", "200", ",", "979"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "-", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "4"}], "+", 
         RowBox[{"3", " ", 
          SqrtBox["2"]}]}]]}]}], ",", 
     RowBox[{"{", "510", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "-", 
        RowBox[{"8", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "627", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "956", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"312", ",", "319", ",", "572"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["49", "18"], ",", 
     RowBox[{"{", 
      RowBox[{"183", ",", "252"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "16"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "220", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["4", "169"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "146"}], "+", 
        RowBox[{"17", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "636", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"314", ",", "561", ",", "679"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["3", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "298", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["72", "25"], ",", 
     RowBox[{"{", 
      RowBox[{"549", ",", "599", ",", "626"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "313", ",", "501", ",", "947", ",", "962"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "-", 
        RowBox[{"3", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "18", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"19", "-", 
      RowBox[{"10", " ", 
       SqrtBox["2"]}], "-", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"10", "-", 
           RowBox[{"7", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "166", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "98"], " ", 
      RowBox[{"(", 
       RowBox[{"561", "-", 
        RowBox[{"184", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "391", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "18"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "210", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "8"], ",", 
     RowBox[{"{", 
      RowBox[{
      "76", ",", "95", ",", "277", ",", "333", ",", "353", ",", "492", ",", 
       "631", ",", "801"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "144"], " ", 
      RowBox[{"(", 
       RowBox[{"347", "+", 
        RowBox[{"78", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "871", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["8", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"596", ",", "960", ",", "993"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "12"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "618", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"10", "-", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", 
             SqrtBox["2"]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "556", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "98"], " ", 
      RowBox[{"(", 
       RowBox[{"233", "+", 
        RowBox[{"60", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "330", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{"(", 
       RowBox[{"13", "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "633", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", "-", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "35", ",", "321"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "32"], " ", 
      RowBox[{"(", 
       RowBox[{"83", "+", 
        RowBox[{"18", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"261", ",", "310"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"26", "-", 
        RowBox[{"7", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "302", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"43", "+", 
        RowBox[{"30", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "958", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "-", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "452", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["32", "9"], ",", 
     RowBox[{"{", 
      RowBox[{"140", ",", "141", ",", "182", ",", "566", ",", "641"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "81"}], "+", 
        RowBox[{"56", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "594", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "21", ",", "75", ",", "371", ",", "497", ",", "775", ",", "991", ",", 
       "997"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "+", 
      SqrtBox["3"]}], ",", 
     RowBox[{"{", "15", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "123"}], "+", 
        RowBox[{"22", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"949", ",", "965"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["121", "32"], ",", 
     RowBox[{"{", "308", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"11", "-", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"10", "-", 
         RowBox[{"7", " ", 
          SqrtBox["2"]}]}]]}]}], ",", 
     RowBox[{"{", "503", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["18", "289"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "392", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"6", "-", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", "-", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "188", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"163", "+", 
        RowBox[{"18", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"87", ",", "936"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["4", "121"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "146"}], "+", 
        RowBox[{"17", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "629", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "98"], " ", 
      RowBox[{"(", 
       RowBox[{"193", "+", 
        RowBox[{"132", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "390", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "-", 
        RowBox[{"14", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "966", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["98", "25"], ",", 
     RowBox[{"{", "574", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3249"}], "+", 
        RowBox[{"2296", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "762", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "18"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        RowBox[{"14", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "257", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"{", 
      RowBox[{
      "10", ",", "55", ",", "241", ",", "405", ",", "500", ",", "582", ",", 
       "950"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "3"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "13"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "398", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "274", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["200", "49"], ",", 
     RowBox[{"{", "632", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"31", "-", 
      RowBox[{"20", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"194", "-", 
           RowBox[{"137", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "258", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "169"], " ", 
      RowBox[{"(", 
       RowBox[{"146", "+", 
        RowBox[{"17", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "635", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "18"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "585", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"154", "+", 
        RowBox[{"105", " ", 
         SqrtBox["2"]}], "-", 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"338", "+", 
             RowBox[{"239", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "557", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"137", "+", 
        RowBox[{"48", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "982", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"17", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "1000", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "25"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"380", ",", "846"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "38", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["64", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "45", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"8", "+", 
        RowBox[{"3", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"2", "+", 
             SqrtBox["2"]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "260", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"113", "+", 
        RowBox[{"72", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "984", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", 
           RowBox[{"3", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "364", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "121"}], "+", 
        RowBox[{"84", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "756", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "54", ",", "284", ",", "311", ",", "349", ",", "569", ",", 
       "570", ",", "581", ",", "637", ",", "639", ",", "943"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "64"], " ", 
      RowBox[{"(", 
       RowBox[{"209", "+", 
        RowBox[{"60", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "873", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "36"], " ", 
      RowBox[{"(", 
       RowBox[{"107", "+", 
        RowBox[{"42", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "870", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"57", "+", 
        RowBox[{"40", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "996", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"23", "-", 
      RowBox[{"8", " ", 
       SqrtBox["2"]}], "-", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"50", "-", 
           RowBox[{"31", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "363", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"33", "-", 
      RowBox[{"20", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"964", ",", "986"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", "-", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"2", "-", 
           SqrtBox["2"]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "259", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["16", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"496", ",", "613", ",", "988"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "968", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "8"}], "-", 
        RowBox[{"5", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"10", "+", 
             RowBox[{"7", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "178", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "256", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "623", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "37", ",", "41", ",", "442", ",", "498", ",", "584", ",", "601", ",", 
       "976"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "36"], " ", 
      RowBox[{"(", 
       RowBox[{"97", "+", 
        RowBox[{"60", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "409", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"4", "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["2", 
          RowBox[{"1", "/", "4"}]]}], "+", 
        SqrtBox["2"]}], ")"}]}], ",", 
     RowBox[{"{", "366", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["36", "529"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "551", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"5", "-", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}], ",", 
     RowBox[{"{", "362", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["128", "25"], ",", 
     RowBox[{"{", 
      RowBox[{"575", ",", "695"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"27", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"60", ",", "86", ",", "443"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "961"], " ", 
      RowBox[{"(", 
       RowBox[{"2217", "+", 
        RowBox[{"188", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "980", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["841", "162"], ",", 
     RowBox[{"{", "592", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"18", "-", 
        SqrtBox["2"], "-", 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"2", "-", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "236", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "-", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"612", ",", "894"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"51", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"142", ",", "474", ",", "939", ",", "954", ",", "975"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"14", "-", 
      RowBox[{"5", " ", 
       SqrtBox["3"]}]}], ",", 
     RowBox[{"{", "61", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "-", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"24", "+", 
             RowBox[{"17", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "367", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "-", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "941", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["50", "9"], ",", 
     RowBox[{"{", 
      RowBox[{"39", ",", "233", ",", "493", ",", "567", ",", "590"}], "}"}]}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"73", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "751", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "+", 
        RowBox[{"5", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "300", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["18", "289"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "123"}], "+", 
        RowBox[{"22", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "374", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "121"], " ", 
      RowBox[{"(", 
       RowBox[{"146", "+", 
        RowBox[{"17", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "630", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "377"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["288", "49"], ",", 
     RowBox[{"{", 
      RowBox[{"547", ",", "597"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", 
     RowBox[{"{", 
      RowBox[{"395", ",", "396"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "49"]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "233"}], "+", 
        RowBox[{"60", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "750", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["49", "8"], ",", 
     RowBox[{"{", 
      RowBox[{"83", ",", "288", ",", "327", ",", "588"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "36"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "375", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"123", "+", 
        RowBox[{"22", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "940", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"5", "+", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"1", "+", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "508", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["16", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"495", ",", "611"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "+", 
        RowBox[{"3", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "17", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"27", "-", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"938", ",", "955"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"10", "-", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"2", "-", 
             SqrtBox["2"]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "483", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["162", "25"], ",", 
     RowBox[{"{", "373", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["4", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "893", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"]}], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"2", "-", 
            SqrtBox["2"]}], ")"}], 
          RowBox[{"3", "/", "4"}]]}], ")"}], "2"], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SqrtBox["2"]}], ")"}], "2"]}]], ",", 
     RowBox[{"{", "507", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"32", "-", 
      RowBox[{"19", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"194", "-", 
           RowBox[{"137", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "289", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"129", "-", 
        RowBox[{"16", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "981", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "9"}], "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "42", ",", "863", ",", "922"}], "}"}]}], "}"}], ",", 
   
   RowBox[{"{", 
    RowBox[{
     FractionBox["121", "18"], ",", 
     RowBox[{"{", "384", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", "+", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["2", 
        RowBox[{"3", "/", "4"}]]}]}], ",", 
     RowBox[{"{", "365", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          SuperscriptBox["2", 
           RowBox[{"2", "/", "3"}]], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             SqrtBox["2"]}], ")"}], 
           RowBox[{"1", "/", "3"}]]}]}], ")"}], "2"], 
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SqrtBox["2"]}], ")"}], 
        RowBox[{"2", "/", "3"}]]}]], ",", 
     RowBox[{"{", "506", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"81", ",", "85", ",", "386", ",", "404", ",", "977"}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"7", "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "621", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"41", "-", 
      RowBox[{"24", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", "171", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["18", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"354", ",", "969"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"227", "-", 
        RowBox[{"154", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"28", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"58", "-", 
             RowBox[{"41", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "179", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"21", "+", 
        RowBox[{"9", " ", 
         SqrtBox["3"]}], "-", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"62", "+", 
           RowBox[{"35", " ", 
            SqrtBox["3"]}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "559", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"176", ",", "192", ",", "387", ",", "989"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"6", "+", 
        SqrtBox["2"], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", "+", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "174", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["25", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "987", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"1169", "-", 
        RowBox[{"672", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"33178", "-", 
           RowBox[{"23201", " ", 
            SqrtBox["2"]}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "180", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["3", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"5", "+", 
        RowBox[{"3", " ", 
         SqrtBox["2"]}], "-", 
        SqrtBox[
         RowBox[{"3", " ", 
          RowBox[{"(", 
           RowBox[{"3", "+", 
            RowBox[{"2", " ", 
             SqrtBox["2"]}]}], ")"}]}]]}], ")"}]}], ",", 
     RowBox[{"{", "554", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "995", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"163", "+", 
        RowBox[{"18", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "869", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "18"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "57"}], "+", 
        RowBox[{"40", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "872", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", 
     RowBox[{"{", 
      RowBox[{
      "5", ",", "6", ",", "169", ",", "226", ",", "344", ",", "389", ",", 
       "402", ",", "482", ",", "485", ",", "494", ",", "578", ",", "620", ",",
        "642", ",", "942"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["9", "16"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "757", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "985", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"13", "+", 
        RowBox[{"9", " ", 
         SqrtBox["2"]}], "-", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"58", "+", 
           RowBox[{"41", " ", 
            SqrtBox["2"]}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "177", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "98"], " ", 
      RowBox[{"(", 
       RowBox[{"561", "+", 
        RowBox[{"184", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "89", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"10", "+", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}], "-", 
      SqrtBox[
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"17", "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}]]}], ",", 
     RowBox[{"{", "202", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"17", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"82", ",", "388"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"113", "+", 
        RowBox[{"72", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "999", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", "+", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SqrtBox["2"]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "509", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", 
     RowBox[{"{", "983", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "9"], " ", 
      RowBox[{"(", 
       RowBox[{"27", "+", 
        RowBox[{"10", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "904", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"7", "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"2", "-", 
           SqrtBox["2"]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "173", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "33"}], "+", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"213", ",", "605"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"26", "+", 
        RowBox[{"7", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "303", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "58", ",", "614", ",", "951"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "11"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "172", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "64"], " ", 
      RowBox[{"(", 
       RowBox[{"387", "+", 
        RowBox[{"182", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "763", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["81", "8"], ",", 
     RowBox[{"{", "598", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"177", "+", 
        RowBox[{"52", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "967", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"19", "-", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"43", ",", "937"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", "+", 
      SqrtBox["2"], "+", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"2", "+", 
           SqrtBox["2"]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "266", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["36", "49"], " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "553", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"8", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "948", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "13", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "34"}], "-", 
        RowBox[{"23", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"58", "+", 
             RowBox[{"41", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "234", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "31", ",", "65", ",", "355", ",", "602", ",", "774", ",", "855", ",", 
       "945", ",", "998"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "8"], " ", 
      RowBox[{"(", 
       RowBox[{"57", "+", 
        RowBox[{"28", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "593", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"97", "-", 
      RowBox[{"60", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", "609", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["25", "2"], ",", 
     RowBox[{"{", 
      RowBox[{"194", ",", "251", ",", "262"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["9", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"229", ",", "959"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"18", "+", 
        RowBox[{"7", " ", 
         SqrtBox["2"]}], "+", 
        RowBox[{"4", " ", 
         SqrtBox[
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{"10", "+", 
             RowBox[{"7", " ", 
              SqrtBox["2"]}]}], ")"}]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "555", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["2", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"13", "+", 
        RowBox[{"4", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "397", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "41"}], "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "181", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", "+", 
      RowBox[{"4", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"57", ",", "79", ",", "379"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["25", "32"], " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "552", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"19", "+", 
        RowBox[{"8", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", 
     RowBox[{"{", "628", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"11", "+", 
      RowBox[{"2", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox[
        RowBox[{"2", "-", 
         SqrtBox["2"]}]]}]}], ",", 
     RowBox[{"{", "361", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"17", "+", 
        RowBox[{"12", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"145", ",", "595", ",", "961", ",", "994"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"18", "+", 
        SqrtBox["2"], "+", 
        RowBox[{"8", " ", 
         SqrtBox[
          RowBox[{"2", "+", 
           SqrtBox["2"]}]]}]}], ")"}]}], ",", 
     RowBox[{"{", "558", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"18", ",", 
     RowBox[{"{", 
      RowBox[{
      "32", ",", "51", ",", "195", ",", "218", ",", "381", ",", "568", ",", 
       "800", ",", "864", ",", "973"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "4"], " ", 
      RowBox[{"(", 
       RowBox[{"41", "+", 
        RowBox[{"24", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "849", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"14", "+", 
      RowBox[{"5", " ", 
       SqrtBox["3"]}]}], ",", 
     RowBox[{"{", "62", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
      "56", ",", "214", ",", "215", ",", "481", ",", "502", ",", "946", ",", 
       "990"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"10", "+", 
      RowBox[{"6", " ", 
       SqrtBox["2"]}], "+", 
      SqrtBox[
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"17", "+", 
          RowBox[{"12", " ", 
           SqrtBox["2"]}]}], ")"}]}]]}], ",", 
     RowBox[{"{", "203", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"9", "+", 
        RowBox[{"4", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"560", ",", "678", ",", "854"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"33", "+", 
        RowBox[{"20", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "279", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"32", ",", 
     RowBox[{"{", 
      RowBox[{"143", ",", "263", ",", "546", ",", "576"}], "}"}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"11", "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"583", ",", "604"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"43", "+", 
        RowBox[{"30", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "957", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"12", " ", 
      RowBox[{"(", 
       RowBox[{"2", "+", 
        SqrtBox["3"]}], ")"}]}], ",", 
     RowBox[{"{", "619", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"9", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"267", ",", "269", ",", "978"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "139"}], "+", 
        RowBox[{"66", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "600", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"131", "+", 
        RowBox[{"90", " ", 
         SqrtBox["2"]}]}], ")"}]}], ",", 
     RowBox[{"{", "479", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"47", "+", 
      RowBox[{"32", " ", 
       SqrtBox["2"]}], "+", 
      RowBox[{"6", " ", 
       SqrtBox[
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{"58", "+", 
           RowBox[{"41", " ", 
            SqrtBox["2"]}]}], ")"}]}]]}]}], ",", 
     RowBox[{"{", "505", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"121", "+", 
      RowBox[{"84", " ", 
       SqrtBox["2"]}]}], ",", 
     RowBox[{"{", "738", "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.859213791273181*^9, 3.859213901834807*^9, 
  3.859213945632371*^9, 3.859909461854007*^9, 3.861097968839882*^9},
 CellLabel->
  "Out[183]=",ExpressionUUID->"dc8d5f7d-cb5f-4946-8b8c-d2a81cc27c2c"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Transcendental centers. Theorems 7.33 and 7.34:  X(356), X(357), X(358), \
X(359), X(360)\
\>", "Subsubsection",
 CellChangeTimes->{{3.859407655311322*^9, 3.859407764084786*^9}, {
  3.8594078012932997`*^9, 3.8594078070129013`*^9}, {3.8610903986358557`*^9, 
  3.861090401994954*^9}},ExpressionUUID->"e44758e3-5ba0-41c5-ab5f-\
7524e2251187"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"xf", "[", "356", "]"}], "=", 
   RowBox[{
    RowBox[{"a", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"A", "/", "3"}], "]"}]}], "+", 
    RowBox[{"2", "a", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"B", "/", "3"}], "]"}], 
     RowBox[{"Cos", "[", 
      RowBox[{"C", "/", "3"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xf", "[", "357", "]"}], "=", 
   RowBox[{"a", " ", 
    RowBox[{"Sec", "[", 
     RowBox[{"A", "/", "3"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xf", "[", "358", "]"}], "=", 
   RowBox[{"a", " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"A", "/", "3"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xf", "[", "359", "]"}], "=", 
   RowBox[{
    RowBox[{"a", "^", "2"}], "/", "A"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xf", "[", "360", "]"}], "=", "A"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xf", "[", "848", "]"}], "=", 
   RowBox[{"1", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Cot", "[", "A", "]"}], "-", 
      RowBox[{
       RowBox[{"Cot", "[", 
        RowBox[{"2", "a", " ", "\[Pi]"}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "c"}], ")"}]}]}], ")"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.8593029020063066`*^9, 3.8593030589628687`*^9}, {
  3.859303158420253*^9, 3.8593031891153*^9}, {3.859303307644094*^9, 
  3.85930336439703*^9}, {3.859303994686549*^9, 3.859303995103428*^9}},
 CellLabel->
  "In[184]:=",ExpressionUUID->"9ff275d5-5d7c-4d9d-bf9b-7d39e4422ab5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"transPairs", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"trans", "[", 
    RowBox[{"n_", ",", "fna_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "fnb", ",", "fnc", ",", "u", ",", "v", ",", "w", ",", "ratio", ",", 
       "aratio", ",", "areaRatio"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"fnb", "=", 
       RowBox[{"fna", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"a", "\[Rule]", "b"}], ",", 
          RowBox[{"b", "\[Rule]", "c"}], ",", 
          RowBox[{"c", "\[Rule]", "a"}], ",", 
          RowBox[{"A", "\[Rule]", "B"}], ",", 
          RowBox[{"B", "\[Rule]", "C"}], ",", 
          RowBox[{"C", "\[Rule]", "A"}]}], "}"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"fnc", "=", 
       RowBox[{"fnb", "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"a", "\[Rule]", "b"}], ",", 
          RowBox[{"b", "\[Rule]", "c"}], ",", 
          RowBox[{"c", "\[Rule]", "a"}], ",", 
          RowBox[{"A", "\[Rule]", "B"}], ",", 
          RowBox[{"B", "\[Rule]", "C"}], ",", 
          RowBox[{"C", "\[Rule]", "A"}]}], "}"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
       RowBox[{"{", 
        RowBox[{"fna", ",", "fnb", ",", "fnc"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"ratio", " ", "=", " ", 
        RowBox[{"XM", "/", "AM"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"ratio", "=", 
       RowBox[{"FullSimplify", "[", 
        RowBox[{
         RowBox[{"u", "/", 
          RowBox[{"(", 
           RowBox[{"u", "+", 
            RowBox[{"2", "v"}]}], ")"}]}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"a", "\[Rule]", 
            RowBox[{"Sqrt", "[", "2", "]"}]}], ",", 
           RowBox[{"b", "\[Rule]", "1"}], ",", 
           RowBox[{"c", "\[Rule]", "1"}], ",", 
           RowBox[{"A", "\[Rule]", 
            RowBox[{"\[Pi]", "/", "2"}]}], ",", 
           RowBox[{"B", "->", 
            RowBox[{"\[Pi]", "/", "4"}]}], ",", 
           RowBox[{"C", "->", 
            RowBox[{"\[Pi]", "/", "4"}]}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"areaRatio", " ", "=", " ", 
        RowBox[{"ABCD", "/", "FGHI"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"aRatio", "=", 
       RowBox[{"2", "/", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "ratio"}], ")"}], "^", "2"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"areaRatio", " ", "=", 
       RowBox[{"Together", "[", 
        RowBox[{"ToRadicals", "[", 
         RowBox[{"RootReduce", "[", "aRatio", "]"}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "areaRatio", "]"}], "===", "Root"}], ",", 
        RowBox[{"areaRatio", "=", 
         RowBox[{"Together", "[", 
          RowBox[{"ToRadicals", "[", "aRatio", "]"}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"NumericQ", "[", "areaRatio", "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"AppendTo", "[", 
         RowBox[{"transPairs", ",", 
          RowBox[{"{", 
           RowBox[{"areaRatio", ",", "n"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{
         "\"\<Bug for n=\>\"", ",", "n", ",", "\"\<  areaRatio=\>\"", ",", 
          "areaRatio"}], "]"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.859303720617717*^9, 3.859304120912403*^9}, {
  3.859304378944426*^9, 3.859304410649478*^9}, {3.859304849578999*^9, 
  3.859304856594668*^9}, {3.859305004467675*^9, 3.859305010090642*^9}, {
  3.85930525890699*^9, 3.8593053557482347`*^9}},
 CellLabel->
  "In[190]:=",ExpressionUUID->"8b88a03f-6e19-49aa-9c30-ffde68eede0f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"trans", "[", 
   RowBox[{"356", ",", 
    RowBox[{"xf", "[", "356", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trans", "[", 
   RowBox[{"357", ",", 
    RowBox[{"xf", "[", "357", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trans", "[", 
   RowBox[{"358", ",", 
    RowBox[{"xf", "[", "358", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trans", "[", 
   RowBox[{"359", ",", 
    RowBox[{"xf", "[", "359", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trans", "[", 
   RowBox[{"360", ",", 
    RowBox[{"xf", "[", "360", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trans", "[", 
   RowBox[{"848", ",", 
    RowBox[{"xf", "[", "848", "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.85930413666503*^9, 3.859304156271596*^9}, {
  3.85930503855514*^9, 3.859305090201524*^9}},
 CellLabel->
  "In[192]:=",ExpressionUUID->"67792618-1ad4-40f4-a788-24eaccb9c79f"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \\\"0\\\"]\\) \
encountered.\"",2,197,1,32009855945572602238,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.8594080822624807`*^9, 3.859408104964313*^9}, 
   3.859909462992258*^9, 3.861097968965014*^9},
 CellLabel->
  "During evaluation of \
In[192]:=",ExpressionUUID->"c58a5183-c2a4-4278-bf9c-b9613cd308cc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Bug for n=\"\>", "\[InvisibleSpace]", "848", 
   "\[InvisibleSpace]", "\<\"  areaRatio=\"\>", "\[InvisibleSpace]", 
   "ComplexInfinity"}],
  SequenceForm["Bug for n=", 848, "  areaRatio=", 
   DirectedInfinity[]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.859408082272641*^9, 3.859408104971702*^9}, 
   3.859909462994972*^9, 3.8610979689752693`*^9},
 CellLabel->
  "During evaluation of \
In[192]:=",ExpressionUUID->"05c6f870-2535-4c3f-a882-bd8b90a9a24a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"X", 
   RowBox[{"(", "848", ")"}], " ", "us", " ", "at", " ", "infinity"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.859407735119081*^9, 3.859407746844798*^9}},
 CellLabel->
  "In[198]:=",ExpressionUUID->"4672a498-0912-4829-956f-348fb3a88eeb"],

Cell[CellGroupData[{

Cell[BoxData["transPairs"], "Input",
 CellLabel->
  "In[199]:=",ExpressionUUID->"d3962030-db04-4cf8-94c6-35c60ac4f231"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"6", ",", "356"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      FractionBox["1", "3"], " ", 
      RowBox[{"(", 
       RowBox[{"14", "+", 
        RowBox[{"3", " ", 
         SqrtBox["3"]}]}], ")"}]}], ",", "357"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"14", "-", 
      RowBox[{"5", " ", 
       SqrtBox["3"]}]}], ",", "358"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["9", "2"], ",", "359"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "360"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.859304993014624*^9, 3.8593050270376863`*^9}, 
   3.859305366482616*^9, {3.859408085911242*^9, 3.859408107893722*^9}, 
   3.859909463097431*^9, 3.861097969019895*^9},
 CellLabel->
  "Out[199]=",ExpressionUUID->"f7e940da-2589-4ea3-a02d-8cd713e68fee"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Theorem 7.34 for X (369)", "Subsubsection",
 CellChangeTimes->{{3.859407832471489*^9, 3.8594078493511143`*^9}, {
  3.86109061594007*^9, 
  3.8610906356677303`*^9}},ExpressionUUID->"7015cd4e-bbce-462f-ae74-\
f18ff1e388b9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cubic", "=", 
  RowBox[{
   RowBox[{"2", 
    RowBox[{"t", "^", "3"}]}], "-", 
   RowBox[{"3", 
    RowBox[{"(", 
     RowBox[{"a", "+", "b", "+", "c"}], ")"}], 
    RowBox[{"t", "^", "2"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "^", "2"}], "+", 
      RowBox[{"b", "^", "2"}], "+", 
      RowBox[{"c", "^", "2"}], "+", 
      RowBox[{"8", "b", " ", "c"}], "+", 
      RowBox[{"8", "c", " ", "a"}], "+", 
      RowBox[{"8", "a", " ", "b"}]}], ")"}], "t"}], "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"c", " ", 
      RowBox[{"b", "^", "2"}]}], "+", 
     RowBox[{"a", " ", 
      RowBox[{"c", "^", "2"}]}], "+", 
     RowBox[{"b", " ", 
      RowBox[{"a", "^", "2"}]}], "+", 
     RowBox[{"5", "b", " ", 
      RowBox[{"c", "^", "2"}]}], "+", 
     RowBox[{"5", "c", " ", 
      RowBox[{"a", "^", "2"}]}], "+", 
     RowBox[{"5", "a", " ", 
      RowBox[{"b", "^", "2"}]}], "+", 
     RowBox[{"9", "a", " ", "b", " ", "c"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.859365517613697*^9, 3.85936558107847*^9}},
 CellLabel->
  "In[200]:=",ExpressionUUID->"13c82cec-1f8a-4683-b3bf-c51c268e4140"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["a", "2"]}], " ", "b"}], "-", 
  RowBox[{"5", " ", "a", " ", 
   SuperscriptBox["b", "2"]}], "-", 
  RowBox[{"5", " ", 
   SuperscriptBox["a", "2"], " ", "c"}], "-", 
  RowBox[{"9", " ", "a", " ", "b", " ", "c"}], "-", 
  RowBox[{
   SuperscriptBox["b", "2"], " ", "c"}], "-", 
  RowBox[{"a", " ", 
   SuperscriptBox["c", "2"]}], "-", 
  RowBox[{"5", " ", "b", " ", 
   SuperscriptBox["c", "2"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["a", "2"], "+", 
     RowBox[{"8", " ", "a", " ", "b"}], "+", 
     SuperscriptBox["b", "2"], "+", 
     RowBox[{"8", " ", "a", " ", "c"}], "+", 
     RowBox[{"8", " ", "b", " ", "c"}], "+", 
     SuperscriptBox["c", "2"]}], ")"}], " ", "t"}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{"a", "+", "b", "+", "c"}], ")"}], " ", 
   SuperscriptBox["t", "2"]}], "+", 
  RowBox[{"2", " ", 
   SuperscriptBox["t", "3"]}]}]], "Output",
 CellChangeTimes->{3.8593655822062683`*^9, 3.85940800246469*^9, 
  3.8599094631093082`*^9, 3.861097969030881*^9},
 CellLabel->
  "Out[200]=",ExpressionUUID->"4c557de8-6272-4b2f-b1ea-488459521534"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ans", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"cubic", "\[Equal]", "0"}], ",", "t"}], "]"}], "//", "First"}], 
   "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.8593656022918863`*^9, 3.859365630438304*^9}, {
  3.859365661095978*^9, 3.859365716926646*^9}, {3.859365801152079*^9, 
  3.85936580455914*^9}},
 CellLabel->
  "In[201]:=",ExpressionUUID->"c61c5ee5-68f5-49d3-9bfb-133d18b30677"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"t", "\[Rule]", 
   RowBox[{
    FractionBox["1", "6"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"a", "+", "b", "+", "c"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["3", 
          RowBox[{"2", "/", "3"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["a", "2"], "+", 
           SuperscriptBox["b", "2"], "-", 
           RowBox[{"10", " ", "b", " ", "c"}], "+", 
           SuperscriptBox["c", "2"], "-", 
           RowBox[{"10", " ", "a", " ", 
            RowBox[{"(", 
             RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ")"}], "/", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "36"}], " ", 
           SuperscriptBox["a", "2"], " ", "b"}], "+", 
          RowBox[{"36", " ", "a", " ", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{"36", " ", 
           SuperscriptBox["a", "2"], " ", "c"}], "-", 
          RowBox[{"36", " ", 
           SuperscriptBox["b", "2"], " ", "c"}], "-", 
          RowBox[{"36", " ", "a", " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{"36", " ", "b", " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{
           FractionBox["1", "6"], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"46656", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"a", "-", "c"}], ")"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"b", "-", "c"}], ")"}], "2"]}], "-", 
             RowBox[{"108", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["a", "2"], "+", 
                 SuperscriptBox["b", "2"], "-", 
                 RowBox[{"10", " ", "b", " ", "c"}], "+", 
                 SuperscriptBox["c", "2"], "-", 
                 RowBox[{"10", " ", "a", " ", 
                  RowBox[{"(", 
                   RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}], "3"]}]}]]}]}], 
         ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{
       SuperscriptBox["3", 
        RowBox[{"1", "/", "3"}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "36"}], " ", 
           SuperscriptBox["a", "2"], " ", "b"}], "+", 
          RowBox[{"36", " ", "a", " ", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{"36", " ", 
           SuperscriptBox["a", "2"], " ", "c"}], "-", 
          RowBox[{"36", " ", 
           SuperscriptBox["b", "2"], " ", "c"}], "-", 
          RowBox[{"36", " ", "a", " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{"36", " ", "b", " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{
           FractionBox["1", "6"], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"46656", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"a", "-", "c"}], ")"}], "2"], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"b", "-", "c"}], ")"}], "2"]}], "-", 
             RowBox[{"108", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["a", "2"], "+", 
                 SuperscriptBox["b", "2"], "-", 
                 RowBox[{"10", " ", "b", " ", "c"}], "+", 
                 SuperscriptBox["c", "2"], "-", 
                 RowBox[{"10", " ", "a", " ", 
                  RowBox[{"(", 
                   RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}], "3"]}]}]]}]}], 
         ")"}], 
        RowBox[{"1", "/", "3"}]]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.859365617979039*^9, 3.8593656322205973`*^9}, {
   3.859365662871648*^9, 3.859365718788138*^9}, 3.859365805504856*^9, 
   3.859408006643456*^9, 3.859909463602314*^9, 3.8610979695291357`*^9},
 CellLabel->
  "Out[201]=",ExpressionUUID->"88dcd874-4906-47b1-848b-9c6694315479"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tt", "=", 
  RowBox[{"t", "/.", "ans"}]}]], "Input",
 CellChangeTimes->{{3.8593658228039503`*^9, 3.85936583303924*^9}},
 CellLabel->
  "In[202]:=",ExpressionUUID->"4500b6a6-b102-4a63-8be2-00a5e40d0ad3"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "6"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"3", " ", 
     RowBox[{"(", 
      RowBox[{"a", "+", "b", "+", "c"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["3", 
        RowBox[{"2", "/", "3"}]], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "2"], "+", 
         SuperscriptBox["b", "2"], "-", 
         RowBox[{"10", " ", "b", " ", "c"}], "+", 
         SuperscriptBox["c", "2"], "-", 
         RowBox[{"10", " ", "a", " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}]}], ")"}], "/", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "36"}], " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"36", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"36", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"36", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"36", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"36", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         FractionBox["1", "6"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"46656", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "c"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}], "2"]}], "-", 
           RowBox[{"108", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               SuperscriptBox["b", "2"], "-", 
               RowBox[{"10", " ", "b", " ", "c"}], "+", 
               SuperscriptBox["c", "2"], "-", 
               RowBox[{"10", " ", "a", " ", 
                RowBox[{"(", 
                 RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}], "3"]}]}]]}]}], 
       ")"}], 
      RowBox[{"1", "/", "3"}]]}], "+", 
    RowBox[{
     SuperscriptBox["3", 
      RowBox[{"1", "/", "3"}]], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "36"}], " ", 
         SuperscriptBox["a", "2"], " ", "b"}], "+", 
        RowBox[{"36", " ", "a", " ", 
         SuperscriptBox["b", "2"]}], "+", 
        RowBox[{"36", " ", 
         SuperscriptBox["a", "2"], " ", "c"}], "-", 
        RowBox[{"36", " ", 
         SuperscriptBox["b", "2"], " ", "c"}], "-", 
        RowBox[{"36", " ", "a", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{"36", " ", "b", " ", 
         SuperscriptBox["c", "2"]}], "+", 
        RowBox[{
         FractionBox["1", "6"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"46656", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"a", "-", "c"}], ")"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"b", "-", "c"}], ")"}], "2"]}], "-", 
           RowBox[{"108", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["a", "2"], "+", 
               SuperscriptBox["b", "2"], "-", 
               RowBox[{"10", " ", "b", " ", "c"}], "+", 
               SuperscriptBox["c", "2"], "-", 
               RowBox[{"10", " ", "a", " ", 
                RowBox[{"(", 
                 RowBox[{"b", "+", "c"}], ")"}]}]}], ")"}], "3"]}]}]]}]}], 
       ")"}], 
      RowBox[{"1", "/", "3"}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8593658357271338`*^9, 3.859408011503199*^9, 
  3.859408132434885*^9, 3.859909463743462*^9, 3.861097969541833*^9},
 CellLabel->
  "Out[202]=",ExpressionUUID->"dcc1efe5-3412-4047-8138-6e5521cdb89d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"xf", "[", "369", "]"}], "=", 
   RowBox[{"b", " ", "c", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"tt", "^", "2"}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "c"}], "+", "a"}], ")"}], "tt"}], "+", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"a", "^", "2"}]}], "+", 
        RowBox[{"b", "^", "2"}], "+", 
        RowBox[{"2", 
         RowBox[{"c", "^", "2"}]}], "+", 
        RowBox[{"2", "b", " ", "c"}], "+", 
        RowBox[{"3", " ", "c", " ", "a"}], "+", 
        RowBox[{"2", " ", "a", " ", "b"}]}], ")"}]}], ")"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8593658585404997`*^9, 3.85936586627955*^9}, {
  3.859365899431513*^9, 3.859366006240841*^9}, {3.859366075457758*^9, 
  3.859366083824065*^9}},
 CellLabel->
  "In[203]:=",ExpressionUUID->"08e6b139-e1b0-497f-a406-92534437e377"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"transPairs", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"trans", "[", 
   RowBox[{"369", ",", 
    RowBox[{"xf", "[", "369", "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.859366116472176*^9, 3.859366118583824*^9}, {
  3.8594079582305727`*^9, 3.859407962493496*^9}},
 CellLabel->
  "In[204]:=",ExpressionUUID->"71cfc4ae-227a-4bf8-a806-9979f307be05"],

Cell[CellGroupData[{

Cell[BoxData["transPairs"], "Input",
 CellLabel->
  "In[206]:=",ExpressionUUID->"36a42698-acda-424f-ad34-4b7a2dd3674d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     FractionBox["1", "4"], " ", 
     RowBox[{"(", 
      RowBox[{"27", "-", 
       RowBox[{"10", " ", 
        SqrtBox["2"]}]}], ")"}]}], ",", "369"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.859366131792985*^9, 3.8594079680751953`*^9, 
  3.8594081446738567`*^9, 3.8599094641721773`*^9, 3.861097970021845*^9},
 CellLabel->
  "Out[206]=",ExpressionUUID->"3a312f8e-015c-40ed-80f2-5cf55d401ab7"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Section 8 (Poncelet Point)", "Section",
 CellChangeTimes->{{3.859883929984612*^9, 
  3.8598839588801727`*^9}},ExpressionUUID->"40c866aa-5b4a-4dd4-b828-\
5d2b26a83d85"],

Cell[CellGroupData[{

Cell["Theorem 8.6 for X(20)", "Subsubsection",
 CellChangeTimes->{{3.861092101327636*^9, 3.861092118004346*^9}, 
   3.861092237320634*^9},ExpressionUUID->"6bd6873f-0240-4df3-8034-\
fd4dd83fab4a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ptA", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptB", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptC", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptD", "=", 
   RowBox[{"{", 
    RowBox[{"p", ",", "q", ",", "r"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptE", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", 
      RowBox[{"q", "+", "1"}], ",", "r"}], "}"}], "/", "2"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.8598960942203836`*^9, 3.8598961113399277`*^9}, {
  3.8599058266281443`*^9, 3.859905840075061*^9}, {3.859907556010416*^9, 
  3.859907562296378*^9}, {3.859907658009869*^9, 3.859907658760771*^9}, {
  3.859919404483058*^9, 3.859919404966362*^9}},
 CellLabel->
  "In[307]:=",ExpressionUUID->"cf35f498-bd63-48b2-b491-9caa2a72d3cb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"AB", "=", "c"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BC", "=", "a"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AC", "=", "b"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8598849566661787`*^9, 3.8598849745761538`*^9}},
 CellLabel->
  "In[312]:=",ExpressionUUID->"9bf9ebcb-3a3f-409b-9ac2-165f2a887b3f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AD", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"dist", "[", 
     RowBox[{"ptA", ",", "ptD"}], "]"}], ",", 
    RowBox[{
     RowBox[{"p", "+", "q", "+", "r"}], "\[Equal]", "1"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.859884305435573*^9, 3.8598843604704123`*^9}},
 CellLabel->
  "In[315]:=",ExpressionUUID->"0614b4a9-801a-47ad-9a9c-3cb6a1a4b7e7"],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], " ", "q", " ", "r"}], "+", 
   RowBox[{
    SuperscriptBox["c", "2"], " ", "q", " ", 
    RowBox[{"(", 
     RowBox[{"q", "+", "r"}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["b", "2"], " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{"q", "+", "r"}], ")"}]}]}]]], "Output",
 CellChangeTimes->{{3.859884330991843*^9, 3.859884365038508*^9}, 
   3.8598961941392193`*^9, 3.8599058583954573`*^9, 3.859907679304521*^9, 
   3.8599094657243*^9, 3.8599160309379063`*^9, 3.859918765979039*^9, 
   3.859919414332301*^9, 3.8610979701225157`*^9, 3.861098347031227*^9},
 CellLabel->
  "Out[315]=",ExpressionUUID->"10129aee-4a47-44c8-9791-23d6c31b2285"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BD", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"dist", "[", 
     RowBox[{"ptB", ",", "ptD"}], "]"}], ",", 
    RowBox[{
     RowBox[{"p", "+", "q", "+", "r"}], "\[Equal]", "1"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.859884377390752*^9, 3.859884382446802*^9}},
 CellLabel->
  "In[316]:=",ExpressionUUID->"88fda2c7-baf5-4b40-8cb4-bd91e5b09e3d"],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["b", "2"]}], " ", "p", " ", "r"}], "+", 
   RowBox[{
    SuperscriptBox["c", "2"], " ", "p", " ", 
    RowBox[{"(", 
     RowBox[{"p", "+", "r"}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", "r", " ", 
    RowBox[{"(", 
     RowBox[{"p", "+", "r"}], ")"}]}]}]]], "Output",
 CellChangeTimes->{3.8598843834313507`*^9, 3.85989619748947*^9, 
  3.859905861423897*^9, 3.859907679364189*^9, 3.8599094658332577`*^9, 
  3.859916031074421*^9, 3.859918766040824*^9, 3.859919414392651*^9, 
  3.861097970189047*^9, 3.861098349467259*^9},
 CellLabel->
  "Out[316]=",ExpressionUUID->"4d191765-6af1-4553-b0b2-aa890c7a7569"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CD", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"dist", "[", 
     RowBox[{"ptC", ",", "ptD"}], "]"}], ",", 
    RowBox[{
     RowBox[{"p", "+", "q", "+", "r"}], "\[Equal]", "1"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.85988439257484*^9, 3.8598843986944857`*^9}},
 CellLabel->
  "In[317]:=",ExpressionUUID->"95880559-62a4-4f20-8f34-9da94f2db1e6"],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["c", "2"]}], " ", "p", " ", "q"}], "+", 
   RowBox[{
    SuperscriptBox["b", "2"], " ", "p", " ", 
    RowBox[{"(", 
     RowBox[{"p", "+", "q"}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", "q", " ", 
    RowBox[{"(", 
     RowBox[{"p", "+", "q"}], ")"}]}]}]]], "Output",
 CellChangeTimes->{3.85988439973529*^9, 3.8598962003959312`*^9, 
  3.859905864234151*^9, 3.859907679419112*^9, 3.859909465903405*^9, 
  3.859916031148778*^9, 3.859918766100086*^9, 3.859919414456407*^9, 
  3.8610979702545443`*^9, 3.861098351784876*^9},
 CellLabel->
  "Out[317]=",ExpressionUUID->"4b66a390-ac7d-4d01-addb-ddfefe50abda"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AE", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"dist", "[", 
     RowBox[{"ptA", ",", "ptE"}], "]"}], ",", 
    RowBox[{
     RowBox[{"p", "+", "q", "+", "r"}], "\[Equal]", "1"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.859884417070907*^9, 3.859884423438868*^9}},
 CellLabel->
  "In[318]:=",ExpressionUUID->"618ea4b7-b95f-447b-8c9d-597328070e1d"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SqrtBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "2"]}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "q"}], ")"}], " ", "r"}], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "q"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "q", "+", "r"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "q", "+", "r"}], ")"}]}]}]]}]], "Output",
 CellChangeTimes->{3.8598844253989353`*^9, 3.859896204455975*^9, 
  3.859905868830893*^9, 3.859907568570179*^9, 3.859907679494277*^9, 
  3.8599094659918547`*^9, 3.8599160312274237`*^9, 3.8599187661663847`*^9, 
  3.859919414516241*^9, 3.8610979703365097`*^9, 3.861098354457533*^9},
 CellLabel->
  "Out[318]=",ExpressionUUID->"eecc9fd3-0d91-4c3f-851a-f07d1d1f414f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BE", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"dist", "[", 
     RowBox[{"ptB", ",", "ptE"}], "]"}], ",", 
    RowBox[{
     RowBox[{"p", "+", "q", "+", "r"}], "\[Equal]", "1"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.859884442630988*^9, 3.8598844468151703`*^9}},
 CellLabel->
  "In[319]:=",ExpressionUUID->"9aa6733d-b244-4a44-9905-cf4456198df2"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SqrtBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "2"]}], " ", "p", " ", "r"}], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", "p", " ", 
     RowBox[{"(", 
      RowBox[{"p", "+", "r"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{"p", "+", "r"}], ")"}]}]}]]}]], "Output",
 CellChangeTimes->{3.859884448628995*^9, 3.8598962112709093`*^9, 
  3.859905879800148*^9, 3.859907572114275*^9, 3.8599076795473013`*^9, 
  3.859909466098506*^9, 3.859916031306073*^9, 3.859918766229424*^9, 
  3.859919414581883*^9, 3.8610979703977222`*^9, 3.861098356857904*^9},
 CellLabel->
  "Out[319]=",ExpressionUUID->"36632e80-d1a8-41d7-b45c-fa1bb959d9f4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CE", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"dist", "[", 
     RowBox[{"ptC", ",", "ptE"}], "]"}], ",", 
    RowBox[{
     RowBox[{"p", "+", "q", "+", "r"}], "\[Equal]", "1"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.859884458407199*^9, 3.859884462487104*^9}},
 CellLabel->
  "In[320]:=",ExpressionUUID->"fa8043ff-112c-461f-b64b-7fe1e0b2af49"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SqrtBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["c", "2"]}], " ", "p", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "q"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", "p", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "p", "+", "q"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "q"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "p", "+", "q"}], ")"}]}]}]]}]], "Output",
 CellChangeTimes->{3.859884464344166*^9, 3.859896216151741*^9, 
  3.859905884439699*^9, 3.859907575706057*^9, 3.859907679627594*^9, 
  3.85990946619378*^9, 3.859916031397286*^9, 3.859918766298291*^9, 
  3.859919414656028*^9, 3.861097970486197*^9, 3.861098359234153*^9},
 CellLabel->
  "Out[320]=",ExpressionUUID->"c5da08f4-af94-495d-ab89-3a3e9a6fd131"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DE", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"dist", "[", 
     RowBox[{"ptD", ",", "ptE"}], "]"}], ",", 
    RowBox[{
     RowBox[{"p", "+", "q", "+", "r"}], "\[Equal]", "1"}]}], "]"}]}]], "Input",\

 CellChangeTimes->{{3.8598844723274384`*^9, 3.859884476679422*^9}},
 CellLabel->
  "In[321]:=",ExpressionUUID->"87f200f2-6308-4873-8ba0-a305c8c7ec54"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SqrtBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "2"]}], " ", "p", " ", "r"}], "+", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", "p", " ", 
     RowBox[{"(", 
      RowBox[{"p", "+", "r"}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", "r", " ", 
     RowBox[{"(", 
      RowBox[{"p", "+", "r"}], ")"}]}]}]]}]], "Output",
 CellChangeTimes->{3.859884480286139*^9, 3.859896221798538*^9, 
  3.85990588906975*^9, 3.8599075786952744`*^9, 3.85990767968159*^9, 
  3.859909466269507*^9, 3.859916031473949*^9, 3.859918766355166*^9, 
  3.859919414716413*^9, 3.8610979705522003`*^9, 3.861098361832274*^9},
 CellLabel->
  "Out[321]=",ExpressionUUID->"fe36bb19-4ec2-4594-b536-2649a98d144e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x20", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["a", "4"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "-", 
     SuperscriptBox["b", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["c", "4"]}], ",", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "4"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["b", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     SuperscriptBox["c", "4"]}], ",", 
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["a", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["b", "2"]}], "-", 
     SuperscriptBox["b", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["a", "2"], " ", 
      SuperscriptBox["c", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"], " ", 
      SuperscriptBox["c", "2"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["c", "4"]}]}]}], "}"}]}]], "Input",
 CellLabel->
  "In[322]:=",ExpressionUUID->"2618993f-47f2-4e88-a41f-aa54090c50e7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["a", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    SuperscriptBox["b", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    SuperscriptBox["c", "4"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["b", "4"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    SuperscriptBox["c", "4"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], "-", 
    SuperscriptBox["b", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["c", "2"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["c", "4"]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8598848846266603`*^9, 3.859896282760206*^9, 
  3.859900142083308*^9, 3.8599058984658117`*^9, 3.8599076796927834`*^9, 
  3.859909466282934*^9, 3.8599160314863443`*^9, 3.859918766363327*^9, 
  3.859919414724506*^9, 3.861097970562991*^9, 3.8610983660523252`*^9},
 CellLabel->
  "Out[322]=",ExpressionUUID->"8aa55efb-a8b4-48ac-8489-241cbec60218"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"x20n", "=", 
   RowBox[{"normed", "[", "x20", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.859916441135846*^9, 3.85991644954074*^9}, 
   3.859918641748863*^9},
 CellLabel->
  "In[323]:=",ExpressionUUID->"9348783e-2593-4190-a27d-ff071608b1b8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ptF", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x20n", ".", 
      RowBox[{"{", 
       RowBox[{"ptA", ",", "ptB", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "BE"}], ",", 
       RowBox[{"b", "\[Rule]", "AE"}], ",", 
       RowBox[{"c", "\[Rule]", "AB"}]}], "}"}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptG", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x20n", ".", 
      RowBox[{"{", 
       RowBox[{"ptB", ",", "ptC", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "CE"}], ",", 
       RowBox[{"b", "\[Rule]", "BE"}], ",", 
       RowBox[{"c", "\[Rule]", "BC"}]}], "}"}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptH", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x20n", ".", 
      RowBox[{"{", 
       RowBox[{"ptC", ",", "ptD", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "DE"}], ",", 
       RowBox[{"b", "\[Rule]", "CE"}], ",", 
       RowBox[{"c", "\[Rule]", "CD"}]}], "}"}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptI", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x20n", ".", 
      RowBox[{"{", 
       RowBox[{"ptD", ",", "ptA", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "AE"}], ",", 
       RowBox[{"b", "\[Rule]", "DE"}], ",", 
       RowBox[{"c", "\[Rule]", "AD"}]}], "}"}]}], "//", "Simplify"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.859884894408589*^9, 3.8598849468882437`*^9}, {
  3.8599164610144653`*^9, 3.8599164690613337`*^9}},
 CellLabel->
  "In[324]:=",ExpressionUUID->"1cbe7926-0cff-4740-923a-1d1513c57b44"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaABC", "=", 
  RowBox[{"baryArea", "[", 
   RowBox[{"ptA", ",", "ptB", ",", "ptC"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.857827314751285*^9, 3.857827349150406*^9}},
 CellLabel->
  "In[328]:=",ExpressionUUID->"dd1ef155-d244-4130-b671-fc17e9ef9126"],

Cell[BoxData["K"], "Output",
 CellChangeTimes->{{3.8578273261494503`*^9, 3.857827352310793*^9}, 
   3.857828708538477*^9, 3.857830506639841*^9, 3.8578333173660173`*^9, 
   3.8590261497735567`*^9, 3.8598876235840473`*^9, 3.859896355812051*^9, 
   3.859905917971445*^9, 3.8599076813640213`*^9, 3.859909468223702*^9, 
   3.859916033170374*^9, 3.859918768897743*^9, 3.8599194183525887`*^9, 
   3.861097976116531*^9, 3.8610983810328217`*^9},
 CellLabel->
  "Out[328]=",ExpressionUUID->"66235106-4ffe-4115-ad1d-639b2c48cb16"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaCDA", "=", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptC", ",", "ptD", ",", "ptA"}], "]"}], "/.", 
   RowBox[{
    RowBox[{"p", "+", "q", "+", "r"}], "\[Rule]", "1"}]}]}]], "Input",
 CellChangeTimes->{{3.857827354822645*^9, 3.857827384718645*^9}, {
  3.857830214121159*^9, 3.8578302268075533`*^9}},
 CellLabel->
  "In[329]:=",ExpressionUUID->"ac3a2e0f-ccea-4e67-9c5e-6d42efa8b8f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "K"}], " ", "q"}]], "Output",
 CellChangeTimes->{3.8578273863582373`*^9, 3.857828712406196*^9, 
  3.857830229448584*^9, 3.857830509359467*^9, 3.857833320109062*^9, 
  3.85902614978332*^9, 3.859887627158935*^9, 3.859896359115012*^9, 
  3.859905921363448*^9, 3.8599076813751583`*^9, 3.859909468236125*^9, 
  3.859916033182269*^9, 3.859918768907048*^9, 3.859919418360859*^9, 
  3.861097976156006*^9, 3.861098384001664*^9},
 CellLabel->
  "Out[329]=",ExpressionUUID->"95a078b1-0f68-46d4-a277-fdb243c15546"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaABCD", "=", 
  RowBox[{
   RowBox[{"areaABC", "+", "areaCDA"}], "//", "Factor"}]}]], "Input",
 CellChangeTimes->{{3.857830194192675*^9, 3.8578302431515102`*^9}},
 CellLabel->
  "In[330]:=",ExpressionUUID->"bde6befb-037f-4bcf-aa6d-c7c080b4c37f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "K"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "q"}], ")"}]}]], "Output",
 CellChangeTimes->{{3.857830233250979*^9, 3.857830244357922*^9}, 
   3.857830513457922*^9, 3.85902614982122*^9, 3.859887634302293*^9, 
   3.8598963632212963`*^9, 3.859905925335944*^9, 3.859907681386095*^9, 
   3.859909468294058*^9, 3.859916033252543*^9, 3.859918768968354*^9, 
   3.859919418421126*^9, 3.861097976166687*^9, 3.861098386901989*^9},
 CellLabel->
  "Out[330]=",ExpressionUUID->"0c6869b6-11de-4e0a-a085-677bb5a14b09"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hj", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"AD", "^", "2"}], "+", 
       RowBox[{"CD", "^", "2"}]}], "\[Equal]", 
      RowBox[{"AC", "^", "2"}]}], "/.", 
     RowBox[{"b", "\[Rule]", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"a", "^", "2"}], "+", 
        RowBox[{"c", "^", "2"}]}], "]"}]}]}], "/.", 
    RowBox[{"r", "\[Rule]", 
     RowBox[{"1", "-", "p", "-", "q"}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.859906121014258*^9, 3.859906182044142*^9}, {
  3.859906512630796*^9, 3.859906518173223*^9}},
 CellLabel->
  "In[331]:=",ExpressionUUID->"ea13d807-6fde-473d-b68b-1ce7be1126f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "p"}], ")"}], " ", "p"}], "+", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p", "2"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "q"}], ")"}], " ", "q"}], "+", 
      RowBox[{"p", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "q"}]}], ")"}]}]}], ")"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.8599061317776823`*^9, 3.859906183163924*^9}, 
   3.859906519372203*^9, 3.859907627288817*^9, 3.859907685240231*^9, 
   3.859909476518427*^9, 3.859916625434225*^9, 3.8599187922989483`*^9, 
   3.859919422804345*^9, 3.861097976208454*^9, 3.861098391940134*^9},
 CellLabel->
  "Out[331]=",ExpressionUUID->"a3568072-78c8-4179-9826-5b1550663df9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hjc", "=", 
  RowBox[{"hj", "/.", 
   RowBox[{
    RowBox[{"c", "^", "2"}], "\[Rule]", "c2"}]}]}]], "Input",
 CellChangeTimes->{{3.8599062764708433`*^9, 3.8599062947409267`*^9}},
 CellLabel->
  "In[332]:=",ExpressionUUID->"c76324e8-70ec-45c8-a75c-9a72f598cd53"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"c2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "p"}], ")"}], " ", "p"}], "+", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["p", "2"], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "q"}], ")"}], " ", "q"}], "+", 
      RowBox[{"p", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "q"}]}], ")"}]}]}], ")"}]}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{3.859906295770035*^9, 3.8599065284218473`*^9, 
  3.859907629992856*^9, 3.859907685256083*^9, 3.859909476531148*^9, 
  3.85991662966572*^9, 3.8599187923075867`*^9, 3.859919422812645*^9, 
  3.861097976218451*^9, 3.861098396095352*^9},
 CellLabel->
  "Out[332]=",ExpressionUUID->"5c578cd8-2650-45a3-993f-df04fea6a2f2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ans", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{"hjc", ",", "c2"}], "]"}], "//", "First"}]}]], "Input",
 CellChangeTimes->{{3.8599063011749907`*^9, 3.85990633963778*^9}},
 CellLabel->
  "In[333]:=",ExpressionUUID->"d42d6993-5ae5-4fc2-8b66-85323ee4850c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"c2", "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "p"}], "+", 
        SuperscriptBox["p", "2"], "-", "q", "+", 
        RowBox[{"2", " ", "p", " ", "q"}], "+", 
        SuperscriptBox["q", "2"]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "p"}], ")"}], " ", "p"}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.85990631248332*^9, 3.859906340767255*^9}, 
   3.859906531888508*^9, 3.859907633172217*^9, 3.859907685333836*^9, 
   3.859909476597857*^9, 3.859916632715818*^9, 3.8599187923787727`*^9, 
   3.8599194228745127`*^9, 3.861097976258231*^9, 3.861098400398101*^9},
 CellLabel->
  "Out[333]=",ExpressionUUID->"fe0da95e-f9e6-44da-aa41-37735ddc3518"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ans2", "=", 
  RowBox[{"ans", "/.", 
   RowBox[{"c2", "\[Rule]", 
    RowBox[{"c", "^", "2"}]}]}]}]], "Input",
 CellChangeTimes->{{3.859906344375169*^9, 3.859906354164905*^9}},
 CellLabel->
  "In[334]:=",ExpressionUUID->"5bb860f8-865c-4e66-8838-143b913c7558"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["c", "2"], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["a", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "p"}], "+", 
        SuperscriptBox["p", "2"], "-", "q", "+", 
        RowBox[{"2", " ", "p", " ", "q"}], "+", 
        SuperscriptBox["q", "2"]}], ")"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "p"}], ")"}], " ", "p"}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.859919766918976*^9, 3.861097976268016*^9, 
  3.861098403776724*^9},
 CellLabel->
  "Out[334]=",ExpressionUUID->"d9ec142b-da41-4dcd-9923-b22715180f06"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cval", "=", 
  RowBox[{
   RowBox[{"ans2", "//", "First"}], "//", "Last"}]}]], "Input",
 CellLabel->
  "In[335]:=",ExpressionUUID->"86c6af17-a5b1-4318-a5b7-5f73a6d263a3"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "p"}], "+", 
      SuperscriptBox["p", "2"], "-", "q", "+", 
      RowBox[{"2", " ", "p", " ", "q"}], "+", 
      SuperscriptBox["q", "2"]}], ")"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "p"}], ")"}], " ", "p"}]]}]], "Output",
 CellChangeTimes->{{3.859919747231505*^9, 3.859919774987949*^9}, 
   3.861097976306732*^9, 3.861098406854941*^9},
 CellLabel->
  "Out[335]=",ExpressionUUID->"ba4e786a-30ab-45f4-ab8e-89c6de98fa54"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptF", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"ptF", "/.", 
      RowBox[{"b", "\[Rule]", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"a", "^", "2"}], "+", 
         RowBox[{"c", "^", "2"}]}], "]"}]}]}], "/.", 
     RowBox[{"r", "\[Rule]", 
      RowBox[{"1", "-", "p", "-", "q"}]}]}], "/.", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{"Sqrt", "[", "cval", "]"}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.859920528138291*^9, 3.859920529441951*^9}},
 CellLabel->
  "In[336]:=",ExpressionUUID->"87f70291-eb88-453c-84ac-1a1f9a517bfd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1", "-", 
    FractionBox["p", "2"]}], ",", 
   FractionBox[
    RowBox[{"1", "+", "p", "+", 
     RowBox[{"3", " ", "q"}], "-", 
     RowBox[{"p", " ", "q"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "p"}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["p", "2"], "+", 
     RowBox[{"p", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "q"}], ")"}]}], "-", 
     RowBox[{"3", " ", "q"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "p"}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.859920532688858*^9, 3.86109797635914*^9, 
  3.861098411967018*^9},
 CellLabel->
  "Out[336]=",ExpressionUUID->"a4fd9f7a-980c-4d7f-b9fe-3fcb558ec5c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptG", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"ptG", "/.", 
      RowBox[{"b", "\[Rule]", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"a", "^", "2"}], "+", 
         RowBox[{"c", "^", "2"}]}], "]"}]}]}], "/.", 
     RowBox[{"r", "\[Rule]", 
      RowBox[{"1", "-", "p", "-", "q"}]}]}], "/.", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{"Sqrt", "[", "cval", "]"}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.859920542770378*^9, 3.859920545978606*^9}},
 CellLabel->
  "In[337]:=",ExpressionUUID->"66891831-de67-4c61-878d-3ffee7fc1311"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["p", "2"], "+", 
      RowBox[{"p", " ", "q"}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "q"}], ")"}]}]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"p", "+", "q"}], ")"}]}]]}], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", "+", 
      RowBox[{"p", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "q"}], ")"}]}], "+", "q", "+", 
      SuperscriptBox["q", "2"]}], 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{"p", "+", "q"}], ")"}]}]]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "p", "+", "q"}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.859920547152611*^9, 3.861097976402659*^9, 
  3.861098415323929*^9},
 CellLabel->
  "Out[337]=",ExpressionUUID->"6e06d671-9bb6-400e-98b5-91f5514da8dd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptH", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"ptH", "/.", 
      RowBox[{"b", "\[Rule]", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"a", "^", "2"}], "+", 
         RowBox[{"c", "^", "2"}]}], "]"}]}]}], "/.", 
     RowBox[{"r", "\[Rule]", 
      RowBox[{"1", "-", "p", "-", "q"}]}]}], "/.", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{"Sqrt", "[", "cval", "]"}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.859920550786778*^9, 3.859920563418338*^9}},
 CellLabel->
  "In[338]:=",ExpressionUUID->"b472338a-3819-482d-aa88-e5c547ddc9dd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"1", "+", 
    FractionBox["p", "2"], "+", "q"}], ",", 
   FractionBox[
    RowBox[{"1", "+", 
     RowBox[{"p", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "q"}], ")"}]}], "+", "q", "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["q", "2"]}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "p"}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{"1", "-", 
     RowBox[{"2", " ", "p"}], "+", 
     SuperscriptBox["p", "2"], "-", "q", "+", 
     RowBox[{"3", " ", "p", " ", "q"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["q", "2"]}]}], 
    RowBox[{"2", "-", 
     RowBox[{"2", " ", "p"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{3.859920564452577*^9, 3.861097976442889*^9, 
  3.8610984207440977`*^9},
 CellLabel->
  "Out[338]=",ExpressionUUID->"5e49e353-b179-4dba-83d8-41815606bcd5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptI", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"ptI", "/.", 
      RowBox[{"b", "\[Rule]", 
       RowBox[{"Sqrt", "[", 
        RowBox[{
         RowBox[{"a", "^", "2"}], "+", 
         RowBox[{"c", "^", "2"}]}], "]"}]}]}], "/.", 
     RowBox[{"r", "\[Rule]", 
      RowBox[{"1", "-", "p", "-", "q"}]}]}], "/.", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{"Sqrt", "[", "cval", "]"}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.859920573274406*^9, 3.859920576810361*^9}},
 CellLabel->
  "In[339]:=",ExpressionUUID->"e7eb7a63-f5ea-4ea8-9d52-639bc5080486"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["p", "2"], "+", 
     RowBox[{"2", " ", "q"}], "-", 
     RowBox[{"p", " ", "q"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"p", "+", "q"}], ")"}]}]], ",", 
   FractionBox[
    RowBox[{
     RowBox[{"p", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "q"}], ")"}]}], "-", 
     RowBox[{"q", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", "q"}], ")"}]}]}], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{"p", "+", "q"}], ")"}]}]], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"3", "-", "p", "+", "q"}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.859920577919096*^9, 3.861097976487568*^9, 
  3.861098424246353*^9},
 CellLabel->
  "Out[339]=",ExpressionUUID->"659a23f0-da63-41c2-ac23-b34f665cc1b0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaFGH", "=", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptF", ",", "ptG", ",", "ptH"}], "]"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.859887663369461*^9, 3.859887676656836*^9}, 
   3.8598964676781397`*^9, 3.859896622831819*^9, 3.859918648764759*^9, {
   3.859920583691729*^9, 3.859920605338134*^9}},
 CellLabel->
  "In[340]:=",ExpressionUUID->"e411fb5f-b26e-4eb2-b351-fd31fb96f1e2"],

Cell[BoxData[
 FractionBox[
  RowBox[{"K", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "q", "+", 
     SuperscriptBox["q", "2"], "+", 
     RowBox[{"p", " ", 
      RowBox[{"(", 
       RowBox[{"3", "+", "q"}], ")"}]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"-", "1"}], "+", "p"}]]], "Output",
 CellChangeTimes->{3.8599206071109743`*^9, 3.8610979765279016`*^9, 
  3.861098440108953*^9},
 CellLabel->
  "Out[340]=",ExpressionUUID->"0f983c99-9579-4a7c-b4da-b6e5dd877d8b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaHIF", "=", 
  RowBox[{
   RowBox[{"baryArea", "[", 
    RowBox[{"ptH", ",", "ptI", ",", "ptF"}], "]"}], "//", 
   "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.859887704329392*^9, 3.859887723216958*^9}, 
   3.859896461918048*^9, 3.859896627911354*^9, 3.859918657108766*^9, {
   3.859920613619402*^9, 3.859920617419454*^9}},
 CellLabel->
  "In[341]:=",ExpressionUUID->"ccc32568-eb37-40db-85e1-214e76dbfe21"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"K", " ", 
    RowBox[{"(", 
     RowBox[{"p", "+", 
      RowBox[{"3", " ", "p", " ", "q"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "q"}], ")"}], " ", "q"}]}], ")"}]}], 
   RowBox[{
    RowBox[{"-", "1"}], "+", "p"}]]}]], "Output",
 CellChangeTimes->{3.859920618528495*^9, 3.8610979765687733`*^9, 
  3.8610984550361023`*^9},
 CellLabel->
  "Out[341]=",ExpressionUUID->"4bc39f43-bc94-4183-acd5-6a531dbff933"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaFGHI", "=", 
  RowBox[{
   RowBox[{"areaFGH", "+", "areaHIF"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.859887730414658*^9, 3.859887744593927*^9}, {
   3.8598963951503277`*^9, 3.8598963980608387`*^9}, 3.859896479225615*^9, {
   3.859896638351307*^9, 3.859896656109652*^9}, {3.85990606566074*^9, 
   3.859906076211648*^9}, 3.859918676892606*^9, {3.859920640003584*^9, 
   3.859920646306628*^9}},
 CellLabel->
  "In[342]:=",ExpressionUUID->"5363117e-16a9-4e14-a4c9-8e9c5bfd817d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "2"}], " ", "K", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "q"}], ")"}]}]], "Output",
 CellChangeTimes->{3.859920647499452*^9, 3.8610979765791893`*^9, 
  3.8610984610620823`*^9},
 CellLabel->
  "Out[342]=",ExpressionUUID->"a404d907-7ae8-443d-8863-b0613dc7a479"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaABCD", "/", "areaFGHI"}]], "Input",
 CellChangeTimes->{{3.85989649790169*^9, 3.85989650205402*^9}, {
  3.859919577616448*^9, 3.859919580318681*^9}, {3.859919836017071*^9, 
  3.859919865689032*^9}, {3.8610982341948977`*^9, 3.861098235155971*^9}},
 CellLabel->
  "In[343]:=",ExpressionUUID->"4473368d-ab26-42af-a91f-7a70f84bf02b"],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{
  3.859896502866671*^9, 3.8598966611458817`*^9, 3.8599076860216103`*^9, 
   3.8599094773977833`*^9, 3.8599187926961823`*^9, 3.859919423011095*^9, 
   3.859919581526017*^9, {3.859919836941485*^9, 3.859919866806539*^9}, 
   3.8599206581383953`*^9, 3.8610979766176767`*^9, 3.861098241141658*^9, 
   3.861098466530059*^9},
 CellLabel->
  "Out[343]=",ExpressionUUID->"0da7c30d-ddb6-4edd-8a53-acd12ada78e1"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Section 10 (Steiner Point)", "Section",
 CellChangeTimes->{{3.859883929984612*^9, 3.8598839588801727`*^9}, {
  3.860071697994548*^9, 
  3.860071703034281*^9}},ExpressionUUID->"af10d3f7-8d70-42f6-b4b4-\
c79912629014"],

Cell[CellGroupData[{

Cell["Theorem 10.7 for X(642) (alternate proof)", "Subsection",
 CellChangeTimes->{{3.861093231659135*^9, 3.861093249927772*^9}, {
  3.86109333133251*^9, 
  3.861093338660204*^9}},ExpressionUUID->"8d9f6e14-fc77-4b02-802e-\
2fa9e5cd71ab"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "p"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptA", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptB", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptC", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"midAC", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptD", "=", 
   RowBox[{"{", 
    RowBox[{"p", ",", 
     RowBox[{"1", "-", 
      RowBox[{"2", "p"}]}], ",", "p"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptE", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", 
      RowBox[{"2", "-", 
       RowBox[{"2", "p"}]}], ",", "p"}], "}"}], "/", "2"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Sval", " ", "=", " ", 
   RowBox[{
    RowBox[{"b", "^", "2"}], "/", "4"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8598960942203836`*^9, 3.8598961113399277`*^9}, {
   3.8599058266281443`*^9, 3.859905840075061*^9}, {3.859907556010416*^9, 
   3.859907562296378*^9}, {3.859907658009869*^9, 3.859907658760771*^9}, {
   3.859919404483058*^9, 3.859919404966362*^9}, {3.860071753315181*^9, 
   3.860071776610392*^9}, {3.860071807714518*^9, 3.860071844210682*^9}, {
   3.860072005812338*^9, 3.860072021939646*^9}, {3.8600722326129503`*^9, 
   3.8600722351082687`*^9}, {3.86007295597556*^9, 3.86007295639054*^9}, {
   3.860075099990563*^9, 3.8600751193663597`*^9}, {3.8601200782814083`*^9, 
   3.860120102143853*^9}, {3.86012021524025*^9, 3.8601202158797617`*^9}, {
   3.860120804267604*^9, 3.860120809570797*^9}, {3.860158705635351*^9, 
   3.860158721049971*^9}, 3.8601592674927683`*^9, {3.861093004156398*^9, 
   3.861093043611425*^9}, 3.8610932219894733`*^9},
 CellLabel->
  "In[244]:=",ExpressionUUID->"292c1b8c-0336-42ac-9a66-18fe0c09961d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"AB", "=", "a"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BC", "=", "a"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AC", "=", "b"}], ";"}]}], "Input",
 CellChangeTimes->{{3.8598849566661787`*^9, 3.8598849745761538`*^9}, 
   3.860073353320929*^9},
 CellLabel->
  "In[252]:=",ExpressionUUID->"3e73ad66-b4cc-4278-b545-e42fcc12b2d0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptG", "=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"ptA", "+", "ptB", "+", "ptC", "+", "ptD"}], ")"}], "/", 
   "4"}]}]], "Input",
 CellChangeTimes->{{3.860121174269444*^9, 3.860121193451092*^9}},
 CellLabel->
  "In[255]:=",ExpressionUUID->"38b8b03a-9825-45c8-9d16-a940ef86ecb3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"1", "+", "p"}], "4"], ",", 
   RowBox[{
    FractionBox["1", "4"], " ", 
    RowBox[{"(", 
     RowBox[{"2", "-", 
      RowBox[{"2", " ", "p"}]}], ")"}]}], ",", 
   FractionBox[
    RowBox[{"1", "+", "p"}], "4"]}], "}"}]], "Output",
 CellChangeTimes->{3.860121194443451*^9, 3.860158905182749*^9, 
  3.861092756543667*^9, 3.861093019133645*^9, 3.861093057167001*^9, 
  3.861097976670154*^9},
 CellLabel->
  "Out[255]=",ExpressionUUID->"3a4cb63d-dfa8-4198-9f5d-7fe2d6d182c4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AD", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"dist", "[", 
     RowBox[{"ptA", ",", "ptD"}], "]"}], "]"}], "/.", 
   RowBox[{"c", "\[Rule]", "a"}]}]}]], "Input",
 CellChangeTimes->{{3.859884305435573*^9, 3.8598843604704123`*^9}, {
   3.860071875507576*^9, 3.8600718800267*^9}, {3.8600719171002607`*^9, 
   3.8600719309229517`*^9}, 3.860072030716546*^9, {3.860073609545829*^9, 
   3.860073611320365*^9}},
 CellLabel->
  "In[256]:=",ExpressionUUID->"d20941c4-35ae-4637-aa33-65d3b9a3a00e"],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["b", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "p"}], ")"}], " ", "p"}], "+", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "p"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "p"}]}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", "p", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "p"}]}], ")"}]}]}]]], "Output",
 CellChangeTimes->{{3.859884330991843*^9, 3.859884365038508*^9}, 
   3.8598961941392193`*^9, 3.8599058583954573`*^9, 3.859907679304521*^9, 
   3.8599094657243*^9, 3.8599160309379063`*^9, 3.859918765979039*^9, 
   3.859919414332301*^9, {3.860071882376367*^9, 3.8600719320643787`*^9}, 
   3.860072031729854*^9, 3.860073362660087*^9, 3.860073612071447*^9, 
   3.860075125130354*^9, 3.8601202429742203`*^9, 3.860120817208109*^9, 
   3.860158908681862*^9, 3.861092761906062*^9, 3.861093061372658*^9, 
   3.861097976711508*^9},
 CellLabel->
  "Out[256]=",ExpressionUUID->"4c6496f5-a549-4f45-99aa-df26af49f87f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BD", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"dist", "[", 
     RowBox[{"ptB", ",", "ptD"}], "]"}], "]"}], "/.", 
   RowBox[{"c", "\[Rule]", "a"}]}]}]], "Input",
 CellChangeTimes->{{3.859884377390752*^9, 3.859884382446802*^9}, {
   3.860071936219941*^9, 3.860071938226852*^9}, {3.860073401209312*^9, 
   3.860073403503414*^9}, 3.8600751766544113`*^9},
 CellLabel->
  "In[257]:=",ExpressionUUID->"d8f2b9d3-295e-43f9-a5b4-abef642cde59"],

Cell[BoxData[
 RowBox[{
  SqrtBox[
   RowBox[{
    RowBox[{"4", " ", 
     SuperscriptBox["a", "2"]}], "-", 
    SuperscriptBox["b", "2"]}]], " ", "p"}]], "Output",
 CellChangeTimes->{3.8598843834313507`*^9, 3.85989619748947*^9, 
  3.859905861423897*^9, 3.859907679364189*^9, 3.8599094658332577`*^9, 
  3.859916031074421*^9, 3.859918766040824*^9, 3.859919414392651*^9, 
  3.86007193951082*^9, 3.8600733715061893`*^9, 3.860073405081863*^9, 
  3.860075137942452*^9, 3.8600751784086313`*^9, 3.8601202482219353`*^9, 
  3.860120823403892*^9, 3.860158914708783*^9, 3.861092765375946*^9, 
  3.8610930649994392`*^9, 3.861097976722814*^9},
 CellLabel->
  "Out[257]=",ExpressionUUID->"9b4fee51-17d3-4828-830b-4a7470cd3c97"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CD", "=", "AD"}]], "Input",
 CellChangeTimes->{{3.85988439257484*^9, 3.8598843986944857`*^9}, {
   3.8600719721401453`*^9, 3.860071975219069*^9}, 3.8600720892050943`*^9, {
   3.860073426032764*^9, 3.860073426383585*^9}},
 CellLabel->
  "In[258]:=",ExpressionUUID->"8a7d64e9-54d1-482f-84c8-eeedf411524e"],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["b", "2"]}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "p"}], ")"}], " ", "p"}], "+", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "p"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "p"}]}], ")"}]}], "+", 
   RowBox[{
    SuperscriptBox["a", "2"], " ", "p", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "p"}]}], ")"}]}]}]]], "Output",
 CellChangeTimes->{
  3.85988439973529*^9, 3.8598962003959312`*^9, 3.859905864234151*^9, 
   3.859907679419112*^9, 3.859909465903405*^9, 3.859916031148778*^9, 
   3.859918766100086*^9, 3.859919414456407*^9, 3.860071976591077*^9, 
   3.860072090268415*^9, {3.860073421171082*^9, 3.860073427585268*^9}, 
   3.860073681377923*^9, 3.860120271927898*^9, 3.860120826864972*^9, 
   3.860158917461124*^9, 3.861092769129171*^9, 3.8610930706724577`*^9, 
   3.861097976761353*^9},
 CellLabel->
  "Out[258]=",ExpressionUUID->"c8497e7d-1ee9-4240-801d-e9dde324a8d5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AE", "=", 
  RowBox[{
   RowBox[{"Simplify", "[", 
    RowBox[{"dist", "[", 
     RowBox[{"ptA", ",", "ptE"}], "]"}], "]"}], "/.", 
   RowBox[{"c", "\[Rule]", "a"}]}]}]], "Input",
 CellChangeTimes->{{3.859884417070907*^9, 3.859884423438868*^9}, 
   3.8600719803398323`*^9, 3.860072097659848*^9, {3.860073443224887*^9, 
   3.860073445103818*^9}},
 CellLabel->
  "In[259]:=",ExpressionUUID->"bd8c24c0-f6b6-46ba-be17-dd1c4c24b612"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SqrtBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "2"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "p"}], ")"}], " ", "p"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "p"}], ")"}], " ", "p"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"3", " ", "p"}], "+", 
       SuperscriptBox["p", "2"]}], ")"}]}]}]]}]], "Output",
 CellChangeTimes->{
  3.8598844253989353`*^9, 3.859896204455975*^9, 3.859905868830893*^9, 
   3.859907568570179*^9, 3.859907679494277*^9, 3.8599094659918547`*^9, 
   3.8599160312274237`*^9, 3.8599187661663847`*^9, 3.859919414516241*^9, 
   3.860072098984853*^9, 3.860072962783362*^9, {3.860073439731842*^9, 
   3.860073446008706*^9}, 3.860120282212042*^9, 3.860120830141572*^9, 
   3.860158921274075*^9, 3.861092771991287*^9, 3.861093073654519*^9, 
   3.861097976802256*^9},
 CellLabel->
  "Out[259]=",ExpressionUUID->"8a120162-73cf-4431-9056-94e4f204259f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BE", "=", 
  RowBox[{"b", "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.859884442630988*^9, 3.8598844468151703`*^9}, 
   3.8600721107963247`*^9, {3.8600724345661497`*^9, 3.860072435436593*^9}},
 CellLabel->
  "In[260]:=",ExpressionUUID->"c3b69c8b-a31d-4bc2-bb29-804413a13b83"],

Cell[BoxData[
 FractionBox["b", "2"]], "Output",
 CellChangeTimes->{3.859884448628995*^9, 3.8598962112709093`*^9, 
  3.859905879800148*^9, 3.859907572114275*^9, 3.8599076795473013`*^9, 
  3.859909466098506*^9, 3.859916031306073*^9, 3.859918766229424*^9, 
  3.859919414581883*^9, 3.860072112606966*^9, 3.860072436094182*^9, 
  3.8601202887804832`*^9, 3.860120834173615*^9, 3.8601589239949713`*^9, 
  3.861092775935154*^9, 3.861093076946744*^9, 3.8610979768123627`*^9},
 CellLabel->
  "Out[260]=",ExpressionUUID->"464eed09-2d5c-48a3-853b-2a112d910014"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CE", "=", "AE"}]], "Input",
 CellChangeTimes->{{3.859884458407199*^9, 3.859884462487104*^9}, 
   3.860072120916419*^9, {3.8600734536021233`*^9, 3.8600734558238783`*^9}, {
   3.860120306266254*^9, 3.860120306640029*^9}},
 CellLabel->
  "In[261]:=",ExpressionUUID->"e60128e5-1e38-404c-b018-ba07f1170db9"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SqrtBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["b", "2"]}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "p"}], ")"}], " ", "p"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "p"}], ")"}], " ", "p"}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"3", " ", "p"}], "+", 
       SuperscriptBox["p", "2"]}], ")"}]}]}]]}]], "Output",
 CellChangeTimes->{
  3.859884464344166*^9, 3.859896216151741*^9, 3.859905884439699*^9, 
   3.859907575706057*^9, 3.859907679627594*^9, 3.85990946619378*^9, 
   3.859916031397286*^9, 3.859918766298291*^9, 3.859919414656028*^9, 
   3.860072122016919*^9, 3.8600729674429007`*^9, 3.8600734567055807`*^9, {
   3.8601203012665653`*^9, 3.8601203078952637`*^9}, 3.860120837086458*^9, 
   3.8601589267484293`*^9, 3.861092778547949*^9, 3.8610930810954103`*^9, 
   3.861097976850608*^9},
 CellLabel->
  "Out[261]=",ExpressionUUID->"023072f7-a177-47f6-97fe-9d792ff69d43"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DE", "=", 
  RowBox[{"b", "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.8598844723274384`*^9, 3.859884476679422*^9}, 
   3.8600721269403467`*^9, {3.860072445366001*^9, 3.8600724462444572`*^9}},
 CellLabel->
  "In[262]:=",ExpressionUUID->"514cff67-8929-45ac-ab4d-d511fa8f415d"],

Cell[BoxData[
 FractionBox["b", "2"]], "Output",
 CellChangeTimes->{3.859884480286139*^9, 3.859896221798538*^9, 
  3.85990588906975*^9, 3.8599075786952744`*^9, 3.85990767968159*^9, 
  3.859909466269507*^9, 3.859916031473949*^9, 3.859918766355166*^9, 
  3.859919414716413*^9, 3.860072127939996*^9, 3.8600724470207567`*^9, 
  3.860120313959278*^9, 3.860120841138513*^9, 3.86015893064075*^9, 
  3.8610927821032953`*^9, 3.8610930839593277`*^9, 3.861097976860725*^9},
 CellLabel->
  "Out[262]=",ExpressionUUID->"a71f40bf-3b0c-499b-893a-8adbfcf78ce3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x642", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"642", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.86007219326154*^9, 3.860072206107666*^9}, {
  3.860073026610812*^9, 3.860073039534506*^9}, {3.8600745093005943`*^9, 
  3.860074515956313*^9}},
 CellLabel->
  "In[263]:=",ExpressionUUID->"d4bd24a2-5800-417a-b61f-42033a7d45a7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     SuperscriptBox["a", "4"]}], "-", 
    SuperscriptBox["b", "4"], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "+", 
       SuperscriptBox["c", "2"]}], ")"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["c", "2"], "-", "S"}], ")"}]}], "-", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       RowBox[{"2", " ", "S"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["b", "4"]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["b", "2"], " ", 
     SuperscriptBox["c", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["b", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["c", "2"]}], "-", 
       RowBox[{"2", " ", "S"}]}], ")"}]}], "-", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["c", "2"], "+", 
       RowBox[{"2", " ", "S"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "4"]}], "-", 
    SuperscriptBox["b", "4"], "-", 
    RowBox[{"2", " ", 
     SuperscriptBox["c", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["b", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["c", "2"]}], "-", 
       RowBox[{"2", " ", "S"}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["a", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["b", "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["c", "2"]}], "-", 
       RowBox[{"2", " ", "S"}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8598848846266603`*^9, 3.859896282760206*^9, 3.859900142083308*^9, 
   3.8599058984658117`*^9, 3.8599076796927834`*^9, 3.859909466282934*^9, 
   3.8599160314863443`*^9, 3.859918766363327*^9, 3.859919414724506*^9, 
   3.8600721711169853`*^9, 3.860072207078141*^9, {3.860073029380248*^9, 
   3.860073040658731*^9}, 3.860073469764123*^9, {3.8600745107038813`*^9, 
   3.86007451695185*^9}, 3.860120318281404*^9, 3.8601589355521173`*^9, 
   3.86109278822713*^9, 3.861093087293515*^9, 3.861097976900096*^9},
 CellLabel->
  "Out[263]=",ExpressionUUID->"d82d340a-93ea-469a-a794-7de8004832b3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"x642n", "=", 
   RowBox[{"normed", "[", "x642", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.859916441135846*^9, 3.85991644954074*^9}, 
   3.859918641748863*^9, {3.8600722511328077`*^9, 3.860072256835825*^9}},
 CellLabel->
  "In[264]:=",ExpressionUUID->"4e22e1a0-d118-4c83-b931-40141e33d299"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ptF", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x642n", ".", 
      RowBox[{"{", 
       RowBox[{"ptA", ",", "ptB", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "BE"}], ",", 
       RowBox[{"b", "\[Rule]", "AE"}], ",", 
       RowBox[{"c", "\[Rule]", "AB"}], ",", 
       RowBox[{"S", "\[Rule]", "Sval"}]}], "}"}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptG", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x642n", ".", 
      RowBox[{"{", 
       RowBox[{"ptB", ",", "ptC", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "CE"}], ",", 
       RowBox[{"b", "\[Rule]", "BE"}], ",", 
       RowBox[{"c", "\[Rule]", "BC"}], ",", 
       RowBox[{"S", "\[Rule]", "Sval"}]}], "}"}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptH", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x642n", ".", 
      RowBox[{"{", 
       RowBox[{"ptC", ",", "ptD", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "DE"}], ",", 
       RowBox[{"b", "\[Rule]", "CE"}], ",", 
       RowBox[{"c", "\[Rule]", "CD"}], ",", 
       RowBox[{"S", "\[Rule]", "Sval"}]}], "}"}]}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptI", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"x642n", ".", 
      RowBox[{"{", 
       RowBox[{"ptD", ",", "ptA", ",", "ptE"}], "}"}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a", "\[Rule]", "AE"}], ",", 
       RowBox[{"b", "\[Rule]", "DE"}], ",", 
       RowBox[{"c", "\[Rule]", "AD"}], ",", 
       RowBox[{"S", "\[Rule]", "Sval"}]}], "}"}]}], "//", "Simplify"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.859884894408589*^9, 3.8598849468882437`*^9}, {
  3.8599164610144653`*^9, 3.8599164690613337`*^9}, {3.860072274256464*^9, 
  3.8600722785994873`*^9}, {3.8600727726874647`*^9, 3.860072780926096*^9}, {
  3.8600729904081583`*^9, 3.860072995534604*^9}, {3.860074630101417*^9, 
  3.8600746608680887`*^9}, {3.8601204210021477`*^9, 3.860120443364541*^9}},
 CellLabel->
  "In[265]:=",ExpressionUUID->"ccce49ac-66cc-49da-be06-186b0c5755cb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaABC", "=", 
  RowBox[{"baryArea", "[", 
   RowBox[{"ptA", ",", "ptB", ",", "ptC"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.857827314751285*^9, 3.857827349150406*^9}},
 CellLabel->
  "In[269]:=",ExpressionUUID->"6304914e-b094-4a4b-9d57-da0255098fa3"],

Cell[BoxData["K"], "Output",
 CellChangeTimes->{{3.8578273261494503`*^9, 3.857827352310793*^9}, 
   3.857828708538477*^9, 3.857830506639841*^9, 3.8578333173660173`*^9, 
   3.8590261497735567`*^9, 3.8598876235840473`*^9, 3.859896355812051*^9, 
   3.859905917971445*^9, 3.8599076813640213`*^9, 3.859909468223702*^9, 
   3.859916033170374*^9, 3.859918768897743*^9, 3.8599194183525887`*^9, 
   3.8600722870770483`*^9, 3.8610928061137667`*^9, 3.8610930980997*^9, 
   3.8610979771826*^9},
 CellLabel->
  "Out[269]=",ExpressionUUID->"6296765e-2a20-4206-9a74-f865cd503f25"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaCDA", "=", 
  RowBox[{"baryArea", "[", 
   RowBox[{"ptC", ",", "ptD", ",", "ptA"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.857827354822645*^9, 3.857827384718645*^9}, {
  3.857830214121159*^9, 3.8578302268075533`*^9}, {3.860072293300943*^9, 
  3.860072341141378*^9}},
 CellLabel->
  "In[270]:=",ExpressionUUID->"692e8bba-2edc-41ca-863d-4cb0cfd8e138"],

Cell[BoxData[
 RowBox[{"K", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    RowBox[{"2", " ", "p"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.8578273863582373`*^9, 3.857828712406196*^9, 3.857830229448584*^9, 
   3.857830509359467*^9, 3.857833320109062*^9, 3.85902614978332*^9, 
   3.859887627158935*^9, 3.859896359115012*^9, 3.859905921363448*^9, 
   3.8599076813751583`*^9, 3.859909468236125*^9, 3.859916033182269*^9, 
   3.859918768907048*^9, 3.859919418360859*^9, {3.860072299527295*^9, 
   3.8600723422815*^9}, 3.861092809347534*^9, 3.861093101644539*^9, 
   3.861097977192718*^9},
 CellLabel->
  "Out[270]=",ExpressionUUID->"e8aad6ed-0878-4125-a2a4-117b2823c452"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"areaABCD", "=", 
  RowBox[{
   RowBox[{"areaABC", "+", "areaCDA"}], "//", "Factor"}]}]], "Input",
 CellChangeTimes->{{3.857830194192675*^9, 3.8578302431515102`*^9}},
 CellLabel->
  "In[271]:=",ExpressionUUID->"0d09ac81-ff6c-4e8f-9766-dc2fff281612"],

Cell[BoxData[
 RowBox[{"2", " ", "K", " ", "p"}]], "Output",
 CellChangeTimes->{{3.857830233250979*^9, 3.857830244357922*^9}, 
   3.857830513457922*^9, 3.85902614982122*^9, 3.859887634302293*^9, 
   3.8598963632212963`*^9, 3.859905925335944*^9, 3.859907681386095*^9, 
   3.859909468294058*^9, 3.859916033252543*^9, 3.859918768968354*^9, 
   3.859919418421126*^9, 3.860072352632317*^9, 3.86109282583445*^9, 
   3.861093107215341*^9, 3.86109797723116*^9},
 CellLabel->
  "Out[271]=",ExpressionUUID->"827a9aa1-1b01-49b4-98df-04f51d0777f3"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"areaEFG", "=", 
   RowBox[{
    RowBox[{"baryArea", "[", 
     RowBox[{"ptE", ",", "ptF", ",", "ptG"}], "]"}], "//", "Simplify"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8601689633627872`*^9, 3.8601689734823933`*^9}, 
   3.861092871924115*^9},
 CellLabel->
  "In[272]:=",ExpressionUUID->"3d1c0ec6-876e-44ae-a848-39e212896d71"],

Cell[BoxData[
 RowBox[{
  RowBox[{"areaFGH", "=", 
   RowBox[{
    RowBox[{"baryArea", "[", 
     RowBox[{"ptF", ",", "ptG", ",", "ptH"}], "]"}], "//", "Simplify"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.859887663369461*^9, 3.859887676656836*^9}, 
   3.8598964676781397`*^9, 3.859896622831819*^9, 3.859918648764759*^9, {
   3.859920583691729*^9, 3.859920605338134*^9}, {3.860074575181288*^9, 
   3.8600745855876513`*^9}, 3.8601204981138973`*^9, 3.861092877371622*^9},
 CellLabel->
  "In[273]:=",ExpressionUUID->"4957d9f5-021b-49ef-bd3e-e7caab5539a5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"areaHIF", "=", 
   RowBox[{
    RowBox[{"baryArea", "[", 
     RowBox[{"ptH", ",", "ptI", ",", "ptF"}], "]"}], "//", "Simplify"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.859887704329392*^9, 3.859887723216958*^9}, 
   3.859896461918048*^9, 3.859896627911354*^9, 3.859918657108766*^9, {
   3.859920613619402*^9, 3.859920617419454*^9}, 3.861092884323613*^9},
 CellLabel->
  "In[274]:=",ExpressionUUID->"29830824-7269-41ba-8e5f-2dfdc58d7b70"],

Cell[BoxData[
 RowBox[{
  RowBox[{"areaFGHI", "=", 
   RowBox[{
    RowBox[{"areaFGH", "+", "areaHIF"}], "//", "Simplify"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.859887730414658*^9, 3.859887744593927*^9}, {
   3.8598963951503277`*^9, 3.8598963980608387`*^9}, 3.859896479225615*^9, {
   3.859896638351307*^9, 3.859896656109652*^9}, {3.85990606566074*^9, 
   3.859906076211648*^9}, 3.859918676892606*^9, {3.859920640003584*^9, 
   3.859920646306628*^9}, 3.861092890220201*^9},
 CellLabel->
  "In[275]:=",ExpressionUUID->"7c376211-1cce-4bbb-b824-6194f33bcadd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"areaABCD", "/", "areaFGHI"}], "/.", 
   RowBox[{"p", "->", 
    RowBox[{"b", "/", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"4", 
        RowBox[{"a", "^", "2"}]}], "-", 
       RowBox[{"b", "^", "2"}]}], "]"}]}]}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.85989649790169*^9, 3.85989650205402*^9}, {
  3.859919577616448*^9, 3.859919580318681*^9}, {3.859919836017071*^9, 
  3.859919865689032*^9}, {3.861093162244945*^9, 3.8610931953478127`*^9}},
 CellLabel->
  "In[276]:=",ExpressionUUID->"1eab49df-ccd2-40d6-9027-56f3e125329f"],

Cell[BoxData["8"], "Output",
 CellChangeTimes->{
  3.859896502866671*^9, 3.8598966611458817`*^9, 3.8599076860216103`*^9, 
   3.8599094773977833`*^9, 3.8599187926961823`*^9, 3.859919423011095*^9, 
   3.859919581526017*^9, {3.859919836941485*^9, 3.859919866806539*^9}, 
   3.8599206581383953`*^9, 3.861092898584174*^9, 3.861093125822338*^9, {
   3.861093164405552*^9, 3.8610931965340757`*^9}, 3.861097977436274*^9},
 CellLabel->
  "Out[276]=",ExpressionUUID->"1b8cd376-0f52-4104-91bf-0dc8c928d2b4"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Section 11 (Centroid)", "Section",
 CellChangeTimes->{{3.859883929984612*^9, 3.8598839588801727`*^9}, {
  3.860071697994548*^9, 3.860071703034281*^9}, {3.860328773477935*^9, 
  3.860328779317732*^9}, {3.860329387591918*^9, 
  3.860329389599712*^9}},ExpressionUUID->"f36c3083-14c3-4dc6-b0b1-\
305596aea1d8"],

Cell[CellGroupData[{

Cell["Proposition 11.6 for X(74) in right triangle", "Subsection",
 CellChangeTimes->{{3.860328792864188*^9, 3.860328811388102*^9}, {
  3.861093364644689*^9, 3.861093379548407*^9}, {3.861093415396572*^9, 
  3.8610934191803617`*^9}},ExpressionUUID->"46f75a37-1ddf-496a-86b5-\
3b9692fe57ba"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ptA", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptB", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptC", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.8603288197102613`*^9, 3.860328831910038*^9}},
 CellLabel->
  "In[277]:=",ExpressionUUID->"14cb0ca1-4f1e-429c-bb3d-a75c8952f7e1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x74", "=", 
  RowBox[{"ETC1", "[", 
   RowBox[{"[", 
    RowBox[{"74", ",", "2"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.860328846272711*^9, 3.860328858149889*^9}, {
  3.861096812776723*^9, 3.8610968135917187`*^9}},
 CellLabel->
  "In[280]:=",ExpressionUUID->"f7f0cdfd-6ccb-455c-a92b-c78a63fea029"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["a", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["b", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "4"], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["c", "4"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ")"}]}], ",", 
   RowBox[{
    SuperscriptBox["c", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       SuperscriptBox["a", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "+", 
      SuperscriptBox["b", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "4"], "+", 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["b", "2"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["b", "4"]}], "-", 
      RowBox[{"2", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      RowBox[{
       SuperscriptBox["b", "2"], " ", 
       SuperscriptBox["c", "2"]}], "+", 
      SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.860400181867919*^9, 3.860400190793154*^9}, 
   3.860567436465085*^9, 3.861096814642589*^9, 3.861096866395837*^9, 
   3.861097977484284*^9},
 CellLabel->
  "Out[280]=",ExpressionUUID->"6af1a505-fe4f-409c-b1cd-1b1a34c0839e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptP", "=", 
  RowBox[{
   RowBox[{"x74", "/.", 
    RowBox[{"c", "\[Rule]", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"a", "^", "2"}], "+", 
       RowBox[{"b", "^", "2"}]}], "]"}]}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.860328875321951*^9, 3.8603289097343483`*^9}, {
  3.861096818984671*^9, 3.861096833976982*^9}, {3.861096888600972*^9, 
  3.861096915970523*^9}},
 CellLabel->
  "In[281]:=",ExpressionUUID->"a5c0b0ef-80d4-4453-80e8-0c2c990aaa1c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "8"}], " ", 
    SuperscriptBox["a", "6"], " ", 
    SuperscriptBox["b", "4"]}], ",", 
   RowBox[{
    RowBox[{"-", "8"}], " ", 
    SuperscriptBox["a", "4"], " ", 
    SuperscriptBox["b", "6"]}], ",", 
   RowBox[{"4", " ", 
    SuperscriptBox["a", "4"], " ", 
    SuperscriptBox["b", "4"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["a", "2"], "+", 
      SuperscriptBox["b", "2"]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.860328893084426*^9, 3.860328914119873*^9}, {
   3.860329058351362*^9, 3.86032907967032*^9}, 3.860369200399852*^9, 
   3.860395813437955*^9, {3.8604001773328943`*^9, 3.860400195210972*^9}, 
   3.861096842041107*^9, {3.861096889620267*^9, 3.861096917333544*^9}, 
   3.8610979774958344`*^9},
 CellLabel->
  "Out[281]=",ExpressionUUID->"6f833cf6-59c3-4cf2-9389-fb8fe14b76c1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptP", "=", 
  RowBox[{"ptP", "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "4"}], 
     RowBox[{"a", "^", "4"}], 
     RowBox[{"b", "^", "4"}]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.860329017264873*^9, 3.860329052632203*^9}, 
   3.860329083256048*^9, {3.861096931145742*^9, 3.8610969329848413`*^9}},
 CellLabel->
  "In[282]:=",ExpressionUUID->"7a328517-9896-48b9-86ba-33f8fd163b37"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["a", "2"]}], ",", 
   RowBox[{"2", " ", 
    SuperscriptBox["b", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], "-", 
    SuperscriptBox["b", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.860329047541189*^9, 3.860329083865198*^9}, 
   3.860369203728972*^9, 3.860395816257189*^9, 3.860400355046719*^9, 
   3.8610969339106493`*^9, 3.861097977535129*^9},
 CellLabel->
  "Out[282]=",ExpressionUUID->"58456d73-cee7-49da-958c-5e92504adc16"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"dist", "[", 
    RowBox[{"ptA", ",", "ptP"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"a", "^", "2"}], "+", 
       RowBox[{"b", "^", "2"}]}], "\[Equal]", 
      RowBox[{"c", "^", "2"}]}], ",", 
     RowBox[{"c", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.860369146530917*^9, 3.860369155571362*^9}, {
   3.8603694135897493`*^9, 3.860369494564528*^9}, 3.8610969573697767`*^9},
 CellLabel->
  "In[283]:=",ExpressionUUID->"b168d41b-9ec2-4a0d-97b8-1dfbfba43d95"],

Cell[BoxData["b"], "Output",
 CellChangeTimes->{
  3.860369159683189*^9, 3.8603692163913593`*^9, {3.8603694149848146`*^9, 
   3.860369424423946*^9}, {3.860369476585338*^9, 3.8603694958835373`*^9}, {
   3.8610969446096888`*^9, 3.861096958466076*^9}, 3.861097977575966*^9},
 CellLabel->
  "Out[283]=",ExpressionUUID->"c643d78b-371d-4df3-ab22-86fd1fc8dae9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"dist", "[", 
    RowBox[{"ptC", ",", "ptP"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"a", "^", "2"}], "+", 
       RowBox[{"b", "^", "2"}]}], "\[Equal]", 
      RowBox[{"c", "^", "2"}]}], ",", 
     RowBox[{"c", ">", "0"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.860369630493414*^9, 3.86036963749649*^9}, 
   3.861096963921117*^9},
 CellLabel->
  "In[284]:=",ExpressionUUID->"9f09a5ce-efb0-49c3-b455-008393bbb6fd"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "a", " ", "b"}], "c"]], "Output",
 CellChangeTimes->{3.860369631686219*^9, 3.861096965139707*^9, 
  3.861097977616487*^9},
 CellLabel->
  "Out[284]=",ExpressionUUID->"e51d2078-8515-4530-b0ac-83456a0a216a"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Proposition 11.7 for X(74) in isosceles triangle", "Subsection",
 CellChangeTimes->{{3.860328792864188*^9, 3.860328811388102*^9}, {
  3.8603324702738743`*^9, 3.860332474681385*^9}, {3.8610934253405724`*^9, 
  3.861093471197588*^9}},ExpressionUUID->"bca03947-f218-45a0-8c99-\
71f18dae00c3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ptA", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptB", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ptC", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], ";"}]}], "Input",
 CellLabel->
  "In[285]:=",ExpressionUUID->"99ea167f-a4ec-4bcc-b124-dc773920b5c3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptP", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ETC1", "[", 
     RowBox[{"[", 
      RowBox[{"74", ",", "2"}], "]"}], "]"}], "/.", 
    RowBox[{"a", "\[Rule]", "b"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.860332490533025*^9, 3.860332513770013*^9}, 
   3.86036985672723*^9, {3.8610964057993813`*^9, 3.861096407118083*^9}, 
   3.8610970543219023`*^9},
 CellLabel->
  "In[288]:=",ExpressionUUID->"7ad756a3-3b9a-4b74-99f6-ed2d3aef5a3f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["c", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "3"], "-", 
       RowBox[{"b", " ", 
        SuperscriptBox["c", "2"]}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["c", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "3"], "-", 
       RowBox[{"b", " ", 
        SuperscriptBox["c", "2"]}]}], ")"}], "2"]}], ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["b", "2"]}], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "5"]}], ")"}], "2"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.860332514459922*^9, 3.8603327396449957`*^9, 3.860369690841003*^9, 
   3.86036985822696*^9, {3.86036989200847*^9, 3.860369918342462*^9}, 
   3.860395824267021*^9, 3.8604003660556307`*^9, 3.86109640906504*^9, 
   3.861096469184401*^9, {3.86109650683202*^9, 3.8610965227120123`*^9}, 
   3.8610970555452843`*^9, 3.8610979776626787`*^9},
 CellLabel->
  "Out[288]=",ExpressionUUID->"f2df018f-1156-4abf-910e-37ba685cb24d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptP", "=", 
  RowBox[{
   RowBox[{"ptP", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["c", "4"]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "-", 
          RowBox[{"b", " ", 
           SuperscriptBox["c", "2"]}]}], ")"}], "2"], "/", 
       SuperscriptBox["b", "2"]}]}], ")"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.8603326930047083`*^9, 3.8603327243224783`*^9}, {
  3.860369862423396*^9, 3.8603698671981707`*^9}, {3.8610964334083147`*^9, 
  3.861096518312067*^9}, {3.861097058897972*^9, 3.861097061888832*^9}},
 CellLabel->
  "In[289]:=",ExpressionUUID->"7f8050ce-710c-4ac9-83c4-e7a58e5b7768"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["b", "2"]}], ",", 
   RowBox[{"2", " ", 
    SuperscriptBox["b", "2"]}], ",", 
   RowBox[{"-", 
    SuperscriptBox["c", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.860332710516913*^9, 3.860332743239587*^9}, 
   3.860369695585165*^9, {3.860369869042986*^9, 3.860369885478196*^9}, 
   3.860369921101056*^9, 3.8603958272539454`*^9, 3.8604003702474203`*^9, 
   3.861096434283061*^9, {3.861096464520829*^9, 3.861096526491702*^9}, 
   3.861097062813678*^9, 3.861097977673841*^9},
 CellLabel->
  "Out[289]=",ExpressionUUID->"d5261d52-f2e9-41bb-bae3-0ed7881fbf24"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ptM", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"1", "/", "2"}], ",", 
    RowBox[{"1", "/", "2"}], ",", "0"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.861097072035035*^9, 3.861097089528346*^9}},
 CellLabel->
  "In[290]:=",ExpressionUUID->"26878ae2-3805-40c0-a78a-b40ca241b1a4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "2"], ",", 
   FractionBox["1", "2"], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.86109709066358*^9, 3.861097977712278*^9},
 CellLabel->
  "Out[290]=",ExpressionUUID->"6a79b27d-c2f9-4fae-9ee8-fecde76daca1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CM", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"dist", "[", 
     RowBox[{"ptC", ",", "ptM"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "\[Equal]", "b"}], ",", 
      RowBox[{"c", ">", "0"}], ",", 
      RowBox[{"a", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.860369717861602*^9, 3.8603697995988073`*^9}, 
   3.860369927791501*^9, {3.8610971123457403`*^9, 3.861097130904604*^9}, {
   3.861097207066332*^9, 3.861097208025219*^9}},
 CellLabel->
  "In[291]:=",ExpressionUUID->"1853f242-b402-43ea-983f-73d7d7ada5f2"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  SqrtBox[
   RowBox[{
    RowBox[{"4", " ", 
     SuperscriptBox["b", "2"]}], "-", 
    SuperscriptBox["c", "2"]}]]}]], "Output",
 CellChangeTimes->{3.860369800713786*^9, 3.860369929275144*^9, 
  3.861097132447218*^9, 3.861097209004847*^9, 3.8610979777532454`*^9},
 CellLabel->
  "Out[291]=",ExpressionUUID->"5c343420-d5b4-456a-b5f0-b12fc79bff64"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MP", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{
    RowBox[{"dist", "[", 
     RowBox[{"ptM", ",", "ptP"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"a", "\[Equal]", "b"}], ",", 
      RowBox[{"c", ">", "0"}], ",", 
      RowBox[{"a", ">", "0"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.861097173417192*^9, 3.861097213224935*^9}, {
  3.861097243682569*^9, 3.861097257705398*^9}},
 CellLabel->
  "In[292]:=",ExpressionUUID->"66a11b97-b72a-4585-a46f-815f96e3fc2d"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   SuperscriptBox["c", "2"], 
   RowBox[{"2", " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"4", " ", 
       SuperscriptBox["b", "2"]}], "-", 
      SuperscriptBox["c", "2"]}]]}]]}]], "Output",
 CellChangeTimes->{{3.861097174800167*^9, 3.861097214127529*^9}, {
   3.861097248273095*^9, 3.861097259530786*^9}, 3.86109797779438*^9},
 CellLabel->
  "Out[292]=",ExpressionUUID->"6b8ef921-0f38-4a6c-8894-d43a74262c6e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CM", "*", "MP"}]], "Input",
 CellChangeTimes->{{3.861097217859356*^9, 3.861097220040594*^9}},
 CellLabel->
  "In[293]:=",ExpressionUUID->"cca77729-1a3c-4e65-bdcc-5fad9f537660"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   SuperscriptBox["c", "2"], "4"]}]], "Output",
 CellChangeTimes->{3.861097221056398*^9, 3.861097977804652*^9},
 CellLabel->
  "Out[293]=",ExpressionUUID->"50c99523-5fda-47cd-923e-62e5e455e581"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Lemma 11.9 for X(74)/X(477) for isosceles triangle", "Subsection",
 CellChangeTimes->{{3.860669595236927*^9, 3.8606696107084293`*^9}, {
  3.861095917812874*^9, 3.8610959615244913`*^9}, {3.861096128981534*^9, 
  3.861096137829105*^9}},ExpressionUUID->"24065629-c85c-494c-8753-\
31cf53326a1f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x74", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ETC1", "[", 
     RowBox[{"[", 
      RowBox[{"74", ",", "2"}], "]"}], "]"}], "/.", 
    RowBox[{"a", "\[Rule]", "b"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.860332490533025*^9, 3.860332513770013*^9}, 
   3.86036985672723*^9, {3.8610964057993813`*^9, 3.861096407118083*^9}, {
   3.8610966024960012`*^9, 3.86109660337541*^9}},
 CellLabel->
  "In[294]:=",ExpressionUUID->"15b5ee01-4790-434c-a5c0-e4c6446d5fe0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["c", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "3"], "-", 
       RowBox[{"b", " ", 
        SuperscriptBox["c", "2"]}]}], ")"}], "2"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["c", "4"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "3"], "-", 
       RowBox[{"b", " ", 
        SuperscriptBox["c", "2"]}]}], ")"}], "2"]}], ",", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["b", "2"]}], " ", 
       SuperscriptBox["c", "3"]}], "+", 
      SuperscriptBox["c", "5"]}], ")"}], "2"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.860332514459922*^9, 3.8603327396449957`*^9, 3.860369690841003*^9, 
   3.86036985822696*^9, {3.86036989200847*^9, 3.860369918342462*^9}, 
   3.860395824267021*^9, 3.8604003660556307`*^9, 3.86109640906504*^9, 
   3.861096469184401*^9, {3.86109650683202*^9, 3.8610965227120123`*^9}, 
   3.8610979778441153`*^9},
 CellLabel->
  "Out[294]=",ExpressionUUID->"c371f98f-d964-4aa7-aaec-9d88413f2cb1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x74forIscoscelesTriangle", "=", 
  RowBox[{
   RowBox[{"x74", "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       SuperscriptBox["c", "4"]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["b", "3"], "-", 
          RowBox[{"b", " ", 
           SuperscriptBox["c", "2"]}]}], ")"}], "2"], "/", 
       SuperscriptBox["b", "2"]}]}], ")"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.8603326930047083`*^9, 3.8603327243224783`*^9}, {
  3.860369862423396*^9, 3.8603698671981707`*^9}, {3.8610964334083147`*^9, 
  3.861096518312067*^9}, {3.861096610712652*^9, 3.861096615519864*^9}},
 CellLabel->
  "In[295]:=",ExpressionUUID->"8330b75d-cfb7-482c-84df-f3c661e38510"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["b", "2"]}], ",", 
   RowBox[{"2", " ", 
    SuperscriptBox["b", "2"]}], ",", 
   RowBox[{"-", 
    SuperscriptBox["c", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.860332710516913*^9, 3.860332743239587*^9}, 
   3.860369695585165*^9, {3.860369869042986*^9, 3.860369885478196*^9}, 
   3.860369921101056*^9, 3.8603958272539454`*^9, 3.8604003702474203`*^9, 
   3.861096434283061*^9, {3.861096464520829*^9, 3.861096526491702*^9}, 
   3.8610979778547783`*^9},
 CellLabel->
  "Out[295]=",ExpressionUUID->"31ea77ae-ac06-414b-8ccf-b089793ab871"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x477", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"ETC1", "[", 
     RowBox[{"[", 
      RowBox[{"477", ",", "2"}], "]"}], "]"}], "/.", 
    RowBox[{"a", "\[Rule]", "b"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.860332490533025*^9, 3.860332513770013*^9}, 
   3.86036985672723*^9, {3.8610964057993813`*^9, 3.861096407118083*^9}, {
   3.8610966024960012`*^9, 3.86109660337541*^9}, {3.861096636471346*^9, 
   3.861096640694903*^9}},
 CellLabel->
  "In[296]:=",ExpressionUUID->"6e09a110-41f3-4b99-94ae-4146b8f0b638"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "6"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "4"]}], ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    SuperscriptBox["b", "2"], " ", 
    SuperscriptBox["c", "6"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "4"]}], ",", 
   RowBox[{
    SuperscriptBox["c", "8"], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["b", "2"], "-", 
       SuperscriptBox["c", "2"]}], ")"}], "4"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.860332514459922*^9, 3.8603327396449957`*^9, 3.860369690841003*^9, 
   3.86036985822696*^9, {3.86036989200847*^9, 3.860369918342462*^9}, 
   3.860395824267021*^9, 3.8604003660556307`*^9, 3.86109640906504*^9, 
   3.861096469184401*^9, {3.86109650683202*^9, 3.8610965227120123`*^9}, 
   3.8610966412588873`*^9, 3.861097977894615*^9},
 CellLabel->
  "Out[296]=",ExpressionUUID->"d88ac8da-17de-4c82-8811-2c109bafbe08"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x74forIscoscelesTriangle", "=", 
  RowBox[{"x477", "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", " ", 
      SuperscriptBox["c", "6"]}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["b", "2"], "-", 
        SuperscriptBox["c", "2"]}], ")"}], "4"]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.861096670736146*^9, 3.8610966953128023`*^9}},
 CellLabel->
  "In[297]:=",ExpressionUUID->"615ec0c7-af57-406f-a2ca-2086ed39e7ec"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["b", "2"]}], ",", 
   RowBox[{"2", " ", 
    SuperscriptBox["b", "2"]}], ",", 
   RowBox[{"-", 
    SuperscriptBox["c", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.86109668062939*^9, 3.8610966964001007`*^9}, 
   3.861097977905064*^9},
 CellLabel->
  "Out[297]=",ExpressionUUID->"582cb834-6592-4394-8e28-a3b5ae046e47"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Lemma 11.10 for X(74)/X(477) for right triangle", "Subsection",
 CellChangeTimes->{{3.860669595236927*^9, 3.8606696107084293`*^9}, {
  3.861095917812874*^9, 3.8610959615244913`*^9}, {3.861096142037181*^9, 
  3.861096145557063*^9}},ExpressionUUID->"3ced53ba-a336-4864-9de4-\
8ca8104515fb"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"x74", "=", 
   RowBox[{"ETC1", "[", 
    RowBox[{"[", 
     RowBox[{"74", ",", "2"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"x74forRightTriangle", "=", 
   RowBox[{
    RowBox[{"x74", "/.", 
     RowBox[{"c", "\[Rule]", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"a", "^", "2"}], "+", 
        RowBox[{"b", "^", "2"}]}], "]"}]}]}], "//", "Simplify"}]}], 
  ";"}], "\n", 
 RowBox[{"F", "=", 
  RowBox[{"x74forRightTriangle", "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     RowBox[{"a", "^", "4"}], " ", 
     RowBox[{"b", "^", "4"}]}], ")"}]}]}]}], "Input",
 CellChangeTimes->{{3.861096000261269*^9, 3.861096010836895*^9}, {
  3.8610960735022163`*^9, 3.861096074085103*^9}},
 CellLabel->
  "In[298]:=",ExpressionUUID->"45f06879-cbd4-4be5-a3a5-eb1f93b0edcd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2", " ", 
    SuperscriptBox["a", "2"]}], ",", 
   RowBox[{"2", " ", 
    SuperscriptBox["b", "2"]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["a", "2"]}], "-", 
    SuperscriptBox["b", "2"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.861096003888818*^9, 3.861096012221344*^9}, 
   3.861096075223596*^9, 3.86109797794526*^9},
 CellLabel->
  "Out[300]=",ExpressionUUID->"0482922e-0b6a-46cd-bd47-1bebd3f795e6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"x477", "=", 
   RowBox[{"ETC1", "[", 
    RowBox[{"[", 
     RowBox[{"477", ",", "2"}], "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"x477forRightTriangle", "=", 
   RowBox[{
    RowBox[{"x477", "/.", 
     RowBox[{"c", "\[Rule]", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"a", "^", "2"}], "+", 
        RowBox[{"b", "^", "2"}]}], "]"}]}]}], "//", "Factor"}]}], ";"}], "\n", 
 RowBox[{"G", "=", 
  RowBox[{"x477forRightTriangle", "/", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", " ", 
       RowBox[{"a", "^", "6"}], " ", 
       RowBox[{"b", "^", "6"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", "^", "2"}], "-", 
       RowBox[{"3", " ", 
        RowBox[{"b", "^", "2"}]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        RowBox[{"a", "^", "2"}]}], "-", 
       RowBox[{"b", "^", "2"}]}], ")"}]}], ")"}]}]}]}], "Input",
 CellChangeTimes->{{3.860663511974461*^9, 3.860663511979611*^9}, 
   3.8610959941913223`*^9, {3.861096027301108*^9, 3.861096045918459*^9}},
 CellLabel->
  "In[301]:=",ExpressionUUID->"8af35673-7391-455b-bfb3-edcfb6ef6a2f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"]}], 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["a", "2"]}], "-", 
     SuperscriptBox["b", "2"]}]], ",", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["b", "2"]}], 
     RowBox[{
      SuperscriptBox["a", "2"], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["b", "2"]}]}]]}], ",", 
   RowBox[{"-", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{3.861096046942286*^9, 3.86109797795687*^9},
 CellLabel->
  "Out[303]=",ExpressionUUID->"4c266aef-4815-4e3c-823f-936cdd176cdf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mid", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"normed", "[", "F", "]"}], "+", 
    RowBox[{"normed", "[", "G", "]"}]}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.86066352731597*^9, 3.86066354704653*^9}, {
  3.860663973954253*^9, 3.8606639749598627`*^9}},
 CellLabel->
  "In[304]:=",ExpressionUUID->"58b836a0-0353-419f-9182-574fe7747756"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["b", "2"]}], ")"}], "2"]], ",", 
   FractionBox[
    RowBox[{"8", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["b", "2"]}], ")"}], "2"]], ",", 
   FractionBox[
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "4"], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["b", "2"]}], "+", 
       SuperscriptBox["b", "4"]}], ")"}]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "2"], "+", 
       SuperscriptBox["b", "2"]}], ")"}], "2"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.860663541147622*^9, 3.860663548198007*^9}, 
   3.860663978077969*^9, 3.861096087635083*^9, 3.861097977996131*^9},
 CellLabel->
  "Out[304]=",ExpressionUUID->"e07af228-12cd-463e-bc2e-538414abb692"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mid", "*", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "^", "2"}], "+", 
      RowBox[{"b", "^", "2"}]}], ")"}], "^", "2"}], "/", "2"}]}]], "Input",
 CellChangeTimes->{{3.8606639829338417`*^9, 3.860663997695896*^9}},
 CellLabel->
  "In[305]:=",ExpressionUUID->"9679fc2c-d5a3-443e-aa9b-fef7f4106d99"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox["b", "2"]}], ",", 
   RowBox[{"4", " ", 
    SuperscriptBox["a", "2"], " ", 
    SuperscriptBox["b", "2"]}], ",", 
   RowBox[{
    SuperscriptBox["a", "4"], "-", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "2"], " ", 
     SuperscriptBox["b", "2"]}], "+", 
    SuperscriptBox["b", "4"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.860663998616067*^9, 3.861096097605822*^9, 
  3.8610979780071497`*^9},
 CellLabel->
  "Out[305]=",ExpressionUUID->"b8c3347f-56ba-4b9c-9ac7-3c23e2b1bdfe"]
}, Open  ]]
}, Closed]]
}, Closed]]
},
WindowSize->{874, 980},
WindowMargins->{{501, Automatic}, {Automatic, 156}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 1173, 22, 265, "Text",ExpressionUUID->"d08986c7-ef4f-4445-8a81-a177c140a9e8",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1756, 46, 151, 3, 67, "Section",ExpressionUUID->"89212534-7237-4eed-b992-f4fefc071f04"],
Cell[1910, 51, 435, 8, 30, "Input",ExpressionUUID->"7c63bfc2-58ce-4821-8658-b86ccade219d"],
Cell[2348, 61, 2511, 71, 178, "Input",ExpressionUUID->"0863b046-8b0f-4b7d-9bfd-c8c5ca9bd6b2"]
}, Closed]],
Cell[CellGroupData[{
Cell[4896, 137, 460, 7, 53, "Section",ExpressionUUID->"7932e666-d308-4af3-820e-66659bf35ae8"],
Cell[5359, 146, 469, 9, 46, "Text",ExpressionUUID->"f5a7ec9c-ccac-4438-8f9e-acbe28753294",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[5853, 159, 14765, 255, 871, "Input",ExpressionUUID->"513fce6d-e219-4b80-a7c7-f036d4f949ec"],
Cell[20621, 416, 19308, 369, 408, "Output",ExpressionUUID->"7cce6fb0-2805-4de9-aa13-e73715dd2225"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[39978, 791, 305, 5, 53, "Section",ExpressionUUID->"47b6734f-7749-43fd-be07-f0a57a6ed3f6"],
Cell[CellGroupData[{
Cell[40308, 800, 170, 3, 54, "Subsection",ExpressionUUID->"e3e32188-b387-447f-b9c4-d6665e1c49ac"],
Cell[CellGroupData[{
Cell[40503, 807, 6353, 151, 607, "Input",ExpressionUUID->"36e45cb8-39da-47de-8414-d6ba15565464"],
Cell[CellGroupData[{
Cell[46881, 962, 932, 24, 38, "Print",ExpressionUUID->"5c6d8d5e-770a-4186-b380-72766d646354"],
Cell[47816, 988, 1243, 35, 38, "Print",ExpressionUUID->"2d3a2bdc-b1a6-4c9b-84af-4ac36810f9a5"],
Cell[49062, 1025, 1394, 39, 38, "Print",ExpressionUUID->"e2e11ac7-186e-4c6e-9619-f79dc87decc0"],
Cell[50459, 1066, 1333, 37, 27, "Print",ExpressionUUID->"f9a0297d-5b10-4bcc-be47-4e5ac1bac8d5"],
Cell[51795, 1105, 2602, 69, 43, "Print",ExpressionUUID->"132e3841-7ce8-4df2-8a9c-673e8e62e98b"],
Cell[54400, 1176, 1830, 51, 27, "Print",ExpressionUUID->"d5bbd7b9-29b1-45b7-ad74-0415515871cc"],
Cell[56233, 1229, 1802, 51, 27, "Print",ExpressionUUID->"7199de73-10dc-4fb2-b880-09617b211a28"],
Cell[58038, 1282, 1350, 37, 40, "Print",ExpressionUUID->"230c65cb-31d6-453f-b9fe-d85dfc9e3124"],
Cell[59391, 1321, 1249, 35, 38, "Print",ExpressionUUID->"88bac6c7-30f3-4357-aa2f-c53cc1c6e875"],
Cell[60643, 1358, 1204, 33, 38, "Print",ExpressionUUID->"c656a51f-b4e5-411a-8b86-16924d87893e"],
Cell[61850, 1393, 2544, 67, 38, "Print",ExpressionUUID->"78405997-abb3-4837-abc6-c38cfb3ab2b9"],
Cell[64397, 1462, 1530, 43, 38, "Print",ExpressionUUID->"cd004355-3b19-4471-9710-c08e82c22c36"],
Cell[65930, 1507, 1602, 45, 38, "Print",ExpressionUUID->"f5351527-193c-4044-83f6-b649869aae56"],
Cell[67535, 1554, 1424, 40, 40, "Print",ExpressionUUID->"d8241ae3-0717-4e13-9d8a-0cbb502f041b"],
Cell[68962, 1596, 2787, 75, 43, "Print",ExpressionUUID->"10c4a303-8086-4837-87ed-baf6049cdd1b"],
Cell[71752, 1673, 1247, 35, 38, "Print",ExpressionUUID->"1753cea4-4441-4f14-88a3-c3c6818cb1a3"],
Cell[73002, 1710, 1434, 40, 40, "Print",ExpressionUUID->"a2c88a31-ef6b-42dd-858e-e4f53df7d1f1"],
Cell[74439, 1752, 1805, 51, 44, "Print",ExpressionUUID->"9ad79ee6-dc85-41a9-b70f-12f88632f2ad"],
Cell[76247, 1805, 1343, 37, 27, "Print",ExpressionUUID->"b690c040-489d-474c-9aef-3fbf564f2bbe"],
Cell[77593, 1844, 1555, 42, 38, "Print",ExpressionUUID->"d268053f-45ab-43e1-a120-c81f991a32b6"],
Cell[79151, 1888, 1779, 49, 27, "Print",ExpressionUUID->"d5e3011b-243b-4678-b9cf-689948156116"],
Cell[80933, 1939, 1532, 43, 38, "Print",ExpressionUUID->"17b71c74-8c14-486d-a9b4-e6462ff11d52"],
Cell[82468, 1984, 1794, 48, 27, "Print",ExpressionUUID->"5f2eaeec-b51e-4453-a95b-3db966c16996"],
Cell[84265, 2034, 1401, 39, 40, "Print",ExpressionUUID->"892ced67-2b03-4341-a63c-12871fcba72a"],
Cell[85669, 2075, 2787, 75, 51, "Print",ExpressionUUID->"ee896ad0-9412-42f1-886f-aee0fc973e87"],
Cell[88459, 2152, 1679, 45, 43, "Print",ExpressionUUID->"9512e5ae-a3ec-4a38-978d-ac0bb7fc0fb1"],
Cell[90141, 2199, 1326, 36, 38, "Print",ExpressionUUID->"310f45a6-0720-470e-9860-b97acc98c45e"],
Cell[91470, 2237, 1375, 38, 38, "Print",ExpressionUUID->"96765896-037c-47ee-b925-5e19f3ad4361"],
Cell[92848, 2277, 2508, 72, 45, "Print",ExpressionUUID->"2b8d6f4d-d092-4bd9-92cf-0bcd8e32903b"],
Cell[95359, 2351, 1317, 37, 27, "Print",ExpressionUUID->"47c0c36f-0650-43b6-b552-b713985d31bf"],
Cell[96679, 2390, 1328, 36, 38, "Print",ExpressionUUID->"aae936cc-0df0-46f5-8df0-c28c6a487393"],
Cell[98010, 2428, 2874, 78, 47, "Print",ExpressionUUID->"6c04ff74-5c06-4531-b319-1b56c4416a28"],
Cell[100887, 2508, 2943, 78, 67, "Print",ExpressionUUID->"ac0d9d0e-33b5-4fba-bb48-0250ef47e162"],
Cell[103833, 2588, 1456, 39, 38, "Print",ExpressionUUID->"82a3c1db-f6f9-40ec-bae3-e08ca71c0ddb"],
Cell[105292, 2629, 5433, 140, 96, "Print",ExpressionUUID->"9679f988-5b22-45d5-9726-74ffdfa67723"],
Cell[110728, 2771, 1882, 52, 43, "Print",ExpressionUUID->"5f36d8f6-4999-43e2-9d95-d1a2816406dc"],
Cell[112613, 2825, 4971, 129, 79, "Print",ExpressionUUID->"8fc7b2f3-e2b2-451f-b689-b99dd6e09785"],
Cell[117587, 2956, 2650, 70, 43, "Print",ExpressionUUID->"d0c55bf9-de04-49ab-932c-31038521afb2"],
Cell[120240, 3028, 1253, 35, 38, "Print",ExpressionUUID->"38a5b87d-b66b-40e5-a813-f4378b7baa12"],
Cell[121496, 3065, 1200, 33, 38, "Print",ExpressionUUID->"db6a52f9-6aa8-45af-b1b0-bebda354b0b9"],
Cell[122699, 3100, 1253, 35, 38, "Print",ExpressionUUID->"9c4848af-a513-41d0-a1ff-8421176a9108"],
Cell[123955, 3137, 2123, 62, 45, "Print",ExpressionUUID->"927e7963-55fa-44ef-8bfe-231ad6ea9dd8"],
Cell[126081, 3201, 1978, 53, 38, "Print",ExpressionUUID->"47768016-18b4-4c79-97f3-be97971c98d8"],
Cell[128062, 3256, 1202, 33, 38, "Print",ExpressionUUID->"b4b41159-4267-4f11-a9f6-cb720777b203"],
Cell[129267, 3291, 2852, 75, 67, "Print",ExpressionUUID->"c1f0bcf8-614b-455b-b7b9-a672726e0626"],
Cell[132122, 3368, 2937, 80, 76, "Print",ExpressionUUID->"e1170123-7a2a-426f-983e-c7a9f51a440a"],
Cell[135062, 3450, 3367, 92, 68, "Print",ExpressionUUID->"7bfd27e7-bf31-49bc-ab69-ea9f42238e65"],
Cell[138432, 3544, 2525, 67, 41, "Print",ExpressionUUID->"83131197-dd01-4593-9acf-1cbbc5785e3a"],
Cell[140960, 3613, 2752, 74, 60, "Print",ExpressionUUID->"3adead6f-6b3b-4546-a32d-d6764903e79d"],
Cell[143715, 3689, 3004, 80, 67, "Print",ExpressionUUID->"f9ef0307-aa07-4d97-bc5f-c3fc26e4412c"],
Cell[146722, 3771, 3587, 96, 72, "Print",ExpressionUUID->"431979c6-7eb3-4dae-845a-cbdb1c03d65f"],
Cell[150312, 3869, 1649, 46, 38, "Print",ExpressionUUID->"3aa71f05-0f2a-49ea-a718-15946c8e6f39"],
Cell[151964, 3917, 2023, 54, 38, "Print",ExpressionUUID->"0fb326f9-869e-4630-9620-ee4613497bc7"],
Cell[153990, 3973, 1544, 44, 38, "Print",ExpressionUUID->"02930c5d-8c6a-4444-9093-30c83371673a"],
Cell[155537, 4019, 1544, 44, 38, "Print",ExpressionUUID->"34c38970-e371-4370-81c3-1aaf77f6efd5"],
Cell[157084, 4065, 3322, 89, 76, "Print",ExpressionUUID->"aa9fd7cc-3b28-43e6-b7ff-5999aabf83cd"],
Cell[160409, 4156, 1330, 36, 38, "Print",ExpressionUUID->"52bcb4f5-a9dc-4786-aad3-c956f1fbdc9d"],
Cell[161742, 4194, 1431, 40, 40, "Print",ExpressionUUID->"1f232323-f321-4cd8-8bb1-6628891b6bf5"],
Cell[163176, 4236, 1403, 39, 40, "Print",ExpressionUUID->"f4d6070f-f25b-4569-9db4-da97b4b91262"],
Cell[164582, 4277, 1430, 40, 40, "Print",ExpressionUUID->"efe64d11-ab01-464b-b878-343d826e06fd"],
Cell[166015, 4319, 1401, 39, 40, "Print",ExpressionUUID->"87b27210-d1f0-4d6d-b1be-71640bde146b"],
Cell[167419, 4360, 1200, 33, 38, "Print",ExpressionUUID->"3fd78cd7-235b-4c59-8850-9ced10caa02a"],
Cell[168622, 4395, 1424, 40, 40, "Print",ExpressionUUID->"8fb626f5-5ef2-4399-ba19-40514a50626f"],
Cell[170049, 4437, 1434, 40, 40, "Print",ExpressionUUID->"cf91fb30-501b-40a1-881e-031f318591cd"],
Cell[171486, 4479, 1204, 33, 38, "Print",ExpressionUUID->"0abadcb0-b9d9-4656-8882-e9a601062415"],
Cell[172693, 4514, 1839, 50, 43, "Print",ExpressionUUID->"91706627-8d00-41a6-ba95-33b6375aa1ab"],
Cell[174535, 4566, 1200, 33, 38, "Print",ExpressionUUID->"e57dc30f-a964-48c7-96dc-3526d4d7d071"],
Cell[175738, 4601, 3015, 81, 72, "Print",ExpressionUUID->"54497ec0-d65a-4713-8c84-7eb28b49aa21"],
Cell[178756, 4684, 3629, 97, 72, "Print",ExpressionUUID->"92c72a33-01b2-4a99-8d9d-a0c22932960f"],
Cell[182388, 4783, 2933, 79, 70, "Print",ExpressionUUID->"6fd52933-caba-4a4b-8742-cb28d0883229"],
Cell[185324, 4864, 1199, 33, 38, "Print",ExpressionUUID->"525d56bd-1da1-4955-8b0d-1a44f868a62f"],
Cell[186526, 4899, 1686, 46, 43, "Print",ExpressionUUID->"7b5594eb-1f31-4bc5-a9ec-1bd909a59285"],
Cell[188215, 4947, 1832, 51, 27, "Print",ExpressionUUID->"32bce703-9f74-43fc-afaf-6bf45fff8487"],
Cell[190050, 5000, 2489, 67, 47, "Print",ExpressionUUID->"406fde6c-86de-41ff-bef9-9f740fdf9530"],
Cell[192542, 5069, 2276, 63, 49, "Print",ExpressionUUID->"95635b8f-f6c4-455b-a03c-a88e78777a01"],
Cell[194821, 5134, 2624, 72, 49, "Print",ExpressionUUID->"623114e1-1f00-4a34-8013-62ca6e6a8b7c"],
Cell[197448, 5208, 2266, 63, 44, "Print",ExpressionUUID->"353db427-eedc-43cd-90c2-bc944188abcf"],
Cell[199717, 5273, 1950, 54, 44, "Print",ExpressionUUID->"c3ef3b65-ecbd-43c8-86d7-5ef58347a1ed"],
Cell[201670, 5329, 3336, 88, 67, "Print",ExpressionUUID->"e09b9580-cccf-4def-a0b7-a60b5fcd73dc"],
Cell[205009, 5419, 2751, 76, 43, "Print",ExpressionUUID->"e0aa6da3-3e5d-45a1-aba1-96df23674776"],
Cell[207763, 5497, 1931, 53, 44, "Print",ExpressionUUID->"5bf45707-0280-4b35-9594-a985ea3dc41d"],
Cell[209697, 5552, 1932, 54, 27, "Print",ExpressionUUID->"774b31ad-990f-483b-8a41-6c8500eae181"],
Cell[211632, 5608, 6461, 167, 118, "Print",ExpressionUUID->"910a2eaa-9070-4731-a9b3-156868ec3d68"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[218142, 5781, 117, 1, 30, "Input",ExpressionUUID->"54ce18c6-d528-4685-9991-19db1b739853"],
Cell[218262, 5784, 1068, 16, 77, "Output",ExpressionUUID->"64181869-f189-428e-a9e8-d85137825471"]
}, Open  ]],
Cell[CellGroupData[{
Cell[219367, 5805, 179, 2, 30, "Input",ExpressionUUID->"9b0cb274-4df1-455a-add5-1a58f07de223"],
Cell[219549, 5809, 3713, 122, 225, "Output",ExpressionUUID->"42125a45-8754-462b-ba84-f36534e49b33"]
}, Open  ]],
Cell[CellGroupData[{
Cell[223299, 5936, 119, 1, 30, "Input",ExpressionUUID->"554b814f-00b0-4a8b-95c8-add2a6a0fdff"],
Cell[223421, 5939, 554, 9, 56, "Output",ExpressionUUID->"33668292-374e-4110-9668-0743227781f2"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[224024, 5954, 253, 4, 38, "Subsection",ExpressionUUID->"dbb1befd-a849-425c-9ea4-b9d195bfaf81"],
Cell[224280, 5960, 2256, 66, 77, "Input",ExpressionUUID->"306bc053-b366-4a7d-aed9-13d10022fc9a"],
Cell[CellGroupData[{
Cell[226561, 6030, 524, 14, 30, "Input",ExpressionUUID->"c59c02c8-1f35-487d-91fc-7de37b4179a2"],
Cell[227088, 6046, 288, 4, 34, "Output",ExpressionUUID->"c2189221-d3e3-4148-bcf1-d063c91ac4bb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[227413, 6055, 399, 10, 30, "Input",ExpressionUUID->"d5187fbc-36b2-4e24-b3ea-6a94f77efc90"],
Cell[227815, 6067, 1509, 44, 60, "Output",ExpressionUUID->"2ae7d054-9bbc-43ac-ab21-56ecaaf5d104"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[229373, 6117, 325, 5, 38, "Subsection",ExpressionUUID->"7f694f99-2216-46d0-b435-d277881be957"],
Cell[CellGroupData[{
Cell[229723, 6126, 155, 3, 45, "Subsubsection",ExpressionUUID->"3592fc2f-0498-4a33-8241-5a0cecd78f72"],
Cell[CellGroupData[{
Cell[229903, 6133, 6613, 170, 880, "Input",ExpressionUUID->"2174a73f-b1f9-4467-aa7a-16b96a1a56b4"],
Cell[CellGroupData[{
Cell[236541, 6307, 1131, 28, 40, "Print",ExpressionUUID->"4fa7a0c0-e321-4e38-aced-94e41f5cdfcd"],
Cell[237675, 6337, 2933, 78, 49, "Print",ExpressionUUID->"66ecab55-a542-4b63-8a4b-43294fc2e036"],
Cell[240611, 6417, 3797, 95, 49, "Print",ExpressionUUID->"608e0e89-dbca-4e28-925a-b194be006c6d"],
Cell[244411, 6514, 4650, 115, 69, "Print",ExpressionUUID->"f84d67bb-a0a7-464c-8728-9b8e2f2aa65c"],
Cell[249064, 6631, 4202, 112, 62, "Print",ExpressionUUID->"4b40fde0-48d1-4a47-9b92-a0db020a8e18"],
Cell[253269, 6745, 9873, 252, 147, "Print",ExpressionUUID->"d3d3bdd8-eadb-44b9-8bc8-90a5b9a7aa6d"],
Cell[263145, 6999, 2638, 69, 40, "Print",ExpressionUUID->"54591df9-04f6-456e-afd7-32c1ecd2f74a"],
Cell[265786, 7070, 2786, 79, 59, "Print",ExpressionUUID->"af1ad1e6-336c-426b-b55b-450788ccd2e3"],
Cell[268575, 7151, 2203, 60, 40, "Print",ExpressionUUID->"de91ae73-49e0-4a61-87b4-9da43eca257e"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[270839, 7218, 216, 4, 37, "Subsubsection",ExpressionUUID->"8d28747c-75c4-4366-8c07-c55bccddb632"],
Cell[CellGroupData[{
Cell[271080, 7226, 185, 2, 30, "Input",ExpressionUUID->"5c83edd7-f0f5-4b4d-a147-4ccc1ecc1f5c"],
Cell[271268, 7230, 1406, 21, 119, "Output",ExpressionUUID->"c25cee09-4cdf-4c2f-81b2-205788e9684e"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[272723, 7257, 212, 4, 37, "Subsubsection",ExpressionUUID->"0c41d9be-0cc4-4472-b345-b69011c186c7"],
Cell[CellGroupData[{
Cell[272960, 7265, 119, 1, 30, "Input",ExpressionUUID->"9d5ae49b-cb60-4a60-abe0-66b0cab9790e"],
Cell[273082, 7268, 595, 11, 56, "Output",ExpressionUUID->"a6a9de13-18e9-40e1-82e5-0f451a412796"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[273726, 7285, 210, 4, 37, "Subsubsection",ExpressionUUID->"8c5cc360-a212-4ed8-9aa8-3e86e887ee9d"],
Cell[CellGroupData[{
Cell[273961, 7293, 127, 1, 30, "Input",ExpressionUUID->"cf2286b8-72f0-4c7a-8c11-f9111d10bdba"],
Cell[274091, 7296, 789, 12, 56, "Output",ExpressionUUID->"4087c3ff-4390-4d7f-938f-7dbaae67c307"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[274929, 7314, 169, 3, 37, "Subsubsection",ExpressionUUID->"45a91fab-27f0-4050-8126-7564dbe45784"],
Cell[CellGroupData[{
Cell[275123, 7321, 121, 1, 30, "Input",ExpressionUUID->"d45c2ca2-d9e4-4c4b-96db-3b090776d3fd"],
Cell[275247, 7324, 1621, 23, 140, "Output",ExpressionUUID->"66b8f85f-c297-4018-976b-e133360ea132"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[276917, 7353, 167, 3, 37, "Subsubsection",ExpressionUUID->"59324dc0-4f8b-49b9-8a79-4259442ad5b3"],
Cell[CellGroupData[{
Cell[277109, 7360, 184, 2, 30, "Input",ExpressionUUID->"0b14d143-dc6c-419b-b6db-272b3e063e8b"],
Cell[277296, 7364, 380, 7, 34, "Output",ExpressionUUID->"19b49d1c-e7c1-42bb-984d-bf389796cd06"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[277725, 7377, 157, 2, 37, "Subsubsection",ExpressionUUID->"eed99e70-3dba-4177-be17-e45b82903e47"],
Cell[CellGroupData[{
Cell[277907, 7383, 113, 1, 30, "Input",ExpressionUUID->"6b9c45d9-fd46-4d07-a773-7601139e9543"],
Cell[278023, 7386, 1086, 35, 51, "Output",ExpressionUUID->"14fecc82-ad46-428f-837b-197ddc35acef"]
}, Open  ]],
Cell[279124, 7424, 757, 21, 94, "Input",ExpressionUUID->"a7008ab6-a0de-4671-86f5-e4001438a3eb"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[279942, 7452, 224, 4, 53, "Section",ExpressionUUID->"470861c6-3446-4848-9c07-bf0f9b32f469"],
Cell[CellGroupData[{
Cell[280191, 7460, 257, 4, 54, "Subsection",ExpressionUUID->"9d82def8-3fac-42a3-817b-114b3e835fcd"],
Cell[CellGroupData[{
Cell[280473, 7468, 162, 3, 45, "Subsubsection",ExpressionUUID->"64765008-1a29-4e9f-ab64-b3955dcd556a"],
Cell[280638, 7473, 1260, 36, 136, "Input",ExpressionUUID->"4ecfe8d7-059a-474a-9395-a78585538ea2"],
Cell[CellGroupData[{
Cell[281923, 7513, 1643, 49, 56, "Input",ExpressionUUID->"575920e1-afc7-4733-889e-249b92cd939a"],
Cell[283569, 7564, 1671, 50, 60, "Output",ExpressionUUID->"41071dad-4586-4e15-bd8e-858653dd6762"]
}, Open  ]],
Cell[285255, 7617, 762, 21, 30, "Input",ExpressionUUID->"c8f366ff-0239-44cc-af57-aead5947df52"],
Cell[CellGroupData[{
Cell[286042, 7642, 258, 5, 30, "Input",ExpressionUUID->"dfa843dd-4249-4cb9-be50-67fbe28e24be"],
Cell[286303, 7649, 318, 6, 34, "Output",ExpressionUUID->"adbedf3a-21d3-4da9-8ef9-80c9854d839c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[286658, 7660, 258, 5, 30, "Input",ExpressionUUID->"5b36009d-8ab9-4e5b-8739-4736dc02c121"],
Cell[286919, 7667, 487, 12, 51, "Output",ExpressionUUID->"a65f9d0f-9424-4c77-b9f4-61449db61722"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287443, 7684, 460, 12, 30, "Input",ExpressionUUID->"ddd8c2fa-fbeb-44f1-bee4-33dfccb73d3b"],
Cell[287906, 7698, 455, 11, 51, "Output",ExpressionUUID->"e8668853-214b-4c9e-92d0-22134f0eab8a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[288398, 7714, 176, 2, 30, "Input",ExpressionUUID->"186439ff-86f1-44a0-a8d9-f3ec25b5e78c"],
Cell[288577, 7718, 495, 12, 51, "Output",ExpressionUUID->"47b17f17-c67c-46d3-a47e-2da9ab41a3b9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[289109, 7735, 438, 8, 30, "Input",ExpressionUUID->"9291d8b1-7f95-4e75-ae2a-a4036117b8a1"],
Cell[289550, 7745, 561, 12, 51, "Output",ExpressionUUID->"d4dcdb96-fea5-4c2d-a4de-1e9fe89a0612"]
}, Open  ]],
Cell[CellGroupData[{
Cell[290148, 7762, 275, 5, 30, "Input",ExpressionUUID->"3208da89-5644-4afa-a68a-1d74528a20f5"],
Cell[290426, 7769, 319, 4, 34, "Output",ExpressionUUID->"393043e2-3140-4b71-83e1-569c55badfea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[290782, 7778, 417, 9, 30, "Input",ExpressionUUID->"0f132a9e-c928-42df-88cb-5010ffa52448"],
Cell[291202, 7789, 408, 8, 53, "Output",ExpressionUUID->"79132867-195e-4c47-a1e5-07f097530548"]
}, Open  ]],
Cell[CellGroupData[{
Cell[291647, 7802, 268, 5, 30, "Input",ExpressionUUID->"b451f244-a13e-4e1f-9218-9b8d9ccba488"],
Cell[291918, 7809, 395, 9, 53, "Output",ExpressionUUID->"e8fcc13b-b103-43d3-88b8-4f0434a7a80e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[292350, 7823, 234, 4, 30, "Input",ExpressionUUID->"d3dff3e0-0cfe-44b1-83cf-2a60d61091fe"],
Cell[292587, 7829, 3093, 92, 100, "Output",ExpressionUUID->"86afd077-7753-4c78-8389-6366d4e3cf89"]
}, Open  ]],
Cell[295695, 7924, 1211, 34, 178, "Input",ExpressionUUID->"57e50172-32e8-477f-a5f3-ebf840f66a77"],
Cell[296909, 7960, 2141, 61, 94, "Input",ExpressionUUID->"532664f9-0673-4f1c-a9c6-d9bba576ddde"],
Cell[CellGroupData[{
Cell[299075, 8025, 176, 2, 30, "Input",ExpressionUUID->"5524ae46-e8c0-40c7-b089-fa04c6294abe"],
Cell[299254, 8029, 4813, 156, 168, "Output",ExpressionUUID->"cf9e7862-8485-476e-a74d-85e83fc9eab4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[304104, 8190, 411, 9, 30, "Input",ExpressionUUID->"9730d227-81b9-44c9-ac5c-60f628ab0f61"],
Cell[304518, 8201, 612, 12, 53, "Output",ExpressionUUID->"1556f727-324d-474b-aa85-141c9dde579b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305167, 8218, 264, 5, 30, "Input",ExpressionUUID->"8275d24e-0dfa-4bae-a0f3-1fb9f14b2475"],
Cell[305434, 8225, 362, 7, 34, "Output",ExpressionUUID->"d23c9a2b-05df-48c2-81ce-03dc61d398d0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[305833, 8237, 375, 8, 30, "Input",ExpressionUUID->"ae8021bd-6cdf-48db-9b4a-796dfbc8e40a"],
Cell[306211, 8247, 296, 5, 34, "Output",ExpressionUUID->"9e7d500e-bccb-4155-ab86-88adbfad0fbe"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[306568, 8259, 241, 4, 38, "Subsection",ExpressionUUID->"0d17fde0-0d53-4260-88b7-c578768f6c33"],
Cell[CellGroupData[{
Cell[306834, 8267, 270, 4, 45, "Subsubsection",ExpressionUUID->"146aa3cb-e612-4e95-9dfd-28e103e8b38d"],
Cell[CellGroupData[{
Cell[307129, 8275, 277, 6, 30, "Input",ExpressionUUID->"221e464c-a8d6-447e-932e-736ba26b3155"],
Cell[307409, 8283, 1309, 41, 37, "Output",ExpressionUUID->"23634c37-100d-45ea-af9d-30d2133c1bf9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[308755, 8329, 556, 16, 30, "Input",ExpressionUUID->"bdfe97ac-0647-471a-bf2f-551298bda867"],
Cell[309314, 8347, 280, 5, 34, "Output",ExpressionUUID->"7b9d42fd-523f-4917-9502-b394f4f28689"]
}, Open  ]],
Cell[CellGroupData[{
Cell[309631, 8357, 279, 6, 30, "Input",ExpressionUUID->"c7923504-0ddd-42b1-b9c1-9db7cafa8d78"],
Cell[309913, 8365, 6240, 188, 152, "Output",ExpressionUUID->"640be061-c8a3-45ec-82f8-54fc6b04615f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[316190, 8558, 489, 14, 30, "Input",ExpressionUUID->"a04c9867-66ef-4ac5-8d99-9ce89c7d3075"],
Cell[316682, 8574, 256, 5, 34, "Output",ExpressionUUID->"67c44df8-fedd-403f-8297-17a98c194fc2"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[316987, 8585, 273, 4, 37, "Subsubsection",ExpressionUUID->"aaf6148f-d5fe-4ba1-88e3-8a9e590b3d46"],
Cell[CellGroupData[{
Cell[317285, 8593, 279, 6, 30, "Input",ExpressionUUID->"3543d712-1fe4-4727-a85b-dd8b31d1d764"],
Cell[317567, 8601, 6272, 186, 152, "Output",ExpressionUUID->"90cdad47-7011-4b85-a1e2-f100664f48e4"]
}, Open  ]],
Cell[323854, 8790, 404, 9, 52, "Input",ExpressionUUID->"3bacc282-27a9-4321-9459-1cabc57e00b3"],
Cell[CellGroupData[{
Cell[324283, 8803, 389, 8, 30, "Input",ExpressionUUID->"aecccb34-fabd-42e4-8765-b67e6b4dc5ee"],
Cell[324675, 8813, 2098, 62, 60, "Output",ExpressionUUID->"e8a7a926-4c90-404d-aaea-ae70d8c150e2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[326810, 8880, 889, 19, 73, "Input",ExpressionUUID->"7e858350-d466-41f7-b7f7-2626e7c8ceba"],
Cell[327702, 8901, 1688, 49, 60, "Output",ExpressionUUID->"5d5455d2-dd01-4bcc-bcbc-f2c749fd5546"]
}, Open  ]],
Cell[CellGroupData[{
Cell[329427, 8955, 401, 10, 30, "Input",ExpressionUUID->"fba84d91-bbdd-4fd6-af56-00d518d05eee"],
Cell[329831, 8967, 223, 3, 34, "Output",ExpressionUUID->"c9950c45-b737-490c-9160-9badb73fa273"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[330115, 8977, 168, 3, 38, "Subsection",ExpressionUUID->"33efc3b8-cc24-4b49-bdd3-11597d0f8696"],
Cell[CellGroupData[{
Cell[330308, 8984, 278, 4, 45, "Subsubsection",ExpressionUUID->"85dbcfac-3ed2-44b0-890d-8efa96290fc7"],
Cell[CellGroupData[{
Cell[330611, 8992, 887, 28, 94, "Input",ExpressionUUID->"b30efd96-3fde-4377-93d9-4ec246afc3df"],
Cell[331501, 9022, 1087, 33, 49, "Output",ExpressionUUID->"c4644419-a184-4e70-9d5a-d655c6c71725"]
}, Open  ]],
Cell[CellGroupData[{
Cell[332625, 9060, 391, 10, 30, "Input",ExpressionUUID->"354c36f1-bcba-4151-8118-4f68b53cf150"],
Cell[333019, 9072, 677, 18, 37, "Output",ExpressionUUID->"6d9a8438-79e9-4582-81da-7b7e51667be0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[333733, 9095, 272, 6, 30, "Input",ExpressionUUID->"bb371ab0-27e2-4e0e-9887-9d8236ea9a71"],
Cell[334008, 9103, 552, 16, 34, "Output",ExpressionUUID->"d5932f19-d3b0-402c-8964-b79363e3d01d"]
}, Open  ]],
Cell[334575, 9122, 665, 19, 30, "Input",ExpressionUUID->"92697046-2522-46ef-96a5-00ef56a74801"],
Cell[CellGroupData[{
Cell[335265, 9145, 563, 14, 30, "Input",ExpressionUUID->"b5c592c6-75b7-4f62-aa52-bc28789c5ff5"],
Cell[335831, 9161, 349, 7, 52, "Output",ExpressionUUID->"705fa393-aa52-4d95-a60a-6063647cb1fa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[336217, 9173, 662, 16, 30, "Input",ExpressionUUID->"1c3a58d7-5635-4843-a904-c3e212ec6b20"],
Cell[336882, 9191, 413, 9, 52, "Output",ExpressionUUID->"f47b30a4-9853-4a7f-8ec1-ccdbb1dfcfcb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337332, 9205, 437, 9, 30, "Input",ExpressionUUID->"f99fb1c2-bb6f-411e-bda4-9abc44436c23"],
Cell[337772, 9216, 683, 15, 53, "Output",ExpressionUUID->"744d0b97-5b3a-4dff-a3e1-3963fd39aaf3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[338492, 9236, 324, 8, 30, "Input",ExpressionUUID->"cd9660b8-9f44-46cd-8519-094a61bc2258"],
Cell[338819, 9246, 198, 3, 34, "Output",ExpressionUUID->"9325f60f-8c24-47cb-a0d1-dff5834aacf0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[339054, 9254, 482, 12, 30, "Input",ExpressionUUID->"c85ebb44-c58b-4fa8-8a8b-197d53fc310a"],
Cell[339539, 9268, 267, 6, 51, "Output",ExpressionUUID->"4b8f73af-76ea-49fe-b90a-98260853f5e0"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[339855, 9280, 376, 6, 37, "Subsubsection",ExpressionUUID->"31a20017-3f76-4a14-aa99-a70617396042"],
Cell[CellGroupData[{
Cell[340256, 9290, 277, 6, 30, "Input",ExpressionUUID->"8172549d-b095-4b20-ab50-b3aa6e290547"],
Cell[340536, 9298, 3990, 118, 152, "Output",ExpressionUUID->"b28db607-5ee2-48ec-9324-a11db31559a7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[344563, 9421, 813, 27, 30, "Input",ExpressionUUID->"062be80f-d86d-41d9-a0c7-c2f18a396796"],
Cell[345379, 9450, 802, 24, 38, "Output",ExpressionUUID->"a75bf9f0-6746-4b19-b3b2-4657d7ffc92c"]
}, Open  ]],
Cell[346196, 9477, 374, 7, 30, "Input",ExpressionUUID->"2d8f19a8-ca7b-4679-a807-f146a5971917"],
Cell[CellGroupData[{
Cell[346595, 9488, 285, 6, 30, "Input",ExpressionUUID->"857183d2-455b-494f-ae05-8aa0a9d9b750"],
Cell[346883, 9496, 245, 3, 34, "Output",ExpressionUUID->"821e70e4-4acc-4336-b2fc-d32ea64d021a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[347165, 9504, 961, 29, 94, "Input",ExpressionUUID->"2453005f-0845-4ad2-81ee-83b09ba9caa3"],
Cell[348129, 9535, 1046, 31, 49, "Output",ExpressionUUID->"b687ee77-6157-44b6-ad79-93ae6d75a7a0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[349212, 9571, 489, 12, 30, "Input",ExpressionUUID->"ba7da1a1-b591-441b-b943-c676b04da678"],
Cell[349704, 9585, 720, 19, 37, "Output",ExpressionUUID->"45b86ac2-cfe1-4cc5-b0dc-4f35a82e151f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[350461, 9609, 423, 11, 30, "Input",ExpressionUUID->"3eade57d-8abc-4901-83cb-42a57757edfd"],
Cell[350887, 9622, 379, 9, 34, "Output",ExpressionUUID->"1fbae315-fc3a-4e4f-b4c8-13bd5cfaf5de"]
}, Open  ]],
Cell[351281, 9634, 913, 24, 30, "Input",ExpressionUUID->"9489e855-7eb6-4a92-a3af-df91a51c4f30"],
Cell[CellGroupData[{
Cell[352219, 9662, 380, 9, 30, "Input",ExpressionUUID->"069be70a-7e12-4f6b-9993-0ffb9e8f5a09"],
Cell[352602, 9673, 467, 11, 52, "Output",ExpressionUUID->"2e4fcce1-574b-4956-8695-ab2c8b9a24d5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353106, 9689, 720, 18, 30, "Input",ExpressionUUID->"50efbea1-80d0-4528-b5b9-8fc9ac6ca7d3"],
Cell[353829, 9709, 568, 13, 52, "Output",ExpressionUUID->"65e30e63-cdf1-49ae-b353-4d2bdc84374d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[354434, 9727, 816, 19, 30, "Input",ExpressionUUID->"c5cdd15c-2940-4a2d-bcfe-7a0b71eaafe8"],
Cell[355253, 9748, 591, 14, 49, "Output",ExpressionUUID->"06fbb8c8-6432-4126-85a2-ef757080b41a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[355881, 9767, 505, 10, 30, "Input",ExpressionUUID->"b6f73bb7-8227-4899-8c70-f19dfc9d3c69"],
Cell[356389, 9779, 760, 17, 54, "Output",ExpressionUUID->"d3b8c2d7-03a7-44b0-bcc1-5acd91517e0d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[357186, 9801, 530, 14, 30, "Input",ExpressionUUID->"6a1ac0ef-f7ba-4d5b-824f-8b2d0b167604"],
Cell[357719, 9817, 303, 6, 34, "Output",ExpressionUUID->"d3252340-39be-4cb4-96d8-9d38aac232cb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[358059, 9828, 199, 4, 30, "Input",ExpressionUUID->"75a2d2b9-c460-484d-9e12-4f580c19edf1"],
Cell[358261, 9834, 421, 12, 55, "Output",ExpressionUUID->"9f6347ec-be83-4483-ae76-c631a9726f66"]
}, Open  ]],
Cell[CellGroupData[{
Cell[358719, 9851, 313, 8, 30, "Input",ExpressionUUID->"361b179a-0031-4d74-962c-3b7486f04b16"],
Cell[359035, 9861, 784, 22, 55, "Output",ExpressionUUID->"e54e17bb-7022-47ec-b638-8093e74816e3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[359856, 9888, 418, 11, 30, "Input",ExpressionUUID->"5d99dedb-4c1d-4c73-bfdc-9b7d11cc4141"],
Cell[360277, 9901, 247, 6, 51, "Output",ExpressionUUID->"fcd8aa29-aeda-4469-bdfe-fde43c0f9481"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[360585, 9914, 270, 4, 38, "Subsection",ExpressionUUID->"f50f109f-1fc4-4f2a-a4ab-b48d2a93f3f4"],
Cell[CellGroupData[{
Cell[360880, 9922, 249, 4, 45, "Subsubsection",ExpressionUUID->"ccc9f8cb-a605-4c03-99cf-a3ba19de81f4"],
Cell[361132, 9928, 922, 31, 136, "Input",ExpressionUUID->"e4b465cb-fa21-401a-a4d4-bb595b3b33e9"],
Cell[362057, 9961, 516, 15, 115, "Input",ExpressionUUID->"841719af-6a8c-43ff-8499-751ded3c9f7f"],
Cell[CellGroupData[{
Cell[362598, 9980, 387, 9, 30, "Input",ExpressionUUID->"ebe56187-cfa4-41de-8d6a-34d826178c23"],
Cell[362988, 9991, 648, 21, 39, "Output",ExpressionUUID->"3e46321d-ab05-4dfa-89b5-3756c8d0475d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[363673, 10017, 994, 23, 30, "Input",ExpressionUUID->"7b3f8b05-7bd1-4336-8661-03372c17d72a"],
Cell[364670, 10042, 1163, 36, 54, "Output",ExpressionUUID->"9fec80a6-8107-4a35-800d-be49e2af00c1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[365870, 10083, 775, 20, 30, "Input",ExpressionUUID->"11f832d1-8588-46f3-b7a5-9e3de17b2d66"],
Cell[366648, 10105, 896, 29, 54, "Output",ExpressionUUID->"3f20fade-0eb8-4ca3-b109-472d1c576f04"]
}, Open  ]],
Cell[CellGroupData[{
Cell[367581, 10139, 491, 13, 30, "Input",ExpressionUUID->"9547adb8-8e55-4f83-b084-4952c3d29654"],
Cell[368075, 10154, 322, 6, 50, "Output",ExpressionUUID->"0b858f7e-66a2-4cbe-adc4-eb7f2c84cf32"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[368446, 10166, 275, 4, 37, "Subsubsection",ExpressionUUID->"976e2a37-7b08-44a4-9b07-52c74fe73d4b"],
Cell[CellGroupData[{
Cell[368746, 10174, 435, 9, 30, "Input",ExpressionUUID->"c24769c4-6677-4d23-83fd-81b785e6cbd3"],
Cell[369184, 10185, 649, 21, 70, "Output",ExpressionUUID->"b1b68cb1-e5b0-4635-9c2b-616c722162fd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[369870, 10211, 1016, 23, 30, "Input",ExpressionUUID->"74e23c4b-3427-45e0-ba6c-95483c892772"],
Cell[370889, 10236, 1096, 34, 70, "Output",ExpressionUUID->"fb93bbd2-eca0-4bfa-96a8-99e8b8e98783"]
}, Open  ]],
Cell[CellGroupData[{
Cell[372022, 10275, 799, 20, 30, "Input",ExpressionUUID->"7f7b6ecb-b0f2-4dd7-8548-fd991172ecc7"],
Cell[372824, 10297, 897, 29, 70, "Output",ExpressionUUID->"6f296718-a7cc-4434-a946-c101162efe92"]
}, Open  ]],
Cell[CellGroupData[{
Cell[373758, 10331, 491, 13, 30, "Input",ExpressionUUID->"50bc0c8a-95fa-4eb1-b325-64d667aefa2b"],
Cell[374252, 10346, 344, 6, 70, "Output",ExpressionUUID->"668bc71d-4ee8-49ba-8183-661d40f7a6fe"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[374645, 10358, 323, 5, 37, "Subsubsection",ExpressionUUID->"d0046373-2984-4859-8f72-326ffc0fefcc"],
Cell[CellGroupData[{
Cell[374993, 10367, 484, 10, 30, "Input",ExpressionUUID->"7506da5a-ba41-4b04-a0cf-06edf922bc21"],
Cell[375480, 10379, 2453, 81, 70, "Output",ExpressionUUID->"b73713f8-4706-4ee7-a57d-b71732d9fe36"]
}, Open  ]],
Cell[CellGroupData[{
Cell[377970, 10465, 1068, 24, 30, "Input",ExpressionUUID->"97d0268c-efac-49f9-8807-0eee67bfa23e"],
Cell[379041, 10491, 1702, 52, 70, "Output",ExpressionUUID->"01986c69-b959-4b37-bf5d-2c0a063fbc62"]
}, Open  ]],
Cell[CellGroupData[{
Cell[380780, 10548, 849, 21, 30, "Input",ExpressionUUID->"16ef0102-186d-4f22-a818-7532517c6773"],
Cell[381632, 10571, 1467, 46, 70, "Output",ExpressionUUID->"94233189-72ff-4a6b-93ed-51fe306acf90"]
}, Open  ]],
Cell[CellGroupData[{
Cell[383136, 10622, 491, 13, 30, "Input",ExpressionUUID->"8ff5b48c-5e1f-4ac2-a1cc-7f0de2345af0"],
Cell[383630, 10637, 367, 7, 70, "Output",ExpressionUUID->"70507645-d145-4e75-80ee-8981fbd963e3"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[384046, 10650, 346, 5, 37, "Subsubsection",ExpressionUUID->"ad790a4d-acb3-41e0-8d6f-d443f1e96a2d"],
Cell[CellGroupData[{
Cell[384417, 10659, 535, 11, 30, "Input",ExpressionUUID->"907ccbda-af39-4e74-b442-8c2e0d5b368b"],
Cell[384955, 10672, 2469, 81, 70, "Output",ExpressionUUID->"feafa3e4-020f-437a-a0e1-6c4d7446bd09"]
}, Open  ]],
Cell[CellGroupData[{
Cell[387461, 10758, 1092, 24, 30, "Input",ExpressionUUID->"0a6c84b4-9fc6-4090-bc7b-2d66dfceb2ff"],
Cell[388556, 10784, 1798, 56, 70, "Output",ExpressionUUID->"cf2f6614-24b0-445b-bf2a-62ac9021af5c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[390391, 10845, 871, 21, 30, "Input",ExpressionUUID->"13618b1f-7df6-4237-8b3b-eb69acdb3bf4"],
Cell[391265, 10868, 1518, 46, 70, "Output",ExpressionUUID->"d03c9a2c-f568-4d4c-be56-57e36b0d9439"]
}, Open  ]],
Cell[CellGroupData[{
Cell[392820, 10919, 491, 13, 30, "Input",ExpressionUUID->"630b78eb-f4b5-4306-8ea8-beb8003ef4eb"],
Cell[393314, 10934, 389, 7, 70, "Output",ExpressionUUID->"479c7365-b6bf-416e-9d43-ef0949cf365d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[393752, 10947, 398, 6, 37, "Subsubsection",ExpressionUUID->"bb08997d-7014-49b0-abd9-391e0cc0a303"],
Cell[CellGroupData[{
Cell[394175, 10957, 583, 11, 30, "Input",ExpressionUUID->"1c42f395-236e-4a68-85f9-d987e4bc64c9"],
Cell[394761, 10970, 6657, 201, 70, "Output",ExpressionUUID->"7cee9093-0db1-4a35-8a9d-854d83a18794"]
}, Open  ]],
Cell[CellGroupData[{
Cell[401455, 11176, 1142, 25, 30, "Input",ExpressionUUID->"5ed0dbb5-8124-4b2e-b3b4-170d15e15cd9"],
Cell[402600, 11203, 1534, 46, 70, "Output",ExpressionUUID->"50245e89-5ae5-41fb-890e-0ee1d1527e27"]
}, Open  ]],
Cell[CellGroupData[{
Cell[404171, 11254, 921, 22, 30, "Input",ExpressionUUID->"768e57a8-58ad-4707-bb73-fa8ab16cb5d0"],
Cell[405095, 11278, 1472, 47, 70, "Output",ExpressionUUID->"47bde273-e20d-44a5-8dfb-a8c993963628"]
}, Open  ]],
Cell[CellGroupData[{
Cell[406604, 11330, 491, 13, 30, "Input",ExpressionUUID->"ca7b7b5a-2ecd-4261-95f2-5def058f5a37"],
Cell[407098, 11345, 391, 6, 70, "Output",ExpressionUUID->"a27e723e-1196-4568-a25a-04fb6d954466"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[407538, 11357, 399, 6, 37, "Subsubsection",ExpressionUUID->"9f17204f-a935-48b4-9347-af6013b7e006"],
Cell[CellGroupData[{
Cell[407962, 11367, 632, 12, 30, "Input",ExpressionUUID->"1bb652cc-81d2-4b0e-8dc4-82da9407bf0e"],
Cell[408597, 11381, 4138, 130, 70, "Output",ExpressionUUID->"9bcbc869-fa07-4c93-9d24-d177db7b70ba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[412772, 11516, 1164, 25, 30, "Input",ExpressionUUID->"23b3d934-81a7-4fac-9ea6-68119d998f95"],
Cell[413939, 11543, 1544, 46, 70, "Output",ExpressionUUID->"9bdf446d-d7dd-4ec2-826b-9cdf9820c146"]
}, Open  ]],
Cell[CellGroupData[{
Cell[415520, 11594, 943, 22, 30, "Input",ExpressionUUID->"8993f150-0627-4fe5-a0f4-3056976e56de"],
Cell[416466, 11618, 1483, 48, 70, "Output",ExpressionUUID->"f03624df-7b30-466f-9c51-2c01e31fbf44"]
}, Open  ]],
Cell[CellGroupData[{
Cell[417986, 11671, 491, 13, 30, "Input",ExpressionUUID->"1f0b5c6a-f503-4833-b53e-618fee01d588"],
Cell[418480, 11686, 419, 7, 70, "Output",ExpressionUUID->"c93c71c1-e472-4a77-8acd-fcfceef4c97a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[418948, 11699, 421, 6, 37, "Subsubsection",ExpressionUUID->"74b698cb-b9ee-4266-9b66-2bcc8e23feea"],
Cell[CellGroupData[{
Cell[419394, 11709, 631, 12, 30, "Input",ExpressionUUID->"3a45b50d-1352-4807-9b10-64e6417279b5"],
Cell[420028, 11723, 2541, 76, 70, "Output",ExpressionUUID->"664181ee-5e8a-47ef-9791-a75ec13ab6ba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[422606, 11804, 1188, 25, 30, "Input",ExpressionUUID->"3d562128-095b-4412-a36e-b3c017f10a6d"],
Cell[423797, 11831, 1163, 33, 70, "Output",ExpressionUUID->"38edfd7b-e4f6-4116-995e-973c8775bd62"]
}, Open  ]],
Cell[CellGroupData[{
Cell[424997, 11869, 969, 22, 30, "Input",ExpressionUUID->"b370ef14-e4bc-4fc9-bd8b-fbd558b426a8"],
Cell[425969, 11893, 1086, 35, 70, "Output",ExpressionUUID->"b056c503-2c0c-4e78-9739-98b11ea72d54"]
}, Open  ]],
Cell[CellGroupData[{
Cell[427092, 11933, 491, 13, 30, "Input",ExpressionUUID->"5c365c94-6724-4e79-9573-2791a943c2c5"],
Cell[427586, 11948, 417, 7, 70, "Output",ExpressionUUID->"6321edfd-6e21-4ce9-b37f-b55016bfaa6d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[428052, 11961, 449, 7, 37, "Subsubsection",ExpressionUUID->"ac1a83d0-835a-46e5-b4f2-fbb027e73ec3"],
Cell[CellGroupData[{
Cell[428526, 11972, 680, 13, 30, "Input",ExpressionUUID->"b584d897-e52c-4f81-b164-50a442ed7630"],
Cell[429209, 11987, 19583, 571, 70, "Output",ExpressionUUID->"5c41ce3a-aa7d-4bb0-a0bb-d7cf86fb333d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[448829, 12563, 1216, 26, 30, "Input",ExpressionUUID->"29c8b74f-cea6-40bc-a8f2-eccac2e3f312"],
Cell[450048, 12591, 1402, 41, 70, "Output",ExpressionUUID->"d181f1b7-8fa8-44b4-ab65-6e1e86a9fcf1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[451487, 12637, 997, 23, 30, "Input",ExpressionUUID->"60a601be-16c4-4424-8e43-89317be7d95b"],
Cell[452487, 12662, 1339, 42, 70, "Output",ExpressionUUID->"0b9337f4-63e1-4683-9a32-bbd06cbeef36"]
}, Open  ]],
Cell[CellGroupData[{
Cell[453863, 12709, 491, 13, 30, "Input",ExpressionUUID->"b05f1a13-aa8f-4b2a-a3b0-fec484c9f1be"],
Cell[454357, 12724, 441, 7, 70, "Output",ExpressionUUID->"4bde0875-9159-48d6-b46e-c4e9b9c0f064"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[454847, 12737, 447, 7, 37, "Subsubsection",ExpressionUUID->"466f562e-5536-4cb7-ae0d-23406d1e39ca"],
Cell[CellGroupData[{
Cell[455319, 12748, 680, 13, 30, "Input",ExpressionUUID->"d14e7844-35ac-472d-9a53-13e50aeecddb"],
Cell[456002, 12763, 12500, 373, 70, "Output",ExpressionUUID->"2528f025-4cc3-4d61-b483-de03827dafa4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[468539, 13141, 1216, 26, 30, "Input",ExpressionUUID->"e1e660c3-c3ac-4b1c-a8d9-60c4a6414016"],
Cell[469758, 13169, 1402, 41, 70, "Output",ExpressionUUID->"af9c21b9-2589-49e2-997f-21977f144425"]
}, Open  ]],
Cell[CellGroupData[{
Cell[471197, 13215, 995, 23, 30, "Input",ExpressionUUID->"5063e10a-f0aa-4fd4-a02c-bb212c54480e"],
Cell[472195, 13240, 1341, 42, 70, "Output",ExpressionUUID->"7057ec0e-be55-468c-8e15-2980d89dce8f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[473573, 13287, 491, 13, 30, "Input",ExpressionUUID->"540a1099-2a15-496a-ab97-08ff57296ddd"],
Cell[474067, 13302, 438, 7, 70, "Output",ExpressionUUID->"49a3d817-be8d-44c2-acd1-acdaeb205621"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[474554, 13315, 447, 7, 37, "Subsubsection",ExpressionUUID->"2136fb2c-be89-435e-b259-eb87f4c72114"],
Cell[CellGroupData[{
Cell[475026, 13326, 681, 13, 30, "Input",ExpressionUUID->"f1817b25-1fb6-4c7b-b6cb-39830d90a507"],
Cell[475710, 13341, 10093, 301, 70, "Output",ExpressionUUID->"12b6bd83-3453-4163-aa35-e60152f99337"]
}, Open  ]],
Cell[CellGroupData[{
Cell[485840, 13647, 1216, 26, 30, "Input",ExpressionUUID->"66420ba0-ed48-4e4c-9e0e-333e071ac3a1"],
Cell[487059, 13675, 1400, 41, 70, "Output",ExpressionUUID->"8686ea5a-12fa-45c1-a9b9-0af3f5cec659"]
}, Open  ]],
Cell[CellGroupData[{
Cell[488496, 13721, 995, 23, 30, "Input",ExpressionUUID->"83c5d417-a304-4a50-8b97-89f31c4eb412"],
Cell[489494, 13746, 1339, 42, 70, "Output",ExpressionUUID->"db88960a-b462-4275-b969-2342ffb2ea41"]
}, Open  ]],
Cell[CellGroupData[{
Cell[490870, 13793, 491, 13, 30, "Input",ExpressionUUID->"2d1b1e62-37f7-4ba7-bb12-a8f968cf0176"],
Cell[491364, 13808, 441, 7, 70, "Output",ExpressionUUID->"c14a3478-16de-405e-8bbe-330fbf4628a1"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[491866, 13822, 157, 3, 38, "Subsection",ExpressionUUID->"806362de-4648-42d4-b529-fe243a62ed6f"],
Cell[CellGroupData[{
Cell[492048, 13829, 215, 4, 45, "Subsubsection",ExpressionUUID->"4a77c34f-b15c-4e24-bf4f-85b2f82558c7"],
Cell[CellGroupData[{
Cell[492288, 13837, 9782, 245, 1342, "Input",ExpressionUUID->"1f601afd-4d8e-4850-b494-11213f28173a"],
Cell[CellGroupData[{
Cell[502095, 14086, 337, 9, 24, "Print",ExpressionUUID->"424ce6a4-95f1-47b7-8e19-66a703bf6195"],
Cell[502435, 14097, 952, 27, 26, "Print",ExpressionUUID->"60806bc5-1385-463e-a1f0-4aea5b859fee"],
Cell[503390, 14126, 337, 9, 24, "Print",ExpressionUUID->"123efc4d-4e24-4ed1-a68a-c3368021f9c3"],
Cell[503730, 14137, 866, 24, 40, "Print",ExpressionUUID->"03483b21-8a72-488f-98b7-05668a04a6eb"],
Cell[504599, 14163, 339, 9, 24, "Print",ExpressionUUID->"8fba131c-c01c-4fea-bb16-346769de3710"],
Cell[504941, 14174, 339, 9, 24, "Print",ExpressionUUID->"503c6680-ab2a-415f-8cbe-c5b6dc0ab9a3"],
Cell[505283, 14185, 339, 9, 24, "Print",ExpressionUUID->"e2581352-7979-43cc-acf2-7a74f222ca66"],
Cell[505625, 14196, 2480, 69, 40, "Print",ExpressionUUID->"f72b230d-4ac2-4bb8-8e17-3ef4e7cee6f5"],
Cell[508108, 14267, 337, 9, 24, "Print",ExpressionUUID->"8d1aa0f5-297a-44e3-90e9-3c4bad27e0c6"],
Cell[508448, 14278, 999, 29, 40, "Print",ExpressionUUID->"8fe7e7f1-9cf1-43e9-9358-9003087bf803"],
Cell[509450, 14309, 339, 9, 24, "Print",ExpressionUUID->"e65c35d1-533a-454d-a209-0998daece8a8"],
Cell[509792, 14320, 1840, 50, 40, "Print",ExpressionUUID->"3618a02c-e427-4d30-9a31-5a2ef850aa71"],
Cell[511635, 14372, 339, 9, 24, "Print",ExpressionUUID->"088037b8-00f7-4d41-a7e5-ef32c71a7622"],
Cell[511977, 14383, 1214, 33, 26, "Print",ExpressionUUID->"cbe9f8b3-acf8-41af-8c4a-cf2e615788f9"],
Cell[513194, 14418, 337, 9, 24, "Print",ExpressionUUID->"61db27b9-6bf5-452b-a82c-e1aaa20c9b82"],
Cell[513534, 14429, 1504, 42, 40, "Print",ExpressionUUID->"98874294-390d-4452-b9cf-88b3f2a37fb1"],
Cell[515041, 14473, 341, 9, 24, "Print",ExpressionUUID->"7ccffebb-0dc3-40e1-925e-de18c0f66b2a"],
Cell[515385, 14484, 1095, 31, 44, "Print",ExpressionUUID->"7d9dac93-17ee-4ecf-8be0-978697c1df1c"],
Cell[516483, 14517, 339, 9, 24, "Print",ExpressionUUID->"5d0a3600-bf7a-4450-91fa-b7cb3ae908d2"],
Cell[516825, 14528, 337, 9, 24, "Print",ExpressionUUID->"522ca8f1-448b-44e9-b728-e709e9f21955"],
Cell[517165, 14539, 2263, 63, 62, "Print",ExpressionUUID->"b549daf0-08d8-47d7-a1c8-d9e765e8de4b"],
Cell[519431, 14604, 341, 9, 24, "Print",ExpressionUUID->"7a1a6c72-7e96-4b20-82f6-a7a164dba007"],
Cell[519775, 14615, 339, 9, 24, "Print",ExpressionUUID->"578f01aa-4746-4c9d-8c9b-48c9376ae058"],
Cell[520117, 14626, 341, 9, 24, "Print",ExpressionUUID->"79d028cc-b52d-41d6-8d52-0eb84b8298e5"],
Cell[520461, 14637, 339, 9, 24, "Print",ExpressionUUID->"c7a1bc50-db15-4a76-8405-92d05f944943"],
Cell[520803, 14648, 341, 9, 24, "Print",ExpressionUUID->"e9ab77c7-1a97-4d98-8594-eb71f0819bef"],
Cell[521147, 14659, 339, 9, 24, "Print",ExpressionUUID->"a8867059-2695-41ac-aa78-5367a11adbe3"],
Cell[521489, 14670, 339, 9, 24, "Print",ExpressionUUID->"1617dc21-353c-411a-a326-917399ac1afc"],
Cell[521831, 14681, 339, 9, 24, "Print",ExpressionUUID->"13f4af50-99d9-4cbe-a5c4-fd882717b5f5"],
Cell[522173, 14692, 2844, 78, 49, "Print",ExpressionUUID->"8d0346e3-8a40-4d0a-84c2-69f74c6432ee"],
Cell[525020, 14772, 341, 9, 24, "Print",ExpressionUUID->"0dc35bcc-93df-49cf-a863-e3170efefa14"],
Cell[525364, 14783, 2167, 60, 40, "Print",ExpressionUUID->"2dec7cec-30c2-42ce-9daf-c9c2789a6649"],
Cell[527534, 14845, 339, 9, 24, "Print",ExpressionUUID->"79e75b8a-24bc-4c92-9158-c5305f8058bb"],
Cell[527876, 14856, 1756, 51, 27, "Print",ExpressionUUID->"2c107739-1e8b-456f-9b01-1df245c63963"],
Cell[529635, 14909, 339, 9, 24, "Print",ExpressionUUID->"8a542d14-967e-4fc4-8bb3-97f63042f55a"],
Cell[529977, 14920, 2148, 60, 27, "Print",ExpressionUUID->"0d4e7760-8044-4d3f-97a1-79831009e668"],
Cell[532128, 14982, 339, 9, 24, "Print",ExpressionUUID->"c9f17cfa-937a-4fa8-96c1-acbd80e09968"],
Cell[532470, 14993, 339, 9, 24, "Print",ExpressionUUID->"269cd1bc-97d5-4665-a87f-d27ec35deace"],
Cell[532812, 15004, 338, 9, 24, "Print",ExpressionUUID->"d2036a4c-0252-4a57-8a69-bf2d998f3aa1"],
Cell[533153, 15015, 339, 9, 24, "Print",ExpressionUUID->"932643cb-fd58-4e7d-b155-34cf5ed7446f"],
Cell[533495, 15026, 339, 9, 24, "Print",ExpressionUUID->"18f3c47b-2204-4818-91bf-8f9c53b40e27"],
Cell[533837, 15037, 337, 9, 24, "Print",ExpressionUUID->"02f414cb-42d5-4267-ae94-c9bbb8762b1c"],
Cell[534177, 15048, 339, 9, 24, "Print",ExpressionUUID->"f0b52c3f-eb4e-4247-8e56-9df74d2449e1"],
Cell[534519, 15059, 339, 9, 24, "Print",ExpressionUUID->"5fad6241-a2e4-40fd-84d8-3d7b1a8bc877"],
Cell[534861, 15070, 1021, 29, 28, "Print",ExpressionUUID->"e2ea7745-681e-4626-92a8-58779ca92c99"],
Cell[535885, 15101, 341, 9, 24, "Print",ExpressionUUID->"a2e647c3-29b7-420a-a5fa-5c5085ec8575"],
Cell[536229, 15112, 1001, 29, 40, "Print",ExpressionUUID->"f3a82601-a615-4123-beb4-a10ddaa3b8b1"],
Cell[537233, 15143, 339, 9, 24, "Print",ExpressionUUID->"9edb0959-833b-4b22-a956-fe5c0965d065"],
Cell[537575, 15154, 339, 9, 24, "Print",ExpressionUUID->"ab9d527c-37a7-4089-be3e-9b708d172af4"],
Cell[537917, 15165, 339, 9, 24, "Print",ExpressionUUID->"fb9f1969-bff1-467c-99b8-3c19e9b32ec9"],
Cell[538259, 15176, 2104, 59, 40, "Print",ExpressionUUID->"2b917bd2-3a69-4316-9eee-eea3b3edee17"],
Cell[540366, 15237, 339, 9, 24, "Print",ExpressionUUID->"cc46c660-5745-432e-8c1f-22d61915008b"],
Cell[540708, 15248, 2009, 56, 28, "Print",ExpressionUUID->"93c591f4-079e-4641-8b32-5b7cc15f3a63"],
Cell[542720, 15306, 338, 9, 24, "Print",ExpressionUUID->"abf263e6-0f1f-474f-9ec3-65367f917cab"],
Cell[543061, 15317, 1379, 40, 40, "Print",ExpressionUUID->"f3ea4a23-ae2a-4ea2-a897-0b1cb093ca34"],
Cell[544443, 15359, 339, 9, 24, "Print",ExpressionUUID->"8c5ea486-a4ef-4d49-9f79-e2b0c91dbff6"],
Cell[544785, 15370, 1624, 48, 40, "Print",ExpressionUUID->"02f8bf6f-42f4-405d-93f9-b1fdf2185d3f"],
Cell[546412, 15420, 339, 9, 24, "Print",ExpressionUUID->"f0e8cbf4-506c-4736-b6e4-82dc97f73d1b"],
Cell[546754, 15431, 1547, 46, 40, "Print",ExpressionUUID->"7358a143-133d-4032-a86c-6363af182125"],
Cell[548304, 15479, 339, 9, 24, "Print",ExpressionUUID->"0e1cf711-2e67-4770-8c28-1202039ffad0"],
Cell[548646, 15490, 3936, 100, 71, "Print",ExpressionUUID->"90eb361c-2578-4ebe-9e13-6495e01d02e5"],
Cell[552585, 15592, 339, 9, 24, "Print",ExpressionUUID->"2159859e-9223-4a18-b591-286f89d816f1"],
Cell[552927, 15603, 1602, 46, 40, "Print",ExpressionUUID->"03352f43-4c48-4a0a-941d-a078dd2ab482"],
Cell[554532, 15651, 339, 9, 24, "Print",ExpressionUUID->"f10b31d4-2f23-4057-bd0d-01ff874a3ac9"],
Cell[554874, 15662, 1402, 41, 44, "Print",ExpressionUUID->"363fe076-c38a-4e45-905e-b2ecd398adf6"],
Cell[556279, 15705, 341, 9, 24, "Print",ExpressionUUID->"fa35cff0-ac0b-4f06-8033-b499bb77f5f5"],
Cell[556623, 15716, 1890, 53, 40, "Print",ExpressionUUID->"22235675-479d-4a73-8c62-f13c9182469a"],
Cell[558516, 15771, 339, 9, 24, "Print",ExpressionUUID->"4a3d5d03-77c8-4ee0-be20-71c2895f6280"],
Cell[558858, 15782, 1517, 44, 26, "Print",ExpressionUUID->"16cc39b8-1a6f-4bec-bce7-d4c090f9476d"],
Cell[560378, 15828, 339, 9, 24, "Print",ExpressionUUID->"8dd6d15d-f51b-4ecd-8385-a81cf5c83180"],
Cell[560720, 15839, 1716, 49, 40, "Print",ExpressionUUID->"7d9ee4a5-eb53-40b2-a2ac-53570c6957c7"],
Cell[562439, 15890, 341, 9, 24, "Print",ExpressionUUID->"d1e6f408-9177-450c-870a-b565e0050e83"],
Cell[562783, 15901, 341, 9, 24, "Print",ExpressionUUID->"071f29f9-09fe-4993-bbac-5701944806e8"],
Cell[563127, 15912, 341, 9, 24, "Print",ExpressionUUID->"429892d4-d9ee-482b-afe6-6ff6b7d89b45"],
Cell[563471, 15923, 339, 9, 24, "Print",ExpressionUUID->"12d71520-3e46-4442-92d4-39df0049b81a"],
Cell[563813, 15934, 339, 9, 24, "Print",ExpressionUUID->"401cee13-da71-42ed-887e-330d4254be7b"],
Cell[564155, 15945, 338, 9, 24, "Print",ExpressionUUID->"d12baa10-3e54-402d-b0c0-196cdbc98c14"],
Cell[564496, 15956, 2892, 81, 62, "Print",ExpressionUUID->"dcf398dc-8535-4a20-8654-0a060b3899ac"],
Cell[567391, 16039, 339, 9, 24, "Print",ExpressionUUID->"f23de30e-eee5-4173-9482-4c265dd8ef94"],
Cell[567733, 16050, 339, 9, 24, "Print",ExpressionUUID->"f348457d-018c-4f8b-a8de-96d3827a7e23"],
Cell[568075, 16061, 339, 9, 24, "Print",ExpressionUUID->"812174b8-f79a-4fff-9f25-0223eb2466a6"],
Cell[568417, 16072, 4678, 128, 84, "Print",ExpressionUUID->"59f4cac2-4898-43a7-b616-e5d77d3b9925"],
Cell[573098, 16202, 339, 9, 24, "Print",ExpressionUUID->"7e91b8dd-3304-45be-8a6f-d8ba83a58847"],
Cell[573440, 16213, 1530, 44, 44, "Print",ExpressionUUID->"1d2d4cb1-758a-4d6d-aab5-90960b967d6c"],
Cell[574973, 16259, 341, 9, 24, "Print",ExpressionUUID->"88f4296e-a436-4bab-81d8-2c3d84365e7b"],
Cell[575317, 16270, 1883, 51, 44, "Print",ExpressionUUID->"97886cd3-4edd-4d2b-bae8-4a5df86f7e42"],
Cell[577203, 16323, 341, 9, 24, "Print",ExpressionUUID->"c4367e4d-5791-4cd8-8465-962a95ab308c"],
Cell[577547, 16334, 1892, 51, 40, "Print",ExpressionUUID->"9909bec2-8128-48b3-abc8-43ca2a5f35fd"],
Cell[579442, 16387, 341, 9, 24, "Print",ExpressionUUID->"b26ffa10-9306-49e6-9d51-55fea53e2bcf"],
Cell[579786, 16398, 1797, 51, 40, "Print",ExpressionUUID->"894966c4-3ec2-4658-9454-5337c943c2cd"],
Cell[581586, 16451, 341, 9, 24, "Print",ExpressionUUID->"5d4cf0e1-cd30-4b79-ae3f-c216fc2d41ca"],
Cell[581930, 16462, 339, 9, 24, "Print",ExpressionUUID->"dd24dae8-b57d-43f2-b674-79bc6d10b1a4"],
Cell[582272, 16473, 2425, 68, 62, "Print",ExpressionUUID->"12cc8230-3729-4a48-8787-920dfe6ffd0b"],
Cell[584700, 16543, 341, 9, 24, "Print",ExpressionUUID->"86018b45-a0f8-46e3-b813-687fd361d6c9"],
Cell[585044, 16554, 339, 9, 24, "Print",ExpressionUUID->"f618f488-7d4a-4015-9f7b-d7c857c38a4d"],
Cell[585386, 16565, 339, 9, 24, "Print",ExpressionUUID->"d8df3ea7-baea-4fc6-8b75-d1ccb0b6fbe8"],
Cell[585728, 16576, 339, 9, 24, "Print",ExpressionUUID->"0f81b2e1-bd10-487c-a60e-0073315a43e7"],
Cell[586070, 16587, 337, 9, 24, "Print",ExpressionUUID->"31b006db-c60d-497d-a3bd-d06b2097f7ea"],
Cell[586410, 16598, 2097, 55, 45, "Print",ExpressionUUID->"ea8a76c5-8add-4cdb-9e7f-cbcc3d136e2c"],
Cell[588510, 16655, 338, 9, 24, "Print",ExpressionUUID->"632fa184-b0a7-4496-b26c-911527d53fac"],
Cell[588851, 16666, 339, 9, 24, "Print",ExpressionUUID->"075cce28-02c2-40fd-8019-fbabbd2f1c8b"],
Cell[589193, 16677, 3129, 87, 62, "Print",ExpressionUUID->"78886b45-39f0-4739-a03d-ac283cc2a9e1"],
Cell[592325, 16766, 339, 9, 24, "Print",ExpressionUUID->"20256040-78a3-4e18-b4ee-7753bec41749"],
Cell[592667, 16777, 339, 9, 24, "Print",ExpressionUUID->"248a9e60-9d3e-47a1-9133-47fbab963829"],
Cell[593009, 16788, 339, 9, 24, "Print",ExpressionUUID->"37f7a08d-8694-43d8-adf3-d262c22f5dff"],
Cell[593351, 16799, 8737, 227, 137, "Print",ExpressionUUID->"0f91c55e-ead1-4d63-8007-5459b924f442"],
Cell[602091, 17028, 338, 9, 24, "Print",ExpressionUUID->"a8cd29e9-6a8c-4e22-9aa7-b780f6880d79"],
Cell[602432, 17039, 339, 9, 24, "Print",ExpressionUUID->"bf6350a3-e5e0-41a1-bc05-52ad2671ef61"],
Cell[602774, 17050, 339, 9, 24, "Print",ExpressionUUID->"4cda1e34-56a3-4378-bb9b-0ca832c2e751"],
Cell[603116, 17061, 341, 9, 24, "Print",ExpressionUUID->"c178e9ab-8ed5-4dae-8f23-a2873ead0dd2"],
Cell[603460, 17072, 5216, 140, 71, "Print",ExpressionUUID->"bb440a8a-1252-4d84-8b59-306505566943"],
Cell[608679, 17214, 339, 9, 24, "Print",ExpressionUUID->"cb60cc51-bf6b-490e-8936-d9067617c95d"],
Cell[609021, 17225, 1119, 32, 44, "Print",ExpressionUUID->"f2bcb83a-09db-4be2-b723-2f86d93539e9"],
Cell[610143, 17259, 341, 9, 24, "Print",ExpressionUUID->"9d998c17-7ddf-48a1-9f9c-db6e7e4d7a5d"],
Cell[610487, 17270, 1219, 36, 40, "Print",ExpressionUUID->"8c26d848-386c-4c09-bcea-1445b8677c61"],
Cell[611709, 17308, 338, 9, 24, "Print",ExpressionUUID->"681d764e-a5c1-4c1e-9172-f072ee33c6c3"],
Cell[612050, 17319, 339, 9, 24, "Print",ExpressionUUID->"16672548-9cb6-4caf-9ba6-91ecc315897f"],
Cell[612392, 17330, 339, 9, 24, "Print",ExpressionUUID->"0bdedcc7-4a28-410f-942e-3d82250acc96"],
Cell[612734, 17341, 2825, 77, 62, "Print",ExpressionUUID->"e88a210e-a05f-4f15-8a64-a36c3a2681c4"],
Cell[615562, 17420, 339, 9, 24, "Print",ExpressionUUID->"47307d44-bb60-4297-b1e5-d5fcde83df7b"],
Cell[615904, 17431, 2729, 74, 49, "Print",ExpressionUUID->"be7a87b8-b7a9-4680-b19c-ff0a324079a8"],
Cell[618636, 17507, 341, 9, 24, "Print",ExpressionUUID->"84d5a05c-e5d3-4a42-b626-868182b8d2e5"],
Cell[618980, 17518, 1709, 48, 40, "Print",ExpressionUUID->"8998f67f-d08d-4a31-9fc2-427a72fb8458"],
Cell[620692, 17568, 339, 9, 24, "Print",ExpressionUUID->"0eff2d1a-50b4-4387-b0bd-43a3c45789f2"],
Cell[621034, 17579, 1997, 58, 28, "Print",ExpressionUUID->"f7ce5fc3-3d70-45df-a8a4-9c3a73054683"],
Cell[623034, 17639, 339, 9, 24, "Print",ExpressionUUID->"62053529-1d2d-4e1f-bc53-15b0d926acde"],
Cell[623376, 17650, 1871, 56, 40, "Print",ExpressionUUID->"e9b723ab-a02e-4a75-bbb8-bd15686dbdb8"],
Cell[625250, 17708, 339, 9, 24, "Print",ExpressionUUID->"180e8179-8ad5-4a2d-9eb6-328380f58c13"],
Cell[625592, 17719, 6840, 169, 113, "Print",ExpressionUUID->"5fd3d6e7-808e-463d-95ca-e076e81f4ded"],
Cell[632435, 17890, 339, 9, 24, "Print",ExpressionUUID->"6ec0dca9-6c6a-45ed-b18c-7a13994a843a"],
Cell[632777, 17901, 2054, 55, 40, "Print",ExpressionUUID->"fe12eea6-0df5-4104-a81b-8a6605cac1a8"],
Cell[634834, 17958, 341, 9, 24, "Print",ExpressionUUID->"2df0dc22-433b-487b-997b-46780541904f"],
Cell[635178, 17969, 1636, 48, 40, "Print",ExpressionUUID->"fe5ef645-4580-4df4-8baf-17734029dde6"],
Cell[636817, 18019, 341, 9, 24, "Print",ExpressionUUID->"30bd1631-a5dc-4385-803d-bd424d7e6ae6"],
Cell[637161, 18030, 2748, 75, 59, "Print",ExpressionUUID->"9cd0dd67-50f6-4f48-ba87-1ade4015f719"],
Cell[639912, 18107, 339, 9, 24, "Print",ExpressionUUID->"aaf78a81-8dff-49dc-b907-afcb244291ad"],
Cell[640254, 18118, 2159, 61, 40, "Print",ExpressionUUID->"544e99fd-57e0-42e1-a7d8-3b1da82be018"],
Cell[642416, 18181, 338, 9, 24, "Print",ExpressionUUID->"7fa094c2-cd14-4783-82b6-704cf8cd31a2"],
Cell[642757, 18192, 2324, 65, 59, "Print",ExpressionUUID->"3d9ad199-2565-436c-b429-9085d19b108d"],
Cell[645084, 18259, 339, 9, 24, "Print",ExpressionUUID->"9427fcd5-a196-4303-8876-5f48a2d7de15"],
Cell[645426, 18270, 339, 9, 24, "Print",ExpressionUUID->"f41739a2-8187-4dc2-8b9a-7cace5295de7"],
Cell[645768, 18281, 339, 9, 24, "Print",ExpressionUUID->"7674844f-e79f-46f6-9052-84fe414a098c"],
Cell[646110, 18292, 341, 9, 24, "Print",ExpressionUUID->"9ec84b58-d43e-4f0e-9ad9-5513bc89ff1d"],
Cell[646454, 18303, 341, 9, 24, "Print",ExpressionUUID->"e73c6bdf-1a05-4a9e-8cdc-64660ca7dd6a"],
Cell[646798, 18314, 4849, 126, 71, "Print",ExpressionUUID->"48b43764-8302-4dfa-8638-1bf7a3e5c7f5"],
Cell[651650, 18442, 339, 9, 24, "Print",ExpressionUUID->"5388e781-b05c-491f-b7b5-74185c14e1d9"],
Cell[651992, 18453, 4513, 125, 84, "Print",ExpressionUUID->"4122fda2-1a78-494c-99c1-ad300b023cf6"],
Cell[656508, 18580, 339, 9, 24, "Print",ExpressionUUID->"ae344921-dbf9-4e0b-ba61-a024605324b5"],
Cell[656850, 18591, 339, 9, 24, "Print",ExpressionUUID->"92e0a467-7c6f-4530-9eec-bcd9a0aa2cb1"],
Cell[657192, 18602, 341, 9, 24, "Print",ExpressionUUID->"4eb002ba-2c03-494e-b11f-7f473bab44c0"],
Cell[657536, 18613, 3563, 99, 49, "Print",ExpressionUUID->"d4b0c781-209e-4471-81d9-9041268c3165"],
Cell[661102, 18714, 339, 9, 24, "Print",ExpressionUUID->"928028ad-eddb-4df8-9164-4940b7b9cdf7"],
Cell[661444, 18725, 341, 9, 24, "Print",ExpressionUUID->"99cbda87-6f0e-4cfd-99e5-9167379e4d65"],
Cell[661788, 18736, 340, 9, 24, "Print",ExpressionUUID->"bb2a0c2e-9892-4f6c-a29b-1e3a5dc4f61d"],
Cell[662131, 18747, 341, 9, 24, "Print",ExpressionUUID->"1640a2bf-b523-430e-8b2c-44fba46047d9"],
Cell[662475, 18758, 10194, 251, 137, "Print",ExpressionUUID->"a3700dec-c1cf-4cc0-b129-4d95c1dfb108"],
Cell[672672, 19011, 341, 9, 24, "Print",ExpressionUUID->"120b1561-fdef-443f-82cf-ec0114f53662"],
Cell[673016, 19022, 5162, 135, 71, "Print",ExpressionUUID->"a5614611-646d-4954-b1f0-5a3869390628"],
Cell[678181, 19159, 341, 9, 24, "Print",ExpressionUUID->"2b2de884-e619-4474-8766-a6e314f933e1"],
Cell[678525, 19170, 5190, 130, 71, "Print",ExpressionUUID->"a5cfa3e1-37bc-40a8-afec-928ab1d4258f"],
Cell[683718, 19302, 343, 9, 24, "Print",ExpressionUUID->"9600fb82-6611-46a8-8660-97eb1ecd29ff"],
Cell[684064, 19313, 2848, 76, 49, "Print",ExpressionUUID->"898a7033-be37-476c-9b6a-446f3d6253f7"],
Cell[686915, 19391, 341, 9, 24, "Print",ExpressionUUID->"9d135c43-49e6-46d8-8827-a980238298d7"],
Cell[687259, 19402, 2063, 58, 27, "Print",ExpressionUUID->"a7ac71df-575b-43e5-90c2-34dd94bb64dc"],
Cell[689325, 19462, 343, 9, 24, "Print",ExpressionUUID->"02c12e9f-4698-48b2-b810-ca9dd53bb769"],
Cell[689671, 19473, 341, 9, 24, "Print",ExpressionUUID->"a11c073a-8af9-4e04-9caa-1baa0579b312"],
Cell[690015, 19484, 341, 9, 24, "Print",ExpressionUUID->"78e72e7b-4b12-4e87-89db-89c5dd75b3aa"],
Cell[690359, 19495, 341, 9, 24, "Print",ExpressionUUID->"af30f489-3af0-4f47-aec6-2a5e41caf95a"],
Cell[690703, 19506, 343, 9, 24, "Print",ExpressionUUID->"1e81873f-c364-4881-8665-2ec09a157e9d"],
Cell[691049, 19517, 2643, 76, 47, "Print",ExpressionUUID->"7b13667c-e774-48a7-9ef5-a4d303e6c356"],
Cell[693695, 19595, 343, 9, 24, "Print",ExpressionUUID->"0c0aec3b-0cfd-4252-b5e0-43534917b428"],
Cell[694041, 19606, 343, 9, 24, "Print",ExpressionUUID->"c9ad7577-fe77-4669-9198-4ff3f071c50b"],
Cell[694387, 19617, 343, 9, 24, "Print",ExpressionUUID->"19834269-9f97-4dfe-ad4a-b6250d436bd2"],
Cell[694733, 19628, 341, 9, 24, "Print",ExpressionUUID->"7f495590-44f1-4580-a510-7e2545afe374"],
Cell[695077, 19639, 341, 9, 24, "Print",ExpressionUUID->"2203fb3d-c934-4a9c-91d1-82d416c834a3"],
Cell[695421, 19650, 341, 9, 24, "Print",ExpressionUUID->"485d1fac-e84e-4e04-b6af-423fe29c589a"],
Cell[695765, 19661, 341, 9, 24, "Print",ExpressionUUID->"ce13a429-c650-4363-aee0-d84b5fa826da"],
Cell[696109, 19672, 341, 9, 24, "Print",ExpressionUUID->"96d202cc-37c9-4541-870a-f21bd0b30194"],
Cell[696453, 19683, 341, 9, 24, "Print",ExpressionUUID->"306e7695-c2b7-41ba-af8b-6f365f181be5"],
Cell[696797, 19694, 343, 9, 24, "Print",ExpressionUUID->"7863921d-c554-487d-b9ee-eb59540d4814"],
Cell[697143, 19705, 343, 9, 24, "Print",ExpressionUUID->"2431f9bf-29c0-455b-b880-c3ee7fa04cf5"],
Cell[697489, 19716, 341, 9, 24, "Print",ExpressionUUID->"a0732156-87e9-49d1-ae9c-35dcfdea82ab"],
Cell[697833, 19727, 343, 9, 24, "Print",ExpressionUUID->"87164327-e440-4f61-bd2d-1b06e0be7acd"],
Cell[698179, 19738, 343, 9, 24, "Print",ExpressionUUID->"8e3cfdea-14ed-479d-915c-6180389d1b03"],
Cell[698525, 19749, 343, 9, 24, "Print",ExpressionUUID->"ef12ce19-9a73-451b-92ab-a735476c41f8"],
Cell[698871, 19760, 341, 9, 24, "Print",ExpressionUUID->"ef258d72-b844-4532-ae29-c2ced517f661"],
Cell[699215, 19771, 341, 9, 24, "Print",ExpressionUUID->"409f840e-d564-4f3f-b347-dadc059fc402"],
Cell[699559, 19782, 341, 9, 24, "Print",ExpressionUUID->"aee5d8cf-33b0-47d7-aa8f-a6fa2fbcc36d"],
Cell[699903, 19793, 341, 9, 24, "Print",ExpressionUUID->"b43881be-88c4-4f46-9482-dd118b8d9d0f"],
Cell[700247, 19804, 341, 9, 24, "Print",ExpressionUUID->"b74733c8-42ad-41fc-bb8d-cbd5de9a3fe0"],
Cell[700591, 19815, 341, 9, 24, "Print",ExpressionUUID->"861475cb-86da-4fea-a980-627045d114c2"],
Cell[700935, 19826, 341, 9, 24, "Print",ExpressionUUID->"c9957821-c973-44df-833c-8e610f2414ae"],
Cell[701279, 19837, 341, 9, 24, "Print",ExpressionUUID->"5cbec0e8-1ced-4265-b127-8acb8409555b"],
Cell[701623, 19848, 340, 9, 24, "Print",ExpressionUUID->"b8416c47-b8fe-4cf8-9d25-8d187c84332b"],
Cell[701966, 19859, 343, 9, 24, "Print",ExpressionUUID->"a97cebc5-db01-4961-91ac-796d422f6797"],
Cell[702312, 19870, 341, 9, 24, "Print",ExpressionUUID->"3968a1b7-155b-4470-981a-81b389368c23"],
Cell[702656, 19881, 341, 9, 24, "Print",ExpressionUUID->"b4de687a-d490-4f1d-bc73-a7ba4fd6b1aa"],
Cell[703000, 19892, 341, 9, 24, "Print",ExpressionUUID->"5e9e8f3b-db2d-4f9e-833a-f5187a1bff1b"],
Cell[703344, 19903, 340, 9, 24, "Print",ExpressionUUID->"a30efa3c-0b8b-4237-a524-5db21b0fa7e2"],
Cell[703687, 19914, 2818, 77, 62, "Print",ExpressionUUID->"aeef31c2-aac6-40be-8011-b61e5ab322d4"],
Cell[706508, 19993, 341, 9, 24, "Print",ExpressionUUID->"e1846d12-c837-4207-950b-a66ddb339d88"],
Cell[706852, 20004, 1227, 36, 40, "Print",ExpressionUUID->"12518b44-aed2-4eea-a1e7-dc71beb0f3b2"],
Cell[708082, 20042, 341, 9, 24, "Print",ExpressionUUID->"67f02c12-6216-47af-9ca3-96e255fdcb16"],
Cell[708426, 20053, 1979, 53, 44, "Print",ExpressionUUID->"fd53ad82-c52e-446b-907a-0025f6d1b22e"],
Cell[710408, 20108, 341, 9, 24, "Print",ExpressionUUID->"93e057d3-9fdb-48a6-a7d0-7efb49d5af47"],
Cell[710752, 20119, 4901, 132, 84, "Print",ExpressionUUID->"afde3554-c1ff-4711-99d3-dc636944dbff"],
Cell[715656, 20253, 341, 9, 24, "Print",ExpressionUUID->"e4fd3928-1e74-4602-ba90-bad6e0faa176"],
Cell[716000, 20264, 2448, 64, 62, "Print",ExpressionUUID->"06a0c80d-78cf-49e8-851c-539c67186cdd"],
Cell[718451, 20330, 341, 9, 24, "Print",ExpressionUUID->"1b183894-4318-4657-9cfd-97d7c63aae7c"],
Cell[718795, 20341, 1338, 38, 26, "Print",ExpressionUUID->"44b044e9-ec4d-4f8f-a74a-690ab13bed21"],
Cell[720136, 20381, 343, 9, 24, "Print",ExpressionUUID->"4d9beaf2-2566-47c2-9c9c-0202cd4fa908"],
Cell[720482, 20392, 10194, 259, 129, "Print",ExpressionUUID->"80efc043-7f3d-449b-ad12-30bbea8eb5ff"],
Cell[730679, 20653, 341, 9, 24, "Print",ExpressionUUID->"85de3362-4388-4c5c-a82d-a9718189ee6c"],
Cell[731023, 20664, 6411, 169, 69, "Print",ExpressionUUID->"4bebea59-594e-41fa-96a7-a6e776c28987"],
Cell[737437, 20835, 341, 9, 24, "Print",ExpressionUUID->"a2c7f76b-223f-4318-9c30-8b6d706d1188"],
Cell[737781, 20846, 2665, 74, 49, "Print",ExpressionUUID->"de6321ce-0fba-4c75-99d4-0fc5a1fe14ee"],
Cell[740449, 20922, 343, 9, 24, "Print",ExpressionUUID->"1b3ca52c-2db5-4935-8baa-15297aec3172"],
Cell[740795, 20933, 3534, 91, 49, "Print",ExpressionUUID->"ed07be22-09d8-48cf-9c4a-fb91b02e16a6"],
Cell[744332, 21026, 341, 9, 24, "Print",ExpressionUUID->"84ca9f10-2d9d-4e33-879d-59f78f7d7d66"],
Cell[744676, 21037, 4385, 111, 69, "Print",ExpressionUUID->"f67cca86-b93d-44c0-939a-83d24189c909"],
Cell[749064, 21150, 343, 9, 24, "Print",ExpressionUUID->"da250596-cc5a-4509-aef3-fa0c92bf207c"],
Cell[749410, 21161, 30236, 731, 389, "Print",ExpressionUUID->"75cf250d-3e25-49c1-a240-a4dd28db53fd"],
Cell[779649, 21894, 341, 9, 24, "Print",ExpressionUUID->"fd49f28f-2caa-447a-b6bb-4ea231bf2b26"],
Cell[779993, 21905, 19522, 481, 249, "Print",ExpressionUUID->"314f3435-bf8b-48ae-b907-7e206b27bc5c"],
Cell[799518, 22388, 341, 9, 24, "Print",ExpressionUUID->"ddd7dcf1-7318-4ed6-8a75-eb40206aafd2"],
Cell[799862, 22399, 15848, 392, 189, "Print",ExpressionUUID->"256ca2d7-b5ca-4717-8b48-8b976c72c584"],
Cell[815713, 22793, 341, 9, 24, "Print",ExpressionUUID->"a0f61774-a7d9-4a8b-a5a9-cc6d9d389bd0"],
Cell[816057, 22804, 341, 9, 24, "Print",ExpressionUUID->"902dedb7-6d17-486b-9db0-27c4af1fc3af"],
Cell[816401, 22815, 343, 9, 24, "Print",ExpressionUUID->"47355131-9a58-4976-9fcd-95b156332986"],
Cell[816747, 22826, 343, 9, 24, "Print",ExpressionUUID->"68f0c73e-ce25-40ed-abd1-7a453eacac3a"],
Cell[817093, 22837, 341, 9, 24, "Print",ExpressionUUID->"200a0f91-52e7-4a03-a6a6-39170935139b"],
Cell[817437, 22848, 343, 9, 24, "Print",ExpressionUUID->"c9d59bf2-70f8-48a9-a587-53c2818c8d6f"],
Cell[817783, 22859, 341, 9, 24, "Print",ExpressionUUID->"2d718167-8eaa-448c-9408-af4f697002ec"],
Cell[818127, 22870, 2824, 79, 47, "Print",ExpressionUUID->"4fc6ec18-4ba4-4b09-a298-09b10a3793ef"],
Cell[820954, 22951, 341, 9, 24, "Print",ExpressionUUID->"60f0927f-0980-4458-8010-276c6d92f440"],
Cell[821298, 22962, 341, 9, 24, "Print",ExpressionUUID->"dfafd102-4f3e-4aee-975a-67fdd705bba4"],
Cell[821642, 22973, 341, 9, 24, "Print",ExpressionUUID->"18614846-c110-4a94-ac08-2b7f06bb424f"],
Cell[821986, 22984, 343, 9, 24, "Print",ExpressionUUID->"07227088-0b5a-4600-a990-d8f9e5b08675"],
Cell[822332, 22995, 5070, 139, 162, "Print",ExpressionUUID->"a6d7747f-4fa5-40ec-aa21-7bc549931ef7"],
Cell[827405, 23136, 341, 9, 24, "Print",ExpressionUUID->"9cab8fa7-76ff-4c54-a9c1-565e48153eb0"],
Cell[827749, 23147, 2685, 70, 62, "Print",ExpressionUUID->"6c867f42-f39c-41cc-85d9-8a5025bff966"],
Cell[830437, 23219, 341, 9, 24, "Print",ExpressionUUID->"49ae287b-815e-4d4d-88e5-73c65da41852"],
Cell[830781, 23230, 343, 9, 24, "Print",ExpressionUUID->"827cd299-52d7-4b39-b350-67de707c1b68"],
Cell[831127, 23241, 341, 9, 24, "Print",ExpressionUUID->"1dd35fc8-e1d9-4e2c-8789-0af4f005c6db"],
Cell[831471, 23252, 341, 9, 24, "Print",ExpressionUUID->"90201050-c21a-498e-abb6-f1eb4d6dfbe0"],
Cell[831815, 23263, 3582, 94, 62, "Print",ExpressionUUID->"fa05db61-7fb6-41e4-b7b9-b6b5f8f1b643"],
Cell[835400, 23359, 341, 9, 24, "Print",ExpressionUUID->"cbd9fc59-5040-4ed7-9d64-bb959a0ec275"],
Cell[835744, 23370, 12374, 301, 188, "Print",ExpressionUUID->"4977d45a-29bf-4042-a56a-e97b13cbcc23"],
Cell[848121, 23673, 340, 9, 24, "Print",ExpressionUUID->"af5c0fd3-995e-41c8-bb33-89cf8d49214d"],
Cell[848464, 23684, 1660, 49, 40, "Print",ExpressionUUID->"5c41e648-ecf0-470d-b93f-8406b1fbafce"],
Cell[850127, 23735, 343, 9, 24, "Print",ExpressionUUID->"cee09fb9-d82c-44c3-bd18-6430a1828b51"],
Cell[850473, 23746, 1632, 48, 44, "Print",ExpressionUUID->"f0b44a56-3f8d-494c-a900-b68916369396"],
Cell[852108, 23796, 343, 9, 24, "Print",ExpressionUUID->"01ea50aa-bd82-4803-b533-7b263a2e928f"],
Cell[852454, 23807, 4003, 126, 122, "Print",ExpressionUUID->"80fb240a-af66-4566-84eb-5a628c309213"],
Cell[856460, 23935, 341, 9, 24, "Print",ExpressionUUID->"df0667bc-5351-49d3-9082-cf135ada2eae"],
Cell[856804, 23946, 2129, 61, 87, "Print",ExpressionUUID->"e94cfece-55d0-47fa-b64e-1b885e1eae9e"],
Cell[858936, 24009, 341, 9, 24, "Print",ExpressionUUID->"71295953-e0b4-4cbb-941b-524207e90501"],
Cell[859280, 24020, 341, 9, 24, "Print",ExpressionUUID->"2372d605-3e1b-4845-879b-ea0ded575733"],
Cell[859624, 24031, 343, 9, 24, "Print",ExpressionUUID->"ec6c7c64-ca92-4f84-ae9c-1900dbd3bb0a"],
Cell[859970, 24042, 3731, 111, 123, "Print",ExpressionUUID->"812e6988-b0b2-422c-b883-1d6eca0a2a7b"],
Cell[863704, 24155, 343, 9, 24, "Print",ExpressionUUID->"5c5dec5a-0723-48ad-a6ec-b3f66abc77a9"],
Cell[864050, 24166, 2383, 74, 82, "Print",ExpressionUUID->"91430612-ff35-4163-bd16-6d6bd5bd6a54"],
Cell[866436, 24242, 341, 9, 24, "Print",ExpressionUUID->"c2ff204b-5b0b-43d4-9720-0ba627e21482"],
Cell[866780, 24253, 340, 9, 24, "Print",ExpressionUUID->"5cdb1669-b7e7-4bed-9e64-513e28601448"],
Cell[867123, 24264, 339, 9, 24, "Print",ExpressionUUID->"148a63ab-b960-4abe-a114-9470e75ab7d8"],
Cell[867465, 24275, 2432, 67, 62, "Print",ExpressionUUID->"b0cb241a-07c4-4782-92fa-d42715d80afb"],
Cell[869900, 24344, 341, 9, 24, "Print",ExpressionUUID->"3f1d9762-9372-46af-869c-03e4f4c5f9a5"],
Cell[870244, 24355, 2710, 77, 40, "Print",ExpressionUUID->"4c7a7ae5-aab7-4682-a4c4-82920c2ea40f"],
Cell[872957, 24434, 341, 9, 24, "Print",ExpressionUUID->"2986f96e-d608-476d-bcd4-f752869dcbf6"],
Cell[873301, 24445, 2338, 67, 40, "Print",ExpressionUUID->"860e2360-9874-467e-a00f-503bf189ea40"],
Cell[875642, 24514, 341, 9, 24, "Print",ExpressionUUID->"88aec533-fc51-4189-95e0-b6bc4323d2ab"],
Cell[875986, 24525, 341, 9, 24, "Print",ExpressionUUID->"eb701827-2be2-4229-a9a9-134b2e6db3f2"],
Cell[876330, 24536, 343, 9, 24, "Print",ExpressionUUID->"97c56e2d-780b-420d-9343-9fa62fa8fc1c"],
Cell[876676, 24547, 341, 9, 24, "Print",ExpressionUUID->"b501c19a-8759-472d-8f30-c298ef55df93"],
Cell[877020, 24558, 1843, 54, 27, "Print",ExpressionUUID->"15eb4da7-d256-4bec-bb72-6ac4fb2a01bb"],
Cell[878866, 24614, 341, 9, 24, "Print",ExpressionUUID->"7baea0b9-ca05-494d-896c-678347a72da2"],
Cell[879210, 24625, 1718, 52, 60, "Print",ExpressionUUID->"5b67ac84-c7d6-4cc5-9562-db2b6b29bd1a"],
Cell[880931, 24679, 341, 9, 24, "Print",ExpressionUUID->"8b7ab2f2-4db8-471a-aa16-4012b201e275"],
Cell[881275, 24690, 6796, 170, 113, "Print",ExpressionUUID->"dff85a27-2999-429e-9043-9b028f2d93e2"],
Cell[888074, 24862, 341, 9, 24, "Print",ExpressionUUID->"ca5aab45-13e0-407d-a696-7d9dadf327ee"],
Cell[888418, 24873, 341, 9, 24, "Print",ExpressionUUID->"f587e2b4-806d-4537-9fef-b60c947cc634"],
Cell[888762, 24884, 4015, 103, 81, "Print",ExpressionUUID->"41a952b4-2cc6-4e3e-9a55-587aefafef02"],
Cell[892780, 24989, 341, 9, 24, "Print",ExpressionUUID->"a92589d3-547b-448a-82c9-b569fb726219"],
Cell[893124, 25000, 1705, 48, 40, "Print",ExpressionUUID->"ca3ceca8-025e-4a3a-b6ac-035488ec8b7e"],
Cell[894832, 25050, 341, 9, 24, "Print",ExpressionUUID->"5c665a55-4376-4ce1-afa5-5be1ad5c213b"],
Cell[895176, 25061, 341, 9, 24, "Print",ExpressionUUID->"18b939a3-0014-4844-886c-b50903b5e6fb"],
Cell[895520, 25072, 2120, 62, 40, "Print",ExpressionUUID->"de57ef61-20e7-416e-b6b9-fcd30ed6bf30"],
Cell[897643, 25136, 343, 9, 24, "Print",ExpressionUUID->"8cf908a9-e0a5-483f-956a-cf6baed49eb9"],
Cell[897989, 25147, 7692, 195, 147, "Print",ExpressionUUID->"db7e6bf9-2822-4855-bb8e-1f50a34e2a81"],
Cell[905684, 25344, 341, 9, 24, "Print",ExpressionUUID->"49db7a6b-1659-412a-b6d9-f9ac4a512d8d"],
Cell[906028, 25355, 343, 9, 24, "Print",ExpressionUUID->"3f06f4e4-006a-4f2b-9b4a-8ca93454da27"],
Cell[906374, 25366, 3580, 91, 49, "Print",ExpressionUUID->"eb544c6e-540d-42be-b9af-5d3ca5d969e2"],
Cell[909957, 25459, 340, 9, 24, "Print",ExpressionUUID->"c86e9c45-6c72-4b4c-a65b-18e6e44e82d6"],
Cell[910300, 25470, 4046, 104, 88, "Print",ExpressionUUID->"717be07b-a86d-4edb-9749-cc3384771b76"],
Cell[914349, 25576, 341, 9, 24, "Print",ExpressionUUID->"7213a0e0-517b-40df-b20c-b9ff9a164959"],
Cell[914693, 25587, 4925, 124, 88, "Print",ExpressionUUID->"661ee9e7-fd17-479d-b522-757c8b87ee9f"],
Cell[919621, 25713, 341, 9, 24, "Print",ExpressionUUID->"e2f79e39-9b0f-4608-b11b-af09a08e708f"],
Cell[919965, 25724, 1640, 47, 40, "Print",ExpressionUUID->"01b82fdc-cec2-4575-9e93-d55e3e5c576c"],
Cell[921608, 25773, 341, 9, 24, "Print",ExpressionUUID->"3b037879-b114-4e14-97f4-cbe0cce8cf4a"],
Cell[921952, 25784, 341, 9, 24, "Print",ExpressionUUID->"222e7fd0-5d80-4d83-8394-d106dd81c492"],
Cell[922296, 25795, 341, 9, 24, "Print",ExpressionUUID->"7319168e-fffb-4880-b9aa-5ab3823f4c78"],
Cell[922640, 25806, 341, 9, 24, "Print",ExpressionUUID->"0eb6e242-fab6-4221-a701-fd06a4a8512e"],
Cell[922984, 25817, 343, 9, 24, "Print",ExpressionUUID->"4e23acf7-3ae9-4f0a-8f4e-8ef833f95787"],
Cell[923330, 25828, 3671, 94, 49, "Print",ExpressionUUID->"d3f0e582-11ca-437a-a9e1-d0c51624d015"],
Cell[927004, 25924, 341, 9, 24, "Print",ExpressionUUID->"755d36ba-bacc-4767-b797-e1f222c49def"],
Cell[927348, 25935, 341, 9, 24, "Print",ExpressionUUID->"694b7461-e978-47da-8c7c-869ab5b8f8ff"],
Cell[927692, 25946, 341, 9, 24, "Print",ExpressionUUID->"c07d6efc-de23-4eb1-8d62-994d6b23ec05"],
Cell[928036, 25957, 341, 9, 24, "Print",ExpressionUUID->"f11fc1ab-e69e-4bb9-ae8a-49b5c5a8d9ee"],
Cell[928380, 25968, 343, 9, 24, "Print",ExpressionUUID->"844ea55d-9da9-475d-a8b9-2f01756c2f14"],
Cell[928726, 25979, 1811, 50, 40, "Print",ExpressionUUID->"a716f608-0b32-4010-874f-68182d44666e"],
Cell[930540, 26031, 341, 9, 24, "Print",ExpressionUUID->"a8ae8276-dcb3-4a27-942f-ef25784401c3"],
Cell[930884, 26042, 343, 9, 24, "Print",ExpressionUUID->"cc534cd7-44b3-445c-832b-8b6402dde8a8"],
Cell[931230, 26053, 341, 9, 24, "Print",ExpressionUUID->"e56ce8c6-8ca9-4e36-af04-6055250e8cdc"],
Cell[931574, 26064, 1520, 45, 40, "Print",ExpressionUUID->"44952c49-5b94-4d32-9588-9b0fd11ba8a9"],
Cell[933097, 26111, 343, 9, 24, "Print",ExpressionUUID->"92cd81cf-7e14-478a-90ee-2d85a1e47508"],
Cell[933443, 26122, 2459, 68, 66, "Print",ExpressionUUID->"44056a51-e697-40b6-9972-6fac7f4b834d"],
Cell[935905, 26192, 343, 9, 24, "Print",ExpressionUUID->"3eef0a47-2c85-4d18-a242-37feefd5e322"],
Cell[936251, 26203, 2552, 70, 66, "Print",ExpressionUUID->"55512347-bfa3-476c-8d95-26d449a90317"],
Cell[938806, 26275, 341, 9, 24, "Print",ExpressionUUID->"f6d1163a-0c56-4d20-9522-e0802154f088"],
Cell[939150, 26286, 340, 9, 24, "Print",ExpressionUUID->"beeca184-8582-41ff-b04f-7077866e9b7b"],
Cell[939493, 26297, 341, 9, 24, "Print",ExpressionUUID->"be11cb74-2c4f-4f36-ba89-62be638b1f25"],
Cell[939837, 26308, 2245, 59, 40, "Print",ExpressionUUID->"10ddc38d-7e79-4b9e-997f-1bf52a80f2ae"],
Cell[942085, 26369, 343, 9, 24, "Print",ExpressionUUID->"1b17d887-2610-4aa7-ab1e-f143110c490a"],
Cell[942431, 26380, 343, 9, 24, "Print",ExpressionUUID->"9074ca5c-2a73-439d-b60d-afe30e8561bf"],
Cell[942777, 26391, 1700, 49, 40, "Print",ExpressionUUID->"4d165aa5-b4cb-4820-b080-391d61d149dd"],
Cell[944480, 26442, 341, 9, 24, "Print",ExpressionUUID->"a9f06b5d-ae24-4b1a-8ae6-78368c3fd98f"],
Cell[944824, 26453, 341, 9, 24, "Print",ExpressionUUID->"8ac18be1-b88b-4433-be06-49eec5880a83"],
Cell[945168, 26464, 341, 9, 24, "Print",ExpressionUUID->"009918e2-471c-47dd-8d0f-f56c3583369d"],
Cell[945512, 26475, 4778, 120, 71, "Print",ExpressionUUID->"dbae63dc-2250-43fd-9934-c7ef2008bf34"],
Cell[950293, 26597, 343, 9, 24, "Print",ExpressionUUID->"93a18f8a-cb58-418b-8e66-56f4ece14e1e"],
Cell[950639, 26608, 4771, 120, 88, "Print",ExpressionUUID->"286a0e0a-b278-480a-801f-84b7a7f590b9"],
Cell[955413, 26730, 341, 9, 24, "Print",ExpressionUUID->"a308199b-53cc-456f-a803-9040297a444d"],
Cell[955757, 26741, 341, 9, 24, "Print",ExpressionUUID->"06fab6f5-148a-4de5-8fb0-7c3d390dd82e"],
Cell[956101, 26752, 2006, 55, 40, "Print",ExpressionUUID->"f74ead31-ccb4-411b-a828-7c4fab0367d3"],
Cell[958110, 26809, 343, 9, 24, "Print",ExpressionUUID->"bb453a80-51ac-4744-9706-38efbc6514ab"],
Cell[958456, 26820, 5045, 126, 71, "Print",ExpressionUUID->"5b72f46f-47f4-4b45-a423-8f60eb6176c2"],
Cell[963504, 26948, 341, 9, 24, "Print",ExpressionUUID->"80171790-57bd-41f6-85cf-8219cc7fdd13"],
Cell[963848, 26959, 341, 9, 24, "Print",ExpressionUUID->"31e04e2d-7846-4a00-830e-9afc2cdf1a9b"],
Cell[964192, 26970, 4093, 104, 84, "Print",ExpressionUUID->"1ee9c17e-52d3-44b7-80db-64a5e5935736"],
Cell[968288, 27076, 341, 9, 24, "Print",ExpressionUUID->"5de85d77-2706-44cc-9d97-a96e2238820d"],
Cell[968632, 27087, 341, 9, 24, "Print",ExpressionUUID->"b69c6c7e-7dc7-414b-9870-317582db5a56"],
Cell[968976, 27098, 341, 9, 24, "Print",ExpressionUUID->"5e3e6695-53fc-48d4-81c4-37c6e5cd2b8f"],
Cell[969320, 27109, 341, 9, 24, "Print",ExpressionUUID->"ea9ff7c2-3b27-4fa2-9deb-894225b63ff1"],
Cell[969664, 27120, 4884, 133, 84, "Print",ExpressionUUID->"11cb14ab-ed56-4326-a47d-02d51b708b05"],
Cell[974551, 27255, 341, 9, 24, "Print",ExpressionUUID->"7b60b894-0f1f-43d3-ac70-f28c0728c537"],
Cell[974895, 27266, 340, 9, 24, "Print",ExpressionUUID->"b78faaa7-5445-4343-a298-6626c0e28431"],
Cell[975238, 27277, 341, 9, 24, "Print",ExpressionUUID->"e1ee56ee-9412-4070-8699-529896240b42"],
Cell[975582, 27288, 341, 9, 24, "Print",ExpressionUUID->"4408f436-8867-4657-88a6-ad049deb9af7"],
Cell[975926, 27299, 2386, 67, 27, "Print",ExpressionUUID->"c5a6cb11-aa2f-4868-a722-766c45b2b55a"],
Cell[978315, 27368, 343, 9, 24, "Print",ExpressionUUID->"51382ead-a4d6-49dd-b554-7c9e6f2bc53a"],
Cell[978661, 27379, 1541, 45, 28, "Print",ExpressionUUID->"a0837c02-21b7-4ea7-adb0-f3ba72d441ce"],
Cell[980205, 27426, 343, 9, 24, "Print",ExpressionUUID->"12d22f2c-3485-41d3-a153-043e2e3f5619"],
Cell[980551, 27437, 1336, 39, 28, "Print",ExpressionUUID->"f30adc5e-714a-4b4c-8373-06bac7520675"],
Cell[981890, 27478, 340, 9, 24, "Print",ExpressionUUID->"58d7cb7d-07be-4397-b028-98342e3ea861"],
Cell[982233, 27489, 341, 9, 24, "Print",ExpressionUUID->"de20ab84-946c-446d-af4b-bfa762e60d53"],
Cell[982577, 27500, 2801, 73, 66, "Print",ExpressionUUID->"14f22f81-26b1-42e3-b72b-23f3919fbdb4"],
Cell[985381, 27575, 341, 9, 24, "Print",ExpressionUUID->"8b2570e9-4517-4b62-a6fb-e3a908c1337a"],
Cell[985725, 27586, 341, 9, 24, "Print",ExpressionUUID->"0cce9d06-a821-4607-bdb1-b54d395d16ed"],
Cell[986069, 27597, 341, 9, 24, "Print",ExpressionUUID->"2bd52b36-a715-4503-b128-b0359d2458e0"],
Cell[986413, 27608, 341, 9, 24, "Print",ExpressionUUID->"e1cf9257-9e4b-4c74-abb0-4c40c35fb0ef"],
Cell[986757, 27619, 341, 9, 24, "Print",ExpressionUUID->"f8cd5c74-8fea-4ef5-b26d-dd665e1ae889"],
Cell[987101, 27630, 341, 9, 24, "Print",ExpressionUUID->"50b913c8-199e-4211-af52-1ec16d67d5a9"],
Cell[987445, 27641, 341, 9, 24, "Print",ExpressionUUID->"67ec631e-9815-4264-b19e-18207f69eed2"],
Cell[987789, 27652, 343, 9, 24, "Print",ExpressionUUID->"9d94d5e8-04a2-45d0-abb7-4d9355b27de7"],
Cell[988135, 27663, 341, 9, 24, "Print",ExpressionUUID->"335297b6-f578-4f32-88bd-62b0e04943e4"],
Cell[988479, 27674, 341, 9, 24, "Print",ExpressionUUID->"50b73e62-a268-4ea8-bd7b-4d603a880a61"],
Cell[988823, 27685, 2042, 60, 40, "Print",ExpressionUUID->"fbc6ef28-059a-4f44-a948-381af93ae706"],
Cell[990868, 27747, 343, 9, 24, "Print",ExpressionUUID->"bdd59463-3575-4a27-af51-29ee33f0e2fc"],
Cell[991214, 27758, 8539, 228, 128, "Print",ExpressionUUID->"8a7936e1-f6f0-4b55-a555-0684146d8957"],
Cell[999756, 27988, 341, 9, 24, "Print",ExpressionUUID->"86062456-9a6b-47c4-ad0b-5cf08939e375"],
Cell[1000100, 27999, 5239, 140, 71, "Print",ExpressionUUID->"3f355569-0641-4dd8-887e-7547e6ee4ffb"],
Cell[1005342, 28141, 341, 9, 24, "Print",ExpressionUUID->"1e57bbb0-5dea-453f-b145-e33c6edda52c"],
Cell[1005686, 28152, 341, 9, 24, "Print",ExpressionUUID->"60142560-8765-4e5a-a287-91f5afdea32b"],
Cell[1006030, 28163, 340, 9, 24, "Print",ExpressionUUID->"ad076a7d-9b4b-42e6-b8e7-cd1a4df48350"],
Cell[1006373, 28174, 2173, 62, 40, "Print",ExpressionUUID->"e9d5d0a0-9d7a-4b04-b7e5-4b9493cf86d4"],
Cell[1008549, 28238, 341, 9, 24, "Print",ExpressionUUID->"64c95578-a3cc-4a88-9859-0b2fa073d569"],
Cell[1008893, 28249, 2094, 61, 40, "Print",ExpressionUUID->"47bfbf71-b992-400d-a3c8-7e2a1f271475"],
Cell[1010990, 28312, 341, 9, 24, "Print",ExpressionUUID->"ec084309-4fa8-4b48-a57f-88af37803ffd"],
Cell[1011334, 28323, 341, 9, 24, "Print",ExpressionUUID->"a4193b0e-bd68-40c1-96df-36ed6f785330"],
Cell[1011678, 28334, 1873, 58, 60, "Print",ExpressionUUID->"010c5753-99cc-417d-b42c-b491491065f4"],
Cell[1013554, 28394, 341, 9, 24, "Print",ExpressionUUID->"176b1ea3-e38e-4a77-b0d2-5cd8248e4b0c"],
Cell[1013898, 28405, 5311, 164, 162, "Print",ExpressionUUID->"e5cf615e-bd06-469b-82bd-f443f8598d8e"],
Cell[1019212, 28571, 343, 9, 24, "Print",ExpressionUUID->"79b6800f-97c2-4890-966d-5cea54767618"],
Cell[1019558, 28582, 2262, 64, 62, "Print",ExpressionUUID->"1062ab32-4c00-42f9-bcbf-c39d31b08c71"],
Cell[1021823, 28648, 341, 9, 24, "Print",ExpressionUUID->"6d7ed5c2-0286-4a6f-8ab0-3f2ab09dbbfe"],
Cell[1022167, 28659, 4141, 114, 81, "Print",ExpressionUUID->"f7595d67-bf41-44fc-8317-a2672bed4181"],
Cell[1026311, 28775, 341, 9, 24, "Print",ExpressionUUID->"ade5152f-f1e1-4abd-8349-e999678c6d3a"],
Cell[1026655, 28786, 4306, 118, 81, "Print",ExpressionUUID->"0aa3d95a-4763-44c4-913d-bf489183fbc6"],
Cell[1030964, 28906, 341, 9, 24, "Print",ExpressionUUID->"9cc4b346-b23b-4d49-9380-d38b4c1eb6c4"],
Cell[1031308, 28917, 341, 9, 24, "Print",ExpressionUUID->"741ae08a-7d27-4eba-a77a-b62b63909989"],
Cell[1031652, 28928, 341, 9, 24, "Print",ExpressionUUID->"f00db44d-4eeb-44b9-b6b2-3efc13458814"],
Cell[1031996, 28939, 2341, 69, 82, "Print",ExpressionUUID->"07274a37-c526-43a9-af40-76b55e5ca1db"],
Cell[1034340, 29010, 343, 9, 24, "Print",ExpressionUUID->"c7141bec-fd51-4a18-9688-e19604ea9f57"],
Cell[1034686, 29021, 6838, 169, 125, "Print",ExpressionUUID->"1efb87c0-0c69-4c2f-870b-026422206f71"],
Cell[1041527, 29192, 341, 9, 24, "Print",ExpressionUUID->"a18e29f9-477f-4595-a791-c37bab7912c0"],
Cell[1041871, 29203, 341, 9, 24, "Print",ExpressionUUID->"4ee0d389-f0e2-42c7-beba-a156accd1dc6"],
Cell[1042215, 29214, 2088, 57, 40, "Print",ExpressionUUID->"d3bdb38f-7630-41f7-b98c-b33be8a84389"],
Cell[1044306, 29273, 341, 9, 24, "Print",ExpressionUUID->"29995b0a-e409-4816-be13-95dbb250c165"],
Cell[1044650, 29284, 341, 9, 24, "Print",ExpressionUUID->"750dde33-6b41-4bc5-b1ec-e1743b7ecf8f"],
Cell[1044994, 29295, 341, 9, 24, "Print",ExpressionUUID->"21bbc277-0542-412c-8ef3-02d0be421cb1"],
Cell[1045338, 29306, 341, 9, 24, "Print",ExpressionUUID->"bdc783d1-90e8-4340-97e8-9349940b6db8"],
Cell[1045682, 29317, 341, 9, 24, "Print",ExpressionUUID->"719f8145-23f4-4b14-980f-395f86ac146d"],
Cell[1046026, 29328, 1788, 49, 40, "Print",ExpressionUUID->"16074bd8-2bb0-4f5d-8fe7-9d473ae7453f"],
Cell[1047817, 29379, 341, 9, 24, "Print",ExpressionUUID->"20c7eea0-d331-4f0a-8492-81d0a8866983"],
Cell[1048161, 29390, 341, 9, 24, "Print",ExpressionUUID->"70cc638b-cc3e-4752-8a56-54ba5b2ab6be"],
Cell[1048505, 29401, 341, 9, 24, "Print",ExpressionUUID->"f50c8abf-faee-46c6-b980-dffd3dca96f6"],
Cell[1048849, 29412, 3281, 83, 62, "Print",ExpressionUUID->"d7d6d250-dda6-41dd-8d85-e9f09aec986f"],
Cell[1052133, 29497, 341, 9, 24, "Print",ExpressionUUID->"cafa5243-be28-44f1-98cd-068a4fc6a43a"],
Cell[1052477, 29508, 341, 9, 24, "Print",ExpressionUUID->"94b47b77-704f-4379-82c4-8f303f73acc5"],
Cell[1052821, 29519, 2044, 57, 40, "Print",ExpressionUUID->"93e3b98b-1a72-4237-b7b2-2e8f2fe25cea"],
Cell[1054868, 29578, 341, 9, 24, "Print",ExpressionUUID->"a4c4b3e2-b546-4189-a5da-7a07de871125"],
Cell[1055212, 29589, 7161, 178, 115, "Print",ExpressionUUID->"a05ce5bf-327f-4a3a-9c2e-8cd09c1a4b1c"],
Cell[1062376, 29769, 341, 9, 24, "Print",ExpressionUUID->"f8af33a5-4da0-42d6-ba5a-ef35f4fbc991"],
Cell[1062720, 29780, 341, 9, 24, "Print",ExpressionUUID->"a6425d0e-35e1-493f-8e85-2c6fe8727ee7"],
Cell[1063064, 29791, 7296, 180, 115, "Print",ExpressionUUID->"d76e9edd-dabe-4cd1-8331-2f56cd50f1c9"],
Cell[1070363, 29973, 341, 9, 24, "Print",ExpressionUUID->"c5b790fe-6416-4cee-bbb4-d01ec78004a7"],
Cell[1070707, 29984, 341, 9, 24, "Print",ExpressionUUID->"74684ac1-0e89-4245-bbf7-f7cf4fdb1247"],
Cell[1071051, 29995, 2092, 58, 40, "Print",ExpressionUUID->"18113a9c-9cc9-47d6-8fe9-94432851f950"],
Cell[1073146, 30055, 341, 9, 24, "Print",ExpressionUUID->"eb62840e-df10-4bed-950a-0ff48556676b"],
Cell[1073490, 30066, 7927, 196, 115, "Print",ExpressionUUID->"f558dc1f-a6a5-42a7-97e1-37ac62022d4a"],
Cell[1081420, 30264, 341, 9, 24, "Print",ExpressionUUID->"9be85843-979f-494f-acb2-054a15f36fd2"],
Cell[1081764, 30275, 340, 9, 24, "Print",ExpressionUUID->"93ecd33d-e789-4726-8aaf-953e0fa2976d"],
Cell[1082107, 30286, 341, 9, 24, "Print",ExpressionUUID->"67c10975-06e4-4b53-85de-6babd6756408"],
Cell[1082451, 30297, 9012, 240, 128, "Print",ExpressionUUID->"e09ea3f7-6984-4eda-afbc-7c0c60414424"],
Cell[1091466, 30539, 341, 9, 24, "Print",ExpressionUUID->"579a1ee7-d718-43b9-b89e-7d3c1571be5c"],
Cell[1091810, 30550, 341, 9, 24, "Print",ExpressionUUID->"d787a4e4-b00f-45c2-a216-8a0f176bcf01"],
Cell[1092154, 30561, 3937, 108, 62, "Print",ExpressionUUID->"a22bcbd7-91a5-4b57-a3a5-852c9067b151"],
Cell[1096094, 30671, 341, 9, 24, "Print",ExpressionUUID->"bc9755ae-f4f0-441d-8cc6-10083cf3d804"],
Cell[1096438, 30682, 2148, 62, 28, "Print",ExpressionUUID->"d3564f8c-6632-4690-bdff-de9a8d95967d"],
Cell[1098589, 30746, 341, 9, 24, "Print",ExpressionUUID->"3676c641-9ae3-424d-90ad-ea5deee1e68b"],
Cell[1098933, 30757, 2254, 66, 44, "Print",ExpressionUUID->"8c1577d2-1362-48ab-8777-5d762cd50442"],
Cell[1101190, 30825, 341, 9, 24, "Print",ExpressionUUID->"24096d6f-43dc-44a0-8cdc-d8cb8d320ac5"],
Cell[1101534, 30836, 341, 9, 24, "Print",ExpressionUUID->"b29163f9-3f46-4cd4-9d66-8f48712cd79e"],
Cell[1101878, 30847, 3445, 91, 62, "Print",ExpressionUUID->"874d56ec-f75a-4367-81b0-cd7324af4c4d"],
Cell[1105326, 30940, 341, 9, 24, "Print",ExpressionUUID->"adc7fbc4-c012-4310-8453-0efc5e96a95f"],
Cell[1105670, 30951, 341, 9, 24, "Print",ExpressionUUID->"91375344-143d-4f92-90bd-8559dcadb8ea"],
Cell[1106014, 30962, 341, 9, 24, "Print",ExpressionUUID->"e8ac3745-2416-4149-8899-b5c00c73cd39"],
Cell[1106358, 30973, 341, 9, 24, "Print",ExpressionUUID->"21ec6c22-3470-4501-99d4-d2d7c78005b4"],
Cell[1106702, 30984, 341, 9, 24, "Print",ExpressionUUID->"62a00e5f-ceeb-4ad9-bf93-717ad4344b92"],
Cell[1107046, 30995, 341, 9, 24, "Print",ExpressionUUID->"2381b5cc-6ea8-4003-bb6c-0dbc18d85ffe"],
Cell[1107390, 31006, 341, 9, 24, "Print",ExpressionUUID->"b2b72c14-6df5-4809-bccc-d6d8db8cd368"],
Cell[1107734, 31017, 341, 9, 24, "Print",ExpressionUUID->"0f279507-efe2-4930-911f-6e2534cd11c6"],
Cell[1108078, 31028, 341, 9, 24, "Print",ExpressionUUID->"a466dceb-1876-4a42-b427-4cc9b118800d"],
Cell[1108422, 31039, 343, 9, 24, "Print",ExpressionUUID->"10ffc00e-e923-49e4-9fd2-73d6c357ccd0"],
Cell[1108768, 31050, 341, 9, 24, "Print",ExpressionUUID->"ec1a85c7-0106-482d-8cc0-14c048678b40"],
Cell[1109112, 31061, 341, 9, 24, "Print",ExpressionUUID->"83d259ba-4cd0-4164-98ea-66dd2fe4d027"],
Cell[1109456, 31072, 341, 9, 24, "Print",ExpressionUUID->"96983d1a-3934-420b-97cb-f5801f49e613"],
Cell[1109800, 31083, 341, 9, 24, "Print",ExpressionUUID->"486b3d32-d4f9-4c0c-86ed-11959dedcac4"],
Cell[1110144, 31094, 2207, 63, 40, "Print",ExpressionUUID->"9533d487-0852-4946-97a5-35389aa0ec5e"],
Cell[1112354, 31159, 341, 9, 24, "Print",ExpressionUUID->"157331d8-9038-4a78-b1db-c2ee0f210e0a"],
Cell[1112698, 31170, 6968, 171, 135, "Print",ExpressionUUID->"6324f719-a5bf-461e-8f07-b21292319288"],
Cell[1119669, 31343, 341, 9, 24, "Print",ExpressionUUID->"52e0751d-86ca-403c-bbb2-a02bfe52fdb8"],
Cell[1120013, 31354, 1968, 55, 40, "Print",ExpressionUUID->"5775ee99-8eb7-4a64-b5e7-56d082843dcb"],
Cell[1121984, 31411, 341, 9, 24, "Print",ExpressionUUID->"38c8d04f-510c-47e7-ba8d-c0e9f26a2d6a"],
Cell[1122328, 31422, 3036, 84, 62, "Print",ExpressionUUID->"33191216-504a-4daf-8f26-2375867b8f37"],
Cell[1125367, 31508, 341, 9, 24, "Print",ExpressionUUID->"8121741f-db97-4af6-8970-8e30e62426b5"],
Cell[1125711, 31519, 1595, 43, 40, "Print",ExpressionUUID->"8ee70194-db20-48c6-83b7-670a38b7f395"],
Cell[1127309, 31564, 341, 9, 24, "Print",ExpressionUUID->"b6f57e9e-00e7-4f33-8620-a2722c2ebd45"],
Cell[1127653, 31575, 1569, 45, 28, "Print",ExpressionUUID->"fad40cc4-d0d6-4ae7-ad10-da47cfe19c09"],
Cell[1129225, 31622, 343, 9, 24, "Print",ExpressionUUID->"8a89e601-6e64-48fe-93eb-8be1e2244368"],
Cell[1129571, 31633, 2219, 59, 59, "Print",ExpressionUUID->"7b17f2ff-f26d-4512-acac-22981d191a88"],
Cell[1131793, 31694, 341, 9, 24, "Print",ExpressionUUID->"b9b8cf44-b85d-4c58-b7ca-297e1d2e8727"],
Cell[1132137, 31705, 1470, 43, 40, "Print",ExpressionUUID->"cbbb40a4-6cb8-4220-a595-af008f4ad901"],
Cell[1133610, 31750, 341, 9, 24, "Print",ExpressionUUID->"7c180919-da20-42c5-8a3e-2a9852462357"],
Cell[1133954, 31761, 1827, 52, 27, "Print",ExpressionUUID->"e30e3623-f4b1-4f9e-b3f3-e4f098ae829e"],
Cell[1135784, 31815, 341, 9, 24, "Print",ExpressionUUID->"77b78e82-6ca4-4158-9f91-0747f3094b80"],
Cell[1136128, 31826, 343, 9, 24, "Print",ExpressionUUID->"f0355589-33a7-49a2-9bba-0f3872bd7829"],
Cell[1136474, 31837, 341, 9, 24, "Print",ExpressionUUID->"bfad4bf5-986f-487c-8f81-7601f07c5db2"],
Cell[1136818, 31848, 1741, 49, 44, "Print",ExpressionUUID->"ab66bffa-2e4e-42d7-9f8d-4c24ef6f5c68"],
Cell[1138562, 31899, 343, 9, 24, "Print",ExpressionUUID->"851ebb1d-8e0a-4882-8c00-d7342137d4bd"],
Cell[1138908, 31910, 1732, 49, 28, "Print",ExpressionUUID->"6f8dc7d3-8445-4c9f-bcf4-1a78908f6cda"],
Cell[1140643, 31961, 341, 9, 24, "Print",ExpressionUUID->"c20ba21f-c16d-4297-ac65-245117d67aba"],
Cell[1140987, 31972, 1390, 38, 44, "Print",ExpressionUUID->"3621c02d-acd0-41a6-9554-7514d0c74d76"],
Cell[1142380, 32012, 343, 9, 24, "Print",ExpressionUUID->"ec3d7069-9730-4eed-821d-4ea0907003f9"],
Cell[1142726, 32023, 4038, 101, 71, "Print",ExpressionUUID->"50a5b0f6-3c51-4218-98be-77521c2c9789"],
Cell[1146767, 32126, 341, 9, 24, "Print",ExpressionUUID->"46f8ac36-3f72-4176-be19-cb6148cabb48"],
Cell[1147111, 32137, 2912, 79, 49, "Print",ExpressionUUID->"7b1ee731-72a3-4114-a3d9-b44c4e332d2c"],
Cell[1150026, 32218, 343, 9, 24, "Print",ExpressionUUID->"b9afde1b-e796-4b56-89d3-7993c89a143a"],
Cell[1150372, 32229, 341, 9, 24, "Print",ExpressionUUID->"8a9a8941-f23e-4e8c-a562-6ff9672ed4b7"],
Cell[1150716, 32240, 2024, 57, 27, "Print",ExpressionUUID->"ac9c9a22-48bf-4295-a5bc-9a46193eb59d"],
Cell[1152743, 32299, 341, 9, 24, "Print",ExpressionUUID->"ddce47ea-49fc-45c4-a681-7ddf7a6dc94f"],
Cell[1153087, 32310, 341, 9, 24, "Print",ExpressionUUID->"14005ef7-b916-4662-b84e-80bc134b040b"],
Cell[1153431, 32321, 4537, 126, 84, "Print",ExpressionUUID->"01e791e3-8737-4f82-9b2c-92502d7681ad"],
Cell[1157971, 32449, 341, 9, 24, "Print",ExpressionUUID->"73fabea8-af04-4bf7-94fb-fd4299f0fe17"],
Cell[1158315, 32460, 343, 9, 24, "Print",ExpressionUUID->"da0f7a45-ebd4-46de-9ee4-67327fbfd122"],
Cell[1158661, 32471, 3746, 98, 81, "Print",ExpressionUUID->"01ee6d72-bccf-4cde-99eb-63dad2e0d446"],
Cell[1162410, 32571, 341, 9, 24, "Print",ExpressionUUID->"9da1a101-8095-4b11-a28f-18e6ff31cdb6"],
Cell[1162754, 32582, 2666, 75, 63, "Print",ExpressionUUID->"8179a83a-9d54-4117-9ca2-69460b2e9608"],
Cell[1165423, 32659, 341, 9, 24, "Print",ExpressionUUID->"ba6b287b-2321-4b5f-a044-9ee4d653393d"],
Cell[1165767, 32670, 341, 9, 24, "Print",ExpressionUUID->"2ef32488-1c68-40df-9032-7639c7166746"],
Cell[1166111, 32681, 341, 9, 24, "Print",ExpressionUUID->"5e7cd583-e486-46a8-888c-250dc441d119"],
Cell[1166455, 32692, 1921, 54, 40, "Print",ExpressionUUID->"39e0a773-55fb-427a-835d-bb9ecc02d638"],
Cell[1168379, 32748, 341, 9, 24, "Print",ExpressionUUID->"281a6d16-50a7-48bd-8d9f-4c298d576f0f"],
Cell[1168723, 32759, 2223, 63, 28, "Print",ExpressionUUID->"208c434f-a362-4de7-8008-80d802f3a481"],
Cell[1170949, 32824, 343, 9, 24, "Print",ExpressionUUID->"69ca4076-489c-4165-8ee4-6979877dd4df"],
Cell[1171295, 32835, 2144, 63, 40, "Print",ExpressionUUID->"e3c9cb99-6e97-4df5-b9e4-28567bd8c1de"],
Cell[1173442, 32900, 343, 9, 24, "Print",ExpressionUUID->"8d938587-da0d-4e8c-a9ec-820f564bafa6"],
Cell[1173788, 32911, 341, 9, 24, "Print",ExpressionUUID->"0dcd2863-e9b2-495a-b170-4cd6f103cba8"],
Cell[1174132, 32922, 341, 9, 24, "Print",ExpressionUUID->"f387d762-0b38-44f2-a1d1-2ddb9d3b61de"],
Cell[1174476, 32933, 341, 9, 24, "Print",ExpressionUUID->"63433333-697b-4d99-ba5b-7d14f833b445"],
Cell[1174820, 32944, 343, 9, 24, "Print",ExpressionUUID->"b8747bc7-d15d-49b6-8fac-15a277db4336"],
Cell[1175166, 32955, 341, 9, 24, "Print",ExpressionUUID->"6f7be15f-254b-4a4d-a467-2a9425859ffb"],
Cell[1175510, 32966, 1632, 44, 43, "Print",ExpressionUUID->"5cdafa1d-abea-4f81-8c22-31ab21e30e5c"],
Cell[1177145, 33012, 341, 9, 24, "Print",ExpressionUUID->"136d2cc8-5089-4ff1-ad7e-9eda7bc04bfc"],
Cell[1177489, 33023, 341, 9, 24, "Print",ExpressionUUID->"8befae4a-cc30-4002-8c5d-1a1356a3bcb3"],
Cell[1177833, 33034, 341, 9, 24, "Print",ExpressionUUID->"2b324eba-a7bf-46cc-991f-f033e3dd2fb8"],
Cell[1178177, 33045, 1909, 50, 40, "Print",ExpressionUUID->"f0786ab4-6bc6-4469-9272-f901c207d345"],
Cell[1180089, 33097, 341, 9, 24, "Print",ExpressionUUID->"200772f6-ff0a-4222-a0d3-b4ff3bec6c8c"],
Cell[1180433, 33108, 343, 9, 24, "Print",ExpressionUUID->"f5f82b55-4d84-4f25-bc50-ec660607e331"],
Cell[1180779, 33119, 1509, 43, 40, "Print",ExpressionUUID->"3ccb8b41-1453-4104-8033-0d3e34094ed6"],
Cell[1182291, 33164, 341, 9, 24, "Print",ExpressionUUID->"85ee4f42-233b-43fa-b9ed-b61f36deaf1c"],
Cell[1182635, 33175, 4639, 116, 71, "Print",ExpressionUUID->"6e88506b-2627-4554-9e06-d04d71ddd992"],
Cell[1187277, 33293, 341, 9, 24, "Print",ExpressionUUID->"91102656-c8b1-4c93-be21-2534ba7752c6"],
Cell[1187621, 33304, 341, 9, 24, "Print",ExpressionUUID->"d67c1764-24ef-46c2-a1bc-fa220f44fd40"],
Cell[1187965, 33315, 2388, 64, 62, "Print",ExpressionUUID->"1e8d510c-7765-41d7-b94f-3032aa9f59f6"],
Cell[1190356, 33381, 341, 9, 24, "Print",ExpressionUUID->"35298271-b006-4747-af1a-1e10c7f3b1fa"],
Cell[1190700, 33392, 1691, 48, 28, "Print",ExpressionUUID->"f9b978a9-8a8f-4638-aaa0-db4b518de0ca"],
Cell[1192394, 33442, 341, 9, 24, "Print",ExpressionUUID->"711664fe-d192-484b-9484-e1899fa787b9"],
Cell[1192738, 33453, 341, 9, 24, "Print",ExpressionUUID->"12d19f96-cf6f-4e21-a44d-8ad7e48140a1"],
Cell[1193082, 33464, 3078, 83, 49, "Print",ExpressionUUID->"e50c0145-5de5-4ac7-8c35-c01915f64efc"],
Cell[1196163, 33549, 341, 9, 24, "Print",ExpressionUUID->"743a6701-a767-40c5-beb1-dec05032617c"],
Cell[1196507, 33560, 3429, 96, 62, "Print",ExpressionUUID->"bf7fb261-ab63-45de-ab84-0a984efb1485"],
Cell[1199939, 33658, 341, 9, 24, "Print",ExpressionUUID->"b2b4cace-4500-438c-afb5-25e2f1455c98"],
Cell[1200283, 33669, 2235, 59, 43, "Print",ExpressionUUID->"e8191bcc-7dfd-4809-aa88-23abd585e47b"],
Cell[1202521, 33730, 343, 9, 24, "Print",ExpressionUUID->"d059878d-dcbe-414f-b4bc-ded5a3ccccfc"],
Cell[1202867, 33741, 4316, 112, 69, "Print",ExpressionUUID->"06c3e5b4-50bf-4801-ae80-a64df6d95f5d"],
Cell[1207186, 33855, 343, 9, 24, "Print",ExpressionUUID->"9e313773-5336-40e2-80c0-8bae51e3d7cc"],
Cell[1207532, 33866, 340, 9, 24, "Print",ExpressionUUID->"c3c98a3a-a83c-4f0e-a91c-39ee65805d13"],
Cell[1207875, 33877, 341, 9, 24, "Print",ExpressionUUID->"4e12f0d7-ae1c-4e32-b6f7-29152bd5c99e"],
Cell[1208219, 33888, 341, 9, 24, "Print",ExpressionUUID->"2e9a0de8-ebbe-44fc-bb1a-8fe90e329faf"],
Cell[1208563, 33899, 341, 9, 24, "Print",ExpressionUUID->"833ccdd4-0d41-408a-a6f4-fecab933296e"],
Cell[1208907, 33910, 341, 9, 24, "Print",ExpressionUUID->"eca3b39a-525f-4c83-b80e-15d90f9d7534"],
Cell[1209251, 33921, 341, 9, 24, "Print",ExpressionUUID->"b6cc92dd-a541-4f20-940d-ac58aabddef3"],
Cell[1209595, 33932, 341, 9, 24, "Print",ExpressionUUID->"8a1c2bc4-f9b4-469b-99ed-12f7ad1d754c"],
Cell[1209939, 33943, 343, 9, 24, "Print",ExpressionUUID->"abacd4a6-272f-47bd-937f-143f835ec790"],
Cell[1210285, 33954, 2156, 65, 48, "Print",ExpressionUUID->"4310e430-c02e-4fe2-adcc-191f298b94db"],
Cell[1212444, 34021, 341, 9, 24, "Print",ExpressionUUID->"f4ec6a96-4ac4-40e6-8116-4d49d6e7eda1"],
Cell[1212788, 34032, 1286, 37, 44, "Print",ExpressionUUID->"acb934f5-34d6-4e61-b70c-f12a8d3823a2"],
Cell[1214077, 34071, 340, 9, 24, "Print",ExpressionUUID->"54711fa2-2418-45d3-ab56-a915fac780a3"],
Cell[1214420, 34082, 1167, 34, 44, "Print",ExpressionUUID->"1153d3b5-801f-47a6-8ac1-20e61d607b92"],
Cell[1215590, 34118, 341, 9, 24, "Print",ExpressionUUID->"f7d3d7e0-2412-4345-b984-7a85e0325d26"],
Cell[1215934, 34129, 1648, 49, 47, "Print",ExpressionUUID->"e87efdb4-f155-44ec-943f-1c1bb06b4e14"],
Cell[1217585, 34180, 341, 9, 24, "Print",ExpressionUUID->"de1ec8a5-6f4a-4c1f-8ef1-055762f990c9"],
Cell[1217929, 34191, 341, 9, 24, "Print",ExpressionUUID->"07455f57-3256-43cf-b2df-a4b362d35c00"],
Cell[1218273, 34202, 341, 9, 24, "Print",ExpressionUUID->"cac155bf-7415-4004-9fd8-566c3a966fad"],
Cell[1218617, 34213, 343, 9, 24, "Print",ExpressionUUID->"3c4d3976-757d-4ba3-a808-fb541a7d0f32"],
Cell[1218963, 34224, 341, 9, 24, "Print",ExpressionUUID->"56d841cf-fa46-45c6-a3ee-65246cad5c87"],
Cell[1219307, 34235, 341, 9, 24, "Print",ExpressionUUID->"1af26fb4-efbb-428d-93ed-9f4f4f752ddc"],
Cell[1219651, 34246, 2896, 81, 62, "Print",ExpressionUUID->"92d5f925-d1ba-4ef0-afc0-4219591b64d4"],
Cell[1222550, 34329, 341, 9, 24, "Print",ExpressionUUID->"e15a597f-39b0-478c-bef4-9180393c5b21"],
Cell[1222894, 34340, 5488, 137, 84, "Print",ExpressionUUID->"989f5572-1fb5-4507-846f-c52b532ec269"],
Cell[1228385, 34479, 343, 9, 24, "Print",ExpressionUUID->"a81e9ec3-d5d5-4605-ab9f-52bcc40e7525"],
Cell[1228731, 34490, 4418, 115, 84, "Print",ExpressionUUID->"66cf2b21-b800-4d6a-8a87-bed6c541bdba"],
Cell[1233152, 34607, 343, 9, 24, "Print",ExpressionUUID->"0564c2a9-5fcb-40c2-bf65-da3cc8486ea8"],
Cell[1233498, 34618, 2888, 80, 62, "Print",ExpressionUUID->"f1c537c3-ec4e-4f09-ae06-7c1c376fd050"],
Cell[1236389, 34700, 341, 9, 24, "Print",ExpressionUUID->"82577192-0dd1-4302-9173-b3aba932e69e"],
Cell[1236733, 34711, 3204, 81, 49, "Print",ExpressionUUID->"2e0c50f4-0a86-43ac-abe9-2b6bd03ff768"],
Cell[1239940, 34794, 343, 9, 24, "Print",ExpressionUUID->"58faae6e-c3e9-4757-a521-bca7a4530511"],
Cell[1240286, 34805, 341, 9, 24, "Print",ExpressionUUID->"a4578020-2612-4e79-af48-db2293109445"],
Cell[1240630, 34816, 4691, 124, 82, "Print",ExpressionUUID->"852df1ac-0e87-46cd-92a6-cb6d944defef"],
Cell[1245324, 34942, 343, 9, 24, "Print",ExpressionUUID->"ed72ccf3-0f1a-49ef-bed1-c7757b44f844"],
Cell[1245670, 34953, 4603, 115, 84, "Print",ExpressionUUID->"4856b7c1-c2f7-4a4f-a84d-6168ea54440f"],
Cell[1250276, 35070, 341, 9, 24, "Print",ExpressionUUID->"282bd872-7e22-4c67-a11d-1bd94429735c"],
Cell[1250620, 35081, 2881, 82, 62, "Print",ExpressionUUID->"c507bfed-d1a0-40a2-87f9-98dd23552624"],
Cell[1253504, 35165, 341, 9, 24, "Print",ExpressionUUID->"a0c76553-aa77-4ce7-b996-b6bbb67d8c6f"],
Cell[1253848, 35176, 2931, 83, 49, "Print",ExpressionUUID->"2986bb61-9fb3-4185-b264-cd6f51e0fd44"],
Cell[1256782, 35261, 340, 9, 24, "Print",ExpressionUUID->"03708aba-a52b-4507-8af9-657ce36cd211"],
Cell[1257125, 35272, 343, 9, 24, "Print",ExpressionUUID->"cb69ed1a-fbe5-48f2-98cd-7c3fccd6010d"],
Cell[1257471, 35283, 1453, 43, 40, "Print",ExpressionUUID->"ba65284b-06d6-47b7-9925-7bc6e7b69a93"],
Cell[1258927, 35328, 341, 9, 24, "Print",ExpressionUUID->"f0a7cb4a-1480-44cf-9db1-4f7567cfd3ae"],
Cell[1259271, 35339, 1932, 56, 27, "Print",ExpressionUUID->"66f0d1f6-b143-4c35-91bb-c512482115fb"],
Cell[1261206, 35397, 343, 9, 24, "Print",ExpressionUUID->"4f49452b-a81c-4ba7-bfe8-3557452550ab"],
Cell[1261552, 35408, 2341, 63, 40, "Print",ExpressionUUID->"fdbf56e5-affe-48d3-ad75-146439dc3f72"],
Cell[1263896, 35473, 341, 9, 24, "Print",ExpressionUUID->"457e004b-f8d9-4b26-bd25-10a3dc223bb9"],
Cell[1264240, 35484, 3985, 102, 82, "Print",ExpressionUUID->"640e2324-fc0e-49cb-9a7d-90193d0dc74d"],
Cell[1268228, 35588, 340, 9, 24, "Print",ExpressionUUID->"38bb1e0a-4f52-482a-a488-59104d6818f7"],
Cell[1268571, 35599, 2689, 71, 49, "Print",ExpressionUUID->"c62e9387-ebb5-4859-b9bc-897d89797be7"],
Cell[1271263, 35672, 341, 9, 24, "Print",ExpressionUUID->"fba7e480-14e6-4a6f-b220-9bd6b1c1b8fd"],
Cell[1271607, 35683, 6941, 180, 106, "Print",ExpressionUUID->"60e9ac99-afec-4910-8d89-5c04bd3c1360"],
Cell[1278551, 35865, 343, 9, 24, "Print",ExpressionUUID->"f4181851-f83f-4f9d-afe4-0fe24b6b38dc"],
Cell[1278897, 35876, 2531, 70, 62, "Print",ExpressionUUID->"33913b52-f74d-4126-9133-7949ff34a4a7"],
Cell[1281431, 35948, 341, 9, 24, "Print",ExpressionUUID->"5d9de8d8-a74d-4a4a-b6ba-8ff6c09735d2"],
Cell[1281775, 35959, 1957, 55, 40, "Print",ExpressionUUID->"ea51ee15-84c4-482a-b2d4-f1fa4a1d8a20"],
Cell[1283735, 36016, 340, 9, 24, "Print",ExpressionUUID->"3bd0794f-0e0f-4920-a869-5929a7f25dfb"],
Cell[1284078, 36027, 3249, 85, 62, "Print",ExpressionUUID->"bc8631a8-4608-4a58-8f1f-0b3095d6dff8"],
Cell[1287330, 36114, 340, 9, 24, "Print",ExpressionUUID->"d08ae32e-000b-4a3d-a32f-7e52c6b42964"],
Cell[1287673, 36125, 341, 9, 24, "Print",ExpressionUUID->"6e2fdf2b-6f91-456a-ad4e-5bea08a833a8"],
Cell[1288017, 36136, 341, 9, 24, "Print",ExpressionUUID->"2b81729e-8d46-4a89-9468-0dac5322f938"],
Cell[1288361, 36147, 341, 9, 24, "Print",ExpressionUUID->"0ea7c4f8-6a35-442a-8529-5f3c29176219"],
Cell[1288705, 36158, 343, 9, 24, "Print",ExpressionUUID->"70bacb4f-0925-4d8b-ab07-fa2c3c1e1331"],
Cell[1289051, 36169, 341, 9, 24, "Print",ExpressionUUID->"19f8cb38-6c91-4171-a906-baf208d33f9d"],
Cell[1289395, 36180, 341, 9, 24, "Print",ExpressionUUID->"9963af1d-73b3-4201-9540-19232caed409"],
Cell[1289739, 36191, 7605, 192, 135, "Print",ExpressionUUID->"c093c7b0-ece9-4323-9bf0-e0887a1e20f3"],
Cell[1297347, 36385, 341, 9, 24, "Print",ExpressionUUID->"548f8bc3-2cb5-4ee9-9693-8916c092bff5"],
Cell[1297691, 36396, 341, 9, 24, "Print",ExpressionUUID->"343495f9-4bd3-4ffd-b9f3-376a62e6b74b"],
Cell[1298035, 36407, 4515, 122, 69, "Print",ExpressionUUID->"d160f047-c09c-4b8e-92dc-51b6759eb672"],
Cell[1302553, 36531, 341, 9, 24, "Print",ExpressionUUID->"9e115fdc-cbf0-4fda-927e-a91b5309d164"],
Cell[1302897, 36542, 9608, 248, 147, "Print",ExpressionUUID->"1d8c05c9-40c2-4ceb-bcb2-52c9cc67aac0"],
Cell[1312508, 36792, 341, 9, 24, "Print",ExpressionUUID->"e7fa5279-80cb-45d4-9c9e-d9789e92b0a7"],
Cell[1312852, 36803, 341, 9, 24, "Print",ExpressionUUID->"b1fa26f3-f860-4736-a0dd-498b2f30bbe8"],
Cell[1313196, 36814, 3006, 79, 62, "Print",ExpressionUUID->"38ab70e5-dfb9-4a92-bf52-318a6377779f"],
Cell[1316205, 36895, 341, 9, 24, "Print",ExpressionUUID->"d8554b17-a576-45ec-82e4-785ef19d2dba"],
Cell[1316549, 36906, 3069, 78, 66, "Print",ExpressionUUID->"768c5223-45c6-4ffc-a93f-44e5800c5187"],
Cell[1319621, 36986, 343, 9, 24, "Print",ExpressionUUID->"303376d0-0c94-4a90-84a5-f6494041f0e4"],
Cell[1319967, 36997, 341, 9, 24, "Print",ExpressionUUID->"3f20aa39-5803-47ab-8df1-03079fc574ca"],
Cell[1320311, 37008, 343, 9, 24, "Print",ExpressionUUID->"2df795f1-f6b3-43aa-b7c7-c041e4bdb07c"],
Cell[1320657, 37019, 341, 9, 24, "Print",ExpressionUUID->"8bd46c4d-9a72-45d9-8b09-b104f4c395dd"],
Cell[1321001, 37030, 5890, 146, 88, "Print",ExpressionUUID->"e0f8aacd-3191-4a3e-bc97-b52d1c53a9ab"],
Cell[1326894, 37178, 343, 9, 24, "Print",ExpressionUUID->"02583476-ed68-4370-8702-5818d318451d"],
Cell[1327240, 37189, 341, 9, 24, "Print",ExpressionUUID->"ba2cfc0a-4207-4220-a958-2802d5556ef4"],
Cell[1327584, 37200, 8321, 208, 147, "Print",ExpressionUUID->"d2a28b65-d104-4e09-bd68-d2b3f19954f2"],
Cell[1335908, 37410, 343, 9, 24, "Print",ExpressionUUID->"3a751576-a046-4406-b7ae-23e9981a7070"],
Cell[1336254, 37421, 341, 9, 24, "Print",ExpressionUUID->"0e98a75b-ec10-45a9-8cfa-c39b0c794065"],
Cell[1336598, 37432, 6004, 150, 106, "Print",ExpressionUUID->"1cc9cade-0616-4d2f-b4d4-061f3688332d"],
Cell[1342605, 37584, 341, 9, 24, "Print",ExpressionUUID->"7adbd482-3cc1-466f-a125-b7806ac5711b"],
Cell[1342949, 37595, 341, 9, 24, "Print",ExpressionUUID->"5bfc1737-bbce-4c44-b33c-56141865dcae"],
Cell[1343293, 37606, 341, 9, 24, "Print",ExpressionUUID->"626f7442-c4b2-4678-9777-cdf489b62d40"],
Cell[1343637, 37617, 24254, 589, 287, "Print",ExpressionUUID->"3d02df3f-aecd-4875-a239-bb0cb5e4a5eb"],
Cell[1367894, 38208, 341, 9, 24, "Print",ExpressionUUID->"90040bcd-3d6a-4438-a3cd-195800636edf"],
Cell[1368238, 38219, 340, 9, 24, "Print",ExpressionUUID->"47abaa87-f607-4d31-913c-90b586bc2b06"],
Cell[1368581, 38230, 343, 9, 24, "Print",ExpressionUUID->"36ddd082-62e9-492a-b402-5cc2bda8c58e"],
Cell[1368927, 38241, 341, 9, 24, "Print",ExpressionUUID->"41a56a8b-8607-469c-8b1a-b26dff7a51bf"],
Cell[1369271, 38252, 343, 9, 24, "Print",ExpressionUUID->"abfcacf6-ac22-4772-80f6-727a13df5185"],
Cell[1369617, 38263, 340, 9, 24, "Print",ExpressionUUID->"68a78233-15a2-49ae-8101-0c814d209b81"],
Cell[1369960, 38274, 341, 9, 24, "Print",ExpressionUUID->"45e1991f-0fce-4584-bf65-02ea4b4eb98a"],
Cell[1370304, 38285, 341, 9, 24, "Print",ExpressionUUID->"9b962e57-6bd7-4687-b3cc-66abf9502f39"],
Cell[1370648, 38296, 341, 9, 24, "Print",ExpressionUUID->"811b9404-6f1a-4e10-b3c3-3513528026cd"],
Cell[1370992, 38307, 340, 9, 24, "Print",ExpressionUUID->"482c75ab-4e9b-4f14-89f1-2bbd5ae5a8b8"],
Cell[1371335, 38318, 341, 9, 24, "Print",ExpressionUUID->"fc914689-165f-4bbc-b7a6-4adf4eff4dec"],
Cell[1371679, 38329, 341, 9, 24, "Print",ExpressionUUID->"ee2ee484-7996-46e7-836d-3813927e34e2"],
Cell[1372023, 38340, 341, 9, 24, "Print",ExpressionUUID->"082569cc-7223-4d7d-8c9f-492aaa60fb52"],
Cell[1372367, 38351, 341, 9, 24, "Print",ExpressionUUID->"56cec37a-103c-4f96-88cc-5232851dab93"],
Cell[1372711, 38362, 341, 9, 24, "Print",ExpressionUUID->"1522dcfe-d0c4-4252-abf6-53809073b2dd"],
Cell[1373055, 38373, 341, 9, 24, "Print",ExpressionUUID->"71ee3204-e0a2-4def-b908-bd936bd00c04"],
Cell[1373399, 38384, 341, 9, 24, "Print",ExpressionUUID->"5054f1f8-1c89-4d4f-a534-259a393afe36"],
Cell[1373743, 38395, 340, 9, 24, "Print",ExpressionUUID->"3ce4610a-2e33-4fc3-ae3a-a7ea838c8a86"],
Cell[1374086, 38406, 341, 9, 24, "Print",ExpressionUUID->"51538395-6ca2-49e0-a508-778155782260"],
Cell[1374430, 38417, 341, 9, 24, "Print",ExpressionUUID->"ff62cd7e-7c28-4b46-9baf-4b13b1405dfa"],
Cell[1374774, 38428, 343, 9, 24, "Print",ExpressionUUID->"53ecd7a9-a9c1-46c1-bd64-c46cd82bf6b5"],
Cell[1375120, 38439, 341, 9, 24, "Print",ExpressionUUID->"356ab676-1fe3-4b95-af76-21cabea21d14"],
Cell[1375464, 38450, 341, 9, 24, "Print",ExpressionUUID->"6cd01530-8e14-482b-8a0d-9bbec09d4fb9"],
Cell[1375808, 38461, 340, 9, 24, "Print",ExpressionUUID->"be2c47f8-27d0-4901-937b-c9b7b165d009"],
Cell[1376151, 38472, 340, 9, 24, "Print",ExpressionUUID->"0b426bea-9951-4339-b78a-2a73831d1c21"],
Cell[1376494, 38483, 341, 9, 24, "Print",ExpressionUUID->"98d663c6-f9ff-4297-9a2e-b69f5f7edd46"],
Cell[1376838, 38494, 3355, 87, 66, "Print",ExpressionUUID->"72932a66-e5f9-4b55-ae12-db8fbd37eeba"],
Cell[1380196, 38583, 343, 9, 24, "Print",ExpressionUUID->"4ef4d903-917d-4402-b13f-b76f498563cf"],
Cell[1380542, 38594, 3311, 84, 62, "Print",ExpressionUUID->"36209484-9f98-4507-a0bc-5f309d75bd9c"],
Cell[1383856, 38680, 341, 9, 24, "Print",ExpressionUUID->"3adfd37f-a796-4ace-a877-4623a9488946"],
Cell[1384200, 38691, 340, 9, 24, "Print",ExpressionUUID->"722b695e-f1a3-4526-9a44-b45900d768f6"],
Cell[1384543, 38702, 343, 9, 24, "Print",ExpressionUUID->"b2790862-a855-4cb9-a615-d4a2dac3b760"],
Cell[1384889, 38713, 8695, 226, 137, "Print",ExpressionUUID->"959f1c07-36dc-440f-8398-d7d6bf5a813a"],
Cell[1393587, 38941, 343, 9, 24, "Print",ExpressionUUID->"96aca875-3b79-4b3d-8245-dd9ad512d5ed"],
Cell[1393933, 38952, 341, 9, 24, "Print",ExpressionUUID->"c2c17647-f705-45dd-bbe3-5b80bbe12113"],
Cell[1394277, 38963, 6624, 170, 92, "Print",ExpressionUUID->"de5df6cc-e5b6-4d57-956a-1301dbb02d3d"],
Cell[1400904, 39135, 343, 9, 24, "Print",ExpressionUUID->"6ef7092c-2f52-4fdb-a120-545790f13722"],
Cell[1401250, 39146, 15576, 383, 189, "Print",ExpressionUUID->"5b70b608-9fb5-4dcd-9cc0-8f28b96725fc"],
Cell[1416829, 39531, 341, 9, 24, "Print",ExpressionUUID->"dea8441e-d0c7-4685-9891-24e35d891309"],
Cell[1417173, 39542, 341, 9, 24, "Print",ExpressionUUID->"aa142e75-db34-49d7-8c0f-9332fafe9a61"],
Cell[1417517, 39553, 341, 9, 24, "Print",ExpressionUUID->"20ff938a-2032-4e49-8b69-6633855d193e"],
Cell[1417861, 39564, 4568, 116, 84, "Print",ExpressionUUID->"f9378bfb-84d5-43ee-a8b5-b0fd8bb69c60"],
Cell[1422432, 39682, 343, 9, 24, "Print",ExpressionUUID->"4c0484ad-b346-4f12-84ba-347530251d85"],
Cell[1422778, 39693, 341, 9, 24, "Print",ExpressionUUID->"e6eba598-53d2-45a5-9caa-369c98db8686"],
Cell[1423122, 39704, 340, 9, 24, "Print",ExpressionUUID->"6907c088-fdf7-4622-831d-f07fc8ce7922"],
Cell[1423465, 39715, 343, 9, 24, "Print",ExpressionUUID->"ca353e45-ad10-4019-b535-9c408931528f"],
Cell[1423811, 39726, 343, 9, 24, "Print",ExpressionUUID->"a6588f0f-ffe4-421b-9224-3c944e22d7b1"],
Cell[1424157, 39737, 341, 9, 24, "Print",ExpressionUUID->"842fd434-354a-479b-9899-de46747ffa20"],
Cell[1424501, 39748, 341, 9, 24, "Print",ExpressionUUID->"c0b12e00-8aac-432a-b89f-2a52adbcecae"],
Cell[1424845, 39759, 341, 9, 24, "Print",ExpressionUUID->"76b8023f-6a27-4314-8ed1-d042ed1004cd"],
Cell[1425189, 39770, 341, 9, 24, "Print",ExpressionUUID->"c240b152-b9ef-4d6f-bf20-1661f258e71b"],
Cell[1425533, 39781, 341, 9, 24, "Print",ExpressionUUID->"1686a336-44d1-4bf4-80be-2608784beac9"],
Cell[1425877, 39792, 341, 9, 24, "Print",ExpressionUUID->"733b51ef-2644-4c05-b709-722361f3e50d"],
Cell[1426221, 39803, 341, 9, 24, "Print",ExpressionUUID->"b522c68d-8eb1-4733-adef-b3cbde3ca9cd"],
Cell[1426565, 39814, 341, 9, 24, "Print",ExpressionUUID->"eec1f171-9a9f-461d-94ed-e237351c554d"],
Cell[1426909, 39825, 339, 9, 24, "Print",ExpressionUUID->"1c3788db-46bb-4be9-a4ce-7624bdc93899"],
Cell[1427251, 39836, 341, 9, 24, "Print",ExpressionUUID->"3b64c30a-bafd-4868-9128-28f794b7b220"],
Cell[1427595, 39847, 343, 9, 24, "Print",ExpressionUUID->"8193c190-b83e-485d-9f9a-69068d3f5119"],
Cell[1427941, 39858, 343, 9, 24, "Print",ExpressionUUID->"dcab09b9-42bd-41d0-b41f-b62435d953e7"],
Cell[1428287, 39869, 339, 9, 24, "Print",ExpressionUUID->"0726df0c-cfd3-49b4-92fe-f5e71410ee6c"],
Cell[1428629, 39880, 341, 9, 24, "Print",ExpressionUUID->"d44f2a09-a805-4100-86f7-dcf1af858931"],
Cell[1428973, 39891, 340, 9, 24, "Print",ExpressionUUID->"85c47776-443d-4150-b404-66b03f83cef6"],
Cell[1429316, 39902, 341, 9, 24, "Print",ExpressionUUID->"929d06f5-1a5a-43f2-a733-91dcbc626d49"],
Cell[1429660, 39913, 341, 9, 24, "Print",ExpressionUUID->"7f3f646f-b591-4dc9-9411-a8927a04b04e"],
Cell[1430004, 39924, 3111, 79, 62, "Print",ExpressionUUID->"5bd8c26c-f833-49c3-b8c6-bc7af3230f75"],
Cell[1433118, 40005, 343, 9, 24, "Print",ExpressionUUID->"7676fc6f-65b0-4574-9e9c-0cc89d0c9cb6"],
Cell[1433464, 40016, 340, 9, 24, "Print",ExpressionUUID->"033ba943-92a3-43ef-afbd-f1dd77d7d852"],
Cell[1433807, 40027, 341, 9, 24, "Print",ExpressionUUID->"9f228a56-28de-40cb-b1b6-f2551c4d96c9"],
Cell[1434151, 40038, 13657, 344, 179, "Print",ExpressionUUID->"d7df4d52-a9ff-4b5b-bcc5-16937e0faa67"],
Cell[1447811, 40384, 341, 9, 24, "Print",ExpressionUUID->"5bcaf7c1-ced6-47d3-a867-613cc05ef788"],
Cell[1448155, 40395, 4396, 109, 71, "Print",ExpressionUUID->"1955eeae-09c1-4b2d-8876-b3dc56e3333d"],
Cell[1452554, 40506, 341, 9, 24, "Print",ExpressionUUID->"f4ac3237-971c-4e71-aeba-98454fff0d9c"],
Cell[1452898, 40517, 2006, 56, 44, "Print",ExpressionUUID->"67a83264-47b2-4b26-8bfa-796bb494ae64"],
Cell[1454907, 40575, 343, 9, 24, "Print",ExpressionUUID->"af02dabc-1b13-4c35-acfe-22c034481ddb"],
Cell[1455253, 40586, 1733, 50, 40, "Print",ExpressionUUID->"38b16b0e-d19b-4a9b-be40-8c57b0735888"],
Cell[1456989, 40638, 343, 9, 24, "Print",ExpressionUUID->"46b42662-e566-4b65-bd69-dec904a20dc8"],
Cell[1457335, 40649, 343, 9, 24, "Print",ExpressionUUID->"d1f1f679-86c6-4cee-be45-ee34c3cacb2d"],
Cell[1457681, 40660, 341, 9, 24, "Print",ExpressionUUID->"54c9ae5f-c6ff-4500-8cfd-07b34cda8100"],
Cell[1458025, 40671, 4824, 141, 153, "Print",ExpressionUUID->"06ba4fbf-99d4-4f8c-a3e4-bf03c8da9c89"],
Cell[1462852, 40814, 341, 9, 24, "Print",ExpressionUUID->"ab695660-2b9a-4b95-970c-5c62ae5c394a"],
Cell[1463196, 40825, 3890, 99, 69, "Print",ExpressionUUID->"05ffdcb2-236a-4911-928f-72ce48b3b2cf"],
Cell[1467089, 40926, 341, 9, 24, "Print",ExpressionUUID->"bcc1a1ee-2dcd-4f1b-9101-4a1f925e7135"],
Cell[1467433, 40937, 341, 9, 24, "Print",ExpressionUUID->"ae0226d9-dc14-4dfe-8234-4c92e1da5013"],
Cell[1467777, 40948, 341, 9, 24, "Print",ExpressionUUID->"810453d5-82c9-434f-81ef-005ce952346e"],
Cell[1468121, 40959, 341, 9, 24, "Print",ExpressionUUID->"79e8482f-0797-47ce-b229-793348899300"],
Cell[1468465, 40970, 341, 9, 24, "Print",ExpressionUUID->"e8fde400-469b-47c6-a32e-5c2321dc911c"],
Cell[1468809, 40981, 340, 9, 24, "Print",ExpressionUUID->"8c977514-052a-493b-8d9c-b03920186773"],
Cell[1469152, 40992, 343, 9, 24, "Print",ExpressionUUID->"88676a9e-5874-4455-b76d-26d805592aa5"],
Cell[1469498, 41003, 343, 9, 24, "Print",ExpressionUUID->"8fd824a7-47e7-4926-81ff-80edbd03e757"],
Cell[1469844, 41014, 341, 9, 24, "Print",ExpressionUUID->"b9dea47b-ec27-4afa-a684-f3957df68abd"],
Cell[1470188, 41025, 341, 9, 24, "Print",ExpressionUUID->"e8460b9a-e9fa-4100-90da-3b762dd6d26f"],
Cell[1470532, 41036, 341, 9, 24, "Print",ExpressionUUID->"dc33e0e0-11e7-497e-bed9-ff2124cbc531"],
Cell[1470876, 41047, 2993, 82, 66, "Print",ExpressionUUID->"ae485af4-4515-4cf1-9110-12c2226e1b16"],
Cell[1473872, 41131, 341, 9, 24, "Print",ExpressionUUID->"2180fd0f-4726-41d2-90fe-a9d8532e29cb"],
Cell[1474216, 41142, 2970, 81, 66, "Print",ExpressionUUID->"c45b4bdb-7c86-4764-86c9-248fe3d95e74"],
Cell[1477189, 41225, 343, 9, 24, "Print",ExpressionUUID->"d3c91ce7-0fbb-43d2-ae62-4b9c66f39e55"],
Cell[1477535, 41236, 2429, 67, 62, "Print",ExpressionUUID->"3c3cc762-7f66-4fe9-ba5e-c3a107770372"],
Cell[1479967, 41305, 341, 9, 24, "Print",ExpressionUUID->"b783f8f2-8d49-4408-9861-4c4849a14e7f"],
Cell[1480311, 41316, 3268, 86, 62, "Print",ExpressionUUID->"2c360002-b2bb-4d4f-9cc8-db90d839f8b5"],
Cell[1483582, 41404, 341, 9, 24, "Print",ExpressionUUID->"30c4393c-4bfc-4106-ae10-6ef566584c1e"],
Cell[1483926, 41415, 341, 9, 24, "Print",ExpressionUUID->"234bdb2f-4453-4d26-9485-d5725919ad13"],
Cell[1484270, 41426, 4182, 108, 88, "Print",ExpressionUUID->"2395c984-5005-4476-90ed-5d549761325a"],
Cell[1488455, 41536, 341, 9, 24, "Print",ExpressionUUID->"f0d587f4-03f0-4432-990e-484b6115a285"],
Cell[1488799, 41547, 4607, 118, 71, "Print",ExpressionUUID->"1309fac4-8ded-44e8-a05c-3cd105f5a34d"],
Cell[1493409, 41667, 341, 9, 24, "Print",ExpressionUUID->"b02b8981-8a8c-4f5c-88dd-23eb8dcabfaf"],
Cell[1493753, 41678, 7011, 175, 132, "Print",ExpressionUUID->"9e249b3f-5fa5-4200-85b5-6629c0c8cf91"],
Cell[1500767, 41855, 343, 9, 24, "Print",ExpressionUUID->"dcaa9557-afe2-4cc3-9721-308a37d8abe8"],
Cell[1501113, 41866, 341, 9, 24, "Print",ExpressionUUID->"ae7fcf9a-f3e0-43a3-95a3-63ff067844ef"],
Cell[1501457, 41877, 5879, 170, 159, "Print",ExpressionUUID->"73449204-3ed8-4d1d-be6e-efce331743c8"],
Cell[1507339, 42049, 341, 9, 24, "Print",ExpressionUUID->"f8ad3b54-ddc1-49c3-928c-96f5fe375a2e"],
Cell[1507683, 42060, 341, 9, 24, "Print",ExpressionUUID->"680878e0-6e99-40ea-946e-3c869bca1b4d"],
Cell[1508027, 42071, 3170, 91, 78, "Print",ExpressionUUID->"059b0b9f-de48-43eb-b9b3-bbaff3191397"],
Cell[1511200, 42164, 341, 9, 24, "Print",ExpressionUUID->"8feac18c-3584-4e7a-b555-367e4fce1b62"],
Cell[1511544, 42175, 3170, 91, 78, "Print",ExpressionUUID->"c8b469c8-9905-4c62-9ba7-618a6d759692"],
Cell[1514717, 42268, 341, 9, 24, "Print",ExpressionUUID->"4ed26d3e-d895-4861-adb6-47c01648ed09"],
Cell[1515061, 42279, 2135, 63, 52, "Print",ExpressionUUID->"e5c9e16d-51ee-4b9b-9e97-e3c6c7128b86"],
Cell[1517199, 42344, 339, 9, 24, "Print",ExpressionUUID->"5c5dd4eb-15ba-4a2c-bf53-1f48149d5f36"],
Cell[1517541, 42355, 2213, 63, 82, "Print",ExpressionUUID->"0bb10af1-1a15-45c7-9e1e-32690a710399"],
Cell[1519757, 42420, 341, 9, 24, "Print",ExpressionUUID->"c1394998-3be6-4b29-acdd-bc4827c3b944"],
Cell[1520101, 42431, 2463, 71, 44, "Print",ExpressionUUID->"5650dd98-9d1c-4aa8-a53f-009af93ad612"],
Cell[1522567, 42504, 341, 9, 24, "Print",ExpressionUUID->"f43c1105-c8c3-4f01-8a06-2859a5ce2457"],
Cell[1522911, 42515, 341, 9, 24, "Print",ExpressionUUID->"01b7ab3a-7668-4ff1-a9c8-be33ba60c782"],
Cell[1523255, 42526, 343, 9, 24, "Print",ExpressionUUID->"4b3821eb-426c-4627-ae5a-bb7ed5397c7c"],
Cell[1523601, 42537, 340, 9, 24, "Print",ExpressionUUID->"49a0c798-dfaf-43ca-b5e3-6141151f7d09"],
Cell[1523944, 42548, 341, 9, 24, "Print",ExpressionUUID->"8018a9fb-4fd7-4912-86ea-8646be7f0640"],
Cell[1524288, 42559, 341, 9, 24, "Print",ExpressionUUID->"3aa82aa1-bd67-4225-b8aa-dfdc4df9fbc9"],
Cell[1524632, 42570, 343, 9, 24, "Print",ExpressionUUID->"8e060ee3-bd7e-472e-8741-eea33a851669"],
Cell[1524978, 42581, 341, 9, 24, "Print",ExpressionUUID->"9e6733c0-d3e1-40fd-8a6c-85ff7986e6d5"],
Cell[1525322, 42592, 341, 9, 24, "Print",ExpressionUUID->"c0ff9c14-0559-45c3-a8f0-fd3c4321b7fe"],
Cell[1525666, 42603, 341, 9, 24, "Print",ExpressionUUID->"cdf22e7e-91b8-4d03-8273-9e492054a160"],
Cell[1526010, 42614, 341, 9, 24, "Print",ExpressionUUID->"abc86692-c32e-4d8a-9023-b4ecb48b46f0"],
Cell[1526354, 42625, 343, 9, 24, "Print",ExpressionUUID->"f3556d5e-d85a-490a-8ba0-3b4078119f8a"],
Cell[1526700, 42636, 343, 9, 24, "Print",ExpressionUUID->"ad9a74cd-9413-404a-91d0-b86d8d31743c"],
Cell[1527046, 42647, 341, 9, 24, "Print",ExpressionUUID->"e0057991-dd04-4686-a0c9-192c3fd18c56"],
Cell[1527390, 42658, 341, 9, 24, "Print",ExpressionUUID->"67d87134-e78b-4abe-96b8-5cc552b6115a"],
Cell[1527734, 42669, 341, 9, 24, "Print",ExpressionUUID->"4c8cfdd5-6633-41bf-a1ca-cf9a0d5a29d0"],
Cell[1528078, 42680, 343, 9, 24, "Print",ExpressionUUID->"d34ce5c5-4dfc-4e32-b219-eb5a9f80b527"],
Cell[1528424, 42691, 341, 9, 24, "Print",ExpressionUUID->"e5873468-2d62-43ba-8fea-a6773b21f058"],
Cell[1528768, 42702, 341, 9, 24, "Print",ExpressionUUID->"ef23d81c-252e-447b-879f-cdf2c6f29a78"],
Cell[1529112, 42713, 343, 9, 24, "Print",ExpressionUUID->"1158f6a1-9256-4b95-8ef3-d8093e3c80fb"],
Cell[1529458, 42724, 341, 9, 24, "Print",ExpressionUUID->"d65bc6c9-ef40-4230-aa8d-4c6f6f537a4b"],
Cell[1529802, 42735, 343, 9, 24, "Print",ExpressionUUID->"a1a1abb4-c15d-44e7-b0f4-d2f73858568a"],
Cell[1530148, 42746, 341, 9, 24, "Print",ExpressionUUID->"7c3d131b-be83-4bd9-9f1b-b765334e7a2b"],
Cell[1530492, 42757, 341, 9, 24, "Print",ExpressionUUID->"b73d46d4-5f0e-4928-a91c-d6f86410c59e"],
Cell[1530836, 42768, 341, 9, 24, "Print",ExpressionUUID->"046b9985-aee7-4e53-9ce1-134fd77fc4e9"],
Cell[1531180, 42779, 343, 9, 24, "Print",ExpressionUUID->"a0c62d44-6956-4d30-8bcc-a8ab95044c04"],
Cell[1531526, 42790, 343, 9, 24, "Print",ExpressionUUID->"44ad3aaf-3294-4580-9daf-1d00892af60a"],
Cell[1531872, 42801, 341, 9, 24, "Print",ExpressionUUID->"f04762f7-87f2-4d65-bb71-2f384836edc1"],
Cell[1532216, 42812, 341, 9, 24, "Print",ExpressionUUID->"1a0f323a-c54e-4dfb-b741-97459e855223"],
Cell[1532560, 42823, 343, 9, 24, "Print",ExpressionUUID->"77cf963d-cb8f-4bf0-9528-1ce36f870f8d"],
Cell[1532906, 42834, 341, 9, 24, "Print",ExpressionUUID->"325e1e46-83f0-4c96-b9a9-a4c03098db06"],
Cell[1533250, 42845, 343, 9, 24, "Print",ExpressionUUID->"5f5e8b77-a67e-4647-8533-3219339f5019"],
Cell[1533596, 42856, 341, 9, 24, "Print",ExpressionUUID->"1db96460-5b55-4d26-953e-711bf37bdc56"],
Cell[1533940, 42867, 341, 9, 24, "Print",ExpressionUUID->"de2ffa55-0826-49dc-8f4f-6428e08f741c"],
Cell[1534284, 42878, 341, 9, 24, "Print",ExpressionUUID->"2e6dd912-05c3-472c-9f41-46ed84c52e25"],
Cell[1534628, 42889, 343, 9, 24, "Print",ExpressionUUID->"9c1bdfc4-2c3b-49ce-bfc0-988683df1ea8"],
Cell[1534974, 42900, 2972, 85, 62, "Print",ExpressionUUID->"52ca00e0-b840-4d5d-8f88-d0a373030e06"],
Cell[1537949, 42987, 341, 9, 24, "Print",ExpressionUUID->"50a46f1f-7297-4ecb-8df4-5540dfdcc7eb"],
Cell[1538293, 42998, 3001, 82, 62, "Print",ExpressionUUID->"e7ae1d4b-7920-41a3-8698-ec696a49e37a"],
Cell[1541297, 43082, 341, 9, 24, "Print",ExpressionUUID->"dcbb421d-6a5d-4843-b9bd-777d30b541d6"],
Cell[1541641, 43093, 2888, 80, 62, "Print",ExpressionUUID->"1cc1bdd7-ca48-41f5-acb0-e43139271a2d"],
Cell[1544532, 43175, 343, 9, 24, "Print",ExpressionUUID->"98429139-58f2-4b15-8fd7-ddc2acbf4120"],
Cell[1544878, 43186, 2818, 77, 62, "Print",ExpressionUUID->"37817d73-f068-46fd-8ae7-7d2111051fb0"],
Cell[1547699, 43265, 341, 9, 24, "Print",ExpressionUUID->"cf6eb37e-f4ad-4cbe-b0d4-0259a40eeff6"],
Cell[1548043, 43276, 2888, 80, 62, "Print",ExpressionUUID->"e1adf657-ef13-4968-9a20-c0da63bdb51f"],
Cell[1550934, 43358, 341, 9, 24, "Print",ExpressionUUID->"c8f6bfe5-cc09-4794-9bd4-6bb5d80460da"],
Cell[1551278, 43369, 1327, 37, 44, "Print",ExpressionUUID->"7ffce710-1eb2-42e1-ab1d-0b9f819ed7ec"],
Cell[1552608, 43408, 341, 9, 24, "Print",ExpressionUUID->"56fb6c49-e193-431e-9b18-aee3524202c5"],
Cell[1552952, 43419, 2644, 72, 62, "Print",ExpressionUUID->"2fb4c2f3-3799-4556-88aa-82e72ac2a6e0"],
Cell[1555599, 43493, 341, 9, 24, "Print",ExpressionUUID->"a305ae6d-924d-4ece-9ca9-42c4122cac26"],
Cell[1555943, 43504, 2304, 62, 59, "Print",ExpressionUUID->"8c20bdf9-42d0-4fe5-b2bf-475e2c647774"],
Cell[1558250, 43568, 340, 9, 24, "Print",ExpressionUUID->"9880a343-c5fe-47ea-97e1-7f1f1eefffca"],
Cell[1558593, 43579, 341, 9, 24, "Print",ExpressionUUID->"c672f595-c327-4e4c-ac37-2e18b1b6d433"],
Cell[1558937, 43590, 2860, 86, 87, "Print",ExpressionUUID->"e23d5246-3e60-4792-80f8-a829f57069d9"],
Cell[1561800, 43678, 341, 9, 24, "Print",ExpressionUUID->"19399d20-e60c-4b56-a595-5c49d2d3239c"],
Cell[1562144, 43689, 1855, 55, 60, "Print",ExpressionUUID->"731e195a-622e-4e18-ae8c-54ba1c9a90ba"],
Cell[1564002, 43746, 341, 9, 24, "Print",ExpressionUUID->"b77064f4-e137-49d6-aee9-3ee55afc4202"],
Cell[1564346, 43757, 2968, 89, 90, "Print",ExpressionUUID->"4b02c749-1438-45fd-9810-363a4da01fd1"],
Cell[1567317, 43848, 343, 9, 24, "Print",ExpressionUUID->"4d27e27e-8f42-4de8-a875-79abb655083a"],
Cell[1567663, 43859, 3012, 91, 90, "Print",ExpressionUUID->"13cbd6cd-d10e-4542-a7df-0896e1b158c0"],
Cell[1570678, 43952, 341, 9, 24, "Print",ExpressionUUID->"0a96457c-ff57-4ee3-b77c-fd5dc5e80c65"],
Cell[1571022, 43963, 341, 9, 24, "Print",ExpressionUUID->"01fb63aa-2452-42c4-8e30-eaf18afb6867"],
Cell[1571366, 43974, 1164, 34, 40, "Print",ExpressionUUID->"4e0d83ef-8231-4b11-a671-bd690476fd33"],
Cell[1572533, 44010, 341, 9, 24, "Print",ExpressionUUID->"36511dff-3a3a-446a-a9c6-18e1baf5472f"],
Cell[1572877, 44021, 1301, 38, 44, "Print",ExpressionUUID->"23de744b-752a-4986-bb36-6c5f08a6a1de"],
Cell[1574181, 44061, 341, 9, 24, "Print",ExpressionUUID->"169c77da-1c11-4283-a2fd-fc0c4c4e5ff0"],
Cell[1574525, 44072, 343, 9, 24, "Print",ExpressionUUID->"11106033-4f64-4ec2-942d-1cf211605846"],
Cell[1574871, 44083, 3384, 91, 49, "Print",ExpressionUUID->"d07ac095-f98e-4768-99b9-eb62bce70c2a"],
Cell[1578258, 44176, 340, 9, 24, "Print",ExpressionUUID->"0ba03440-abd6-42e3-b6d8-b9e0bd67f34f"],
Cell[1578601, 44187, 341, 9, 24, "Print",ExpressionUUID->"cca2dc50-e0be-4c42-9438-282fafc931a2"],
Cell[1578945, 44198, 341, 9, 24, "Print",ExpressionUUID->"63fd6b43-7c9a-40f2-b7d7-995df7f6b5d9"],
Cell[1579289, 44209, 4722, 126, 84, "Print",ExpressionUUID->"37ee45b6-725b-4707-8823-cb72fe8374dc"],
Cell[1584014, 44337, 343, 9, 24, "Print",ExpressionUUID->"2e8fc952-0e5d-4fc6-a904-02170c85b666"],
Cell[1584360, 44348, 7403, 190, 125, "Print",ExpressionUUID->"f7d88fc6-6656-4b44-a690-438770a37372"],
Cell[1591766, 44540, 341, 9, 24, "Print",ExpressionUUID->"e46f03eb-c296-48d0-8d10-0fce10e499f9"],
Cell[1592110, 44551, 7533, 194, 145, "Print",ExpressionUUID->"585c5e7b-371f-4c36-b717-d26a2d7f707e"],
Cell[1599646, 44747, 341, 9, 24, "Print",ExpressionUUID->"71a61bbf-af4d-4241-bb34-07a08d825b06"],
Cell[1599990, 44758, 7403, 190, 125, "Print",ExpressionUUID->"113f879a-445f-4992-ae15-5c7fe08e290e"],
Cell[1607396, 44950, 343, 9, 24, "Print",ExpressionUUID->"c9554ce8-6092-4dd3-b5d7-57cc8431e804"],
Cell[1607742, 44961, 4772, 127, 84, "Print",ExpressionUUID->"cb925893-cb14-48ab-90db-0c1b053df3d6"],
Cell[1612517, 45090, 341, 9, 24, "Print",ExpressionUUID->"ea70d322-dbe8-4681-9927-ddfed81bfc4b"],
Cell[1612861, 45101, 341, 9, 24, "Print",ExpressionUUID->"3c34f052-5e75-40a7-ab98-350f8eeed6e5"],
Cell[1613205, 45112, 3127, 84, 62, "Print",ExpressionUUID->"71c9f44e-5185-4d8b-827f-4e7cabf11424"],
Cell[1616335, 45198, 341, 9, 24, "Print",ExpressionUUID->"ccc3ec3b-8bc7-4690-a84a-afb6b921f032"],
Cell[1616679, 45209, 2668, 72, 62, "Print",ExpressionUUID->"a6159824-df2b-401b-95ae-589360da7348"],
Cell[1619350, 45283, 341, 9, 24, "Print",ExpressionUUID->"dd0200a6-7f64-47c0-905d-fc998824a892"],
Cell[1619694, 45294, 1988, 59, 40, "Print",ExpressionUUID->"ddf2ec3e-d7f2-4ff2-837f-c590cb040783"],
Cell[1621685, 45355, 341, 9, 24, "Print",ExpressionUUID->"b0a7c800-b5ab-4b35-88db-6acb0bfd6543"],
Cell[1622029, 45366, 3213, 88, 62, "Print",ExpressionUUID->"45e20635-ce8d-4b66-a6fe-db9a2b75d46d"],
Cell[1625245, 45456, 341, 9, 24, "Print",ExpressionUUID->"1455cf91-bf0a-4954-832c-7623fa89a25b"],
Cell[1625589, 45467, 3319, 91, 62, "Print",ExpressionUUID->"fc1b48ec-a4cf-4fe1-9bc0-294767d06a35"],
Cell[1628911, 45560, 341, 9, 24, "Print",ExpressionUUID->"fdacead0-f667-42c3-ad7c-d2155051f34e"],
Cell[1629255, 45571, 341, 9, 24, "Print",ExpressionUUID->"0a0f0001-51aa-4dd8-9c0a-521a47094863"],
Cell[1629599, 45582, 7295, 187, 125, "Print",ExpressionUUID->"69bf2116-9ad4-4f75-93fd-2fc80f65661d"],
Cell[1636897, 45771, 343, 9, 24, "Print",ExpressionUUID->"a73bd12a-6f96-4544-b156-beaf9a99345b"],
Cell[1637243, 45782, 341, 9, 24, "Print",ExpressionUUID->"7ce4fdea-2c14-4691-a467-a1c83b46f142"],
Cell[1637587, 45793, 343, 9, 24, "Print",ExpressionUUID->"18ae7858-592b-4910-8b15-392927e38f08"],
Cell[1637933, 45804, 6631, 166, 84, "Print",ExpressionUUID->"04e8390f-82ef-414b-9eb5-52b3c8a60022"],
Cell[1644567, 45972, 341, 9, 24, "Print",ExpressionUUID->"195dff7f-f4bb-4f17-b341-2b44cd6ca460"],
Cell[1644911, 45983, 6733, 167, 110, "Print",ExpressionUUID->"17cbdbce-6d12-4ee8-a180-627bbbd72aa9"],
Cell[1651647, 46152, 341, 9, 24, "Print",ExpressionUUID->"262dfd95-c0eb-47aa-a5a3-74e84289ba78"],
Cell[1651991, 46163, 2685, 72, 62, "Print",ExpressionUUID->"9371d4a4-40b9-413b-9eb2-ae588463e4f0"],
Cell[1654679, 46237, 339, 9, 24, "Print",ExpressionUUID->"53ee3444-759f-4cdd-990b-9f640726d621"],
Cell[1655021, 46248, 3140, 84, 62, "Print",ExpressionUUID->"67ee5130-17b6-4064-8112-9954a0741e6c"],
Cell[1658164, 46334, 341, 9, 24, "Print",ExpressionUUID->"85e0cfb4-3d8d-4735-8923-9db8183ba186"],
Cell[1658508, 46345, 341, 9, 24, "Print",ExpressionUUID->"35bf617e-3cdf-461f-9e97-83e4af702c44"],
Cell[1658852, 46356, 341, 9, 24, "Print",ExpressionUUID->"32606ba1-1d3a-4e96-bc4d-a6e989046dc6"],
Cell[1659196, 46367, 340, 9, 24, "Print",ExpressionUUID->"075b2f7d-070d-48ec-8aed-92de10a18398"],
Cell[1659539, 46378, 341, 9, 24, "Print",ExpressionUUID->"5ec84f45-a4a9-4cc8-bf1a-27fce5f27b03"],
Cell[1659883, 46389, 341, 9, 24, "Print",ExpressionUUID->"deba6317-e38d-493e-a74e-2ab680347c16"],
Cell[1660227, 46400, 340, 9, 24, "Print",ExpressionUUID->"5ad8357c-c4f7-4bd4-a981-d738354b5373"],
Cell[1660570, 46411, 341, 9, 24, "Print",ExpressionUUID->"a03ef924-42e7-444b-b81e-2edd0554681c"],
Cell[1660914, 46422, 13086, 331, 150, "Print",ExpressionUUID->"2c36c97c-2c83-4ef9-a2e3-59644288646f"],
Cell[1674003, 46755, 341, 9, 24, "Print",ExpressionUUID->"8b357926-0dd3-4be5-9db0-15358d0e5dbf"],
Cell[1674347, 46766, 1999, 58, 40, "Print",ExpressionUUID->"fa23c8ff-21fa-4528-9e5f-f14cc56bd563"],
Cell[1676349, 46826, 343, 9, 24, "Print",ExpressionUUID->"02df0a24-6de6-44e9-99b5-f93a3461d825"],
Cell[1676695, 46837, 1306, 38, 44, "Print",ExpressionUUID->"bff45ac8-3a4c-4915-8b0f-1b721caecb4b"],
Cell[1678004, 46877, 341, 9, 24, "Print",ExpressionUUID->"270f2dbd-ae36-4071-ae5b-73ebd4752e39"],
Cell[1678348, 46888, 2114, 59, 28, "Print",ExpressionUUID->"653984d0-3c84-4311-980a-96458d209100"],
Cell[1680465, 46949, 343, 9, 24, "Print",ExpressionUUID->"6fb05bce-0399-4083-ab64-a9e8dc0dd34d"],
Cell[1680811, 46960, 2967, 80, 66, "Print",ExpressionUUID->"d6c6bad9-4d41-4166-a608-6742ee2bc659"],
Cell[1683781, 47042, 341, 9, 24, "Print",ExpressionUUID->"0062aea9-6f9b-496e-aac0-4cd1f52d2d4c"],
Cell[1684125, 47053, 1495, 43, 40, "Print",ExpressionUUID->"d9bfa8a8-f640-4cf5-99a0-dfdb282cba4c"],
Cell[1685623, 47098, 343, 9, 24, "Print",ExpressionUUID->"5ea663d1-e0ed-4343-b513-bc1ec6c00e00"],
Cell[1685969, 47109, 2701, 80, 62, "Print",ExpressionUUID->"7b4cdbc0-d50a-4ff5-88c3-c9aed719190e"],
Cell[1688673, 47191, 341, 9, 24, "Print",ExpressionUUID->"a5ad0307-a822-4d01-86b5-7d17b8bc9c07"],
Cell[1689017, 47202, 1643, 49, 40, "Print",ExpressionUUID->"10283865-afd4-4c86-ae6d-493a7e532d4f"],
Cell[1690663, 47253, 343, 9, 24, "Print",ExpressionUUID->"1d14ae28-a424-4056-bbdd-f18aa7279c40"],
Cell[1691009, 47264, 5041, 142, 84, "Print",ExpressionUUID->"ea91d885-b604-4017-b40f-a94cc2308bbe"],
Cell[1696053, 47408, 343, 9, 24, "Print",ExpressionUUID->"53585159-1191-4d8b-a57b-81782c302718"],
Cell[1696399, 47419, 4388, 112, 84, "Print",ExpressionUUID->"e34d4661-d445-4d80-8e89-aa63da5822e0"],
Cell[1700790, 47533, 341, 9, 24, "Print",ExpressionUUID->"dff936a7-76db-4df6-afb6-55d236ecc401"],
Cell[1701134, 47544, 4264, 108, 71, "Print",ExpressionUUID->"45dc5d8d-fe0c-4e42-944e-7b820e3619e2"],
Cell[1705401, 47654, 341, 9, 24, "Print",ExpressionUUID->"95b89c47-640d-40e2-b545-002e8b347873"],
Cell[1705745, 47665, 343, 9, 24, "Print",ExpressionUUID->"692e95ec-583f-4f4f-981f-02afd6fd3069"],
Cell[1706091, 47676, 1986, 54, 40, "Print",ExpressionUUID->"8263c63c-e8dc-4b16-ac03-28e506c5329a"],
Cell[1708080, 47732, 341, 9, 24, "Print",ExpressionUUID->"19e693ea-05ce-4efd-b4b1-85d3751078a0"],
Cell[1708424, 47743, 340, 9, 24, "Print",ExpressionUUID->"664b9be9-d4ac-4c80-9b41-7e815f854a2d"],
Cell[1708767, 47754, 341, 9, 24, "Print",ExpressionUUID->"9c8942d3-a904-46fe-8f7b-cf4062eccee8"],
Cell[1709111, 47765, 341, 9, 24, "Print",ExpressionUUID->"e33f8b4f-499e-491c-a9bd-76a770a4a5b4"],
Cell[1709455, 47776, 343, 9, 24, "Print",ExpressionUUID->"2c2d782e-55b9-4081-9511-b2fb1a44b291"],
Cell[1709801, 47787, 1738, 51, 44, "Print",ExpressionUUID->"2f3af3cc-e274-448a-b62a-651a68df1583"],
Cell[1711542, 47840, 341, 9, 24, "Print",ExpressionUUID->"c0013f58-837f-4b0c-aafe-3657dda5d81a"],
Cell[1711886, 47851, 3211, 87, 49, "Print",ExpressionUUID->"5f457696-fb16-49ce-84fe-e4e4ff2d28b7"],
Cell[1715100, 47940, 341, 9, 24, "Print",ExpressionUUID->"27fa3268-35e8-43b4-a4b2-ac761fa96b5d"],
Cell[1715444, 47951, 4351, 111, 88, "Print",ExpressionUUID->"ab99b60f-6505-4e3e-9d7a-6ac7c61aac67"],
Cell[1719798, 48064, 343, 9, 24, "Print",ExpressionUUID->"6f5a0016-87af-46cc-9a10-baeaba3add10"],
Cell[1720144, 48075, 2101, 59, 40, "Print",ExpressionUUID->"0706b83a-8747-4609-ac67-c71483311e03"],
Cell[1722248, 48136, 341, 9, 24, "Print",ExpressionUUID->"b3af236c-84b2-4ced-ae30-001873792a19"],
Cell[1722592, 48147, 4329, 110, 88, "Print",ExpressionUUID->"e2d21af4-a8ab-4b4c-bf93-0856552e7bb8"],
Cell[1726924, 48259, 341, 9, 24, "Print",ExpressionUUID->"ecb18a3d-a266-4275-b454-f77d485a7fb5"],
Cell[1727268, 48270, 2050, 57, 40, "Print",ExpressionUUID->"fa874115-2345-4dfa-a492-5e1272387a84"],
Cell[1729321, 48329, 341, 9, 24, "Print",ExpressionUUID->"f333abef-a91d-4d68-bcea-3c43d01b4c04"],
Cell[1729665, 48340, 343, 9, 24, "Print",ExpressionUUID->"ab960db8-95ef-4e6f-a348-831be22b5b06"],
Cell[1730011, 48351, 341, 9, 24, "Print",ExpressionUUID->"166c052e-07ab-4c3f-9741-c210da538a87"],
Cell[1730355, 48362, 341, 9, 24, "Print",ExpressionUUID->"719656bc-ee6e-45ca-be47-3777ffee2e76"],
Cell[1730699, 48373, 341, 9, 24, "Print",ExpressionUUID->"6abe7ef0-6b64-41e2-a1fd-8ba661003fb3"],
Cell[1731043, 48384, 341, 9, 24, "Print",ExpressionUUID->"dcf245bd-3723-414f-876d-954fd362645a"],
Cell[1731387, 48395, 2371, 65, 40, "Print",ExpressionUUID->"f468549b-64f5-4f15-a91d-a7d8f0c6d6ba"],
Cell[1733761, 48462, 343, 9, 24, "Print",ExpressionUUID->"ce48fb82-178b-4a2f-9d45-205fcba92bf0"],
Cell[1734107, 48473, 341, 9, 24, "Print",ExpressionUUID->"d549e9a8-b75b-424e-8eb5-8bbb5f3fbe41"],
Cell[1734451, 48484, 341, 9, 24, "Print",ExpressionUUID->"feba8461-f47e-4855-b9ad-ce247a8439f0"],
Cell[1734795, 48495, 341, 9, 24, "Print",ExpressionUUID->"204cef78-3d82-4b7f-be72-da13ec022864"],
Cell[1735139, 48506, 343, 9, 24, "Print",ExpressionUUID->"6c789516-1ee9-4c95-9b67-ce58bac524c5"],
Cell[1735485, 48517, 2733, 80, 59, "Print",ExpressionUUID->"e5cc316c-c6c3-405e-ad2d-0a1d41e996b6"],
Cell[1738221, 48599, 341, 9, 24, "Print",ExpressionUUID->"83c1e1d1-9ae2-4737-8e73-e1b39eb11d49"],
Cell[1738565, 48610, 1227, 36, 40, "Print",ExpressionUUID->"1ba71fd5-4d6c-4e61-aa1b-90ad9464840c"],
Cell[1739795, 48648, 341, 9, 24, "Print",ExpressionUUID->"e9c39fe5-9a09-4307-a542-3182e658b67b"],
Cell[1740139, 48659, 341, 9, 24, "Print",ExpressionUUID->"02819502-2080-4f10-a477-d446c967ff9c"],
Cell[1740483, 48670, 343, 9, 24, "Print",ExpressionUUID->"27f07491-4a10-48cc-8de0-0686be1ccc4a"],
Cell[1740829, 48681, 341, 9, 24, "Print",ExpressionUUID->"6cefb0fc-87a0-4e2d-aa7c-ea64b50af384"],
Cell[1741173, 48692, 343, 9, 24, "Print",ExpressionUUID->"27727e4d-7c0d-49cc-a74d-87f325850775"],
Cell[1741519, 48703, 2820, 77, 62, "Print",ExpressionUUID->"93127921-3268-4af3-aa1c-f54432be5493"],
Cell[1744342, 48782, 341, 9, 24, "Print",ExpressionUUID->"86b14fc4-d381-4a9b-bb5a-6666ebe71ed2"],
Cell[1744686, 48793, 2995, 82, 62, "Print",ExpressionUUID->"8b1ae753-2f5a-429c-85d9-0c313169aa3c"],
Cell[1747684, 48877, 341, 9, 24, "Print",ExpressionUUID->"0e054ce8-6e9c-4524-b480-96a246ca787c"],
Cell[1748028, 48888, 341, 9, 24, "Print",ExpressionUUID->"1e00e9f7-217e-48e9-886c-db0c4c9fb54f"],
Cell[1748372, 48899, 343, 9, 24, "Print",ExpressionUUID->"a09a8b0c-ee07-44f9-a679-b8416fa1db4e"],
Cell[1748718, 48910, 341, 9, 24, "Print",ExpressionUUID->"248337c6-b3e5-4d28-a44d-be8403de09f9"],
Cell[1749062, 48921, 341, 9, 24, "Print",ExpressionUUID->"f76cd649-d007-4ee8-88f2-7b4dc66362ed"],
Cell[1749406, 48932, 341, 9, 24, "Print",ExpressionUUID->"b386dddc-cbec-4102-8c59-7d3c12b2fff0"],
Cell[1749750, 48943, 340, 9, 24, "Print",ExpressionUUID->"df17f45e-ca97-479a-97ba-24b301f21429"],
Cell[1750093, 48954, 343, 9, 24, "Print",ExpressionUUID->"16d6f0d8-eac7-4fea-84f6-5eb2b84800f2"],
Cell[1750439, 48965, 343, 9, 24, "Print",ExpressionUUID->"7f062c4b-7c52-479a-be55-e7e88b6c18a5"],
Cell[1750785, 48976, 7293, 190, 200, "Print",ExpressionUUID->"ad7680f1-9826-4d37-b637-2c56389a3dfb"],
Cell[1758081, 49168, 343, 9, 24, "Print",ExpressionUUID->"d3551dcb-048a-467a-aa33-a8a33679050f"],
Cell[1758427, 49179, 7273, 191, 201, "Print",ExpressionUUID->"84643ec2-caec-46fd-af18-18a51f19b124"],
Cell[1765703, 49372, 341, 9, 24, "Print",ExpressionUUID->"57c6274c-6148-48d9-9f8c-773ce7b2fd90"],
Cell[1766047, 49383, 341, 9, 24, "Print",ExpressionUUID->"847b0c83-c28c-4dd1-be44-007fe122f2ec"],
Cell[1766391, 49394, 341, 9, 24, "Print",ExpressionUUID->"3cff3202-8072-40be-872d-202f426273bf"],
Cell[1766735, 49405, 341, 9, 24, "Print",ExpressionUUID->"b6ab89f5-3af7-4574-8c0d-18ab166d1afb"],
Cell[1767079, 49416, 341, 9, 24, "Print",ExpressionUUID->"5e916696-f8cd-458a-9030-d70feac97253"],
Cell[1767423, 49427, 341, 9, 24, "Print",ExpressionUUID->"829411a9-1028-411b-b906-41b63c9378c7"],
Cell[1767767, 49438, 341, 9, 24, "Print",ExpressionUUID->"add3abbb-2df6-45e4-a244-636625e444ca"],
Cell[1768111, 49449, 339, 9, 24, "Print",ExpressionUUID->"81ae5e1d-ff66-44f0-87c6-10f24415bd3e"],
Cell[1768453, 49460, 341, 9, 24, "Print",ExpressionUUID->"2460bd24-0495-44ac-b6fb-7d8b38022dc1"],
Cell[1768797, 49471, 341, 9, 24, "Print",ExpressionUUID->"6df215c5-89c4-4e1e-863a-4bed59cbf6bb"],
Cell[1769141, 49482, 343, 9, 24, "Print",ExpressionUUID->"bae3db52-bf29-4d46-9535-bf718eb9b138"],
Cell[1769487, 49493, 343, 9, 24, "Print",ExpressionUUID->"8d506efb-9db3-44c8-8133-2c76996b12a6"],
Cell[1769833, 49504, 341, 9, 24, "Print",ExpressionUUID->"047dc5e9-bc48-4888-80b3-89160a7764c3"],
Cell[1770177, 49515, 339, 9, 24, "Print",ExpressionUUID->"10bd169e-3b38-4513-8d2c-ec7f72a6a15d"],
Cell[1770519, 49526, 343, 9, 24, "Print",ExpressionUUID->"3ead7f4a-ab5a-460a-b433-5d66e4c620e7"],
Cell[1770865, 49537, 343, 9, 24, "Print",ExpressionUUID->"d47030dc-8259-42ea-bfe1-8db7a0233761"],
Cell[1771211, 49548, 341, 9, 24, "Print",ExpressionUUID->"8ebc20e5-2b4c-41a6-90af-545034be047b"],
Cell[1771555, 49559, 343, 9, 24, "Print",ExpressionUUID->"1b4fdfc4-33bc-4566-b47e-f32de1ac7388"],
Cell[1771901, 49570, 341, 9, 24, "Print",ExpressionUUID->"782e50d9-c21d-455c-a678-2663c9997bb3"],
Cell[1772245, 49581, 341, 9, 24, "Print",ExpressionUUID->"51f1b4dc-4505-4119-ac70-28d645a281ca"],
Cell[1772589, 49592, 343, 9, 24, "Print",ExpressionUUID->"580dde49-4cf2-4058-9aa5-d614556b04b1"],
Cell[1772935, 49603, 343, 9, 24, "Print",ExpressionUUID->"a5eea736-a24c-4ffd-ae61-1923849fd32d"],
Cell[1773281, 49614, 340, 9, 24, "Print",ExpressionUUID->"536b90f5-617a-4ac3-91bf-41ab6f4a08ed"],
Cell[1773624, 49625, 341, 9, 24, "Print",ExpressionUUID->"c6bc83d2-e85a-48da-a742-84b9e7829f8f"],
Cell[1773968, 49636, 341, 9, 24, "Print",ExpressionUUID->"cdb85eae-c000-4877-9be1-e297317ef9cb"],
Cell[1774312, 49647, 341, 9, 24, "Print",ExpressionUUID->"8b09c97a-d076-4191-95f1-79fc756de044"],
Cell[1774656, 49658, 343, 9, 24, "Print",ExpressionUUID->"d4132f77-eaf0-467f-9b56-150b95ab8e40"],
Cell[1775002, 49669, 341, 9, 24, "Print",ExpressionUUID->"ce2ef112-3734-441a-b07d-567afdd249c0"],
Cell[1775346, 49680, 340, 9, 24, "Print",ExpressionUUID->"166dc1d2-156e-4cdc-b4ab-46c0481bff73"],
Cell[1775689, 49691, 2521, 75, 59, "Print",ExpressionUUID->"983d36c7-8775-42c2-b35a-00faa1fc93bc"],
Cell[1778213, 49768, 343, 9, 24, "Print",ExpressionUUID->"64909839-6424-4197-a259-f2fe980b5dd0"],
Cell[1778559, 49779, 2048, 57, 28, "Print",ExpressionUUID->"46c4bf10-ecc9-4ccf-acce-9a13d1704de2"],
Cell[1780610, 49838, 343, 9, 24, "Print",ExpressionUUID->"31511db9-e98c-4859-a9ea-39961316b412"],
Cell[1780956, 49849, 2958, 81, 62, "Print",ExpressionUUID->"534c3339-7d73-47a2-8863-6575fcff0961"],
Cell[1783917, 49932, 341, 9, 24, "Print",ExpressionUUID->"768e4a7b-6677-4016-adab-6911149b11f6"],
Cell[1784261, 49943, 341, 9, 24, "Print",ExpressionUUID->"39d7255d-eeae-4e25-b5b6-bd0d4ef00c04"],
Cell[1784605, 49954, 3164, 87, 49, "Print",ExpressionUUID->"f89b1539-f87e-4f90-967d-4f56c2377754"],
Cell[1787772, 50043, 341, 9, 24, "Print",ExpressionUUID->"cb771d62-08c3-40e4-8621-87f1c5896b15"],
Cell[1788116, 50054, 341, 9, 24, "Print",ExpressionUUID->"ebc05458-7aa3-4416-80f0-d97d53892012"],
Cell[1788460, 50065, 341, 9, 24, "Print",ExpressionUUID->"c1e63660-1724-41f6-84e7-bcb32d0bf085"],
Cell[1788804, 50076, 1765, 52, 40, "Print",ExpressionUUID->"e72fabbe-dd47-4d83-99f3-7772121ca4b7"],
Cell[1790572, 50130, 343, 9, 24, "Print",ExpressionUUID->"d04ff6ca-5aed-4de4-b94d-b1d876861ca2"],
Cell[1790918, 50141, 2287, 66, 47, "Print",ExpressionUUID->"7498c996-8517-4dad-ae8a-5da9bb1e7319"],
Cell[1793208, 50209, 341, 9, 24, "Print",ExpressionUUID->"68aae70d-c9f3-4e6e-8cea-8826c489db24"],
Cell[1793552, 50220, 340, 9, 24, "Print",ExpressionUUID->"4bdaa75e-9e98-4c5a-b22e-3e2c9004be6a"],
Cell[1793895, 50231, 343, 9, 24, "Print",ExpressionUUID->"89f18f59-3b3f-4b28-845f-df160c18eed9"],
Cell[1794241, 50242, 341, 9, 24, "Print",ExpressionUUID->"2af29ba5-f936-494e-828b-e0d604043534"],
Cell[1794585, 50253, 339, 9, 24, "Print",ExpressionUUID->"275076b9-da3c-464d-b41f-a3848a0db89a"],
Cell[1794927, 50264, 343, 9, 24, "Print",ExpressionUUID->"8ab1e88f-4d2c-4437-9c08-729e5d8c7a81"],
Cell[1795273, 50275, 341, 9, 24, "Print",ExpressionUUID->"c13cd578-c457-43fe-8690-41bdc82069cb"],
Cell[1795617, 50286, 341, 9, 24, "Print",ExpressionUUID->"a962265b-a740-4d3a-8b2d-eeec10a0cb0e"],
Cell[1795961, 50297, 341, 9, 24, "Print",ExpressionUUID->"f666369d-04e0-472b-ba4b-661eb84e2994"],
Cell[1796305, 50308, 341, 9, 24, "Print",ExpressionUUID->"9b064f64-00f5-4a70-9e61-9a5d0a1cca82"],
Cell[1796649, 50319, 341, 9, 24, "Print",ExpressionUUID->"b9be1bf4-4b24-4307-a3c7-6f2608a4b58e"],
Cell[1796993, 50330, 341, 9, 24, "Print",ExpressionUUID->"069413cd-d28c-45c2-adcf-443602943dec"],
Cell[1797337, 50341, 341, 9, 24, "Print",ExpressionUUID->"47be2979-32da-4f45-8c9d-9d6e7adc8ae4"],
Cell[1797681, 50352, 341, 9, 24, "Print",ExpressionUUID->"350234d0-9cc5-4501-8f8f-31abcfe5ed49"],
Cell[1798025, 50363, 341, 9, 24, "Print",ExpressionUUID->"5ab52653-2121-41d3-9b32-f30d9325ba58"],
Cell[1798369, 50374, 3304, 95, 62, "Print",ExpressionUUID->"18b132b8-b3ec-4283-a571-48b85221b2bd"],
Cell[1801676, 50471, 341, 9, 24, "Print",ExpressionUUID->"c318db44-75a0-48e7-8eca-fc435589e9d9"],
Cell[1802020, 50482, 2512, 73, 40, "Print",ExpressionUUID->"90369f05-6412-41df-beb5-cbbdeb234338"],
Cell[1804535, 50557, 341, 9, 24, "Print",ExpressionUUID->"b6096247-b7a6-44f0-ad2a-8535b575abd2"],
Cell[1804879, 50568, 341, 9, 24, "Print",ExpressionUUID->"64735831-56ee-420a-8ddf-112f543d8e34"],
Cell[1805223, 50579, 3930, 107, 49, "Print",ExpressionUUID->"6a432f25-56f6-4eec-8a8d-ae13a4fc48a1"],
Cell[1809156, 50688, 341, 9, 24, "Print",ExpressionUUID->"272d1fe2-3e70-4f9d-9d6f-74b644586d7a"],
Cell[1809500, 50699, 341, 9, 24, "Print",ExpressionUUID->"a9b7e6c5-9852-4f25-9c06-11aab8452b0b"],
Cell[1809844, 50710, 4728, 132, 71, "Print",ExpressionUUID->"596ce0af-ac35-4078-84e2-92cd83ca552b"],
Cell[1814575, 50844, 341, 9, 24, "Print",ExpressionUUID->"f0934802-c8cf-4dd2-bb54-03c7a71d163a"],
Cell[1814919, 50855, 341, 9, 24, "Print",ExpressionUUID->"c23c32c8-9b96-4121-97d1-39d608d46e67"],
Cell[1815263, 50866, 4728, 132, 71, "Print",ExpressionUUID->"d506c1cd-2d01-4803-865a-81e66157841c"],
Cell[1819994, 51000, 340, 9, 24, "Print",ExpressionUUID->"2ecd86fc-a3c1-450b-9fca-d8d9de7fa93a"],
Cell[1820337, 51011, 341, 9, 24, "Print",ExpressionUUID->"b8f5d58a-7e00-4b0f-914d-5ebd3b233e35"],
Cell[1820681, 51022, 3998, 113, 49, "Print",ExpressionUUID->"034984d8-adfe-4d27-9591-6ce14cd7f8ea"],
Cell[1824682, 51137, 341, 9, 24, "Print",ExpressionUUID->"fd535445-b3d8-486c-a7b0-c879f0dca2b4"],
Cell[1825026, 51148, 343, 9, 24, "Print",ExpressionUUID->"72c65aeb-b26f-4207-98da-41b6ffd43c91"],
Cell[1825372, 51159, 4728, 132, 71, "Print",ExpressionUUID->"f67cc154-ef8f-4632-8798-008006ff2d4e"],
Cell[1830103, 51293, 341, 9, 24, "Print",ExpressionUUID->"83ab8a5c-6bd7-44a7-b4cd-b44ca9b013c4"],
Cell[1830447, 51304, 341, 9, 24, "Print",ExpressionUUID->"839fc24f-a050-4343-8a9c-b0bb227cdd72"],
Cell[1830791, 51315, 4728, 132, 71, "Print",ExpressionUUID->"58c0064f-fee1-4b89-9460-1a73cd123cd1"],
Cell[1835522, 51449, 341, 9, 24, "Print",ExpressionUUID->"f45675d2-d599-41c9-9c69-4f3e01a76e00"],
Cell[1835866, 51460, 341, 9, 24, "Print",ExpressionUUID->"36935f13-c967-4a8c-bbf0-fa96eda0351d"],
Cell[1836210, 51471, 4730, 132, 71, "Print",ExpressionUUID->"a966e954-5a95-423e-b1cf-407b9fe331b3"],
Cell[1840943, 51605, 341, 9, 24, "Print",ExpressionUUID->"4f6a82eb-e1ac-4355-9a3b-f75381b5ca32"],
Cell[1841287, 51616, 341, 9, 24, "Print",ExpressionUUID->"42645651-9df7-4ad1-abe2-823ea6a02f85"],
Cell[1841631, 51627, 5695, 160, 71, "Print",ExpressionUUID->"32269d9f-5062-48ea-ae06-3b0d2744f995"],
Cell[1847329, 51789, 341, 9, 24, "Print",ExpressionUUID->"a7ab812a-3f03-4564-bdf8-1bf96746e5f7"],
Cell[1847673, 51800, 340, 9, 24, "Print",ExpressionUUID->"6aca29a8-62fe-4a91-bd12-41f7a2a89fd2"],
Cell[1848016, 51811, 3932, 107, 49, "Print",ExpressionUUID->"49c8cc64-ce31-4bb1-b445-aac0a1d19199"],
Cell[1851951, 51920, 343, 9, 24, "Print",ExpressionUUID->"18d7662f-6b2d-494a-8c30-7e5ba0c7ef8e"],
Cell[1852297, 51931, 343, 9, 24, "Print",ExpressionUUID->"06a1fad5-b89c-45f6-8687-360961660565"],
Cell[1852643, 51942, 5280, 142, 71, "Print",ExpressionUUID->"15e4d677-5482-451c-88e1-78908c587aed"],
Cell[1857926, 52086, 343, 9, 24, "Print",ExpressionUUID->"e5b49b72-8195-4c30-8f79-b90a89494c43"],
Cell[1858272, 52097, 343, 9, 24, "Print",ExpressionUUID->"3864a5c1-6e8a-42f4-8353-b99b71a2b5c5"],
Cell[1858618, 52108, 3998, 113, 49, "Print",ExpressionUUID->"dc049eb4-f8a1-49c8-90b5-fed79a2b4793"],
Cell[1862619, 52223, 343, 9, 24, "Print",ExpressionUUID->"3b6921c5-4862-4d80-8e16-ee1b94861d3f"],
Cell[1862965, 52234, 343, 9, 24, "Print",ExpressionUUID->"98c4b553-22cb-4a79-9bb1-fe25174ad15d"],
Cell[1863311, 52245, 5280, 142, 71, "Print",ExpressionUUID->"3b7f95d7-d5ca-47b9-bea9-5f4aa3aaee95"],
Cell[1868594, 52389, 341, 9, 24, "Print",ExpressionUUID->"09a5e1e4-2b2f-45cd-a0df-9c6c73ab3ea8"],
Cell[1868938, 52400, 341, 9, 24, "Print",ExpressionUUID->"2a7365ee-157d-4116-aee1-afc486fa3139"],
Cell[1869282, 52411, 4730, 132, 71, "Print",ExpressionUUID->"4bc94ec8-a3aa-4312-a24b-28acb60ad05d"],
Cell[1874015, 52545, 341, 9, 24, "Print",ExpressionUUID->"f9373e86-07f9-4519-a724-c44430455ce7"],
Cell[1874359, 52556, 341, 9, 24, "Print",ExpressionUUID->"5f1bbefe-ed08-43ee-9320-e89a9ea0d22e"],
Cell[1874703, 52567, 6452, 172, 71, "Print",ExpressionUUID->"bcff5f5c-fd2e-4360-a260-79f4ffa4b41e"],
Cell[1881158, 52741, 340, 9, 24, "Print",ExpressionUUID->"73c94d4b-96c3-4aea-b180-842f3619b45b"],
Cell[1881501, 52752, 340, 9, 24, "Print",ExpressionUUID->"e3b973bd-bd9f-477c-b2c6-b04a2ceba215"],
Cell[1881844, 52763, 4728, 132, 71, "Print",ExpressionUUID->"22983366-a32d-4d26-8d03-ebbcd4ac2a39"],
Cell[1886575, 52897, 340, 9, 24, "Print",ExpressionUUID->"84476d0c-f17a-4e64-9864-427cd51965bf"],
Cell[1886918, 52908, 341, 9, 24, "Print",ExpressionUUID->"e3a91fad-55db-492a-8f72-a1dd2f8864e6"],
Cell[1887262, 52919, 3930, 107, 49, "Print",ExpressionUUID->"cd0b5db2-0f50-403c-acde-a9645b5a3b49"],
Cell[1891195, 53028, 340, 9, 24, "Print",ExpressionUUID->"6f09560e-1274-44e2-9e65-4a995f32f28f"],
Cell[1891538, 53039, 1645, 47, 40, "Print",ExpressionUUID->"6099b4c2-0562-4eca-8a3b-da3fe4f4a030"],
Cell[1893186, 53088, 340, 9, 24, "Print",ExpressionUUID->"35a155d3-598e-401d-abe9-2cb9af3699f1"],
Cell[1893529, 53099, 4000, 113, 49, "Print",ExpressionUUID->"fd73b994-d3e6-455c-83f8-8ca98ca659d6"],
Cell[1897532, 53214, 343, 9, 24, "Print",ExpressionUUID->"eebcb52a-c2d7-461e-88f7-5117e9fd4373"],
Cell[1897878, 53225, 341, 9, 24, "Print",ExpressionUUID->"f7767737-cadc-4e0e-b73b-3d5dcfc88e4c"],
Cell[1898222, 53236, 4728, 132, 71, "Print",ExpressionUUID->"91900c13-972a-44b9-8ab4-4b76191348e3"],
Cell[1902953, 53370, 341, 9, 24, "Print",ExpressionUUID->"0e8120b4-10f5-43b3-b9db-bf626ed44409"],
Cell[1903297, 53381, 343, 9, 24, "Print",ExpressionUUID->"792948ea-0a0a-4dbb-979f-cc79e3fe29b4"],
Cell[1903643, 53392, 4244, 120, 71, "Print",ExpressionUUID->"ef8899d4-a5a4-4560-9d66-ec7e6685aa87"],
Cell[1907890, 53514, 340, 9, 24, "Print",ExpressionUUID->"8aec9a87-3b1b-4196-9a8e-96a946b97e52"],
Cell[1908233, 53525, 341, 9, 24, "Print",ExpressionUUID->"91f6e04d-9029-4a6f-bcc8-46abcad5da30"],
Cell[1908577, 53536, 4730, 132, 71, "Print",ExpressionUUID->"78bde90b-2085-43e8-bf0f-8d045973bb17"],
Cell[1913310, 53670, 343, 9, 24, "Print",ExpressionUUID->"da70c59c-72f6-42f1-a924-5306577f1b2b"],
Cell[1913656, 53681, 341, 9, 24, "Print",ExpressionUUID->"0980afe6-c142-4024-a4f9-f91286a790b0"],
Cell[1914000, 53692, 4728, 132, 71, "Print",ExpressionUUID->"403ffcdb-3f1c-4452-8df1-00c2315bca0a"],
Cell[1918731, 53826, 341, 9, 24, "Print",ExpressionUUID->"3b05e712-ccf2-4bb9-86b9-22b556f69200"],
Cell[1919075, 53837, 2125, 58, 40, "Print",ExpressionUUID->"02d7881b-bd1c-45bd-b3d0-59dd7d11fd3d"],
Cell[1921203, 53897, 343, 9, 24, "Print",ExpressionUUID->"53c8f330-2e48-4332-8dbb-733471aa2aee"],
Cell[1921549, 53908, 2808, 77, 49, "Print",ExpressionUUID->"04228ee2-ff22-45a3-aa96-f62fe005e66c"],
Cell[1924360, 53987, 343, 9, 24, "Print",ExpressionUUID->"7b1450ea-00f4-43d6-aad4-605b8e74e32d"],
Cell[1924706, 53998, 343, 9, 24, "Print",ExpressionUUID->"06be6b28-f745-4056-97e8-bb42a8b63c10"],
Cell[1925052, 54009, 2748, 77, 49, "Print",ExpressionUUID->"72baabfa-437d-44b2-a084-43439042b727"],
Cell[1927803, 54088, 341, 9, 24, "Print",ExpressionUUID->"7173441b-8455-4f92-9321-d38aebb72eb8"],
Cell[1928147, 54099, 343, 9, 24, "Print",ExpressionUUID->"853fe7e7-b808-4036-8648-4b7186ba9261"],
Cell[1928493, 54110, 3936, 108, 49, "Print",ExpressionUUID->"5bdf1b34-b6c0-45eb-b882-55f9260ec795"],
Cell[1932432, 54220, 341, 9, 24, "Print",ExpressionUUID->"f64aea1e-b2c7-4eec-bbf9-d1b22e028d3d"],
Cell[1932776, 54231, 341, 9, 24, "Print",ExpressionUUID->"b2fc1963-2f92-42cc-ae2e-c942bbfd2015"],
Cell[1933120, 54242, 4454, 121, 71, "Print",ExpressionUUID->"a56bd30c-1c83-469e-8b1a-5e316eb47976"],
Cell[1937577, 54365, 341, 9, 24, "Print",ExpressionUUID->"412ca65b-b459-4fe7-b3ba-fe8a123b0004"],
Cell[1937921, 54376, 341, 9, 24, "Print",ExpressionUUID->"fe84262e-b41d-444f-8fe5-84b983d7de19"],
Cell[1938265, 54387, 3884, 106, 49, "Print",ExpressionUUID->"a56a506f-7a5a-4777-bb86-041db50829b1"],
Cell[1942152, 54495, 341, 9, 24, "Print",ExpressionUUID->"3693d6ef-9181-4882-8bf0-50795f8a219a"],
Cell[1942496, 54506, 340, 9, 24, "Print",ExpressionUUID->"47ba4ee8-da91-42e2-b0fc-07bf903c2f3d"],
Cell[1942839, 54517, 341, 9, 24, "Print",ExpressionUUID->"7640e242-ac55-4387-85ce-109d15733213"],
Cell[1943183, 54528, 1706, 49, 40, "Print",ExpressionUUID->"b0df8b58-dd8b-4cd1-95fc-3b5b4e87cc24"],
Cell[1944892, 54579, 341, 9, 24, "Print",ExpressionUUID->"f6a57a14-8d5b-4526-875e-9c5927363434"],
Cell[1945236, 54590, 2263, 63, 40, "Print",ExpressionUUID->"c5c137e2-0b46-4342-99bc-0a47ae00fdc7"],
Cell[1947502, 54655, 343, 9, 24, "Print",ExpressionUUID->"92125144-622b-4f8a-96c1-30e7557c5c5f"],
Cell[1947848, 54666, 341, 9, 24, "Print",ExpressionUUID->"5dc588b6-4fe8-4f8e-8aa5-001e39048248"],
Cell[1948192, 54677, 2644, 76, 47, "Print",ExpressionUUID->"7b003024-288e-460e-92ac-87f517f4c7b4"],
Cell[1950839, 54755, 341, 9, 24, "Print",ExpressionUUID->"679c8933-5d5a-447d-be04-68e0fdd6ba76"],
Cell[1951183, 54766, 340, 9, 24, "Print",ExpressionUUID->"eef8dbed-f99a-4dfb-b46a-7081ce373aea"],
Cell[1951526, 54777, 2644, 76, 47, "Print",ExpressionUUID->"7b1fe5c0-df76-454e-9257-6ecd77d0b36d"],
Cell[1954173, 54855, 341, 9, 24, "Print",ExpressionUUID->"3feed5fb-3c15-4f80-8d0e-e9a661e1db29"],
Cell[1954517, 54866, 1555, 46, 40, "Print",ExpressionUUID->"8251c4db-46dc-43f6-bf80-2c04ab724379"],
Cell[1956075, 54914, 341, 9, 24, "Print",ExpressionUUID->"4b061954-66e2-437e-a5b3-529eab49b13f"],
Cell[1956419, 54925, 1905, 54, 40, "Print",ExpressionUUID->"a85d72ac-ebb0-4c50-8103-b66dae2b5fd1"],
Cell[1958327, 54981, 341, 9, 24, "Print",ExpressionUUID->"3478695c-bc89-41da-8cf2-1de65137052d"],
Cell[1958671, 54992, 340, 9, 24, "Print",ExpressionUUID->"46d2db9d-405e-49ec-8d07-2bb1c945e4b0"],
Cell[1959014, 55003, 3370, 89, 49, "Print",ExpressionUUID->"5ec3e967-d01e-42de-b69e-0e4a051d2a22"],
Cell[1962387, 55094, 341, 9, 24, "Print",ExpressionUUID->"5cd20166-a8ba-4632-869b-6b7e9ce4fa59"],
Cell[1962731, 55105, 341, 9, 24, "Print",ExpressionUUID->"8f400b92-e746-4341-9cd2-c07f274eeb32"],
Cell[1963075, 55116, 3246, 88, 49, "Print",ExpressionUUID->"1fa55e13-17f5-4205-a22a-2a3aeff54e8f"],
Cell[1966324, 55206, 341, 9, 24, "Print",ExpressionUUID->"c2ef6555-5e7e-451c-afd8-4202b58f4620"],
Cell[1966668, 55217, 1497, 44, 47, "Print",ExpressionUUID->"da0d4199-9e5e-4f01-9f11-0224ab9dd85e"],
Cell[1968168, 55263, 341, 9, 24, "Print",ExpressionUUID->"6b196a20-80cd-4cbc-8e1d-edd2b7cff6b9"],
Cell[1968512, 55274, 1909, 54, 40, "Print",ExpressionUUID->"9252adfd-db38-4e90-ba8e-033cdf21a572"],
Cell[1970424, 55330, 341, 9, 24, "Print",ExpressionUUID->"c8cda3a8-72b3-4f2a-977d-ed4e87a8d7ce"],
Cell[1970768, 55341, 340, 9, 24, "Print",ExpressionUUID->"b0b68482-3f69-4909-af55-8fb02f6631d6"],
Cell[1971111, 55352, 341, 9, 24, "Print",ExpressionUUID->"43abc38c-7b84-4360-a270-51a08875384c"],
Cell[1971455, 55363, 341, 9, 24, "Print",ExpressionUUID->"42a24cc7-2563-49c3-b96c-44d621dc2310"],
Cell[1971799, 55374, 3319, 88, 49, "Print",ExpressionUUID->"14fa8bd9-bee3-4901-a513-812da1d02305"],
Cell[1975121, 55464, 341, 9, 24, "Print",ExpressionUUID->"536172ee-ee8d-4a1d-95d8-9a8fbebed665"],
Cell[1975465, 55475, 341, 9, 24, "Print",ExpressionUUID->"cf01bf80-f456-4df0-bcc6-9be9fe16357d"],
Cell[1975809, 55486, 341, 9, 24, "Print",ExpressionUUID->"ef2bfc5a-8424-41c1-98df-223cae744e15"],
Cell[1976153, 55497, 341, 9, 24, "Print",ExpressionUUID->"3ef5a5cf-ee5b-4cb7-af24-2ff0cd3a036b"],
Cell[1976497, 55508, 343, 9, 24, "Print",ExpressionUUID->"60bcb038-b7c7-48f4-abf0-2df9ca3af7c5"],
Cell[1976843, 55519, 341, 9, 24, "Print",ExpressionUUID->"0fc1aa68-a661-45fb-9138-4ff6403ae82e"],
Cell[1977187, 55530, 341, 9, 24, "Print",ExpressionUUID->"3908a243-c9d7-428d-a576-2aeb612a63e5"],
Cell[1977531, 55541, 4696, 123, 71, "Print",ExpressionUUID->"58376ce5-d63d-4a42-81e7-3c5875038ddb"],
Cell[1982230, 55666, 341, 9, 24, "Print",ExpressionUUID->"54e7add5-4b96-4bd3-8cce-dc4fa3825cf8"],
Cell[1982574, 55677, 8476, 220, 154, "Print",ExpressionUUID->"bb359055-c5f6-4847-bedd-af18f342b762"],
Cell[1991053, 55899, 340, 9, 24, "Print",ExpressionUUID->"7e3a1ddb-2e71-4c9d-a765-980421cd3cf9"],
Cell[1991396, 55910, 341, 9, 24, "Print",ExpressionUUID->"5c629cc5-ed8e-476c-895f-aa3562716fa9"],
Cell[1991740, 55921, 341, 9, 24, "Print",ExpressionUUID->"e15a45b0-3342-469f-8eb8-a6c09e6cde25"],
Cell[1992084, 55932, 343, 9, 24, "Print",ExpressionUUID->"d33750d9-7de6-47a6-81f8-7a23b50e94d3"],
Cell[1992430, 55943, 343, 9, 24, "Print",ExpressionUUID->"5e0d04aa-479a-46cc-a8f1-d3eb98a3681b"],
Cell[1992776, 55954, 341, 9, 24, "Print",ExpressionUUID->"9672ac79-bc0a-4bc6-ad56-7b31b3e8aa0a"],
Cell[1993120, 55965, 341, 9, 24, "Print",ExpressionUUID->"7c6b230f-0b63-4280-b64e-d294ea167a5f"],
Cell[1993464, 55976, 343, 9, 24, "Print",ExpressionUUID->"593f6058-1338-4449-889a-3fdcd181a18e"],
Cell[1993810, 55987, 343, 9, 24, "Print",ExpressionUUID->"ead96d22-4a6d-4e2d-8001-a57eb9dda1f3"],
Cell[1994156, 55998, 341, 9, 24, "Print",ExpressionUUID->"ab5db203-e3d8-4e54-bf73-a6bc130d369a"],
Cell[1994500, 56009, 341, 9, 24, "Print",ExpressionUUID->"f7d2d39d-a584-483a-9a68-236bde62d4b9"],
Cell[1994844, 56020, 341, 9, 24, "Print",ExpressionUUID->"3c5ec2b5-d4a5-4aad-841e-ccc152362421"],
Cell[1995188, 56031, 341, 9, 24, "Print",ExpressionUUID->"581cf19d-94d6-492b-babd-9744a710fe85"],
Cell[1995532, 56042, 341, 9, 24, "Print",ExpressionUUID->"5d622b53-6fb9-4997-9e58-83ed5d1e718e"],
Cell[1995876, 56053, 341, 9, 24, "Print",ExpressionUUID->"7815e1fd-c3c7-4df0-95c8-48cad22cb089"],
Cell[1996220, 56064, 341, 9, 24, "Print",ExpressionUUID->"5b64e602-5043-4942-b940-8bf388cad611"],
Cell[1996564, 56075, 341, 9, 24, "Print",ExpressionUUID->"e35547ab-de37-467b-811f-5e4504e0f3ed"],
Cell[1996908, 56086, 343, 9, 24, "Print",ExpressionUUID->"fc6f680e-3812-485d-9fc2-3c988aeb6974"],
Cell[1997254, 56097, 343, 9, 24, "Print",ExpressionUUID->"9b15f7b8-babd-4b8b-b04f-9a7ae9510d56"],
Cell[1997600, 56108, 341, 9, 24, "Print",ExpressionUUID->"8bb1c9be-eb30-46be-b8a0-ccd4817cfdcd"],
Cell[1997944, 56119, 341, 9, 24, "Print",ExpressionUUID->"6d791ecc-ad04-41c9-ae0e-9e453a029a8b"],
Cell[1998288, 56130, 341, 9, 24, "Print",ExpressionUUID->"019ff082-b109-45d2-a538-24b57f6813ed"],
Cell[1998632, 56141, 341, 9, 24, "Print",ExpressionUUID->"840cfeb3-2d02-4f20-b0ad-97abb3fbfea8"],
Cell[1998976, 56152, 343, 9, 24, "Print",ExpressionUUID->"9b6137a2-13cc-4241-afdf-7e39d84a16a7"],
Cell[1999322, 56163, 343, 9, 24, "Print",ExpressionUUID->"a88beb57-fbf0-4b1d-86c4-40ebbe2dcfed"],
Cell[1999668, 56174, 4772, 127, 84, "Print",ExpressionUUID->"9dde0893-ff42-4929-aff5-03cd75670601"],
Cell[2004443, 56303, 343, 9, 24, "Print",ExpressionUUID->"d1e6683d-7d12-44e2-a8eb-e4b11ce92d0f"],
Cell[2004789, 56314, 8319, 218, 150, "Print",ExpressionUUID->"6548ef06-4791-44b6-af20-feef8a3679ec"],
Cell[2013111, 56534, 341, 9, 24, "Print",ExpressionUUID->"2d9dee77-70d2-48e7-aa1d-b47056f75900"],
Cell[2013455, 56545, 341, 9, 24, "Print",ExpressionUUID->"df3378be-3254-4415-801a-27328de4fec3"],
Cell[2013799, 56556, 341, 9, 24, "Print",ExpressionUUID->"5ffd1f1a-9f22-4430-90b1-978d45b5f4d7"],
Cell[2014143, 56567, 341, 9, 24, "Print",ExpressionUUID->"d2edc2de-780e-44c1-aafb-051101c03061"],
Cell[2014487, 56578, 343, 9, 24, "Print",ExpressionUUID->"32a959e6-08ab-463a-adfb-1a5dfe3ab86b"],
Cell[2014833, 56589, 341, 9, 24, "Print",ExpressionUUID->"98feaa01-0d57-4575-80ed-3447dcddf390"],
Cell[2015177, 56600, 341, 9, 24, "Print",ExpressionUUID->"19dcaabd-4a93-490a-b498-7332f93c4ee1"],
Cell[2015521, 56611, 341, 9, 24, "Print",ExpressionUUID->"0ce4d6e0-3dd4-4d2a-9d6e-15b58df6ab21"],
Cell[2015865, 56622, 341, 9, 24, "Print",ExpressionUUID->"1ab7ed62-e8d9-4644-ba90-10d26bda07f9"],
Cell[2016209, 56633, 341, 9, 24, "Print",ExpressionUUID->"d4b482e2-9578-4fc2-ad2b-a63668015b4d"],
Cell[2016553, 56644, 340, 9, 24, "Print",ExpressionUUID->"3a7d535d-046a-46bf-895b-652f1122ed5f"],
Cell[2016896, 56655, 341, 9, 24, "Print",ExpressionUUID->"83f1b173-ff4b-415f-aff6-a2b6e262f1a0"],
Cell[2017240, 56666, 341, 9, 24, "Print",ExpressionUUID->"a0d4d7df-8534-4f00-92e3-9114a2adf6a0"],
Cell[2017584, 56677, 343, 9, 24, "Print",ExpressionUUID->"afa1c406-c8d5-487d-b045-cb72f2ea1d5b"],
Cell[2017930, 56688, 341, 9, 24, "Print",ExpressionUUID->"b5306fe6-64a7-4024-a139-de1439eda36f"],
Cell[2018274, 56699, 341, 9, 24, "Print",ExpressionUUID->"9ddeb378-75a6-4cfe-a625-6a0926398907"],
Cell[2018618, 56710, 341, 9, 24, "Print",ExpressionUUID->"b14439a8-f5c2-4337-b741-317c499224ab"],
Cell[2018962, 56721, 343, 9, 24, "Print",ExpressionUUID->"55986510-c87d-4660-afa1-93b5d7d0d3bc"],
Cell[2019308, 56732, 343, 9, 24, "Print",ExpressionUUID->"d0b2e957-f1c6-4c15-bfba-b805cb18e3ee"],
Cell[2019654, 56743, 343, 9, 24, "Print",ExpressionUUID->"5d711980-07e3-45de-b095-a4bf44adb96e"],
Cell[2020000, 56754, 343, 9, 24, "Print",ExpressionUUID->"e5856c2a-56c2-44b1-9573-163340eb727f"],
Cell[2020346, 56765, 341, 9, 24, "Print",ExpressionUUID->"8c60d04a-a45c-4eb7-937c-8db2a3073db4"],
Cell[2020690, 56776, 341, 9, 24, "Print",ExpressionUUID->"79505f91-2df4-4cdd-84be-22befe3bc747"],
Cell[2021034, 56787, 343, 9, 24, "Print",ExpressionUUID->"b30f0195-7092-4353-961c-edbb7e1f1fb4"],
Cell[2021380, 56798, 341, 9, 24, "Print",ExpressionUUID->"0adf8f73-213b-4dc1-ae52-d1cf94294a15"],
Cell[2021724, 56809, 341, 9, 24, "Print",ExpressionUUID->"d6361451-952c-4126-8484-cea8a0ed5cd3"],
Cell[2022068, 56820, 343, 9, 24, "Print",ExpressionUUID->"a6ff87e5-6b53-4080-9236-2b62d7095d54"],
Cell[2022414, 56831, 341, 9, 24, "Print",ExpressionUUID->"358c6fc3-e2de-4f64-8b92-bc5fa61b7510"],
Cell[2022758, 56842, 341, 9, 24, "Print",ExpressionUUID->"1775ccc9-4f97-4580-a731-68f91a982dec"],
Cell[2023102, 56853, 341, 9, 24, "Print",ExpressionUUID->"3b3aeb95-a7df-4d88-b69e-7de9fae698b3"],
Cell[2023446, 56864, 341, 9, 24, "Print",ExpressionUUID->"07c24eb6-8a62-483a-b39a-e4fe90e95408"],
Cell[2023790, 56875, 341, 9, 24, "Print",ExpressionUUID->"89e2f39e-937d-471a-8c88-10f1f5c7b322"],
Cell[2024134, 56886, 341, 9, 24, "Print",ExpressionUUID->"83e25644-22fd-4b24-a26a-3b3b49723808"],
Cell[2024478, 56897, 343, 9, 24, "Print",ExpressionUUID->"22198181-75f7-4ca7-9863-34655e95b44e"],
Cell[2024824, 56908, 343, 9, 24, "Print",ExpressionUUID->"04f37746-a93b-4e28-a955-75a99c8d13d5"],
Cell[2025170, 56919, 341, 9, 24, "Print",ExpressionUUID->"93013369-de48-4cc9-ab85-c5403d2ca44a"],
Cell[2025514, 56930, 341, 9, 24, "Print",ExpressionUUID->"6d1a379d-a6d2-4c47-9c50-e6cd21fee9bc"],
Cell[2025858, 56941, 341, 9, 24, "Print",ExpressionUUID->"ce5fe48f-e95a-4a08-a140-bd4eb353f176"],
Cell[2026202, 56952, 340, 9, 24, "Print",ExpressionUUID->"e19380dd-8400-4964-a741-3a27a62bcaf7"],
Cell[2026545, 56963, 6614, 168, 113, "Print",ExpressionUUID->"34f9e0a2-31f7-4fb5-b21a-66fa42a64982"],
Cell[2033162, 57133, 341, 9, 24, "Print",ExpressionUUID->"fc2359e3-1651-4fb0-96be-6975ccbce5df"],
Cell[2033506, 57144, 19720, 492, 269, "Print",ExpressionUUID->"f0162ccd-7c70-4b89-ba7c-510051aa61b5"],
Cell[2053229, 57638, 341, 9, 24, "Print",ExpressionUUID->"b20fde6c-7f01-4128-aac0-bdccc1171c5e"],
Cell[2053573, 57649, 7802, 205, 137, "Print",ExpressionUUID->"e896d20c-98ac-4a52-b768-e61a9663d043"],
Cell[2061378, 57856, 343, 9, 24, "Print",ExpressionUUID->"09e8f136-4754-47ec-9577-01ebb22c9da1"],
Cell[2061724, 57867, 5416, 145, 71, "Print",ExpressionUUID->"ac70d84f-55ae-46f6-9f61-45a413d15301"],
Cell[2067143, 58014, 341, 9, 24, "Print",ExpressionUUID->"8b7e0e9a-1a17-492d-a4dd-1694716b3594"],
Cell[2067487, 58025, 7165, 204, 170, "Print",ExpressionUUID->"88891cef-e05d-4399-abb0-4725bc4a4066"],
Cell[2074655, 58231, 341, 9, 24, "Print",ExpressionUUID->"0c0f5d36-b60b-4100-87a7-84636568f025"],
Cell[2074999, 58242, 6704, 193, 177, "Print",ExpressionUUID->"db0b5449-69f3-45d5-a693-7d22cb99422c"],
Cell[2081706, 58437, 341, 9, 24, "Print",ExpressionUUID->"2a9c990b-cf07-45dc-8c32-9925ada28d41"],
Cell[2082050, 58448, 2449, 65, 59, "Print",ExpressionUUID->"d277071b-80e2-46b3-9eb2-e8bca3b5f693"],
Cell[2084502, 58515, 341, 9, 24, "Print",ExpressionUUID->"587be98d-56c5-4311-873a-2ff266be7c69"],
Cell[2084846, 58526, 5839, 153, 84, "Print",ExpressionUUID->"ba353b31-1c63-4d29-ba17-29121289a4ad"],
Cell[2090688, 58681, 343, 9, 24, "Print",ExpressionUUID->"70cfd6db-e370-429f-b3fd-79c957fa5dc2"],
Cell[2091034, 58692, 341, 9, 24, "Print",ExpressionUUID->"0c9bf53a-307a-4ccc-8b3f-25837aa7e793"],
Cell[2091378, 58703, 1997, 58, 40, "Print",ExpressionUUID->"dbd370be-5794-40b4-b421-f3f70f049573"],
Cell[2093378, 58763, 340, 9, 24, "Print",ExpressionUUID->"1a18ef15-7488-4320-9232-74bdec211a12"],
Cell[2093721, 58774, 343, 9, 24, "Print",ExpressionUUID->"1b929672-0009-46ad-a130-f7c9d26f5b5b"],
Cell[2094067, 58785, 3967, 105, 69, "Print",ExpressionUUID->"7158d20e-c9b9-4c20-be3f-05aaef076109"],
Cell[2098037, 58892, 341, 9, 24, "Print",ExpressionUUID->"ab509e3d-5292-4fb1-b14a-18d70b134cdd"],
Cell[2098381, 58903, 343, 9, 24, "Print",ExpressionUUID->"f0f888ab-8c01-4879-9863-168923d815de"],
Cell[2098727, 58914, 8876, 226, 135, "Print",ExpressionUUID->"63e3e4f9-2037-4350-8e82-7d084b9bd81a"],
Cell[2107606, 59142, 341, 9, 24, "Print",ExpressionUUID->"18dbaeae-4d91-43bf-8414-36c480fc29c3"],
Cell[2107950, 59153, 8458, 217, 147, "Print",ExpressionUUID->"e622b667-7ba6-4c54-b814-2b95e9fc2db5"],
Cell[2116411, 59372, 343, 9, 24, "Print",ExpressionUUID->"452d66a6-ff0e-42ec-ad22-7aa051fbf7c7"],
Cell[2116757, 59383, 8508, 210, 135, "Print",ExpressionUUID->"27d25f24-74d4-40ac-989c-4df1ff9fcb67"],
Cell[2125268, 59595, 343, 9, 24, "Print",ExpressionUUID->"7b35ba7e-e5c5-49ac-8246-7ca4cae5a15b"],
Cell[2125614, 59606, 341, 9, 24, "Print",ExpressionUUID->"f1c8f5f7-944b-4c80-ad8c-4c621db59084"],
Cell[2125958, 59617, 2946, 79, 49, "Print",ExpressionUUID->"bda3573c-cb22-45b2-b838-76e1791abbe4"],
Cell[2128907, 59698, 341, 9, 24, "Print",ExpressionUUID->"4ff58052-4bc7-428a-9772-c6bcd1911bc4"],
Cell[2129251, 59709, 3453, 95, 49, "Print",ExpressionUUID->"fd33c150-cd5b-447e-a9a3-62167f2393b9"],
Cell[2132707, 59806, 341, 9, 24, "Print",ExpressionUUID->"435d7e82-2b78-49fc-a003-5938d343ac45"],
Cell[2133051, 59817, 3819, 99, 71, "Print",ExpressionUUID->"29e17946-7016-4e82-b820-92ca8fa3fba1"],
Cell[2136873, 59918, 341, 9, 24, "Print",ExpressionUUID->"97ccc61d-444f-41f3-925f-969d477282fc"],
Cell[2137217, 59929, 340, 9, 24, "Print",ExpressionUUID->"74c48b28-b6ea-4dd9-8cb9-0cbfc9d6f8dd"],
Cell[2137560, 59940, 8964, 222, 135, "Print",ExpressionUUID->"6e998cc5-bd49-46bd-ab75-1248a1d3fac3"],
Cell[2146527, 60164, 340, 9, 24, "Print",ExpressionUUID->"473d7af6-3f0d-4c8e-a48d-afa4e2cf3800"],
Cell[2146870, 60175, 341, 9, 24, "Print",ExpressionUUID->"f8315810-07f3-4dff-86a1-16540fe18a07"],
Cell[2147214, 60186, 6544, 170, 84, "Print",ExpressionUUID->"cc344f33-9222-4334-aa6a-31f57ceab195"],
Cell[2153761, 60358, 340, 9, 24, "Print",ExpressionUUID->"85b68a81-04e9-4a15-975d-208b85a4bde5"],
Cell[2154104, 60369, 4171, 115, 62, "Print",ExpressionUUID->"b77127ce-cbec-4c4f-93c1-aa47ab11cc0c"],
Cell[2158278, 60486, 340, 9, 24, "Print",ExpressionUUID->"4a8da548-cf1d-4d7c-93a9-b209cae9a744"],
Cell[2158621, 60497, 343, 9, 24, "Print",ExpressionUUID->"0f5444dd-2e5c-4d18-943e-7feb7b7d8b25"],
Cell[2158967, 60508, 340, 9, 24, "Print",ExpressionUUID->"7f022c1f-ce63-4128-9d64-89da9183cbdf"],
Cell[2159310, 60519, 341, 9, 24, "Print",ExpressionUUID->"279356ad-9ee1-407c-9a89-e4fff5ab72e6"],
Cell[2159654, 60530, 343, 9, 24, "Print",ExpressionUUID->"c241fb0e-0112-4ece-84cf-8fa7c8610dc5"],
Cell[2160000, 60541, 1956, 56, 40, "Print",ExpressionUUID->"b371092f-45b2-4282-984a-db2958ac5a47"],
Cell[2161959, 60599, 341, 9, 24, "Print",ExpressionUUID->"ce549080-13a4-4410-970e-a32f30146f0a"],
Cell[2162303, 60610, 2606, 70, 62, "Print",ExpressionUUID->"5520dad1-ce43-4eda-a719-c523ee2cd041"],
Cell[2164912, 60682, 343, 9, 24, "Print",ExpressionUUID->"fb87dbb6-6487-4439-b0a9-54fd4fae8ddd"],
Cell[2165258, 60693, 2790, 76, 62, "Print",ExpressionUUID->"1feb81d8-932e-4454-ac76-e7eea07c8683"],
Cell[2168051, 60771, 343, 9, 24, "Print",ExpressionUUID->"dc213849-27d4-468a-81b3-00d03facc4d4"],
Cell[2168397, 60782, 1616, 48, 40, "Print",ExpressionUUID->"00eb5f5e-848e-4825-ae81-e6abe3457c85"],
Cell[2170016, 60832, 341, 9, 24, "Print",ExpressionUUID->"74df74db-af4b-43b4-ba88-0cf618ab6599"],
Cell[2170360, 60843, 1986, 55, 40, "Print",ExpressionUUID->"0a3f00bf-c614-4543-aed3-7dce70e7a043"],
Cell[2172349, 60900, 343, 9, 24, "Print",ExpressionUUID->"0fc64b1d-0fc3-477d-8842-1d885063815e"],
Cell[2172695, 60911, 343, 9, 24, "Print",ExpressionUUID->"b2baef97-bad4-4b5f-92cf-49334115182a"],
Cell[2173041, 60922, 343, 9, 24, "Print",ExpressionUUID->"8b8cbff3-c286-4e06-a2f6-d0fe4ab75f16"],
Cell[2173387, 60933, 341, 9, 24, "Print",ExpressionUUID->"b1244b46-a987-4611-a32b-ac9f8f15e191"],
Cell[2173731, 60944, 341, 9, 24, "Print",ExpressionUUID->"1910cf00-9879-4183-9fa1-51af58ba044f"],
Cell[2174075, 60955, 341, 9, 24, "Print",ExpressionUUID->"6109c70c-effc-427c-806e-e5d7e2c4477c"],
Cell[2174419, 60966, 341, 9, 24, "Print",ExpressionUUID->"70b1f551-d4e2-44ee-8141-e1549b78add3"],
Cell[2174763, 60977, 341, 9, 24, "Print",ExpressionUUID->"07bea58e-48ce-4ca6-b4f7-65b70b13bfd3"],
Cell[2175107, 60988, 340, 9, 24, "Print",ExpressionUUID->"ceec645a-3e6c-490d-ac0b-4547e792618c"],
Cell[2175450, 60999, 341, 9, 24, "Print",ExpressionUUID->"9a274137-536f-4c3d-a044-b25b3dabbea7"],
Cell[2175794, 61010, 341, 9, 24, "Print",ExpressionUUID->"f0bb4956-446e-4cbd-b257-9fdef566caba"],
Cell[2176138, 61021, 341, 9, 24, "Print",ExpressionUUID->"70cce601-dcb4-40a5-9426-018054ec7bea"],
Cell[2176482, 61032, 340, 9, 24, "Print",ExpressionUUID->"52bc3da8-1b0f-44c9-bef8-b74379762e44"],
Cell[2176825, 61043, 343, 9, 24, "Print",ExpressionUUID->"10a7c122-761e-4fa3-93ab-7086b8204988"],
Cell[2177171, 61054, 343, 9, 24, "Print",ExpressionUUID->"86efab23-5f6c-40ac-ab87-4f2f030937df"],
Cell[2177517, 61065, 341, 9, 24, "Print",ExpressionUUID->"ec37c6df-be70-4c35-b563-894111bd2d50"],
Cell[2177861, 61076, 343, 9, 24, "Print",ExpressionUUID->"eb651212-0eed-4f88-8694-7fbf2e5bf8bb"],
Cell[2178207, 61087, 341, 9, 24, "Print",ExpressionUUID->"7b7bd710-2f66-408e-84ec-e917dfb63d3b"],
Cell[2178551, 61098, 343, 9, 24, "Print",ExpressionUUID->"e56ad9e7-fb00-45ff-9778-d3a135608513"],
Cell[2178897, 61109, 343, 9, 24, "Print",ExpressionUUID->"04c1d008-1afb-448f-9ec8-6247760dd884"],
Cell[2179243, 61120, 2261, 65, 40, "Print",ExpressionUUID->"91ba32bd-2100-49ea-bf56-6a4f4ff71b2f"],
Cell[2181507, 61187, 341, 9, 24, "Print",ExpressionUUID->"e54f516d-9a95-4402-93c5-a534aa145cd0"],
Cell[2181851, 61198, 1342, 39, 44, "Print",ExpressionUUID->"19d6dd0b-d0df-4750-8e9b-cc3e4de26387"],
Cell[2183196, 61239, 343, 9, 24, "Print",ExpressionUUID->"5013dc96-0584-412a-937b-02a75ce53cc8"],
Cell[2183542, 61250, 341, 9, 24, "Print",ExpressionUUID->"cbe6aee2-9719-4ddb-83ae-f9774d0398c4"],
Cell[2183886, 61261, 1812, 53, 28, "Print",ExpressionUUID->"38d89ffd-7807-4c2c-97cf-d9cfc433ac2b"],
Cell[2185701, 61316, 343, 9, 24, "Print",ExpressionUUID->"96376876-14de-4695-bde7-0cfc90a2c186"],
Cell[2186047, 61327, 2743, 79, 62, "Print",ExpressionUUID->"4cb38975-55c9-4b4e-9717-0365b7e94d14"],
Cell[2188793, 61408, 341, 9, 24, "Print",ExpressionUUID->"52f9397f-2864-4045-b8c8-12c2a272abea"],
Cell[2189137, 61419, 341, 9, 24, "Print",ExpressionUUID->"3d009f1c-82b3-4c10-b993-67d047bb199a"],
Cell[2189481, 61430, 1840, 51, 26, "Print",ExpressionUUID->"9e1d4b7a-bdd9-4186-8201-c22ba74e6441"],
Cell[2191324, 61483, 341, 9, 24, "Print",ExpressionUUID->"eaae0210-9d3a-4394-8a5e-3ec3aefb0024"],
Cell[2191668, 61494, 341, 9, 24, "Print",ExpressionUUID->"3e4ce93d-e10c-4b08-8c78-a5810d90517e"],
Cell[2192012, 61505, 343, 9, 24, "Print",ExpressionUUID->"a83dc640-5cb0-483f-a970-5fee499ff4aa"],
Cell[2192358, 61516, 1550, 45, 27, "Print",ExpressionUUID->"d9bd17e4-1066-42f6-a0ee-3b41bbba547d"],
Cell[2193911, 61563, 341, 9, 24, "Print",ExpressionUUID->"2d7191d6-32f5-4596-8118-1b99c80e06f8"],
Cell[2194255, 61574, 1938, 56, 40, "Print",ExpressionUUID->"156f005a-937a-47bf-a233-7f05c507f1d7"],
Cell[2196196, 61632, 341, 9, 24, "Print",ExpressionUUID->"4a90604a-536d-4ec9-b9a3-c4d05fc8f804"],
Cell[2196540, 61643, 2260, 65, 40, "Print",ExpressionUUID->"fc203c2a-979e-4466-8267-451fb5ee1232"],
Cell[2198803, 61710, 341, 9, 24, "Print",ExpressionUUID->"bc41932c-0074-4d06-a559-1e2e4fbc2672"],
Cell[2199147, 61721, 343, 9, 24, "Print",ExpressionUUID->"6d3e4184-9520-4765-adef-2a2c3838c035"],
Cell[2199493, 61732, 341, 9, 24, "Print",ExpressionUUID->"09b3d36e-c759-4cdd-910a-64601082561f"],
Cell[2199837, 61743, 340, 9, 24, "Print",ExpressionUUID->"52f65aa5-7a0e-4d07-bc6a-4b9f9b1601df"],
Cell[2200180, 61754, 2862, 76, 49, "Print",ExpressionUUID->"784a9440-9b0b-4a46-824f-40ce88f46ae2"],
Cell[2203045, 61832, 341, 9, 24, "Print",ExpressionUUID->"9921c525-4406-415a-be4a-e42250c22e96"],
Cell[2203389, 61843, 5342, 135, 71, "Print",ExpressionUUID->"d8407544-3bfc-45c5-ae6b-2ca110edaf54"],
Cell[2208734, 61980, 341, 9, 24, "Print",ExpressionUUID->"8f83cd75-e983-4237-940b-acc5e860b54e"],
Cell[2209078, 61991, 3076, 83, 49, "Print",ExpressionUUID->"4a87d6f5-21fa-44d6-b7f2-b4533c62898e"],
Cell[2212157, 62076, 341, 9, 24, "Print",ExpressionUUID->"ebece836-b386-497b-b54d-d8cb08255ba9"],
Cell[2212501, 62087, 5222, 137, 71, "Print",ExpressionUUID->"0fb8133c-07ec-46b6-94d5-a8498757da3f"],
Cell[2217726, 62226, 341, 9, 24, "Print",ExpressionUUID->"a31d123a-31dc-48f2-bcd8-4fc356180249"],
Cell[2218070, 62237, 340, 9, 24, "Print",ExpressionUUID->"ce413e90-0a82-436f-8eea-21a34694481b"],
Cell[2218413, 62248, 10148, 257, 137, "Print",ExpressionUUID->"c300efcb-9d28-421b-82e9-d4542775c898"],
Cell[2228564, 62507, 341, 9, 24, "Print",ExpressionUUID->"ee948d36-49f6-40ef-8dc7-72b1cc3058b4"],
Cell[2228908, 62518, 5481, 142, 71, "Print",ExpressionUUID->"f6e25dd3-9764-4ed4-acca-09cd3d321848"],
Cell[2234392, 62662, 341, 9, 24, "Print",ExpressionUUID->"71206405-21cf-4eb5-bc87-d034ec017afa"],
Cell[2234736, 62673, 9996, 252, 137, "Print",ExpressionUUID->"7926a166-f995-4ed8-8ed3-2c68b9353e77"],
Cell[2244735, 62927, 341, 9, 24, "Print",ExpressionUUID->"7da50bab-3652-4b69-bfbc-fdb51ee5c704"],
Cell[2245079, 62938, 341, 9, 24, "Print",ExpressionUUID->"4019f2df-27ba-4f8d-8f07-e4a04f1805ce"],
Cell[2245423, 62949, 10558, 273, 137, "Print",ExpressionUUID->"5df49939-96cb-4a72-af9f-7495fc79e105"],
Cell[2255984, 63224, 341, 9, 24, "Print",ExpressionUUID->"36408421-8096-4c1d-8d2b-4c38469582c5"],
Cell[2256328, 63235, 339, 9, 24, "Print",ExpressionUUID->"3e71ef95-9206-439a-8112-04eed47e8299"],
Cell[2256670, 63246, 341, 9, 24, "Print",ExpressionUUID->"67e87938-9357-46c3-8cc4-89d885dcefa7"],
Cell[2257014, 63257, 343, 9, 24, "Print",ExpressionUUID->"d38a76e2-57e3-492a-a66c-f265eccd9d6c"],
Cell[2257360, 63268, 341, 9, 24, "Print",ExpressionUUID->"8d4ca027-a8f9-427c-b0de-190a8b506c48"],
Cell[2257704, 63279, 1998, 59, 40, "Print",ExpressionUUID->"2e81d637-a5a8-4901-987d-0ebf21ae5429"],
Cell[2259705, 63340, 343, 9, 24, "Print",ExpressionUUID->"2f234596-116d-4f27-a1b6-13062065f77e"],
Cell[2260051, 63351, 2704, 78, 49, "Print",ExpressionUUID->"62044103-1f40-4bb4-9523-b2c19c321bc1"],
Cell[2262758, 63431, 341, 9, 24, "Print",ExpressionUUID->"129edd70-cf79-494b-8b4e-6b8c00cd0b72"],
Cell[2263102, 63442, 343, 9, 24, "Print",ExpressionUUID->"2592ab20-c79e-4942-90e0-241a3dd7ba4b"],
Cell[2263448, 63453, 343, 9, 24, "Print",ExpressionUUID->"6f76bb00-4899-4f65-9c8b-3d57a9a3c5a0"],
Cell[2263794, 63464, 343, 9, 24, "Print",ExpressionUUID->"abf906e0-4e0c-49bf-9879-0d8431973c25"],
Cell[2264140, 63475, 341, 9, 24, "Print",ExpressionUUID->"8186b2ec-b975-40de-85ae-8bb0fd28bffb"],
Cell[2264484, 63486, 341, 9, 24, "Print",ExpressionUUID->"e5f8bba2-2b85-40ed-8e23-656990bd3050"],
Cell[2264828, 63497, 343, 9, 24, "Print",ExpressionUUID->"aa269226-7b97-4572-8f48-f839095ab4df"],
Cell[2265174, 63508, 341, 9, 24, "Print",ExpressionUUID->"209683d2-21b8-45da-bb4c-8837a8c0418d"],
Cell[2265518, 63519, 341, 9, 24, "Print",ExpressionUUID->"e8792aee-3108-4c66-b0b6-8cb7c15e2981"],
Cell[2265862, 63530, 341, 9, 24, "Print",ExpressionUUID->"d3f91d8a-67ad-4203-bfe2-340561c1bcfe"],
Cell[2266206, 63541, 341, 9, 24, "Print",ExpressionUUID->"651a180f-6320-455d-bfa6-77d2e165eff1"],
Cell[2266550, 63552, 341, 9, 24, "Print",ExpressionUUID->"2485d3de-2cba-4174-870a-8691f1565ca7"],
Cell[2266894, 63563, 340, 9, 24, "Print",ExpressionUUID->"ec7c7cbc-c4e4-4d84-a3fe-821dde5a6a73"],
Cell[2267237, 63574, 4074, 102, 84, "Print",ExpressionUUID->"40980070-2c89-4192-9a98-ace59a9acfa8"],
Cell[2271314, 63678, 341, 9, 24, "Print",ExpressionUUID->"23b59401-3acd-4150-9e64-a96443e1db11"],
Cell[2271658, 63689, 7080, 173, 150, "Print",ExpressionUUID->"ce5f5bf3-26f0-4336-aae5-e3aef95ac2b0"],
Cell[2278741, 63864, 341, 9, 24, "Print",ExpressionUUID->"755cc50c-aa13-4126-90e2-db0f5d9725fa"],
Cell[2279085, 63875, 4709, 117, 82, "Print",ExpressionUUID->"4ed2d8f5-a084-4cc8-a46f-37a15ab6aaf7"],
Cell[2283797, 63994, 341, 9, 24, "Print",ExpressionUUID->"8ecf5505-afea-402f-afa7-c9c2b27e1d97"],
Cell[2284141, 64005, 9040, 215, 150, "Print",ExpressionUUID->"c3c13155-e355-4625-ba2f-3742bc297277"],
Cell[2293184, 64222, 343, 9, 24, "Print",ExpressionUUID->"638e09f7-ad82-45da-8c1f-959a77a9fae1"],
Cell[2293530, 64233, 2093, 57, 40, "Print",ExpressionUUID->"dccef913-1dac-4269-ae7a-a239624e97be"],
Cell[2295626, 64292, 341, 9, 24, "Print",ExpressionUUID->"b40b6f87-b769-4506-a046-79953e9429d0"],
Cell[2295970, 64303, 3125, 80, 62, "Print",ExpressionUUID->"8ddd97ec-0ffc-445a-8f0e-2f2974403b85"],
Cell[2299098, 64385, 341, 9, 24, "Print",ExpressionUUID->"9e5f1b47-90cf-4711-acab-3d5675659923"],
Cell[2299442, 64396, 3111, 81, 62, "Print",ExpressionUUID->"77613275-76fb-44d2-84e9-f70186cd902c"],
Cell[2302556, 64479, 341, 9, 24, "Print",ExpressionUUID->"7013c5ed-e557-47a3-aabf-c00249f07609"],
Cell[2302900, 64490, 5210, 131, 84, "Print",ExpressionUUID->"b1d3f940-ebdf-4802-9371-4617d687147a"],
Cell[2308113, 64623, 341, 9, 24, "Print",ExpressionUUID->"8e9104f0-397e-454c-8aa6-9edd6040d2d2"],
Cell[2308457, 64634, 5594, 139, 69, "Print",ExpressionUUID->"ba23ba1a-f999-4ad6-b036-403410b05017"],
Cell[2314054, 64775, 343, 9, 24, "Print",ExpressionUUID->"bf36c594-de50-4d47-9a76-cd834682de88"],
Cell[2314400, 64786, 10938, 260, 137, "Print",ExpressionUUID->"8f85bedb-4b83-441a-b2fd-66491c3f2128"],
Cell[2325341, 65048, 341, 9, 24, "Print",ExpressionUUID->"9fb813ae-0d5c-4c67-b2bc-93d8d977145f"],
Cell[2325685, 65059, 4921, 127, 86, "Print",ExpressionUUID->"74843884-7e31-462c-9d15-d459743e787d"],
Cell[2330609, 65188, 343, 9, 24, "Print",ExpressionUUID->"9592087a-f411-4bb2-a9f3-30222c4ccbba"],
Cell[2330955, 65199, 9693, 239, 137, "Print",ExpressionUUID->"1afb14e9-b9a7-49cd-9006-f29d55a9cd5c"],
Cell[2340651, 65440, 341, 9, 24, "Print",ExpressionUUID->"f7b89d0f-695e-4078-acaa-68923f5932dd"],
Cell[2340995, 65451, 4808, 121, 84, "Print",ExpressionUUID->"8a7274d7-b80c-41fe-a2aa-5430d3a46226"],
Cell[2345806, 65574, 343, 9, 24, "Print",ExpressionUUID->"4994d32d-b72c-4cb5-98b3-aed13f28f7fb"],
Cell[2346152, 65585, 7464, 186, 128, "Print",ExpressionUUID->"54136938-d3f7-4957-9089-1f3338728bc6"],
Cell[2353619, 65773, 343, 9, 24, "Print",ExpressionUUID->"790b0683-390b-4811-b995-48eb06c83d86"],
Cell[2353965, 65784, 3400, 91, 66, "Print",ExpressionUUID->"1783ad97-d920-43af-a2e8-d0be9ee8de24"],
Cell[2357368, 65877, 341, 9, 24, "Print",ExpressionUUID->"1999d64d-7df0-47b7-9532-2135c90d4ca4"],
Cell[2357712, 65888, 6097, 157, 84, "Print",ExpressionUUID->"9104714d-5423-4dc2-ae14-358143452a10"],
Cell[2363812, 66047, 341, 9, 24, "Print",ExpressionUUID->"58563898-07d4-4061-b38b-6c45d3d29ded"],
Cell[2364156, 66058, 340, 9, 24, "Print",ExpressionUUID->"42ac4302-2560-48e3-bab2-f53cc377e848"],
Cell[2364499, 66069, 10746, 258, 137, "Print",ExpressionUUID->"b6a2fd66-be16-4ad1-9016-fa7d2f365b74"],
Cell[2375248, 66329, 343, 9, 24, "Print",ExpressionUUID->"f17e08fa-85e0-4346-bf83-e104784a32c9"],
Cell[2375594, 66340, 6993, 173, 125, "Print",ExpressionUUID->"28b40769-abae-4ff5-a3ed-3ae5307a7452"],
Cell[2382590, 66515, 343, 9, 24, "Print",ExpressionUUID->"974565cc-df3d-47a4-ba93-8773880711bd"],
Cell[2382936, 66526, 12869, 311, 191, "Print",ExpressionUUID->"59d913e1-4610-4f46-85fd-e3641e3a933e"],
Cell[2395808, 66839, 341, 9, 24, "Print",ExpressionUUID->"2ef17a87-7ae6-4b3f-b2d0-b5ebc17ac195"],
Cell[2396152, 66850, 3091, 79, 66, "Print",ExpressionUUID->"ce6b6cd6-adee-4e6d-85b3-5a5e142c61c3"],
Cell[2399246, 66931, 341, 9, 24, "Print",ExpressionUUID->"9fb775ae-3431-4aac-bced-74dd8f9b911d"],
Cell[2399590, 66942, 5203, 129, 84, "Print",ExpressionUUID->"6d4023ad-74ad-49fd-97cb-60bdf0bc06c9"],
Cell[2404796, 67073, 341, 9, 24, "Print",ExpressionUUID->"584b99e0-cfa7-460e-9c9b-33beb6748ccb"],
Cell[2405140, 67084, 2480, 66, 48, "Print",ExpressionUUID->"ba30fccc-c595-40dd-8bef-daf3faf32d16"],
Cell[2407623, 67152, 343, 9, 24, "Print",ExpressionUUID->"470f74ac-d335-4d62-a4dd-f0f7be5ff3a8"],
Cell[2407969, 67163, 3969, 101, 84, "Print",ExpressionUUID->"586ac716-eb72-4322-9a78-9c11e2a815f7"],
Cell[2411941, 67266, 341, 9, 24, "Print",ExpressionUUID->"f937a62d-8633-4c82-895e-a72571ce034e"],
Cell[2412285, 67277, 2425, 65, 66, "Print",ExpressionUUID->"fdc6bead-9756-4b8b-9290-a484570f3493"],
Cell[2414713, 67344, 341, 9, 24, "Print",ExpressionUUID->"03a0fb97-b5dd-474d-9c0c-acc0e0a76356"],
Cell[2415057, 67355, 3697, 95, 71, "Print",ExpressionUUID->"294e8564-b013-4039-9903-39595404f6a6"],
Cell[2418757, 67452, 343, 9, 24, "Print",ExpressionUUID->"03d08861-c331-40c8-a8fd-cec9c0471955"],
Cell[2419103, 67463, 4629, 115, 69, "Print",ExpressionUUID->"03dc4f10-663f-4648-8296-dd066d917267"],
Cell[2423735, 67580, 341, 9, 24, "Print",ExpressionUUID->"49c99a6e-3641-4b72-936b-4a1558eea61a"],
Cell[2424079, 67591, 8988, 214, 154, "Print",ExpressionUUID->"ac17bae1-6ca6-4da1-a04d-48de34ed1240"],
Cell[2433070, 67807, 341, 9, 24, "Print",ExpressionUUID->"e2038724-4358-43c7-a53d-55e92425c11a"],
Cell[2433414, 67818, 5532, 141, 82, "Print",ExpressionUUID->"4c9444c5-1873-4182-bfdd-c8ac6fa201bf"],
Cell[2438949, 67961, 341, 9, 24, "Print",ExpressionUUID->"c3de4311-80b5-4283-bf3c-848fc76f46a3"],
Cell[2439293, 67972, 5542, 138, 84, "Print",ExpressionUUID->"1f6efffa-baae-455c-b773-f8b3a92c9e53"],
Cell[2444838, 68112, 343, 9, 24, "Print",ExpressionUUID->"a78823f9-b2ad-4121-8411-c09e4b707584"],
Cell[2445184, 68123, 2367, 62, 62, "Print",ExpressionUUID->"adf1bc2d-9d5b-450d-9158-aac7a7240fe8"],
Cell[2447554, 68187, 341, 9, 24, "Print",ExpressionUUID->"65963baa-c145-4f39-83fb-0502b101d07a"],
Cell[2447898, 68198, 4150, 103, 84, "Print",ExpressionUUID->"0352ad51-6a64-4870-ae22-df220898c80e"],
Cell[2452051, 68303, 341, 9, 24, "Print",ExpressionUUID->"26c23bd1-86f2-47e6-9202-ac877bc8c621"],
Cell[2452395, 68314, 2624, 68, 62, "Print",ExpressionUUID->"90d0bb30-9ace-4a71-8b87-ec34b3a2162b"],
Cell[2455022, 68384, 341, 9, 24, "Print",ExpressionUUID->"47c0b7bf-df87-4642-a1d1-350ee02a74fe"],
Cell[2455366, 68395, 3969, 97, 88, "Print",ExpressionUUID->"585a395b-b569-41ff-bb27-5bb0c1b287ea"],
Cell[2459338, 68494, 341, 9, 24, "Print",ExpressionUUID->"a75b95c1-649b-412c-b1bc-e3560dc99750"],
Cell[2459682, 68505, 6926, 174, 110, "Print",ExpressionUUID->"3b8854e9-0d41-4c97-87e9-e6b411ed214d"],
Cell[2466611, 68681, 341, 9, 24, "Print",ExpressionUUID->"754a15b1-4fbe-4a8d-8cec-08bf6205b5dd"],
Cell[2466955, 68692, 343, 9, 24, "Print",ExpressionUUID->"81cbdd54-1dcb-4e83-a5a1-062aaa086c8d"],
Cell[2467301, 68703, 12272, 295, 179, "Print",ExpressionUUID->"bbdbe50f-f3d3-4c15-b3de-c88c21f4872f"],
Cell[2479576, 69000, 341, 9, 24, "Print",ExpressionUUID->"00c440c1-29ba-42c4-bb2f-8e4b30e7dd82"],
Cell[2479920, 69011, 12670, 322, 169, "Print",ExpressionUUID->"81aa6c6b-83aa-4910-a19d-b362f4457d54"],
Cell[2492593, 69335, 341, 9, 24, "Print",ExpressionUUID->"f03f1e2a-1daa-47de-ba61-395923d1c814"],
Cell[2492937, 69346, 341, 9, 24, "Print",ExpressionUUID->"97fad206-3d67-4a01-b652-e12b628e8177"],
Cell[2493281, 69357, 4074, 102, 84, "Print",ExpressionUUID->"35dc837d-4673-4646-8efd-b145fa30846a"],
Cell[2497358, 69461, 343, 9, 24, "Print",ExpressionUUID->"09fa59cf-1182-4711-976f-827738435bd5"],
Cell[2497704, 69472, 2380, 65, 40, "Print",ExpressionUUID->"0594e026-91ec-44c1-98d2-f9972174ed54"],
Cell[2500087, 69539, 341, 9, 24, "Print",ExpressionUUID->"3af82e7d-a832-4c6e-8442-6b80f209b317"],
Cell[2500431, 69550, 3712, 98, 62, "Print",ExpressionUUID->"e6aa5a21-44ee-4f83-8d6a-7ecb94365ea3"],
Cell[2504146, 69650, 341, 9, 24, "Print",ExpressionUUID->"1779fa16-ee00-4066-9e88-f7368382eaad"],
Cell[2504490, 69661, 3425, 90, 62, "Print",ExpressionUUID->"49103765-46fa-4ad4-8316-487361c28f3d"],
Cell[2507918, 69753, 341, 9, 24, "Print",ExpressionUUID->"500cd37c-2315-4d65-9425-54f330655d3a"],
Cell[2508262, 69764, 5853, 150, 84, "Print",ExpressionUUID->"7922dce8-1e65-4cd6-b77c-06ddd9b99b37"],
Cell[2514118, 69916, 341, 9, 24, "Print",ExpressionUUID->"57b3a7ef-5d6d-4fe1-9f8c-1cb4e77d64ed"],
Cell[2514462, 69927, 4480, 114, 84, "Print",ExpressionUUID->"75510c0d-2d31-48ba-933d-de3409b67c4c"],
Cell[2518945, 70043, 340, 9, 24, "Print",ExpressionUUID->"337294a1-0bb0-4644-ae86-04f96e380087"],
Cell[2519288, 70054, 7911, 197, 150, "Print",ExpressionUUID->"3300b872-911d-4ae3-b588-6c41754a275b"],
Cell[2527202, 70253, 343, 9, 24, "Print",ExpressionUUID->"179be93c-173e-4cb1-8209-7f13a0d4b7a9"],
Cell[2527548, 70264, 1819, 51, 40, "Print",ExpressionUUID->"26ee6c01-e2ac-4803-b3b6-7e890a6d7c83"],
Cell[2529370, 70317, 341, 9, 24, "Print",ExpressionUUID->"76ca1f37-a310-405b-b504-1bb95fcbe07a"],
Cell[2529714, 70328, 2439, 66, 64, "Print",ExpressionUUID->"9b8450da-398b-4ee7-b0cc-76a8497007f9"],
Cell[2532156, 70396, 341, 9, 24, "Print",ExpressionUUID->"ee282a88-ef4e-44fb-a60a-f50218a6c69d"],
Cell[2532500, 70407, 1817, 51, 40, "Print",ExpressionUUID->"7a519422-bdc9-4c76-a319-b8195ff0a53e"],
Cell[2534320, 70460, 341, 9, 24, "Print",ExpressionUUID->"95463b26-2f4f-479e-9cec-de107dde025e"],
Cell[2534664, 70471, 2553, 70, 62, "Print",ExpressionUUID->"0250b964-4b8e-4717-b4c9-eb798ac5160e"],
Cell[2537220, 70543, 341, 9, 24, "Print",ExpressionUUID->"802e415d-80a2-4a93-8f33-bb58c18b9387"],
Cell[2537564, 70554, 2530, 67, 62, "Print",ExpressionUUID->"2000ff3e-761f-49b8-b2d7-126b5e0f463f"],
Cell[2540097, 70623, 343, 9, 24, "Print",ExpressionUUID->"f7b9185e-83b7-45a0-b43e-80bee770b541"],
Cell[2540443, 70634, 3910, 100, 81, "Print",ExpressionUUID->"e6b0a1cf-0b41-4bed-b671-3c74239075a4"],
Cell[2544356, 70736, 341, 9, 24, "Print",ExpressionUUID->"e93bc124-7e20-477f-8c4d-be15952750ef"],
Cell[2544700, 70747, 3725, 95, 85, "Print",ExpressionUUID->"ff9f79f9-9726-4401-b96e-25333f290dfb"],
Cell[2548428, 70844, 343, 9, 24, "Print",ExpressionUUID->"20a62979-e11d-4beb-ac27-b09fdb7922f6"],
Cell[2548774, 70855, 6479, 163, 106, "Print",ExpressionUUID->"7838c14d-5ef7-4484-811a-85be4f0c4bbd"],
Cell[2555256, 71020, 341, 9, 24, "Print",ExpressionUUID->"ba9194bd-3185-453a-9d44-4b6bc28f2d34"],
Cell[2555600, 71031, 6318, 153, 110, "Print",ExpressionUUID->"f9a94817-14b6-4b80-bdc3-53de145d7989"],
Cell[2561921, 71186, 341, 9, 24, "Print",ExpressionUUID->"862b6eee-97c4-48fc-8fd6-6d55d8816595"],
Cell[2562265, 71197, 5522, 139, 88, "Print",ExpressionUUID->"3809aaa2-9408-417d-b21a-25416d58c911"],
Cell[2567790, 71338, 343, 9, 24, "Print",ExpressionUUID->"3da50bb0-d037-4851-9ab6-1848d7a5bee5"],
Cell[2568136, 71349, 4513, 116, 88, "Print",ExpressionUUID->"8acb7a55-b360-4c38-9cb7-036a9a5bfe0b"],
Cell[2572652, 71467, 341, 9, 24, "Print",ExpressionUUID->"aa13fe25-9af5-4f0b-93e2-f54c6c89b4c1"],
Cell[2572996, 71478, 2696, 74, 63, "Print",ExpressionUUID->"fd62e93a-8104-4a4e-8055-b4b6c87f7ae1"],
Cell[2575695, 71554, 341, 9, 24, "Print",ExpressionUUID->"3617d050-a952-45d6-93d0-048fe5f6d4e4"],
Cell[2576039, 71565, 4233, 113, 71, "Print",ExpressionUUID->"58195856-f27d-4624-ab07-a46584320d33"],
Cell[2580275, 71680, 341, 9, 24, "Print",ExpressionUUID->"8f0329ff-ab21-413b-8dd6-d98285a7a738"],
Cell[2580619, 71691, 2365, 64, 40, "Print",ExpressionUUID->"2102bb34-f5a9-4d3d-8468-db5277dd487f"],
Cell[2582987, 71757, 341, 9, 24, "Print",ExpressionUUID->"c321fee6-fa83-4ef6-b69c-f793a5cf717e"],
Cell[2583331, 71768, 3216, 84, 49, "Print",ExpressionUUID->"da87dae4-4861-492e-97be-83465709645f"],
Cell[2586550, 71854, 341, 9, 24, "Print",ExpressionUUID->"ce6b8395-0b17-4cd1-8b72-82b3f292243d"],
Cell[2586894, 71865, 4039, 103, 84, "Print",ExpressionUUID->"63b16f98-0fda-4deb-8402-edd1b57daa16"],
Cell[2590936, 71970, 341, 9, 24, "Print",ExpressionUUID->"76568dfc-4c0d-442a-8027-0a4edbaf8f61"],
Cell[2591280, 71981, 6790, 167, 113, "Print",ExpressionUUID->"bbec66ea-b346-4a33-8cb6-1316dd5a0759"],
Cell[2598073, 72150, 341, 9, 24, "Print",ExpressionUUID->"b7f54f88-fcb4-469f-a027-fc3afccd7470"],
Cell[2598417, 72161, 2216, 63, 40, "Print",ExpressionUUID->"c7df5033-ff4a-4788-ad35-aa33fbd24743"],
Cell[2600636, 72226, 343, 9, 24, "Print",ExpressionUUID->"c0c384b2-c41b-4613-9cd9-fb387bbb969c"],
Cell[2600982, 72237, 2886, 79, 49, "Print",ExpressionUUID->"106dffe7-b632-4144-b291-2491ca2f2a66"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2603917, 72322, 125, 2, 30, "Input",ExpressionUUID->"7ff707fe-fb7e-4fb4-a5a8-1d1f07da1fcf"],
Cell[2604045, 72326, 1869, 28, 161, "Output",ExpressionUUID->"532c2965-c49d-47e1-90c5-86467118b034"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2605951, 72359, 169, 3, 30, "Input",ExpressionUUID->"258af001-00c3-48c9-ac4e-b559909e0542"],
Cell[2606123, 72364, 1146, 19, 98, "Output",ExpressionUUID->"bf6882ff-1781-4189-bfd7-52ec84587310"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2607318, 72389, 301, 5, 37, "Subsubsection",ExpressionUUID->"2b8637f3-d4d5-4f42-a9c1-c41976364171"],
Cell[2607622, 72396, 9046, 200, 649, "Input",ExpressionUUID->"770858ec-8802-48fb-954d-e60af9d525c5"],
Cell[CellGroupData[{
Cell[2616693, 72600, 182, 3, 30, "Input",ExpressionUUID->"bd3fbdcf-db05-4c15-87d3-44a58ca8fcc2"],
Cell[2616878, 72605, 92577, 3361, 70, "Output",ExpressionUUID->"29f7a319-432c-43f5-8f53-f123da82ed25"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2709492, 75971, 324, 7, 30, "Input",ExpressionUUID->"b24625dd-6efc-4381-86e8-8289a4f3151d"],
Cell[2709819, 75980, 103733, 3661, 70, "Output",ExpressionUUID->"2a759879-93a8-43b9-abf2-1fe72d147ea9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2813589, 79646, 552, 16, 30, "Input",ExpressionUUID->"2496f4ba-0a8b-475e-b634-963c1ddd21bf"],
Cell[2814144, 79664, 61864, 2197, 70, "Output",ExpressionUUID->"e90b08c6-b038-4e45-a245-c4d069e1edb0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2876045, 81866, 375, 8, 30, "Input",ExpressionUUID->"79fc2e96-9af2-470b-942e-a45dddcfe5aa"],
Cell[2876423, 81876, 61885, 2197, 70, "Output",ExpressionUUID->"dc8d5f7d-cb5f-4946-8b8c-d2a81cc27c2c"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2938357, 84079, 349, 7, 37, "Subsubsection",ExpressionUUID->"e44758e3-5ba0-41c5-ab5f-7524e2251187"],
Cell[2938709, 84088, 1654, 51, 136, "Input",ExpressionUUID->"9ff275d5-5d7c-4d9d-bf9b-7d39e4422ab5"],
Cell[2940366, 84141, 4152, 107, 346, "Input",ExpressionUUID->"8b88a03f-6e19-49aa-9c30-ffde68eede0f"],
Cell[CellGroupData[{
Cell[2944543, 84252, 1013, 28, 136, "Input",ExpressionUUID->"67792618-1ad4-40f4-a788-24eaccb9c79f"],
Cell[2945559, 84282, 438, 10, 70, "Message",ExpressionUUID->"c58a5183-c2a4-4278-bf9c-b9613cd308cc"],
Cell[2946000, 84294, 515, 12, 70, "Print",ExpressionUUID->"05c6f870-2535-4c3f-a882-bd8b90a9a24a"]
}, Open  ]],
Cell[2946530, 84309, 296, 7, 30, "Input",ExpressionUUID->"4672a498-0912-4829-956f-348fb3a88eeb"],
Cell[CellGroupData[{
Cell[2946851, 84320, 119, 2, 30, "Input",ExpressionUUID->"d3962030-db04-4cf8-94c6-35c60ac4f231"],
Cell[2946973, 84324, 879, 27, 70, "Output",ExpressionUUID->"f7e940da-2589-4ea3-a02d-8cd713e68fee"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2947901, 84357, 227, 4, 37, "Subsubsection",ExpressionUUID->"7015cd4e-bbce-462f-ae74-f18ff1e388b9"],
Cell[CellGroupData[{
Cell[2948153, 84365, 1158, 35, 52, "Input",ExpressionUUID->"13c82cec-1f8a-4683-b3bf-c51c268e4140"],
Cell[2949314, 84402, 1174, 34, 70, "Output",ExpressionUUID->"4c557de8-6272-4b2f-b1ea-488459521534"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2950525, 84441, 461, 12, 30, "Input",ExpressionUUID->"c61c5ee5-68f5-49d3-9bfb-133d18b30677"],
Cell[2950989, 84455, 4396, 117, 70, "Output",ExpressionUUID->"88dcd874-4906-47b1-848b-9c6694315479"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2955422, 84577, 226, 5, 30, "Input",ExpressionUUID->"4500b6a6-b102-4a63-8be2-00a5e40d0ad3"],
Cell[2955651, 84584, 4048, 114, 70, "Output",ExpressionUUID->"dcc1efe5-3412-4047-8138-6e5521cdb89d"]
}, Open  ]],
Cell[2959714, 84701, 917, 27, 30, "Input",ExpressionUUID->"08e6b139-e1b0-497f-a406-92534437e377"],
Cell[2960634, 84730, 433, 11, 52, "Input",ExpressionUUID->"71cfc4ae-227a-4bf8-a806-9979f307be05"],
Cell[CellGroupData[{
Cell[2961092, 84745, 119, 2, 30, "Input",ExpressionUUID->"36a42698-acda-424f-ad34-4b7a2dd3674d"],
Cell[2961214, 84749, 471, 13, 70, "Output",ExpressionUUID->"3a312f8e-015c-40ed-80f2-5cf55d401ab7"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2961758, 84770, 173, 3, 53, "Section",ExpressionUUID->"40c866aa-5b4a-4dd4-b828-5d2b26a83d85"],
Cell[CellGroupData[{
Cell[2961956, 84777, 195, 3, 45, "Subsubsection",ExpressionUUID->"6bd6873f-0240-4df3-8034-fd4dd83fab4a"],
Cell[2962154, 84782, 1062, 33, 115, "Input",ExpressionUUID->"cf35f498-bd63-48b2-b491-9caa2a72d3cb"],
Cell[2963219, 84817, 361, 9, 73, "Input",ExpressionUUID->"9bf9ebcb-3a3f-409b-9ac2-165f2a887b3f"],
Cell[CellGroupData[{
Cell[2963605, 84830, 393, 11, 30, "Input",ExpressionUUID->"0614b4a9-801a-47ad-9a9c-3cb6a1a4b7e7"],
Cell[2964001, 84843, 740, 19, 41, "Output",ExpressionUUID->"10129aee-4a47-44c8-9791-23d6c31b2285"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2964778, 84867, 391, 11, 30, "Input",ExpressionUUID->"88fda2c7-baf5-4b40-8cb4-bd91e5b09e3d"],
Cell[2965172, 84880, 710, 19, 41, "Output",ExpressionUUID->"4d191765-6af1-4553-b0b2-aa890c7a7569"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2965919, 84904, 392, 11, 30, "Input",ExpressionUUID->"95880559-62a4-4f20-8f34-9da94f2db1e6"],
Cell[2966314, 84917, 710, 19, 41, "Output",ExpressionUUID->"4b66a390-ac7d-4d01-addb-ddfefe50abda"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2967061, 84941, 391, 11, 30, "Input",ExpressionUUID->"618ea4b7-b95f-447b-8c9d-597328070e1d"],
Cell[2967455, 84954, 921, 25, 50, "Output",ExpressionUUID->"eecc9fd3-0d91-4c3f-851a-f07d1d1f414f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2968413, 84984, 393, 11, 30, "Input",ExpressionUUID->"9aa6733d-b244-4a44-9905-cf4456198df2"],
Cell[2968809, 84997, 791, 21, 50, "Output",ExpressionUUID->"36632e80-d1a8-41d7-b45c-fa1bb959d9f4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2969637, 85023, 391, 11, 30, "Input",ExpressionUUID->"fa8043ff-112c-461f-b64b-7fe1e0b2af49"],
Cell[2970031, 85036, 910, 25, 50, "Output",ExpressionUUID->"c5da08f4-af94-495d-ab89-3a3e9a6fd131"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2970978, 85066, 393, 11, 30, "Input",ExpressionUUID->"87f200f2-6308-4873-8ba0-a305c8c7ec54"],
Cell[2971374, 85079, 787, 21, 50, "Output",ExpressionUUID->"fe36bb19-4ec2-4594-b536-2649a98d144e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2972198, 85105, 1582, 49, 56, "Input",ExpressionUUID->"2618993f-47f2-4e88-a41f-aa54090c50e7"],
Cell[2973783, 85156, 1794, 52, 60, "Output",ExpressionUUID->"8aa55efb-a8b4-48ac-8489-241cbec60218"]
}, Open  ]],
Cell[2975592, 85211, 280, 7, 30, "Input",ExpressionUUID->"9348783e-2593-4190-a27d-ff071608b1b8"],
Cell[2975875, 85220, 1801, 56, 94, "Input",ExpressionUUID->"1cbe7926-0cff-4740-923a-1d1513c57b44"],
Cell[CellGroupData[{
Cell[2977701, 85280, 279, 6, 30, "Input",ExpressionUUID->"dd1ef155-d244-4130-b671-fc17e9ef9126"],
Cell[2977983, 85288, 519, 8, 34, "Output",ExpressionUUID->"66235106-4ffe-4115-ad1d-639b2c48cb16"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2978539, 85301, 421, 10, 30, "Input",ExpressionUUID->"ac3a2e0f-ccea-4e67-9c5e-6d42efa8b8f9"],
Cell[2978963, 85313, 541, 10, 34, "Output",ExpressionUUID->"95a078b1-0f68-46d4-a277-fdb243c15546"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2979541, 85328, 272, 6, 30, "Input",ExpressionUUID->"bde6befb-037f-4bcf-aa6d-c7c080b4c37f"],
Cell[2979816, 85336, 565, 12, 34, "Output",ExpressionUUID->"0c6869b6-11de-4e0a-a085-677bb5a14b09"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2980418, 85353, 696, 20, 30, "Input",ExpressionUUID->"ea13d807-6fde-473d-b68b-1ce7be1126f3"],
Cell[2981117, 85375, 966, 28, 37, "Output",ExpressionUUID->"a3568072-78c8-4179-9826-5b1550663df9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2982120, 85408, 285, 7, 30, "Input",ExpressionUUID->"c76324e8-70ec-45c8-a75c-9a72f598cd53"],
Cell[2982408, 85417, 913, 27, 37, "Output",ExpressionUUID->"5c578cd8-2650-45a3-993f-df04fea6a2f2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2983358, 85449, 290, 7, 30, "Input",ExpressionUUID->"d42d6993-5ae5-4fc2-8b66-85323ee4850c"],
Cell[2983651, 85458, 854, 23, 58, "Output",ExpressionUUID->"fe0da95e-f9e6-44da-aa41-37735ddc3518"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2984542, 85486, 283, 7, 30, "Input",ExpressionUUID->"5bb860f8-865c-4e66-8838-143b913c7558"],
Cell[2984828, 85495, 688, 22, 58, "Output",ExpressionUUID->"d9ec142b-da41-4dcd-9923-b22715180f06"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2985553, 85522, 194, 5, 30, "Input",ExpressionUUID->"86c6af17-a5b1-4318-a5b7-5f73a6d263a3"],
Cell[2985750, 85529, 606, 18, 58, "Output",ExpressionUUID->"ba4e786a-30ab-45f4-ab8e-89c6de98fa54"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2986393, 85552, 606, 17, 30, "Input",ExpressionUUID->"87f70291-eb88-453c-84ac-1a1f9a517bfd"],
Cell[2987002, 85571, 868, 29, 56, "Output",ExpressionUUID->"a4fd9f7a-980c-4d7f-b9fe-3fcb558ec5c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2987907, 85605, 606, 17, 30, "Input",ExpressionUUID->"66891831-de67-4c61-878d-3ffee7fc1311"],
Cell[2988516, 85624, 967, 32, 56, "Output",ExpressionUUID->"6e06d671-9bb6-400e-98b5-91f5514da8dd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2989520, 85661, 606, 17, 30, "Input",ExpressionUUID->"b472338a-3819-482d-aa88-e5c547ddc9dd"],
Cell[2990129, 85680, 922, 29, 56, "Output",ExpressionUUID->"5e49e353-b179-4dba-83d8-41815606bcd5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2991088, 85714, 606, 17, 30, "Input",ExpressionUUID->"e7eb7a63-f5ea-4ea8-9d52-639bc5080486"],
Cell[2991697, 85733, 888, 30, 56, "Output",ExpressionUUID->"659a23f0-da63-41c2-ac23-b34f665cc1b0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2992622, 85768, 438, 10, 30, "Input",ExpressionUUID->"e411fb5f-b26e-4eb2-b351-fd31fb96f1e2"],
Cell[2993063, 85780, 487, 15, 58, "Output",ExpressionUUID->"0f983c99-9579-4a7c-b4da-b6e5dd877d8b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2993587, 85800, 436, 10, 30, "Input",ExpressionUUID->"ccc32568-eb37-40db-85e1-214e76dbfe21"],
Cell[2994026, 85812, 517, 16, 53, "Output",ExpressionUUID->"4bc39f43-bc94-4183-acd5-6a531dbff933"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2994580, 85833, 519, 10, 30, "Input",ExpressionUUID->"5363117e-16a9-4e14-a4c9-8e9c5bfd817d"],
Cell[2995102, 85845, 321, 9, 34, "Output",ExpressionUUID->"a404d907-7ae8-443d-8863-b0613dc7a479"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2995460, 85859, 356, 6, 30, "Input",ExpressionUUID->"4473368d-ab26-42af-a91f-7a70f84bf02b"],
Cell[2995819, 85867, 470, 9, 50, "Output",ExpressionUUID->"0da7c30d-ddb6-4edd-8a53-acd12ada78e1"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2996350, 85883, 222, 4, 53, "Section",ExpressionUUID->"af10d3f7-8d70-42f6-b4b4-c79912629014"],
Cell[CellGroupData[{
Cell[2996597, 85891, 237, 4, 54, "Subsection",ExpressionUUID->"8d9f6e14-fc77-4b02-802e-2fa9e5cd71ab"],
Cell[2996837, 85897, 2114, 56, 178, "Input",ExpressionUUID->"292c1b8c-0336-42ac-9a66-18fe0c09961d"],
Cell[2998954, 85955, 387, 10, 73, "Input",ExpressionUUID->"3e73ad66-b4cc-4278-b545-e42fcc12b2d0"],
Cell[CellGroupData[{
Cell[2999366, 85969, 304, 8, 30, "Input",ExpressionUUID->"38b8b03a-9825-45c8-9d16-a940ef86ecb3"],
Cell[2999673, 85979, 543, 16, 50, "Output",ExpressionUUID->"3a4cb63d-dfa8-4198-9f5d-7fe2d6d182c4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3000253, 86000, 528, 12, 30, "Input",ExpressionUUID->"d20941c4-35ae-4637-aa33-65d3b9a3a00e"],
Cell[3000784, 86014, 1224, 33, 41, "Output",ExpressionUUID->"4c6496f5-a549-4f45-99aa-df26af49f87f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3002045, 86052, 476, 11, 30, "Input",ExpressionUUID->"d8f2b9d3-295e-43f9-a5b4-abef642cde59"],
Cell[3002524, 86065, 713, 15, 42, "Output",ExpressionUUID->"9b4fee51-17d3-4828-830b-4a7470cd3c97"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3003274, 86085, 327, 6, 30, "Input",ExpressionUUID->"8a7d64e9-54d1-482f-84c8-eeedf411524e"],
Cell[3003604, 86093, 1172, 33, 41, "Output",ExpressionUUID->"c8497e7d-1ee9-4240-801d-e9dde324a8d5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3004813, 86131, 452, 11, 30, "Input",ExpressionUUID->"bd8c24c0-f6b6-46ba-be17-dd1c4c24b612"],
Cell[3005268, 86144, 1165, 31, 50, "Output",ExpressionUUID->"8a120162-73cf-4431-9056-94e4f204259f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3006470, 86180, 300, 6, 30, "Input",ExpressionUUID->"c3b69c8b-a31d-4bc2-bb29-804413a13b83"],
Cell[3006773, 86188, 550, 9, 51, "Output",ExpressionUUID->"464eed09-2d5c-48a3-853b-2a112d910014"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3007360, 86202, 326, 6, 30, "Input",ExpressionUUID->"e60128e5-1e38-404c-b018-ba07f1170db9"],
Cell[3007689, 86210, 1168, 31, 50, "Output",ExpressionUUID->"023072f7-a177-47f6-97fe-9d792ff69d43"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3008894, 86246, 300, 6, 30, "Input",ExpressionUUID->"514cff67-8929-45ac-ab4d-d511fa8f415d"],
Cell[3009197, 86254, 545, 9, 51, "Output",ExpressionUUID->"a71f40bf-3b0c-499b-893a-8adbfcf78ce3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3009779, 86268, 382, 9, 30, "Input",ExpressionUUID->"d4bd24a2-5800-417a-b61f-42033a7d45a7"],
Cell[3010164, 86279, 2615, 79, 60, "Output",ExpressionUUID->"d82d340a-93ea-469a-a794-7de8004832b3"]
}, Open  ]],
Cell[3012794, 86361, 330, 7, 30, "Input",ExpressionUUID->"4e22e1a0-d118-4c83-b931-40141e33d299"],
Cell[3013127, 86370, 2242, 63, 94, "Input",ExpressionUUID->"ccce49ac-66cc-49da-be06-186b0c5755cb"],
Cell[CellGroupData[{
Cell[3015394, 86437, 279, 6, 30, "Input",ExpressionUUID->"6304914e-b094-4a4b-9d57-da0255098fa3"],
Cell[3015676, 86445, 565, 9, 34, "Output",ExpressionUUID->"6296765e-2a20-4206-9a74-f865cd503f25"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3016278, 86459, 379, 8, 30, "Input",ExpressionUUID->"692e8bba-2edc-41ca-863d-4cb0cfd8e138"],
Cell[3016660, 86469, 693, 15, 34, "Output",ExpressionUUID->"e8aad6ed-0878-4125-a2a4-117b2823c452"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3017390, 86489, 272, 6, 30, "Input",ExpressionUUID->"0d09ac81-ff6c-4e8f-9766-dc2fff281612"],
Cell[3017665, 86497, 536, 9, 34, "Output",ExpressionUUID->"827a9aa1-1b01-49b4-98df-04f51d0777f3"]
}, Open  ]],
Cell[3018216, 86509, 366, 10, 30, "Input",ExpressionUUID->"3d1c0ec6-876e-44ae-a848-39e212896d71"],
Cell[3018585, 86521, 556, 12, 30, "Input",ExpressionUUID->"4957d9f5-021b-49ef-bd3e-e7caab5539a5"],
Cell[3019144, 86535, 478, 11, 30, "Input",ExpressionUUID->"29830824-7269-41ba-8e5f-2dfdc58d7b70"],
Cell[3019625, 86548, 563, 12, 30, "Input",ExpressionUUID->"7c376211-1cce-4bbb-b824-6194f33bcadd"],
Cell[CellGroupData[{
Cell[3020213, 86564, 603, 15, 30, "Input",ExpressionUUID->"1eab49df-ccd2-40d6-9027-56f3e125329f"],
Cell[3020819, 86581, 496, 8, 34, "Output",ExpressionUUID->"1b8cd376-0f52-4104-91bf-0dc8c928d2b4"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3021376, 86596, 312, 5, 53, "Section",ExpressionUUID->"f36c3083-14c3-4dc6-b0b1-305596aea1d8"],
Cell[CellGroupData[{
Cell[3021713, 86605, 289, 4, 54, "Subsection",ExpressionUUID->"46f75a37-1ddf-496a-86b5-3b9692fe57ba"],
Cell[3022005, 86611, 545, 17, 73, "Input",ExpressionUUID->"14cb0ca1-4f1e-429c-bb3d-a75c8952f7e1"],
Cell[CellGroupData[{
Cell[3022575, 86632, 332, 8, 30, "Input",ExpressionUUID->"f7f0cdfd-6ccb-455c-a92b-c78a63fea029"],
Cell[3022910, 86642, 3362, 105, 83, "Output",ExpressionUUID->"6af1a505-fe4f-409c-b1cd-1b1a34c0839e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3026309, 86752, 506, 13, 30, "Input",ExpressionUUID->"a5c0b0ef-80d4-4453-80e8-0c2c990aaa1c"],
Cell[3026818, 86767, 892, 24, 37, "Output",ExpressionUUID->"6f833cf6-59c3-4cf2-9389-fb8fe14b76c1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3027747, 86796, 421, 11, 30, "Input",ExpressionUUID->"7a328517-9896-48b9-86ba-33f8fd163b37"],
Cell[3028171, 86809, 549, 15, 37, "Output",ExpressionUUID->"58456d73-cee7-49da-958c-5e92504adc16"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3028757, 86829, 588, 16, 30, "Input",ExpressionUUID->"b168d41b-9ec2-4a0d-97b8-1dfbfba43d95"],
Cell[3029348, 86847, 354, 6, 34, "Output",ExpressionUUID->"c643d78b-371d-4df3-ab22-86fd1fc8dae9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3029739, 86858, 537, 16, 30, "Input",ExpressionUUID->"9f09a5ce-efb0-49c3-b455-008393bbb6fd"],
Cell[3030279, 86876, 253, 6, 52, "Output",ExpressionUUID->"e51d2078-8515-4530-b0ac-83456a0a216a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3030581, 86888, 295, 4, 38, "Subsection",ExpressionUUID->"bca03947-f218-45a0-8c99-71f18dae00c3"],
Cell[3030879, 86894, 477, 16, 73, "Input",ExpressionUUID->"99ea167f-a4ec-4bcc-b124-dc773920b5c3"],
Cell[CellGroupData[{
Cell[3031381, 86914, 475, 12, 30, "Input",ExpressionUUID->"7ad756a3-3b9a-4b74-99f6-ed2d3aef5a3f"],
Cell[3031859, 86928, 1228, 36, 38, "Output",ExpressionUUID->"f2df018f-1156-4abf-910e-37ba685cb24d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3033124, 86969, 746, 20, 34, "Input",ExpressionUUID->"7f8050ce-710c-4ac9-83c4-e7a58e5b7768"],
Cell[3033873, 86991, 643, 15, 37, "Output",ExpressionUUID->"d5261d52-f2e9-41bb-bae3-0ed7881fbf24"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3034553, 87011, 307, 8, 30, "Input",ExpressionUUID->"26878ae2-3805-40c0-a78a-b40ca241b1a4"],
Cell[3034863, 87021, 273, 7, 50, "Output",ExpressionUUID->"6a79b27d-c2f9-4fae-9ee8-fecde76daca1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3035173, 87033, 596, 15, 30, "Input",ExpressionUUID->"1853f242-b402-43ea-983f-73d7d7ada5f2"],
Cell[3035772, 87050, 403, 11, 50, "Output",ExpressionUUID->"5c343420-d5b4-456a-b5f0-b12fc79bff64"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3036212, 87066, 519, 14, 30, "Input",ExpressionUUID->"66a11b97-b72a-4585-a46f-815f96e3fc2d"],
Cell[3036734, 87082, 459, 13, 64, "Output",ExpressionUUID->"6b8ef921-0f38-4a6c-8894-d43a74262c6e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3037230, 87100, 200, 4, 30, "Input",ExpressionUUID->"cca77729-1a3c-4e65-bdcc-5fad9f537660"],
Cell[3037433, 87106, 238, 6, 53, "Output",ExpressionUUID->"50c99523-5fda-47cd-923e-62e5e455e581"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3037720, 87118, 297, 4, 38, "Subsection",ExpressionUUID->"24065629-c85c-494c-8753-31cf53326a1f"],
Cell[CellGroupData[{
Cell[3038042, 87126, 498, 12, 30, "Input",ExpressionUUID->"15b5ee01-4790-434c-a5c0-e4c6446d5fe0"],
Cell[3038543, 87140, 1204, 36, 38, "Output",ExpressionUUID->"c371f98f-d964-4aa7-aaec-9d88413f2cb1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3039784, 87181, 767, 20, 34, "Input",ExpressionUUID->"8330b75d-cfb7-482c-84df-f3c661e38510"],
Cell[3040554, 87203, 623, 15, 37, "Output",ExpressionUUID->"31ea77ae-ac06-414b-8ccf-b089793ab871"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3041214, 87223, 550, 13, 30, "Input",ExpressionUUID->"6e09a110-41f3-4b99-94ae-4146b8f0b638"],
Cell[3041767, 87238, 1214, 35, 38, "Output",ExpressionUUID->"d88ac8da-17de-4c82-8811-2c109bafbe08"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3043018, 87278, 494, 14, 34, "Input",ExpressionUUID->"615ec0c7-af57-406f-a2ca-2086ed39e7ec"],
Cell[3043515, 87294, 404, 12, 37, "Output",ExpressionUUID->"582cb834-6592-4394-8e28-a3b5ae046e47"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3043968, 87312, 294, 4, 38, "Subsection",ExpressionUUID->"3ced53ba-a336-4864-9de4-8ca8104515fb"],
Cell[CellGroupData[{
Cell[3044287, 87320, 846, 26, 73, "Input",ExpressionUUID->"45f06879-cbd4-4be5-a3a5-eb1f93b0edcd"],
Cell[3045136, 87348, 476, 14, 37, "Output",ExpressionUUID->"0482922e-0b6a-46cd-bd47-1bebd3f795e6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3045649, 87367, 1191, 36, 73, "Input",ExpressionUUID->"8af35673-7391-455b-bfb3-edcfb6ef6a2f"],
Cell[3046843, 87405, 634, 21, 55, "Output",ExpressionUUID->"4c266aef-4815-4e3c-823f-936cdd176cdf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3047514, 87431, 374, 9, 30, "Input",ExpressionUUID->"58b836a0-0353-419f-9182-574fe7747756"],
Cell[3047891, 87442, 1201, 38, 62, "Output",ExpressionUUID->"e07af228-12cd-463e-bc2e-538414abb692"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3049129, 87485, 354, 10, 30, "Input",ExpressionUUID->"9679fc2c-d5a3-443e-aa9b-fef7f4106d99"],
Cell[3049486, 87497, 604, 18, 37, "Output",ExpressionUUID->"b8c3347f-56ba-4b9c-9ac7-3c23e2b1bdfe"]
}, Open  ]]
}, Closed]]
}, Closed]]
}
]
*)

